<?php
/**
 * Generated stub declarations for WordPress.
 * @see https://wordpress.org
 * @see https://github.com/php-stubs/wordpress-stubs
 */

namespace {
    /**
     * Generic Skin for the WordPress Upgrader classes. This skin is designed to be extended for specific purposes.
     *
     * @since 2.8.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader-skins.php.
     */
    #[\AllowDynamicProperties]
    class WP_Upgrader_Skin
    {
        /**
         * Holds the upgrader data.
         *
         * @since 2.8.0
         * @var WP_Upgrader
         */
        public $upgrader;
        /**
         * Whether header is done.
         *
         * @since 2.8.0
         * @var bool
         */
        public $done_header = \false;
        /**
         * Whether footer is done.
         *
         * @since 2.8.0
         * @var bool
         */
        public $done_footer = \false;
        /**
         * Holds the result of an upgrade.
         *
         * @since 2.8.0
         * @var string|bool|WP_Error
         */
        public $result = \false;
        /**
         * Holds the options of an upgrade.
         *
         * @since 2.8.0
         * @var array
         */
        public $options = array();
        /**
         * Constructor.
         *
         * Sets up the generic skin for the WordPress Upgrader classes.
         *
         * @since 2.8.0
         *
         * @param array $args Optional. The WordPress upgrader skin arguments to
         *                    override default options. Default empty array.
         */
        public function __construct($args = array())
        {
        }
        /**
         * Sets the relationship between the skin being used and the upgrader.
         *
         * @since 2.8.0
         *
         * @param WP_Upgrader $upgrader
         */
        public function set_upgrader(&$upgrader)
        {
        }
        /**
         * Sets up the strings used in the update process.
         *
         * @since 3.0.0
         */
        public function add_strings()
        {
        }
        /**
         * Sets the result of an upgrade.
         *
         * @since 2.8.0
         *
         * @param string|bool|WP_Error $result The result of an upgrade.
         */
        public function set_result($result)
        {
        }
        /**
         * Displays a form to the user to request for their FTP/SSH details in order
         * to connect to the filesystem.
         *
         * @since 2.8.0
         * @since 4.6.0 The `$context` parameter default changed from `false` to an empty string.
         *
         * @see request_filesystem_credentials()
         *
         * @param bool|WP_Error $error                        Optional. Whether the current request has failed to connect,
         *                                                    or an error object. Default false.
         * @param string        $context                      Optional. Full path to the directory that is tested
         *                                                    for being writable. Default empty.
         * @param bool          $allow_relaxed_file_ownership Optional. Whether to allow Group/World writable. Default false.
         * @return bool True on success, false on failure.
         */
        public function request_filesystem_credentials($error = \false, $context = '', $allow_relaxed_file_ownership = \false)
        {
        }
        /**
         * Displays the header before the update process.
         *
         * @since 2.8.0
         * @phpstan-return void
         */
        public function header()
        {
        }
        /**
         * Displays the footer following the update process.
         *
         * @since 2.8.0
         * @phpstan-return void
         */
        public function footer()
        {
        }
        /**
         * Displays an error message about the update.
         *
         * @since 2.8.0
         *
         * @param string|WP_Error $errors Errors.
         */
        public function error($errors)
        {
        }
        /**
         * Displays a message about the update.
         *
         * @since 2.8.0
         * @since 5.9.0 Renamed `$string` (a PHP reserved keyword) to `$feedback` for PHP 8 named parameter support.
         *
         * @param string $feedback Message data.
         * @param mixed  ...$args  Optional text replacements.
         * @phpstan-return void
         */
        public function feedback($feedback, ...$args)
        {
        }
        /**
         * Performs an action before an update.
         *
         * @since 2.8.0
         */
        public function before()
        {
        }
        /**
         * Performs an action following an update.
         *
         * @since 2.8.0
         */
        public function after()
        {
        }
        /**
         * Outputs JavaScript that calls function to decrement the update counts.
         *
         * @since 3.9.0
         *
         * @param string $type Type of update count to decrement. Likely values include 'plugin',
         *                     'theme', 'translation', etc.
         * @phpstan-return void
         */
        protected function decrement_update_count($type)
        {
        }
        /**
         * Displays the header before the bulk update process.
         *
         * @since 3.0.0
         */
        public function bulk_header()
        {
        }
        /**
         * Displays the footer following the bulk update process.
         *
         * @since 3.0.0
         */
        public function bulk_footer()
        {
        }
        /**
         * Hides the `process_failed` error message when updating by uploading a zip file.
         *
         * @since 5.5.0
         *
         * @param WP_Error $wp_error WP_Error object.
         * @return bool True if the error should be hidden, false otherwise.
         */
        public function hide_process_failed($wp_error)
        {
        }
    }
    /**
     * Upgrader Skin for Automatic WordPress Upgrades.
     *
     * This skin is designed to be used when no output is intended, all output
     * is captured and stored for the caller to process and log/email/discard.
     *
     * @since 3.7.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader-skins.php.
     *
     * @see Bulk_Upgrader_Skin
     */
    class Automatic_Upgrader_Skin extends \WP_Upgrader_Skin
    {
        protected $messages = array();
        /**
         * Determines whether the upgrader needs FTP/SSH details in order to connect
         * to the filesystem.
         *
         * @since 3.7.0
         * @since 4.6.0 The `$context` parameter default changed from `false` to an empty string.
         *
         * @see request_filesystem_credentials()
         *
         * @param bool|WP_Error $error                        Optional. Whether the current request has failed to connect,
         *                                                    or an error object. Default false.
         * @param string        $context                      Optional. Full path to the directory that is tested
         *                                                    for being writable. Default empty.
         * @param bool          $allow_relaxed_file_ownership Optional. Whether to allow Group/World writable. Default false.
         * @return bool True on success, false on failure.
         */
        public function request_filesystem_credentials($error = \false, $context = '', $allow_relaxed_file_ownership = \false)
        {
        }
        /**
         * Retrieves the upgrade messages.
         *
         * @since 3.7.0
         *
         * @return string[] Messages during an upgrade.
         */
        public function get_upgrade_messages()
        {
        }
        /**
         * Stores a message about the upgrade.
         *
         * @since 3.7.0
         * @since 5.9.0 Renamed `$data` to `$feedback` for PHP 8 named parameter support.
         *
         * @param string|array|WP_Error $feedback Message data.
         * @param mixed                 ...$args  Optional text replacements.
         * @phpstan-return void
         */
        public function feedback($feedback, ...$args)
        {
        }
        /**
         * Creates a new output buffer.
         *
         * @since 3.7.0
         */
        public function header()
        {
        }
        /**
         * Retrieves the buffered content, deletes the buffer, and processes the output.
         *
         * @since 3.7.0
         */
        public function footer()
        {
        }
    }
    /**
     * Generic Bulk Upgrader Skin for WordPress Upgrades.
     *
     * @since 3.0.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader-skins.php.
     *
     * @see WP_Upgrader_Skin
     */
    class Bulk_Upgrader_Skin extends \WP_Upgrader_Skin
    {
        /**
         * Whether the bulk update process has started.
         *
         * @since 3.0.0
         * @var bool
         */
        public $in_loop = \false;
        /**
         * Stores an error message about the update.
         *
         * @since 3.0.0
         * @var string|false
         */
        public $error = \false;
        /**
         * Constructor.
         *
         * Sets up the generic skin for the Bulk Upgrader classes.
         *
         * @since 3.0.0
         *
         * @param array $args
         */
        public function __construct($args = array())
        {
        }
        /**
         * Sets up the strings used in the update process.
         *
         * @since 3.0.0
         */
        public function add_strings()
        {
        }
        /**
         * Displays a message about the update.
         *
         * @since 3.0.0
         * @since 5.9.0 Renamed `$string` (a PHP reserved keyword) to `$feedback` for PHP 8 named parameter support.
         *
         * @param string $feedback Message data.
         * @param mixed  ...$args  Optional text replacements.
         * @phpstan-return void
         */
        public function feedback($feedback, ...$args)
        {
        }
        /**
         * Displays the header before the update process.
         *
         * @since 3.0.0
         */
        public function header()
        {
        }
        /**
         * Displays the footer following the update process.
         *
         * @since 3.0.0
         */
        public function footer()
        {
        }
        /**
         * Displays an error message about the update.
         *
         * @since 3.0.0
         * @since 5.9.0 Renamed `$error` to `$errors` for PHP 8 named parameter support.
         *
         * @param string|WP_Error $errors Errors.
         */
        public function error($errors)
        {
        }
        /**
         * Displays the header before the bulk update process.
         *
         * @since 3.0.0
         */
        public function bulk_header()
        {
        }
        /**
         * Displays the footer following the bulk update process.
         *
         * @since 3.0.0
         */
        public function bulk_footer()
        {
        }
        /**
         * Performs an action before a bulk update.
         *
         * @since 3.0.0
         *
         * @param string $title
         */
        public function before($title = '')
        {
        }
        /**
         * Performs an action following a bulk update.
         *
         * @since 3.0.0
         *
         * @param string $title
         */
        public function after($title = '')
        {
        }
        /**
         * Resets the properties used in the update process.
         *
         * @since 3.0.0
         */
        public function reset()
        {
        }
        /**
         * Flushes all output buffers.
         *
         * @since 3.0.0
         */
        public function flush_output()
        {
        }
    }
    /**
     * Bulk Plugin Upgrader Skin for WordPress Plugin Upgrades.
     *
     * @since 3.0.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader-skins.php.
     *
     * @see Bulk_Upgrader_Skin
     */
    class Bulk_Plugin_Upgrader_Skin extends \Bulk_Upgrader_Skin
    {
        /**
         * Plugin info.
         *
         * The Plugin_Upgrader::bulk_upgrade() method will fill this in
         * with info retrieved from the get_plugin_data() function.
         *
         * @since 3.0.0
         * @var array Plugin data. Values will be empty if not supplied by the plugin.
         */
        public $plugin_info = array();
        /**
         * Sets up the strings used in the update process.
         *
         * @since 3.0.0
         */
        public function add_strings()
        {
        }
        /**
         * Performs an action before a bulk plugin update.
         *
         * @since 3.0.0
         *
         * @param string $title
         */
        public function before($title = '')
        {
        }
        /**
         * Performs an action following a bulk plugin update.
         *
         * @since 3.0.0
         *
         * @param string $title
         */
        public function after($title = '')
        {
        }
        /**
         * Displays the footer following the bulk update process.
         *
         * @since 3.0.0
         */
        public function bulk_footer()
        {
        }
    }
    /**
     * Bulk Theme Upgrader Skin for WordPress Theme Upgrades.
     *
     * @since 3.0.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader-skins.php.
     *
     * @see Bulk_Upgrader_Skin
     */
    class Bulk_Theme_Upgrader_Skin extends \Bulk_Upgrader_Skin
    {
        /**
         * Theme info.
         *
         * The Theme_Upgrader::bulk_upgrade() method will fill this in
         * with info retrieved from the Theme_Upgrader::theme_info() method,
         * which in turn calls the wp_get_theme() function.
         *
         * @since 3.0.0
         * @var WP_Theme|false The theme's info object, or false.
         */
        public $theme_info = \false;
        /**
         * Sets up the strings used in the update process.
         *
         * @since 3.0.0
         */
        public function add_strings()
        {
        }
        /**
         * Performs an action before a bulk theme update.
         *
         * @since 3.0.0
         *
         * @param string $title
         */
        public function before($title = '')
        {
        }
        /**
         * Performs an action following a bulk theme update.
         *
         * @since 3.0.0
         *
         * @param string $title
         */
        public function after($title = '')
        {
        }
        /**
         * Displays the footer following the bulk update process.
         *
         * @since 3.0.0
         */
        public function bulk_footer()
        {
        }
    }
    /**
     * Core class used for upgrading/installing a local set of files via
     * the Filesystem Abstraction classes from a Zip file.
     *
     * @since 2.8.0
     */
    #[\AllowDynamicProperties]
    class WP_Upgrader
    {
        /**
         * The error/notification strings used to update the user on the progress.
         *
         * @since 2.8.0
         * @var array $strings
         */
        public $strings = array();
        /**
         * The upgrader skin being used.
         *
         * @since 2.8.0
         * @var Automatic_Upgrader_Skin|WP_Upgrader_Skin $skin
         */
        public $skin = \null;
        /**
         * The result of the installation.
         *
         * This is set by WP_Upgrader::install_package(), only when the package is installed
         * successfully. It will then be an array, unless a WP_Error is returned by the
         * {@see 'upgrader_post_install'} filter. In that case, the WP_Error will be assigned to
         * it.
         *
         * @since 2.8.0
         *
         * @var array|WP_Error $result {
         *     @type string $source             The full path to the source the files were installed from.
         *     @type string $source_files       List of all the files in the source directory.
         *     @type string $destination        The full path to the installation destination folder.
         *     @type string $destination_name   The name of the destination folder, or empty if `$destination`
         *                                      and `$local_destination` are the same.
         *     @type string $local_destination  The full local path to the destination folder. This is usually
         *                                      the same as `$destination`.
         *     @type string $remote_destination The full remote path to the destination folder
         *                                      (i.e., from `$wp_filesystem`).
         *     @type bool   $clear_destination  Whether the destination folder was cleared.
         * }
         * @phpstan-var \WP_Error|array{
         *   source: string,
         *   source_files: string,
         *   destination: string,
         *   destination_name: string,
         *   local_destination: string,
         *   remote_destination: string,
         *   clear_destination: bool,
         * }
         */
        public $result = array();
        /**
         * The total number of updates being performed.
         *
         * Set by the bulk update methods.
         *
         * @since 3.0.0
         * @var int $update_count
         */
        public $update_count = 0;
        /**
         * The current update if multiple updates are being performed.
         *
         * Used by the bulk update methods, and incremented for each update.
         *
         * @since 3.0.0
         * @var int
         */
        public $update_current = 0;
        /**
         * Construct the upgrader with a skin.
         *
         * @since 2.8.0
         *
         * @param WP_Upgrader_Skin $skin The upgrader skin to use. Default is a WP_Upgrader_Skin
         *                               instance.
         */
        public function __construct($skin = \null)
        {
        }
        /**
         * Initializes the upgrader.
         *
         * This will set the relationship between the skin being used and this upgrader,
         * and also add the generic strings to `WP_Upgrader::$strings`.
         *
         * Additionally, it will schedule a weekly task to clean up the temporary backup directory.
         *
         * @since 2.8.0
         * @since 6.3.0 Added the `schedule_temp_backup_cleanup()` task.
         */
        public function init()
        {
        }
        /**
         * Schedules the cleanup of the temporary backup directory.
         *
         * @since 6.3.0
         */
        protected function schedule_temp_backup_cleanup()
        {
        }
        /**
         * Adds the generic strings to WP_Upgrader::$strings.
         *
         * @since 2.8.0
         */
        public function generic_strings()
        {
        }
        /**
         * Connects to the filesystem.
         *
         * @since 2.8.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param string[] $directories                  Optional. Array of directories. If any of these do
         *                                               not exist, a WP_Error object will be returned.
         *                                               Default empty array.
         * @param bool     $allow_relaxed_file_ownership Whether to allow relaxed file ownership.
         *                                               Default false.
         * @return bool|WP_Error True if able to connect, false or a WP_Error otherwise.
         */
        public function fs_connect($directories = array(), $allow_relaxed_file_ownership = \false)
        {
        }
        /**
         * Downloads a package.
         *
         * @since 2.8.0
         * @since 5.2.0 Added the `$check_signatures` parameter.
         * @since 5.5.0 Added the `$hook_extra` parameter.
         *
         * @param string $package          The URI of the package. If this is the full path to an
         *                                 existing local file, it will be returned untouched.
         * @param bool   $check_signatures Whether to validate file signatures. Default false.
         * @param array  $hook_extra       Extra arguments to pass to the filter hooks. Default empty array.
         * @return string|WP_Error The full path to the downloaded package file, or a WP_Error object.
         */
        public function download_package($package, $check_signatures = \false, $hook_extra = array())
        {
        }
        /**
         * Unpacks a compressed package file.
         *
         * @since 2.8.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param string $package        Full path to the package file.
         * @param bool   $delete_package Optional. Whether to delete the package file after attempting
         *                               to unpack it. Default true.
         * @return string|WP_Error The path to the unpacked contents, or a WP_Error on failure.
         */
        public function unpack_package($package, $delete_package = \true)
        {
        }
        /**
         * Flattens the results of WP_Filesystem_Base::dirlist() for iterating over.
         *
         * @since 4.9.0
         * @access protected
         *
         * @param array  $nested_files Array of files as returned by WP_Filesystem_Base::dirlist().
         * @param string $path         Relative path to prepend to child nodes. Optional.
         * @return array A flattened array of the $nested_files specified.
         */
        protected function flatten_dirlist($nested_files, $path = '')
        {
        }
        /**
         * Clears the directory where this item is going to be installed into.
         *
         * @since 4.3.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param string $remote_destination The location on the remote filesystem to be cleared.
         * @return true|WP_Error True upon success, WP_Error on failure.
         */
        public function clear_destination($remote_destination)
        {
        }
        /**
         * Install a package.
         *
         * Copies the contents of a package from a source directory, and installs them in
         * a destination directory. Optionally removes the source. It can also optionally
         * clear out the destination folder if it already exists.
         *
         * @since 2.8.0
         * @since 6.2.0 Use move_dir() instead of copy_dir() when possible.
         *
         * @global WP_Filesystem_Base $wp_filesystem        WordPress filesystem subclass.
         * @global array              $wp_theme_directories
         *
         * @param array|string $args {
         *     Optional. Array or string of arguments for installing a package. Default empty array.
         *
         *     @type string $source                      Required path to the package source. Default empty.
         *     @type string $destination                 Required path to a folder to install the package in.
         *                                               Default empty.
         *     @type bool   $clear_destination           Whether to delete any files already in the destination
         *                                               folder. Default false.
         *     @type bool   $clear_working               Whether to delete the files from the working directory
         *                                               after copying them to the destination. Default false.
         *     @type bool   $abort_if_destination_exists Whether to abort the installation if
         *                                               the destination folder already exists. Default true.
         *     @type array  $hook_extra                  Extra arguments to pass to the filter hooks called by
         *                                               WP_Upgrader::install_package(). Default empty array.
         * }
         *
         * @return array|WP_Error The result (also stored in `WP_Upgrader::$result`), or a WP_Error on failure.
         * @phpstan-param array{
         *   source?: string,
         *   destination?: string,
         *   clear_destination?: bool,
         *   clear_working?: bool,
         *   abort_if_destination_exists?: bool,
         *   hook_extra?: array,
         * } $args
         */
        public function install_package($args = array())
        {
        }
        /**
         * Runs an upgrade/installation.
         *
         * Attempts to download the package (if it is not a local file), unpack it, and
         * install it in the destination folder.
         *
         * @since 2.8.0
         *
         * @param array $options {
         *     Array or string of arguments for upgrading/installing a package.
         *
         *     @type string $package                     The full path or URI of the package to install.
         *                                               Default empty.
         *     @type string $destination                 The full path to the destination folder.
         *                                               Default empty.
         *     @type bool   $clear_destination           Whether to delete any files already in the
         *                                               destination folder. Default false.
         *     @type bool   $clear_working               Whether to delete the files from the working
         *                                               directory after copying them to the destination.
         *                                               Default true.
         *     @type bool   $abort_if_destination_exists Whether to abort the installation if the destination
         *                                               folder already exists. When true, `$clear_destination`
         *                                               should be false. Default true.
         *     @type bool   $is_multi                    Whether this run is one of multiple upgrade/installation
         *                                               actions being performed in bulk. When true, the skin
         *                                               WP_Upgrader::header() and WP_Upgrader::footer()
         *                                               aren't called. Default false.
         *     @type array  $hook_extra                  Extra arguments to pass to the filter hooks called by
         *                                               WP_Upgrader::run().
         * }
         * @return array|false|WP_Error The result from self::install_package() on success, otherwise a WP_Error,
         *                              or false if unable to connect to the filesystem.
         * @phpstan-param array{
         *   package?: string,
         *   destination?: string,
         *   clear_destination?: bool,
         *   clear_working?: bool,
         *   abort_if_destination_exists?: bool,
         *   is_multi?: bool,
         *   hook_extra?: array,
         * } $options
         */
        public function run($options)
        {
        }
        /**
         * Toggles maintenance mode for the site.
         *
         * Creates/deletes the maintenance file to enable/disable maintenance mode.
         *
         * @since 2.8.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param bool $enable True to enable maintenance mode, false to disable.
         */
        public function maintenance_mode($enable = \false)
        {
        }
        /**
         * Creates a lock using WordPress options.
         *
         * @since 4.5.0
         *
         * @global wpdb $wpdb The WordPress database abstraction object.
         *
         * @param string $lock_name       The name of this unique lock.
         * @param int    $release_timeout Optional. The duration in seconds to respect an existing lock.
         *                                Default: 1 hour.
         * @return bool False if a lock couldn't be created or if the lock is still valid. True otherwise.
         */
        public static function create_lock($lock_name, $release_timeout = \null)
        {
        }
        /**
         * Releases an upgrader lock.
         *
         * @since 4.5.0
         *
         * @see WP_Upgrader::create_lock()
         *
         * @param string $lock_name The name of this unique lock.
         * @return bool True if the lock was successfully released. False on failure.
         */
        public static function release_lock($lock_name)
        {
        }
        /**
         * Moves the plugin or theme being updated into a temporary backup directory.
         *
         * @since 6.3.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param string[] $args {
         *     Array of data for the temporary backup.
         *
         *     @type string $slug Plugin or theme slug.
         *     @type string $src  Path to the root directory for plugins or themes.
         *     @type string $dir  Destination subdirectory name. Accepts 'plugins' or 'themes'.
         * }
         *
         * @return bool|WP_Error True on success, false on early exit, otherwise WP_Error.
         * @phpstan-param array{
         *   slug?: string,
         *   src?: string,
         *   dir?: string,
         * } $args
         */
        public function move_to_temp_backup_dir($args)
        {
        }
        /**
         * Restores the plugin or theme from temporary backup.
         *
         * @since 6.3.0
         * @since 6.6.0 Added the `$temp_backups` parameter.
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param array[] $temp_backups {
         *     Optional. An array of temporary backups.
         *
         *     @type array ...$0 {
         *         Information about the backup.
         *
         *         @type string $dir  The temporary backup location in the upgrade-temp-backup directory.
         *         @type string $slug The item's slug.
         *         @type string $src  The directory where the original is stored. For example, `WP_PLUGIN_DIR`.
         *     }
         * }
         * @return bool|WP_Error True on success, false on early exit, otherwise WP_Error.
         * @phpstan-param array<int|string, array{
         *   dir: string,
         *   slug: string,
         *   src: string,
         * }> $temp_backups
         */
        public function restore_temp_backup(array $temp_backups = array())
        {
        }
        /**
         * Deletes a temporary backup.
         *
         * @since 6.3.0
         * @since 6.6.0 Added the `$temp_backups` parameter.
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param array[] $temp_backups {
         *     Optional. An array of temporary backups.
         *
         *     @type array ...$0 {
         *         Information about the backup.
         *
         *         @type string $dir  The temporary backup location in the upgrade-temp-backup directory.
         *         @type string $slug The item's slug.
         *         @type string $src  The directory where the original is stored. For example, `WP_PLUGIN_DIR`.
         *     }
         * }
         * @return bool|WP_Error True on success, false on early exit, otherwise WP_Error.
         * @phpstan-param array<int|string, array{
         *   dir: string,
         *   slug: string,
         *   src: string,
         * }> $temp_backups
         */
        public function delete_temp_backup(array $temp_backups = array())
        {
        }
    }
    /**
     * Core class used for updating core.
     *
     * It allows for WordPress to upgrade itself in combination with
     * the wp-admin/includes/update-core.php file.
     *
     * Note: Newly introduced functions and methods cannot be used here.
     * All functions must be present in the previous version being upgraded from
     * as this file is used there too.
     *
     * @since 2.8.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader.php.
     *
     * @see WP_Upgrader
     */
    class Core_Upgrader extends \WP_Upgrader
    {
        /**
         * Initializes the upgrade strings.
         *
         * @since 2.8.0
         */
        public function upgrade_strings()
        {
        }
        /**
         * Upgrades WordPress core.
         *
         * @since 2.8.0
         *
         * @global WP_Filesystem_Base $wp_filesystem                WordPress filesystem subclass.
         * @global callable           $_wp_filesystem_direct_method
         *
         * @param object $current Response object for whether WordPress is current.
         * @param array  $args {
         *     Optional. Arguments for upgrading WordPress core. Default empty array.
         *
         *     @type bool $pre_check_md5    Whether to check the file checksums before
         *                                  attempting the upgrade. Default true.
         *     @type bool $attempt_rollback Whether to attempt to rollback the chances if
         *                                  there is a problem. Default false.
         *     @type bool $do_rollback      Whether to perform this "upgrade" as a rollback.
         *                                  Default false.
         * }
         * @return string|false|WP_Error New WordPress version on success, false or WP_Error on failure.
         * @phpstan-param array{
         *   pre_check_md5?: bool,
         *   attempt_rollback?: bool,
         *   do_rollback?: bool,
         * } $args
         */
        public function upgrade($current, $args = array())
        {
        }
        /**
         * Determines if this WordPress Core version should update to an offered version or not.
         *
         * @since 3.7.0
         *
         * @param string $offered_ver The offered version, of the format x.y.z.
         * @return bool True if we should update to the offered version, otherwise false.
         */
        public static function should_update_to_version($offered_ver)
        {
        }
        /**
         * Compares the disk file checksums against the expected checksums.
         *
         * @since 3.7.0
         *
         * @global string $wp_version       The WordPress version string.
         * @global string $wp_local_package Locale code of the package.
         *
         * @return bool True if the checksums match, otherwise false.
         */
        public function check_files()
        {
        }
    }
    /**
     * The custom background class.
     *
     * @since 3.0.0
     */
    #[\AllowDynamicProperties]
    class Custom_Background
    {
        /**
         * Callback for administration header.
         *
         * @since 3.0.0
         * @var callable
         */
        public $admin_header_callback;
        /**
         * Callback for header div.
         *
         * @since 3.0.0
         * @var callable
         */
        public $admin_image_div_callback;
        /**
         * Constructor - Registers administration header callback.
         *
         * @since 3.0.0
         *
         * @param callable $admin_header_callback    Optional. Administration header callback.
         *                                           Default empty string.
         * @param callable $admin_image_div_callback Optional. Custom image div output callback.
         *                                           Default empty string.
         */
        public function __construct($admin_header_callback = '', $admin_image_div_callback = '')
        {
        }
        /**
         * Sets up the hooks for the Custom Background admin page.
         *
         * @since 3.0.0
         * @phpstan-return void
         */
        public function init()
        {
        }
        /**
         * Sets up the enqueue for the CSS & JavaScript files.
         *
         * @since 3.0.0
         */
        public function admin_load()
        {
        }
        /**
         * Executes custom background modification.
         *
         * @since 3.0.0
         * @phpstan-return void
         */
        public function take_action()
        {
        }
        /**
         * Displays the custom background page.
         *
         * @since 3.0.0
         */
        public function admin_page()
        {
        }
        /**
         * Handles an Image upload for the background image.
         *
         * @since 3.0.0
         * @phpstan-return void
         */
        public function handle_upload()
        {
        }
        /**
         * Handles Ajax request for adding custom background context to an attachment.
         *
         * Triggers when the user adds a new background image from the
         * Media Manager.
         *
         * @since 4.1.0
         * @phpstan-return never
         */
        public function ajax_background_add()
        {
        }
        /**
         * @since 3.4.0
         * @deprecated 3.5.0
         *
         * @param array $form_fields
         * @return array $form_fields
         */
        public function attachment_fields_to_edit($form_fields)
        {
        }
        /**
         * @since 3.4.0
         * @deprecated 3.5.0
         *
         * @param array $tabs
         * @return array $tabs
         */
        public function filter_upload_tabs($tabs)
        {
        }
        /**
         * @since 3.4.0
         * @deprecated 3.5.0
         * @phpstan-return never
         */
        public function wp_set_background_image()
        {
        }
    }
    /**
     * The custom header image class.
     *
     * @since 2.1.0
     */
    #[\AllowDynamicProperties]
    class Custom_Image_Header
    {
        /**
         * Callback for administration header.
         *
         * @since 2.1.0
         * @var callable
         */
        public $admin_header_callback;
        /**
         * Callback for header div.
         *
         * @since 3.0.0
         * @var callable
         */
        public $admin_image_div_callback;
        /**
         * Holds default headers.
         *
         * @since 3.0.0
         * @var array
         */
        public $default_headers = array();
        /**
         * Constructor - Registers administration header callback.
         *
         * @since 2.1.0
         *
         * @param callable $admin_header_callback    Administration header callback.
         * @param callable $admin_image_div_callback Optional. Custom image div output callback.
         *                                           Default empty string.
         */
        public function __construct($admin_header_callback, $admin_image_div_callback = '')
        {
        }
        /**
         * Sets up the hooks for the Custom Header admin page.
         *
         * @since 2.1.0
         * @phpstan-return void
         */
        public function init()
        {
        }
        /**
         * Adds contextual help.
         *
         * @since 3.0.0
         */
        public function help()
        {
        }
        /**
         * Gets the current step.
         *
         * @since 2.6.0
         *
         * @return int Current step.
         */
        public function step()
        {
        }
        /**
         * Sets up the enqueue for the JavaScript files.
         *
         * @since 2.1.0
         */
        public function js_includes()
        {
        }
        /**
         * Sets up the enqueue for the CSS files.
         *
         * @since 2.7.0
         */
        public function css_includes()
        {
        }
        /**
         * Executes custom header modification.
         *
         * @since 2.6.0
         * @phpstan-return void
         */
        public function take_action()
        {
        }
        /**
         * Processes the default headers.
         *
         * @since 3.0.0
         *
         * @global array $_wp_default_headers
         * @phpstan-return void
         */
        public function process_default_headers()
        {
        }
        /**
         * Displays UI for selecting one of several default headers.
         *
         * Shows the random image option if this theme has multiple header images.
         * Random image option is on by default if no header has been set.
         *
         * @since 3.0.0
         *
         * @param string $type The header type. One of 'default' (for the Uploaded Images control)
         *                     or 'uploaded' (for the Uploaded Images control).
         * @phpstan-param 'default'|'uploaded' $type
         */
        public function show_header_selector($type = 'default')
        {
        }
        /**
         * Executes JavaScript depending on step.
         *
         * @since 2.1.0
         */
        public function js()
        {
        }
        /**
         * Displays JavaScript based on Step 1 and 3.
         *
         * @since 2.6.0
         */
        public function js_1()
        {
        }
        /**
         * Displays JavaScript based on Step 2.
         *
         * @since 2.6.0
         */
        public function js_2()
        {
        }
        /**
         * Displays first step of custom header image page.
         *
         * @since 2.1.0
         */
        public function step_1()
        {
        }
        /**
         * Displays second step of custom header image page.
         *
         * @since 2.1.0
         */
        public function step_2()
        {
        }
        /**
         * Uploads the file to be cropped in the second step.
         *
         * @since 3.4.0
         */
        public function step_2_manage_upload()
        {
        }
        /**
         * Displays third step of custom header image page.
         *
         * @since 2.1.0
         * @since 4.4.0 Switched to using wp_get_attachment_url() instead of the guid
         *              for retrieving the header image URL.
         */
        public function step_3()
        {
        }
        /**
         * Displays last step of custom header image page.
         *
         * @since 2.1.0
         */
        public function finished()
        {
        }
        /**
         * Displays the page based on the current step.
         *
         * @since 2.1.0
         */
        public function admin_page()
        {
        }
        /**
         * Unused since 3.5.0.
         *
         * @since 3.4.0
         *
         * @param array $form_fields
         * @return array $form_fields
         */
        public function attachment_fields_to_edit($form_fields)
        {
        }
        /**
         * Unused since 3.5.0.
         *
         * @since 3.4.0
         *
         * @param array $tabs
         * @return array $tabs
         */
        public function filter_upload_tabs($tabs)
        {
        }
        /**
         * Chooses a header image, selected from existing uploaded and default headers,
         * or provides an array of uploaded header data (either new, or from media library).
         *
         * @since 3.4.0
         *
         * @param mixed $choice Which header image to select. Allows for values of 'random-default-image',
         *                      for randomly cycling among the default images; 'random-uploaded-image',
         *                      for randomly cycling among the uploaded images; the key of a default image
         *                      registered for that theme; and the key of an image uploaded for that theme
         *                      (the attachment ID of the image). Or an array of arguments: attachment_id,
         *                      url, width, height. All are required.
         * @phpstan-param string|array{attachment_id: int<1, max>, url: string, width: int<0, max>, height: int<0, max>} $choice
         * @phpstan-return void
         */
        public final function set_header_image($choice)
        {
        }
        /**
         * Removes a header image.
         *
         * @since 3.4.0
         */
        public final function remove_header_image()
        {
        }
        /**
         * Resets a header image to the default image for the theme.
         *
         * This method does not do anything if the theme does not have a default header image.
         *
         * @since 3.4.0
         * @phpstan-return void
         */
        public final function reset_header_image()
        {
        }
        /**
         * Calculates width and height based on what the currently selected theme supports.
         *
         * @since 3.9.0
         *
         * @param array $dimensions
         * @return array dst_height and dst_width of header image.
         */
        public final function get_header_dimensions($dimensions)
        {
        }
        /**
         * Creates an attachment 'object'.
         *
         * @since 3.9.0
         * @deprecated 6.5.0
         *
         * @param string $cropped              Cropped image URL.
         * @param int    $parent_attachment_id Attachment ID of parent image.
         * @return array An array with attachment object data.
         */
        public final function create_attachment_object($cropped, $parent_attachment_id)
        {
        }
        /**
         * Inserts an attachment and its metadata.
         *
         * @since 3.9.0
         *
         * @param array  $attachment An array with attachment object data.
         * @param string $cropped    File path to cropped image.
         * @return int Attachment ID.
         */
        public final function insert_attachment($attachment, $cropped)
        {
        }
        /**
         * Gets attachment uploaded by Media Manager, crops it, then saves it as a
         * new object. Returns JSON-encoded object details.
         *
         * @since 3.9.0
         * @phpstan-return never
         */
        public function ajax_header_crop()
        {
        }
        /**
         * Given an attachment ID for a header image, updates its "last used"
         * timestamp to now.
         *
         * Triggered when the user tries adds a new header image from the
         * Media Manager, even if s/he doesn't save that change.
         *
         * @since 3.9.0
         * @phpstan-return never
         */
        public function ajax_header_add()
        {
        }
        /**
         * Given an attachment ID for a header image, unsets it as a user-uploaded
         * header image for the active theme.
         *
         * Triggered when the user clicks the overlay "X" button next to each image
         * choice in the Customizer's Header tool.
         *
         * @since 3.9.0
         * @phpstan-return never
         */
        public function ajax_header_remove()
        {
        }
        /**
         * Updates the last-used postmeta on a header image attachment after saving a new header image via the Customizer.
         *
         * @since 3.9.0
         *
         * @param WP_Customize_Manager $wp_customize Customize manager.
         * @phpstan-return void
         */
        public function customize_set_last_used($wp_customize)
        {
        }
        /**
         * Gets the details of default header images if defined.
         *
         * @since 3.9.0
         *
         * @return array Default header images.
         */
        public function get_default_header_images()
        {
        }
        /**
         * Gets the previously uploaded header images.
         *
         * @since 3.9.0
         *
         * @return array Uploaded header images.
         */
        public function get_uploaded_header_images()
        {
        }
        /**
         * Gets the ID of a previous crop from the same base image.
         *
         * @since 4.9.0
         *
         * @param array $attachment An array with a cropped attachment object data.
         * @return int|false An attachment ID if one exists. False if none.
         */
        public function get_previous_crop($attachment)
        {
        }
    }
    /**
     * Core class used for handling file uploads.
     *
     * This class handles the upload process and passes it as if it's a local file
     * to the Upgrade/Installer functions.
     *
     * @since 2.8.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader.php.
     */
    #[\AllowDynamicProperties]
    class File_Upload_Upgrader
    {
        /**
         * The full path to the file package.
         *
         * @since 2.8.0
         * @var string $package
         */
        public $package;
        /**
         * The name of the file.
         *
         * @since 2.8.0
         * @var string $filename
         */
        public $filename;
        /**
         * The ID of the attachment post for this file.
         *
         * @since 3.3.0
         * @var int $id
         */
        public $id = 0;
        /**
         * Construct the upgrader for a form.
         *
         * @since 2.8.0
         *
         * @param string $form      The name of the form the file was uploaded from.
         * @param string $urlholder The name of the `GET` parameter that holds the filename.
         */
        public function __construct($form, $urlholder)
        {
        }
        /**
         * Deletes the attachment/uploaded file.
         *
         * @since 3.2.2
         *
         * @return bool Whether the cleanup was successful.
         */
        public function cleanup()
        {
        }
    }
    /**
     * PemFTP base class
     *
     */
    class ftp_base
    {
        var $LocalEcho;
        var $Verbose;
        var $OS_local;
        var $OS_remote;
        var $_lastaction;
        var $_errors;
        var $_type;
        var $_umask;
        var $_timeout;
        var $_passive;
        var $_host;
        var $_fullhost;
        var $_port;
        var $_datahost;
        var $_dataport;
        var $_ftp_control_sock;
        var $_ftp_data_sock;
        var $_ftp_temp_sock;
        var $_ftp_buff_size;
        var $_login;
        var $_password;
        var $_connected;
        var $_ready;
        var $_code;
        var $_message;
        var $_can_restore;
        var $_port_available;
        var $_curtype;
        var $_features;
        var $_error_array;
        var $AuthorizedTransferMode;
        var $OS_FullName;
        var $_eol_code;
        var $AutoAsciiExt;
        function __construct($port_mode = \FALSE, $verb = \FALSE, $le = \FALSE)
        {
        }
        function ftp_base($port_mode = \FALSE)
        {
        }
        function parselisting($line)
        {
        }
        function SendMSG($message = "", $crlf = \true)
        {
        }
        function SetType($mode = \FTP_AUTOASCII)
        {
        }
        function _settype($mode = \FTP_ASCII)
        {
        }
        function Passive($pasv = \NULL)
        {
        }
        function SetServer($host, $port = 21, $reconnect = \true)
        {
        }
        function SetUmask($umask = 022)
        {
        }
        function SetTimeout($timeout = 30)
        {
        }
        function connect($server = \NULL)
        {
        }
        function quit($force = \false)
        {
        }
        function login($user = \NULL, $pass = \NULL)
        {
        }
        function pwd()
        {
        }
        function cdup()
        {
        }
        function chdir($pathname)
        {
        }
        function rmdir($pathname)
        {
        }
        function mkdir($pathname)
        {
        }
        function rename($from, $to)
        {
        }
        function filesize($pathname)
        {
        }
        function abort()
        {
        }
        function mdtm($pathname)
        {
        }
        function systype()
        {
        }
        function delete($pathname)
        {
        }
        function site($command, $fnction = "site")
        {
        }
        function chmod($pathname, $mode)
        {
        }
        function restore($from)
        {
        }
        function features()
        {
        }
        function rawlist($pathname = "", $arg = "")
        {
        }
        function nlist($pathname = "", $arg = "")
        {
        }
        function is_exists($pathname)
        {
        }
        function file_exists($pathname)
        {
        }
        function fget($fp, $remotefile, $rest = 0)
        {
        }
        function get($remotefile, $localfile = \NULL, $rest = 0)
        {
        }
        function fput($remotefile, $fp, $rest = 0)
        {
        }
        function put($localfile, $remotefile = \NULL, $rest = 0)
        {
        }
        function mput($local = ".", $remote = \NULL, $continious = \false)
        {
        }
        function mget($remote, $local = ".", $continious = \false)
        {
        }
        function mdel($remote, $continious = \false)
        {
        }
        function mmkdir($dir, $mode = 0777)
        {
        }
        function glob($pattern, $handle = \NULL)
        {
        }
        function glob_pattern_match($pattern, $subject)
        {
        }
        function glob_regexp($pattern, $subject)
        {
        }
        function dirlist($remote)
        {
        }
        function _checkCode()
        {
        }
        function _list($arg = "", $cmd = "LIST", $fnction = "_list")
        {
        }
        function PushError($fctname, $msg, $desc = \false)
        {
        }
        function PopError()
        {
        }
    }
    /**
     * FTP implementation using fsockopen to connect.
     *
     * @package PemFTP
     * @subpackage Pure
     * @since 2.5.0
     *
     * @version 1.0
     * @copyright Alexey Dotsenko
     * @author Alexey Dotsenko
     * @link https://www.phpclasses.org/package/1743-PHP-FTP-client-in-pure-PHP.html
     * @license LGPL https://opensource.org/licenses/lgpl-license.html
     */
    class ftp_pure extends \ftp_base
    {
        function __construct($verb = \FALSE, $le = \FALSE)
        {
        }
        function _settimeout($sock)
        {
        }
        function _connect($host, $port)
        {
        }
        function _readmsg($fnction = "_readmsg")
        {
        }
        function _exec($cmd, $fnction = "_exec")
        {
        }
        function _data_prepare($mode = \FTP_ASCII)
        {
        }
        function _data_read($mode = \FTP_ASCII, $fp = \NULL)
        {
        }
        function _data_write($mode = \FTP_ASCII, $fp = \NULL)
        {
        }
        function _data_write_block($mode, $block)
        {
        }
        function _data_close()
        {
        }
        function _quit($force = \FALSE)
        {
        }
    }
    /**
     * Socket Based FTP implementation
     *
     * @package PemFTP
     * @subpackage Socket
     * @since 2.5.0
     *
     * @version 1.0
     * @copyright Alexey Dotsenko
     * @author Alexey Dotsenko
     * @link https://www.phpclasses.org/package/1743-PHP-FTP-client-in-pure-PHP.html
     * @license LGPL https://opensource.org/licenses/lgpl-license.html
     */
    class ftp_sockets extends \ftp_base
    {
        function __construct($verb = \FALSE, $le = \FALSE)
        {
        }
        function _settimeout($sock)
        {
        }
        function _connect($host, $port)
        {
        }
        function _readmsg($fnction = "_readmsg")
        {
        }
        function _exec($cmd, $fnction = "_exec")
        {
        }
        function _data_prepare($mode = \FTP_ASCII)
        {
        }
        function _data_read($mode = \FTP_ASCII, $fp = \NULL)
        {
        }
        function _data_write($mode = \FTP_ASCII, $fp = \NULL)
        {
        }
        function _data_write_block($mode, $block)
        {
        }
        function _data_close()
        {
        }
        function _quit()
        {
        }
    }
    class ftp extends \ftp_sockets
    {
    }
    /**
     * Translation Upgrader Skin for WordPress Translation Upgrades.
     *
     * @since 3.7.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader-skins.php.
     *
     * @see WP_Upgrader_Skin
     */
    class Language_Pack_Upgrader_Skin extends \WP_Upgrader_Skin
    {
        public $language_update = \null;
        public $done_header = \false;
        public $done_footer = \false;
        public $display_footer_actions = \true;
        /**
         * Constructor.
         *
         * Sets up the language pack upgrader skin.
         *
         * @since 3.7.0
         *
         * @param array $args
         */
        public function __construct($args = array())
        {
        }
        /**
         * Performs an action before a language pack update.
         *
         * @since 3.7.0
         */
        public function before()
        {
        }
        /**
         * Displays an error message about the update.
         *
         * @since 3.7.0
         * @since 5.9.0 Renamed `$error` to `$errors` for PHP 8 named parameter support.
         *
         * @param string|WP_Error $errors Errors.
         */
        public function error($errors)
        {
        }
        /**
         * Performs an action following a language pack update.
         *
         * @since 3.7.0
         */
        public function after()
        {
        }
        /**
         * Displays the footer following the bulk update process.
         *
         * @since 3.7.0
         */
        public function bulk_footer()
        {
        }
    }
    /**
     * Core class used for updating/installing language packs (translations)
     * for plugins, themes, and core.
     *
     * @since 3.7.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader.php.
     *
     * @see WP_Upgrader
     */
    class Language_Pack_Upgrader extends \WP_Upgrader
    {
        /**
         * Result of the language pack upgrade.
         *
         * @since 3.7.0
         * @var array|WP_Error $result
         * @see WP_Upgrader::$result
         */
        public $result;
        /**
         * Whether a bulk upgrade/installation is being performed.
         *
         * @since 3.7.0
         * @var bool $bulk
         */
        public $bulk = \true;
        /**
         * Asynchronously upgrades language packs after other upgrades have been made.
         *
         * Hooked to the {@see 'upgrader_process_complete'} action by default.
         *
         * @since 3.7.0
         *
         * @param false|WP_Upgrader $upgrader Optional. WP_Upgrader instance or false. If `$upgrader` is
         *                                    a Language_Pack_Upgrader instance, the method will bail to
         *                                    avoid recursion. Otherwise unused. Default false.
         * @phpstan-return void
         */
        public static function async_upgrade($upgrader = \false)
        {
        }
        /**
         * Initializes the upgrade strings.
         *
         * @since 3.7.0
         */
        public function upgrade_strings()
        {
        }
        /**
         * Upgrades a language pack.
         *
         * @since 3.7.0
         *
         * @param string|false $update Optional. Whether an update offer is available. Default false.
         * @param array        $args   Optional. Other optional arguments, see
         *                             Language_Pack_Upgrader::bulk_upgrade(). Default empty array.
         * @return array|bool|WP_Error The result of the upgrade, or a WP_Error object instead.
         * @phpstan-param array{
         *   clear_update_cache?: bool,
         * } $args See Language_Pack_Upgrader::bulk_upgrade()
         */
        public function upgrade($update = \false, $args = array())
        {
        }
        /**
         * Upgrades several language packs at once.
         *
         * @since 3.7.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param object[] $language_updates Optional. Array of language packs to update. See {@see wp_get_translation_updates()}.
         *                                   Default empty array.
         * @param array    $args {
         *     Other arguments for upgrading multiple language packs. Default empty array.
         *
         *     @type bool $clear_update_cache Whether to clear the update cache when done.
         *                                    Default true.
         * }
         * @return array|bool|WP_Error Will return an array of results, or true if there are no updates,
         *                             false or WP_Error for initial errors.
         * @phpstan-param array{
         *   clear_update_cache?: bool,
         * } $args
         */
        public function bulk_upgrade($language_updates = array(), $args = array())
        {
        }
        /**
         * Checks that the package source contains .mo and .po files.
         *
         * Hooked to the {@see 'upgrader_source_selection'} filter by
         * Language_Pack_Upgrader::bulk_upgrade().
         *
         * @since 3.7.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param string|WP_Error $source        The path to the downloaded package source.
         * @param string          $remote_source Remote file source location.
         * @return string|WP_Error The source as passed, or a WP_Error object on failure.
         */
        public function check_package($source, $remote_source)
        {
        }
        /**
         * Gets the name of an item being updated.
         *
         * @since 3.7.0
         *
         * @param object $update The data for an update.
         * @return string The name of the item being updated.
         */
        public function get_name_for_update($update)
        {
        }
        /**
         * Clears existing translations where this item is going to be installed into.
         *
         * @since 5.1.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param string $remote_destination The location on the remote filesystem to be cleared.
         * @return bool|WP_Error True upon success, WP_Error on failure.
         */
        public function clear_destination($remote_destination)
        {
        }
    }
    class PclZip
    {
        var $zipname = '';
        var $zip_fd = 0;
        var $error_code = 1;
        var $error_string = '';
        var $magic_quotes_status;
        function __construct($p_zipname)
        {
        }
        public function PclZip($p_zipname)
        {
        }
        function create($p_filelist)
        {
        }
        function add($p_filelist)
        {
        }
        function listContent()
        {
        }
        function extract()
        {
        }
        function extractByIndex($p_index)
        {
        }
        function delete()
        {
        }
        function deleteByIndex($p_index)
        {
        }
        function properties()
        {
        }
        function duplicate($p_archive)
        {
        }
        function merge($p_archive_to_add)
        {
        }
        function errorCode()
        {
        }
        function errorName($p_with_code = \false)
        {
        }
        function errorInfo($p_full = \false)
        {
        }
        function privCheckFormat($p_level = 0)
        {
        }
        function privParseOptions(&$p_options_list, $p_size, &$v_result_list, $v_requested_options = \false)
        {
        }
        function privOptionDefaultThreshold(&$p_options)
        {
        }
        function privFileDescrParseAtt(&$p_file_list, &$p_filedescr, $v_options, $v_requested_options = \false)
        {
        }
        function privFileDescrExpand(&$p_filedescr_list, &$p_options)
        {
        }
        function privCreate($p_filedescr_list, &$p_result_list, &$p_options)
        {
        }
        function privAdd($p_filedescr_list, &$p_result_list, &$p_options)
        {
        }
        function privOpenFd($p_mode)
        {
        }
        function privCloseFd()
        {
        }
        function privAddList($p_filedescr_list, &$p_result_list, &$p_options)
        {
        }
        function privAddFileList($p_filedescr_list, &$p_result_list, &$p_options)
        {
        }
        function privAddFile($p_filedescr, &$p_header, &$p_options)
        {
        }
        function privAddFileUsingTempFile($p_filedescr, &$p_header, &$p_options)
        {
        }
        function privCalculateStoredFilename(&$p_filedescr, &$p_options)
        {
        }
        function privWriteFileHeader(&$p_header)
        {
        }
        function privWriteCentralFileHeader(&$p_header)
        {
        }
        function privWriteCentralHeader($p_nb_entries, $p_size, $p_offset, $p_comment)
        {
        }
        function privList(&$p_list)
        {
        }
        function privConvertHeader2FileInfo($p_header, &$p_info)
        {
        }
        function privExtractByRule(&$p_file_list, $p_path, $p_remove_path, $p_remove_all_path, &$p_options)
        {
        }
        function privExtractFile(&$p_entry, $p_path, $p_remove_path, $p_remove_all_path, &$p_options)
        {
        }
        function privExtractFileUsingTempFile(&$p_entry, &$p_options)
        {
        }
        function privExtractFileInOutput(&$p_entry, &$p_options)
        {
        }
        function privExtractFileAsString(&$p_entry, &$p_string, &$p_options)
        {
        }
        function privReadFileHeader(&$p_header)
        {
        }
        function privReadCentralFileHeader(&$p_header)
        {
        }
        function privCheckFileHeaders(&$p_local_header, &$p_central_header)
        {
        }
        function privReadEndCentralDir(&$p_central_dir)
        {
        }
        function privDeleteByRule(&$p_result_list, &$p_options)
        {
        }
        function privDirCheck($p_dir, $p_is_dir = \false)
        {
        }
        function privMerge(&$p_archive_to_add)
        {
        }
        function privDuplicate($p_archive_filename)
        {
        }
        function privErrorLog($p_error_code = 0, $p_error_string = '')
        {
        }
        function privErrorReset()
        {
        }
        function privDisableMagicQuotes()
        {
        }
        function privSwapBackMagicQuotes()
        {
        }
        // --------------------------------------------------------------------------------
    }
    /**
     * Plugin Installer Skin for WordPress Plugin Installer.
     *
     * @since 2.8.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader-skins.php.
     *
     * @see WP_Upgrader_Skin
     */
    class Plugin_Installer_Skin extends \WP_Upgrader_Skin
    {
        public $api;
        public $type;
        public $url;
        public $overwrite;
        /**
         * Constructor.
         *
         * Sets up the plugin installer skin.
         *
         * @since 2.8.0
         *
         * @param array $args
         */
        public function __construct($args = array())
        {
        }
        /**
         * Performs an action before installing a plugin.
         *
         * @since 2.8.0
         */
        public function before()
        {
        }
        /**
         * Hides the `process_failed` error when updating a plugin by uploading a zip file.
         *
         * @since 5.5.0
         *
         * @param WP_Error $wp_error WP_Error object.
         * @return bool True if the error should be hidden, false otherwise.
         */
        public function hide_process_failed($wp_error)
        {
        }
        /**
         * Performs an action following a plugin install.
         *
         * @since 2.8.0
         * @phpstan-return void
         */
        public function after()
        {
        }
    }
    /**
     * Plugin Upgrader Skin for WordPress Plugin Upgrades.
     *
     * @since 2.8.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader-skins.php.
     *
     * @see WP_Upgrader_Skin
     */
    class Plugin_Upgrader_Skin extends \WP_Upgrader_Skin
    {
        /**
         * Holds the plugin slug in the Plugin Directory.
         *
         * @since 2.8.0
         *
         * @var string
         */
        public $plugin = '';
        /**
         * Whether the plugin is active.
         *
         * @since 2.8.0
         *
         * @var bool
         */
        public $plugin_active = \false;
        /**
         * Whether the plugin is active for the entire network.
         *
         * @since 2.8.0
         *
         * @var bool
         */
        public $plugin_network_active = \false;
        /**
         * Constructor.
         *
         * Sets up the plugin upgrader skin.
         *
         * @since 2.8.0
         *
         * @param array $args Optional. The plugin upgrader skin arguments to
         *                    override default options. Default empty array.
         */
        public function __construct($args = array())
        {
        }
        /**
         * Performs an action following a single plugin update.
         *
         * @since 2.8.0
         */
        public function after()
        {
        }
    }
    /**
     * Core class used for upgrading/installing plugins.
     *
     * It is designed to upgrade/install plugins from a local zip, remote zip URL,
     * or uploaded zip file.
     *
     * @since 2.8.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader.php.
     *
     * @see WP_Upgrader
     */
    class Plugin_Upgrader extends \WP_Upgrader
    {
        /**
         * Plugin upgrade result.
         *
         * @since 2.8.0
         * @var array|WP_Error $result
         *
         * @see WP_Upgrader::$result
         */
        public $result;
        /**
         * Whether a bulk upgrade/installation is being performed.
         *
         * @since 2.9.0
         * @var bool $bulk
         */
        public $bulk = \false;
        /**
         * New plugin info.
         *
         * @since 5.5.0
         * @var array $new_plugin_data
         *
         * @see check_package()
         */
        public $new_plugin_data = array();
        /**
         * Initializes the upgrade strings.
         *
         * @since 2.8.0
         */
        public function upgrade_strings()
        {
        }
        /**
         * Initializes the installation strings.
         *
         * @since 2.8.0
         */
        public function install_strings()
        {
        }
        /**
         * Install a plugin package.
         *
         * @since 2.8.0
         * @since 3.7.0 The `$args` parameter was added, making clearing the plugin update cache optional.
         *
         * @param string $package The full local path or URI of the package.
         * @param array  $args {
         *     Optional. Other arguments for installing a plugin package. Default empty array.
         *
         *     @type bool $clear_update_cache Whether to clear the plugin updates cache if successful.
         *                                    Default true.
         * }
         * @return bool|WP_Error True if the installation was successful, false or a WP_Error otherwise.
         * @phpstan-param array{
         *   clear_update_cache?: bool,
         * } $args
         */
        public function install($package, $args = array())
        {
        }
        /**
         * Upgrades a plugin.
         *
         * @since 2.8.0
         * @since 3.7.0 The `$args` parameter was added, making clearing the plugin update cache optional.
         *
         * @param string $plugin Path to the plugin file relative to the plugins directory.
         * @param array  $args {
         *     Optional. Other arguments for upgrading a plugin package. Default empty array.
         *
         *     @type bool $clear_update_cache Whether to clear the plugin updates cache if successful.
         *                                    Default true.
         * }
         * @return bool|WP_Error True if the upgrade was successful, false or a WP_Error object otherwise.
         * @phpstan-param array{
         *   clear_update_cache?: bool,
         * } $args
         */
        public function upgrade($plugin, $args = array())
        {
        }
        /**
         * Upgrades several plugins at once.
         *
         * @since 2.8.0
         * @since 3.7.0 The `$args` parameter was added, making clearing the plugin update cache optional.
         *
         * @param string[] $plugins Array of paths to plugin files relative to the plugins directory.
         * @param array    $args {
         *     Optional. Other arguments for upgrading several plugins at once.
         *
         *     @type bool $clear_update_cache Whether to clear the plugin updates cache if successful. Default true.
         * }
         * @return array|false An array of results indexed by plugin file, or false if unable to connect to the filesystem.
         * @phpstan-param array{
         *   clear_update_cache?: bool,
         * } $args
         */
        public function bulk_upgrade($plugins, $args = array())
        {
        }
        /**
         * Checks that the source package contains a valid plugin.
         *
         * Hooked to the {@see 'upgrader_source_selection'} filter by Plugin_Upgrader::install().
         *
         * @since 3.3.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param string $source The path to the downloaded package source.
         * @return string|WP_Error The source as passed, or a WP_Error object on failure.
         */
        public function check_package($source)
        {
        }
        /**
         * Retrieves the path to the file that contains the plugin info.
         *
         * This isn't used internally in the class, but is called by the skins.
         *
         * @since 2.8.0
         *
         * @return string|false The full path to the main plugin file, or false.
         */
        public function plugin_info()
        {
        }
        /**
         * Deactivates a plugin before it is upgraded.
         *
         * Hooked to the {@see 'upgrader_pre_install'} filter by Plugin_Upgrader::upgrade().
         *
         * @since 2.8.0
         * @since 4.1.0 Added a return value.
         *
         * @param bool|WP_Error $response The installation response before the installation has started.
         * @param array         $plugin   Plugin package arguments.
         * @return bool|WP_Error The original `$response` parameter or WP_Error.
         */
        public function deactivate_plugin_before_upgrade($response, $plugin)
        {
        }
        /**
         * Turns on maintenance mode before attempting to background update an active plugin.
         *
         * Hooked to the {@see 'upgrader_pre_install'} filter by Plugin_Upgrader::upgrade().
         *
         * @since 5.4.0
         *
         * @param bool|WP_Error $response The installation response before the installation has started.
         * @param array         $plugin   Plugin package arguments.
         * @return bool|WP_Error The original `$response` parameter or WP_Error.
         */
        public function active_before($response, $plugin)
        {
        }
        /**
         * Turns off maintenance mode after upgrading an active plugin.
         *
         * Hooked to the {@see 'upgrader_post_install'} filter by Plugin_Upgrader::upgrade().
         *
         * @since 5.4.0
         *
         * @param bool|WP_Error $response The installation response after the installation has finished.
         * @param array         $plugin   Plugin package arguments.
         * @return bool|WP_Error The original `$response` parameter or WP_Error.
         */
        public function active_after($response, $plugin)
        {
        }
        /**
         * Deletes the old plugin during an upgrade.
         *
         * Hooked to the {@see 'upgrader_clear_destination'} filter by
         * Plugin_Upgrader::upgrade() and Plugin_Upgrader::bulk_upgrade().
         *
         * @since 2.8.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param bool|WP_Error $removed            Whether the destination was cleared.
         *                                          True on success, WP_Error on failure.
         * @param string        $local_destination  The local package destination.
         * @param string        $remote_destination The remote package destination.
         * @param array         $plugin             Extra arguments passed to hooked filters.
         * @return bool|WP_Error
         */
        public function delete_old_plugin($removed, $local_destination, $remote_destination, $plugin)
        {
        }
    }
    /**
     * Theme Installer Skin for the WordPress Theme Installer.
     *
     * @since 2.8.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader-skins.php.
     *
     * @see WP_Upgrader_Skin
     */
    class Theme_Installer_Skin extends \WP_Upgrader_Skin
    {
        public $api;
        public $type;
        public $url;
        public $overwrite;
        /**
         * Constructor.
         *
         * Sets up the theme installer skin.
         *
         * @since 2.8.0
         *
         * @param array $args
         */
        public function __construct($args = array())
        {
        }
        /**
         * Performs an action before installing a theme.
         *
         * @since 2.8.0
         */
        public function before()
        {
        }
        /**
         * Hides the `process_failed` error when updating a theme by uploading a zip file.
         *
         * @since 5.5.0
         *
         * @param WP_Error $wp_error WP_Error object.
         * @return bool True if the error should be hidden, false otherwise.
         */
        public function hide_process_failed($wp_error)
        {
        }
        /**
         * Performs an action following a single theme install.
         *
         * @since 2.8.0
         * @phpstan-return void
         */
        public function after()
        {
        }
    }
    /**
     * Theme Upgrader Skin for WordPress Theme Upgrades.
     *
     * @since 2.8.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader-skins.php.
     *
     * @see WP_Upgrader_Skin
     */
    class Theme_Upgrader_Skin extends \WP_Upgrader_Skin
    {
        /**
         * Holds the theme slug in the Theme Directory.
         *
         * @since 2.8.0
         *
         * @var string
         */
        public $theme = '';
        /**
         * Constructor.
         *
         * Sets up the theme upgrader skin.
         *
         * @since 2.8.0
         *
         * @param array $args Optional. The theme upgrader skin arguments to
         *                    override default options. Default empty array.
         */
        public function __construct($args = array())
        {
        }
        /**
         * Performs an action following a single theme update.
         *
         * @since 2.8.0
         */
        public function after()
        {
        }
    }
    /**
     * Core class used for upgrading/installing themes.
     *
     * It is designed to upgrade/install themes from a local zip, remote zip URL,
     * or uploaded zip file.
     *
     * @since 2.8.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader.php.
     *
     * @see WP_Upgrader
     */
    class Theme_Upgrader extends \WP_Upgrader
    {
        /**
         * Result of the theme upgrade offer.
         *
         * @since 2.8.0
         * @var array|WP_Error $result
         * @see WP_Upgrader::$result
         */
        public $result;
        /**
         * Whether multiple themes are being upgraded/installed in bulk.
         *
         * @since 2.9.0
         * @var bool $bulk
         */
        public $bulk = \false;
        /**
         * New theme info.
         *
         * @since 5.5.0
         * @var array $new_theme_data
         *
         * @see check_package()
         */
        public $new_theme_data = array();
        /**
         * Initializes the upgrade strings.
         *
         * @since 2.8.0
         */
        public function upgrade_strings()
        {
        }
        /**
         * Initializes the installation strings.
         *
         * @since 2.8.0
         */
        public function install_strings()
        {
        }
        /**
         * Checks if a child theme is being installed and its parent also needs to be installed.
         *
         * Hooked to the {@see 'upgrader_post_install'} filter by Theme_Upgrader::install().
         *
         * @since 3.4.0
         *
         * @param bool  $install_result
         * @param array $hook_extra
         * @param array $child_result
         * @return bool
         */
        public function check_parent_theme_filter($install_result, $hook_extra, $child_result)
        {
        }
        /**
         * Don't display the activate and preview actions to the user.
         *
         * Hooked to the {@see 'install_theme_complete_actions'} filter by
         * Theme_Upgrader::check_parent_theme_filter() when installing
         * a child theme and installing the parent theme fails.
         *
         * @since 3.4.0
         *
         * @param array $actions Preview actions.
         * @return array
         */
        public function hide_activate_preview_actions($actions)
        {
        }
        /**
         * Install a theme package.
         *
         * @since 2.8.0
         * @since 3.7.0 The `$args` parameter was added, making clearing the update cache optional.
         *
         * @param string $package The full local path or URI of the package.
         * @param array  $args {
         *     Optional. Other arguments for installing a theme package. Default empty array.
         *
         *     @type bool $clear_update_cache Whether to clear the updates cache if successful.
         *                                    Default true.
         * }
         *
         * @return bool|WP_Error True if the installation was successful, false or a WP_Error object otherwise.
         * @phpstan-param array{
         *   clear_update_cache?: bool,
         * } $args
         */
        public function install($package, $args = array())
        {
        }
        /**
         * Upgrades a theme.
         *
         * @since 2.8.0
         * @since 3.7.0 The `$args` parameter was added, making clearing the update cache optional.
         *
         * @param string $theme The theme slug.
         * @param array  $args {
         *     Optional. Other arguments for upgrading a theme. Default empty array.
         *
         *     @type bool $clear_update_cache Whether to clear the update cache if successful.
         *                                    Default true.
         * }
         * @return bool|WP_Error True if the upgrade was successful, false or a WP_Error object otherwise.
         * @phpstan-param array{
         *   clear_update_cache?: bool,
         * } $args
         */
        public function upgrade($theme, $args = array())
        {
        }
        /**
         * Upgrades several themes at once.
         *
         * @since 3.0.0
         * @since 3.7.0 The `$args` parameter was added, making clearing the update cache optional.
         *
         * @param string[] $themes Array of the theme slugs.
         * @param array    $args {
         *     Optional. Other arguments for upgrading several themes at once. Default empty array.
         *
         *     @type bool $clear_update_cache Whether to clear the update cache if successful.
         *                                    Default true.
         * }
         * @return array[]|false An array of results, or false if unable to connect to the filesystem.
         * @phpstan-param array{
         *   clear_update_cache?: bool,
         * } $args
         */
        public function bulk_upgrade($themes, $args = array())
        {
        }
        /**
         * Checks that the package source contains a valid theme.
         *
         * Hooked to the {@see 'upgrader_source_selection'} filter by Theme_Upgrader::install().
         *
         * @since 3.3.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param string $source The path to the downloaded package source.
         * @return string|WP_Error The source as passed, or a WP_Error object on failure.
         */
        public function check_package($source)
        {
        }
        /**
         * Turns on maintenance mode before attempting to upgrade the active theme.
         *
         * Hooked to the {@see 'upgrader_pre_install'} filter by Theme_Upgrader::upgrade() and
         * Theme_Upgrader::bulk_upgrade().
         *
         * @since 2.8.0
         *
         * @param bool|WP_Error $response The installation response before the installation has started.
         * @param array         $theme    Theme arguments.
         * @return bool|WP_Error The original `$response` parameter or WP_Error.
         */
        public function current_before($response, $theme)
        {
        }
        /**
         * Turns off maintenance mode after upgrading the active theme.
         *
         * Hooked to the {@see 'upgrader_post_install'} filter by Theme_Upgrader::upgrade()
         * and Theme_Upgrader::bulk_upgrade().
         *
         * @since 2.8.0
         *
         * @param bool|WP_Error $response The installation response after the installation has finished.
         * @param array         $theme    Theme arguments.
         * @return bool|WP_Error The original `$response` parameter or WP_Error.
         */
        public function current_after($response, $theme)
        {
        }
        /**
         * Deletes the old theme during an upgrade.
         *
         * Hooked to the {@see 'upgrader_clear_destination'} filter by Theme_Upgrader::upgrade()
         * and Theme_Upgrader::bulk_upgrade().
         *
         * @since 2.8.0
         *
         * @global WP_Filesystem_Base $wp_filesystem Subclass
         *
         * @param bool   $removed
         * @param string $local_destination
         * @param string $remote_destination
         * @param array  $theme
         * @return bool
         */
        public function delete_old_theme($removed, $local_destination, $remote_destination, $theme)
        {
        }
        /**
         * Gets the WP_Theme object for a theme.
         *
         * @since 2.8.0
         * @since 3.0.0 The `$theme` argument was added.
         *
         * @param string $theme The directory name of the theme. This is optional, and if not supplied,
         *                      the directory name from the last result will be used.
         * @return WP_Theme|false The theme's info object, or false `$theme` is not supplied
         *                        and the last result isn't set.
         */
        public function theme_info($theme = \null)
        {
        }
    }
    /**
     * A class for displaying various tree-like structures.
     *
     * Extend the Walker class to use it, see examples below. Child classes
     * do not need to implement all of the abstract methods in the class. The child
     * only needs to implement the methods that are needed.
     *
     * @since 2.1.0
     *
     * @package WordPress
     * @abstract
     */
    #[\AllowDynamicProperties]
    class Walker
    {
        /**
         * What the class handles.
         *
         * @since 2.1.0
         * @var string
         */
        public $tree_type;
        /**
         * DB fields to use.
         *
         * @since 2.1.0
         * @var string[]
         */
        public $db_fields;
        /**
         * Max number of pages walked by the paged walker.
         *
         * @since 2.7.0
         * @var int
         */
        public $max_pages = 1;
        /**
         * Whether the current element has children or not.
         *
         * To be used in start_el().
         *
         * @since 4.0.0
         * @var bool
         */
        public $has_children;
        /**
         * Starts the list before the elements are added.
         *
         * The $args parameter holds additional values that may be used with the child
         * class methods. This method is called at the start of the output list.
         *
         * @since 2.1.0
         * @abstract
         *
         * @param string $output Used to append additional content (passed by reference).
         * @param int    $depth  Depth of the item.
         * @param array  $args   An array of additional arguments.
         */
        public function start_lvl(&$output, $depth = 0, $args = array())
        {
        }
        /**
         * Ends the list of after the elements are added.
         *
         * The $args parameter holds additional values that may be used with the child
         * class methods. This method finishes the list at the end of output of the elements.
         *
         * @since 2.1.0
         * @abstract
         *
         * @param string $output Used to append additional content (passed by reference).
         * @param int    $depth  Depth of the item.
         * @param array  $args   An array of additional arguments.
         */
        public function end_lvl(&$output, $depth = 0, $args = array())
        {
        }
        /**
         * Starts the element output.
         *
         * The $args parameter holds additional values that may be used with the child
         * class methods. Also includes the element output.
         *
         * @since 2.1.0
         * @since 5.9.0 Renamed `$object` (a PHP reserved keyword) to `$data_object` for PHP 8 named parameter support.
         * @abstract
         *
         * @param string $output            Used to append additional content (passed by reference).
         * @param object $data_object       The data object.
         * @param int    $depth             Depth of the item.
         * @param array  $args              An array of additional arguments.
         * @param int    $current_object_id Optional. ID of the current item. Default 0.
         */
        public function start_el(&$output, $data_object, $depth = 0, $args = array(), $current_object_id = 0)
        {
        }
        /**
         * Ends the element output, if needed.
         *
         * The $args parameter holds additional values that may be used with the child class methods.
         *
         * @since 2.1.0
         * @since 5.9.0 Renamed `$object` (a PHP reserved keyword) to `$data_object` for PHP 8 named parameter support.
         * @abstract
         *
         * @param string $output      Used to append additional content (passed by reference).
         * @param object $data_object The data object.
         * @param int    $depth       Depth of the item.
         * @param array  $args        An array of additional arguments.
         */
        public function end_el(&$output, $data_object, $depth = 0, $args = array())
        {
        }
        /**
         * Traverses elements to create list from elements.
         *
         * Display one element if the element doesn't have any children otherwise,
         * display the element and its children. Will only traverse up to the max
         * depth and no ignore elements under that depth. It is possible to set the
         * max depth to include all depths, see walk() method.
         *
         * This method should not be called directly, use the walk() method instead.
         *
         * @since 2.5.0
         *
         * @param object $element           Data object.
         * @param array  $children_elements List of elements to continue traversing (passed by reference).
         * @param int    $max_depth         Max depth to traverse.
         * @param int    $depth             Depth of current element.
         * @param array  $args              An array of arguments.
         * @param string $output            Used to append additional content (passed by reference).
         * @phpstan-return void
         */
        public function display_element($element, &$children_elements, $max_depth, $depth, $args, &$output)
        {
        }
        /**
         * Displays array of elements hierarchically.
         *
         * Does not assume any existing order of elements.
         *
         * $max_depth = -1 means flatly display every element.
         * $max_depth = 0 means display all levels.
         * $max_depth > 0 specifies the number of display levels.
         *
         * @since 2.1.0
         * @since 5.3.0 Formalized the existing `...$args` parameter by adding it
         *              to the function signature.
         *
         * @param array $elements  An array of elements.
         * @param int   $max_depth The maximum hierarchical depth.
         * @param mixed ...$args   Optional additional arguments.
         * @return string The hierarchical item output.
         */
        public function walk($elements, $max_depth, ...$args)
        {
        }
        /**
         * Produces a page of nested elements.
         *
         * Given an array of hierarchical elements, the maximum depth, a specific page number,
         * and number of elements per page, this function first determines all top level root elements
         * belonging to that page, then lists them and all of their children in hierarchical order.
         *
         * $max_depth = 0 means display all levels.
         * $max_depth > 0 specifies the number of display levels.
         *
         * @since 2.7.0
         * @since 5.3.0 Formalized the existing `...$args` parameter by adding it
         *              to the function signature.
         *
         * @param array $elements  An array of elements.
         * @param int   $max_depth The maximum hierarchical depth.
         * @param int   $page_num  The specific page number, beginning with 1.
         * @param int   $per_page  Number of elements per page.
         * @param mixed ...$args   Optional additional arguments.
         * @return string XHTML of the specified page of elements.
         */
        public function paged_walk($elements, $max_depth, $page_num, $per_page, ...$args)
        {
        }
        /**
         * Calculates the total number of root elements.
         *
         * @since 2.7.0
         *
         * @param array $elements Elements to list.
         * @return int Number of root elements.
         */
        public function get_number_of_root_elements($elements)
        {
        }
        /**
         * Unsets all the children for a given top level element.
         *
         * @since 2.7.0
         *
         * @param object $element           The top level element.
         * @param array  $children_elements The children elements.
         * @phpstan-return void
         */
        public function unset_children($element, &$children_elements)
        {
        }
    }
    /**
     * Core walker class to output an unordered list of category checkbox input elements.
     *
     * @since 2.5.1
     *
     * @see Walker
     * @see wp_category_checklist()
     * @see wp_terms_checklist()
     */
    class Walker_Category_Checklist extends \Walker
    {
        public $tree_type = 'category';
        public $db_fields = array('parent' => 'parent', 'id' => 'term_id');
        /**
         * Starts the list before the elements are added.
         *
         * @see Walker:start_lvl()
         *
         * @since 2.5.1
         *
         * @param string $output Used to append additional content (passed by reference).
         * @param int    $depth  Depth of category. Used for tab indentation.
         * @param array  $args   An array of arguments. See {@see wp_terms_checklist()}.
         * @phpstan-param array{
         *   descendants_and_self?: int,
         *   selected_cats?: int[],
         *   popular_cats?: int[],
         *   walker?: Walker,
         *   taxonomy?: string,
         *   checked_ontop?: bool,
         *   echo?: bool,
         * } $args See wp_terms_checklist()
         */
        public function start_lvl(&$output, $depth = 0, $args = array())
        {
        }
        /**
         * Ends the list of after the elements are added.
         *
         * @see Walker::end_lvl()
         *
         * @since 2.5.1
         *
         * @param string $output Used to append additional content (passed by reference).
         * @param int    $depth  Depth of category. Used for tab indentation.
         * @param array  $args   An array of arguments. See {@see wp_terms_checklist()}.
         * @phpstan-param array{
         *   descendants_and_self?: int,
         *   selected_cats?: int[],
         *   popular_cats?: int[],
         *   walker?: Walker,
         *   taxonomy?: string,
         *   checked_ontop?: bool,
         *   echo?: bool,
         * } $args See wp_terms_checklist()
         */
        public function end_lvl(&$output, $depth = 0, $args = array())
        {
        }
        /**
         * Start the element output.
         *
         * @see Walker::start_el()
         *
         * @since 2.5.1
         * @since 5.9.0 Renamed `$category` to `$data_object` and `$id` to `$current_object_id`
         *              to match parent class for PHP 8 named parameter support.
         *
         * @param string  $output            Used to append additional content (passed by reference).
         * @param WP_Term $data_object       The current term object.
         * @param int     $depth             Depth of the term in reference to parents. Default 0.
         * @param array   $args              An array of arguments. See {@see wp_terms_checklist()}.
         * @param int     $current_object_id Optional. ID of the current term. Default 0.
         * @phpstan-param array{
         *   descendants_and_self?: int,
         *   selected_cats?: int[],
         *   popular_cats?: int[],
         *   walker?: Walker,
         *   taxonomy?: string,
         *   checked_ontop?: bool,
         *   echo?: bool,
         * } $args See wp_terms_checklist()
         */
        public function start_el(&$output, $data_object, $depth = 0, $args = array(), $current_object_id = 0)
        {
        }
        /**
         * Ends the element output, if needed.
         *
         * @see Walker::end_el()
         *
         * @since 2.5.1
         * @since 5.9.0 Renamed `$category` to `$data_object` to match parent class for PHP 8 named parameter support.
         *
         * @param string  $output      Used to append additional content (passed by reference).
         * @param WP_Term $data_object The current term object.
         * @param int     $depth       Depth of the term in reference to parents. Default 0.
         * @param array   $args        An array of arguments. See {@see wp_terms_checklist()}.
         * @phpstan-param array{
         *   descendants_and_self?: int,
         *   selected_cats?: int[],
         *   popular_cats?: int[],
         *   walker?: Walker,
         *   taxonomy?: string,
         *   checked_ontop?: bool,
         *   echo?: bool,
         * } $args See wp_terms_checklist()
         */
        public function end_el(&$output, $data_object, $depth = 0, $args = array())
        {
        }
    }
    /**
     * Core class used to implement an HTML list of nav menu items.
     *
     * @since 3.0.0
     *
     * @see Walker
     */
    class Walker_Nav_Menu extends \Walker
    {
        /**
         * What the class handles.
         *
         * @since 3.0.0
         * @var string
         *
         * @see Walker::$tree_type
         */
        public $tree_type = array('post_type', 'taxonomy', 'custom');
        /**
         * Database fields to use.
         *
         * @since 3.0.0
         * @todo Decouple this.
         * @var string[]
         *
         * @see Walker::$db_fields
         */
        public $db_fields = array('parent' => 'menu_item_parent', 'id' => 'db_id');
        /**
         * Starts the list before the elements are added.
         *
         * @since 3.0.0
         *
         * @see Walker::start_lvl()
         *
         * @param string   $output Used to append additional content (passed by reference).
         * @param int      $depth  Depth of menu item. Used for padding.
         * @param stdClass $args   An object of wp_nav_menu() arguments.
         */
        public function start_lvl(&$output, $depth = 0, $args = \null)
        {
        }
        /**
         * Ends the list of after the elements are added.
         *
         * @since 3.0.0
         *
         * @see Walker::end_lvl()
         *
         * @param string   $output Used to append additional content (passed by reference).
         * @param int      $depth  Depth of menu item. Used for padding.
         * @param stdClass $args   An object of wp_nav_menu() arguments.
         */
        public function end_lvl(&$output, $depth = 0, $args = \null)
        {
        }
        /**
         * Starts the element output.
         *
         * @since 3.0.0
         * @since 4.4.0 The {@see 'nav_menu_item_args'} filter was added.
         * @since 5.9.0 Renamed `$item` to `$data_object` and `$id` to `$current_object_id`
         *              to match parent class for PHP 8 named parameter support.
         * @since 6.7.0 Removed redundant title attributes.
         *
         * @see Walker::start_el()
         *
         * @param string   $output            Used to append additional content (passed by reference).
         * @param WP_Post  $data_object       Menu item data object.
         * @param int      $depth             Depth of menu item. Used for padding.
         * @param stdClass $args              An object of wp_nav_menu() arguments.
         * @param int      $current_object_id Optional. ID of the current menu item. Default 0.
         */
        public function start_el(&$output, $data_object, $depth = 0, $args = \null, $current_object_id = 0)
        {
        }
        /**
         * Ends the element output, if needed.
         *
         * @since 3.0.0
         * @since 5.9.0 Renamed `$item` to `$data_object` to match parent class for PHP 8 named parameter support.
         *
         * @see Walker::end_el()
         *
         * @param string   $output      Used to append additional content (passed by reference).
         * @param WP_Post  $data_object Menu item data object. Not used.
         * @param int      $depth       Depth of page. Not Used.
         * @param stdClass $args        An object of wp_nav_menu() arguments.
         */
        public function end_el(&$output, $data_object, $depth = 0, $args = \null)
        {
        }
        /**
         * Builds a string of HTML attributes from an array of key/value pairs.
         * Empty values are ignored.
         *
         * @since 6.3.0
         *
         * @param  array $atts Optional. An array of HTML attribute key/value pairs. Default empty array.
         * @return string A string of HTML attributes.
         */
        protected function build_atts($atts = array())
        {
        }
    }
    /**
     * Create HTML list of nav menu input items.
     *
     * @since 3.0.0
     * @uses Walker_Nav_Menu
     */
    class Walker_Nav_Menu_Checklist extends \Walker_Nav_Menu
    {
        /**
         * @param array|false $fields Database fields to use.
         */
        public function __construct($fields = \false)
        {
        }
        /**
         * Starts the list before the elements are added.
         *
         * @see Walker_Nav_Menu::start_lvl()
         *
         * @since 3.0.0
         *
         * @param string   $output Used to append additional content (passed by reference).
         * @param int      $depth  Depth of page. Used for padding.
         * @param stdClass $args   Not used.
         */
        public function start_lvl(&$output, $depth = 0, $args = \null)
        {
        }
        /**
         * Ends the list of after the elements are added.
         *
         * @see Walker_Nav_Menu::end_lvl()
         *
         * @since 3.0.0
         *
         * @param string   $output Used to append additional content (passed by reference).
         * @param int      $depth  Depth of page. Used for padding.
         * @param stdClass $args   Not used.
         */
        public function end_lvl(&$output, $depth = 0, $args = \null)
        {
        }
        /**
         * Start the element output.
         *
         * @see Walker_Nav_Menu::start_el()
         *
         * @since 3.0.0
         * @since 5.9.0 Renamed `$item` to `$data_object` and `$id` to `$current_object_id`
         *              to match parent class for PHP 8 named parameter support.
         *
         * @global int        $_nav_menu_placeholder
         * @global int|string $nav_menu_selected_id
         *
         * @param string   $output            Used to append additional content (passed by reference).
         * @param WP_Post  $data_object       Menu item data object.
         * @param int      $depth             Depth of menu item. Used for padding.
         * @param stdClass $args              Not used.
         * @param int      $current_object_id Optional. ID of the current menu item. Default 0.
         */
        public function start_el(&$output, $data_object, $depth = 0, $args = \null, $current_object_id = 0)
        {
        }
    }
    /**
     * Create HTML list of nav menu input items.
     *
     * @since 3.0.0
     *
     * @see Walker_Nav_Menu
     */
    class Walker_Nav_Menu_Edit extends \Walker_Nav_Menu
    {
        /**
         * Starts the list before the elements are added.
         *
         * @see Walker_Nav_Menu::start_lvl()
         *
         * @since 3.0.0
         *
         * @param string   $output Passed by reference.
         * @param int      $depth  Depth of menu item. Used for padding.
         * @param stdClass $args   Not used.
         */
        public function start_lvl(&$output, $depth = 0, $args = \null)
        {
        }
        /**
         * Ends the list of after the elements are added.
         *
         * @see Walker_Nav_Menu::end_lvl()
         *
         * @since 3.0.0
         *
         * @param string   $output Passed by reference.
         * @param int      $depth  Depth of menu item. Used for padding.
         * @param stdClass $args   Not used.
         */
        public function end_lvl(&$output, $depth = 0, $args = \null)
        {
        }
        /**
         * Start the element output.
         *
         * @see Walker_Nav_Menu::start_el()
         * @since 3.0.0
         * @since 5.9.0 Renamed `$item` to `$data_object` and `$id` to `$current_object_id`
         *              to match parent class for PHP 8 named parameter support.
         *
         * @global int $_wp_nav_menu_max_depth
         *
         * @param string   $output            Used to append additional content (passed by reference).
         * @param WP_Post  $data_object       Menu item data object.
         * @param int      $depth             Depth of menu item. Used for padding.
         * @param stdClass $args              Not used.
         * @param int      $current_object_id Optional. ID of the current menu item. Default 0.
         */
        public function start_el(&$output, $data_object, $depth = 0, $args = \null, $current_object_id = 0)
        {
        }
    }
    /**
     * Upgrader Skin for Ajax WordPress upgrades.
     *
     * This skin is designed to be used for Ajax updates.
     *
     * @since 4.6.0
     *
     * @see Automatic_Upgrader_Skin
     */
    class WP_Ajax_Upgrader_Skin extends \Automatic_Upgrader_Skin
    {
        /**
         * Plugin info.
         *
         * The Plugin_Upgrader::bulk_upgrade() method will fill this in
         * with info retrieved from the get_plugin_data() function.
         *
         * @var array Plugin data. Values will be empty if not supplied by the plugin.
         */
        public $plugin_info = array();
        /**
         * Theme info.
         *
         * The Theme_Upgrader::bulk_upgrade() method will fill this in
         * with info retrieved from the Theme_Upgrader::theme_info() method,
         * which in turn calls the wp_get_theme() function.
         *
         * @var WP_Theme|false The theme's info object, or false.
         */
        public $theme_info = \false;
        /**
         * Holds the WP_Error object.
         *
         * @since 4.6.0
         *
         * @var null|WP_Error
         */
        protected $errors = \null;
        /**
         * Constructor.
         *
         * Sets up the WordPress Ajax upgrader skin.
         *
         * @since 4.6.0
         *
         * @see WP_Upgrader_Skin::__construct()
         *
         * @param array $args Optional. The WordPress Ajax upgrader skin arguments to
         *                    override default options. See WP_Upgrader_Skin::__construct().
         *                    Default empty array.
         */
        public function __construct($args = array())
        {
        }
        /**
         * Retrieves the list of errors.
         *
         * @since 4.6.0
         *
         * @return WP_Error Errors during an upgrade.
         */
        public function get_errors()
        {
        }
        /**
         * Retrieves a string for error messages.
         *
         * @since 4.6.0
         *
         * @return string Error messages during an upgrade.
         */
        public function get_error_messages()
        {
        }
        /**
         * Stores an error message about the upgrade.
         *
         * @since 4.6.0
         * @since 5.3.0 Formalized the existing `...$args` parameter by adding it
         *              to the function signature.
         *
         * @param string|WP_Error $errors  Errors.
         * @param mixed           ...$args Optional text replacements.
         */
        public function error($errors, ...$args)
        {
        }
        /**
         * Stores a message about the upgrade.
         *
         * @since 4.6.0
         * @since 5.3.0 Formalized the existing `...$args` parameter by adding it
         *              to the function signature.
         * @since 5.9.0 Renamed `$data` to `$feedback` for PHP 8 named parameter support.
         *
         * @param string|array|WP_Error $feedback Message data.
         * @param mixed                 ...$args  Optional text replacements.
         */
        public function feedback($feedback, ...$args)
        {
        }
    }
    /**
     * Base class for displaying a list of items in an ajaxified HTML table.
     *
     * @since 3.1.0
     */
    #[\AllowDynamicProperties]
    class WP_List_Table
    {
        /**
         * The current list of items.
         *
         * @since 3.1.0
         * @var array
         */
        public $items;
        /**
         * Various information about the current table.
         *
         * @since 3.1.0
         * @var array
         */
        protected $_args;
        /**
         * Various information needed for displaying the pagination.
         *
         * @since 3.1.0
         * @var array
         */
        protected $_pagination_args = array();
        /**
         * The current screen.
         *
         * @since 3.1.0
         * @var WP_Screen
         */
        protected $screen;
        /**
         * The view switcher modes.
         *
         * @since 4.1.0
         * @var array
         */
        protected $modes = array();
        /**
         * Stores the value returned by ->get_column_info().
         *
         * @since 4.1.0
         * @var array
         */
        protected $_column_headers;
        /**
         * {@internal Missing Summary}
         *
         * @var array
         */
        protected $compat_fields = array('_args', '_pagination_args', 'screen', '_actions', '_pagination');
        /**
         * {@internal Missing Summary}
         *
         * @var array
         */
        protected $compat_methods = array('set_pagination_args', 'get_views', 'get_bulk_actions', 'bulk_actions', 'row_actions', 'months_dropdown', 'view_switcher', 'comments_bubble', 'get_items_per_page', 'pagination', 'get_sortable_columns', 'get_column_info', 'get_table_classes', 'display_tablenav', 'extra_tablenav', 'single_row_columns');
        /**
         * Constructor.
         *
         * The child class should call this constructor from its own constructor to override
         * the default $args.
         *
         * @since 3.1.0
         *
         * @param array|string $args {
         *     Array or string of arguments.
         *
         *     @type string $plural   Plural value used for labels and the objects being listed.
         *                            This affects things such as CSS class-names and nonces used
         *                            in the list table, e.g. 'posts'. Default empty.
         *     @type string $singular Singular label for an object being listed, e.g. 'post'.
         *                            Default empty
         *     @type bool   $ajax     Whether the list table supports Ajax. This includes loading
         *                            and sorting data, for example. If true, the class will call
         *                            the _js_vars() method in the footer to provide variables
         *                            to any scripts handling Ajax events. Default false.
         *     @type string $screen   String containing the hook name used to determine the current
         *                            screen. If left null, the current screen will be automatically set.
         *                            Default null.
         * }
         * @phpstan-param array{
         *   plural?: string,
         *   singular?: string,
         *   ajax?: bool,
         *   screen?: string,
         * } $args
         */
        public function __construct($args = array())
        {
        }
        /**
         * Makes private properties readable for backward compatibility.
         *
         * @since 4.0.0
         * @since 6.4.0 Getting a dynamic property is deprecated.
         *
         * @param string $name Property to get.
         * @return mixed Property.
         */
        public function __get($name)
        {
        }
        /**
         * Makes private properties settable for backward compatibility.
         *
         * @since 4.0.0
         * @since 6.4.0 Setting a dynamic property is deprecated.
         *
         * @param string $name  Property to check if set.
         * @param mixed  $value Property value.
         * @phpstan-return void
         */
        public function __set($name, $value)
        {
        }
        /**
         * Makes private properties checkable for backward compatibility.
         *
         * @since 4.0.0
         * @since 6.4.0 Checking a dynamic property is deprecated.
         *
         * @param string $name Property to check if set.
         * @return bool Whether the property is a back-compat property and it is set.
         */
        public function __isset($name)
        {
        }
        /**
         * Makes private properties un-settable for backward compatibility.
         *
         * @since 4.0.0
         * @since 6.4.0 Unsetting a dynamic property is deprecated.
         *
         * @param string $name Property to unset.
         * @phpstan-return void
         */
        public function __unset($name)
        {
        }
        /**
         * Makes private/protected methods readable for backward compatibility.
         *
         * @since 4.0.0
         *
         * @param string $name      Method to call.
         * @param array  $arguments Arguments to pass when calling.
         * @return mixed|bool Return value of the callback, false otherwise.
         */
        public function __call($name, $arguments)
        {
        }
        /**
         * Checks the current user's permissions
         *
         * @since 3.1.0
         * @abstract
         */
        public function ajax_user_can()
        {
        }
        /**
         * Prepares the list of items for displaying.
         *
         * @uses WP_List_Table::set_pagination_args()
         *
         * @since 3.1.0
         * @abstract
         */
        public function prepare_items()
        {
        }
        /**
         * Sets all the necessary pagination arguments.
         *
         * @since 3.1.0
         *
         * @param array|string $args Array or string of arguments with information about the pagination.
         * @phpstan-param array{total_items?: int, total_pages?: int, per_page?: int} $args
         * @phpstan-return void
         */
        protected function set_pagination_args($args)
        {
        }
        /**
         * Access the pagination args.
         *
         * @since 3.1.0
         *
         * @param string $key Pagination argument to retrieve. Common values include 'total_items',
         *                    'total_pages', 'per_page', or 'infinite_scroll'.
         * @return int Number of items that correspond to the given pagination argument.
         */
        public function get_pagination_arg($key)
        {
        }
        /**
         * Determines whether the table has items to display or not
         *
         * @since 3.1.0
         *
         * @return bool
         */
        public function has_items()
        {
        }
        /**
         * Message to be displayed when there are no items
         *
         * @since 3.1.0
         */
        public function no_items()
        {
        }
        /**
         * Displays the search box.
         *
         * @since 3.1.0
         *
         * @param string $text     The 'submit' button label.
         * @param string $input_id ID attribute value for the search input field.
         * @phpstan-return void
         */
        public function search_box($text, $input_id)
        {
        }
        /**
         * Generates views links.
         *
         * @since 6.1.0
         *
         * @param array $link_data {
         *     An array of link data.
         *
         *     @type string $url     The link URL.
         *     @type string $label   The link label.
         *     @type bool   $current Optional. Whether this is the currently selected view.
         * }
         * @return string[] An array of link markup. Keys match the `$link_data` input array.
         * @phpstan-param array{
         *   url?: string,
         *   label?: string,
         *   current?: bool,
         * } $link_data
         */
        protected function get_views_links($link_data = array())
        {
        }
        /**
         * Gets the list of views available on this table.
         *
         * The format is an associative array:
         * - `'id' => 'link'`
         *
         * @since 3.1.0
         *
         * @return array
         */
        protected function get_views()
        {
        }
        /**
         * Displays the list of views available on this table.
         *
         * @since 3.1.0
         * @phpstan-return void
         */
        public function views()
        {
        }
        /**
         * Retrieves the list of bulk actions available for this table.
         *
         * The format is an associative array where each element represents either a top level option value and label, or
         * an array representing an optgroup and its options.
         *
         * For a standard option, the array element key is the field value and the array element value is the field label.
         *
         * For an optgroup, the array element key is the label and the array element value is an associative array of
         * options as above.
         *
         * Example:
         *
         *     [
         *         'edit'         => 'Edit',
         *         'delete'       => 'Delete',
         *         'Change State' => [
         *             'feature' => 'Featured',
         *             'sale'    => 'On Sale',
         *         ]
         *     ]
         *
         * @since 3.1.0
         * @since 5.6.0 A bulk action can now contain an array of options in order to create an optgroup.
         *
         * @return array
         */
        protected function get_bulk_actions()
        {
        }
        /**
         * Displays the bulk actions dropdown.
         *
         * @since 3.1.0
         *
         * @param string $which The location of the bulk actions: Either 'top' or 'bottom'.
         *                      This is designated as optional for backward compatibility.
         * @phpstan-param 'top'|'bottom' $which
         * @phpstan-return void
         */
        protected function bulk_actions($which = '')
        {
        }
        /**
         * Gets the current action selected from the bulk actions dropdown.
         *
         * @since 3.1.0
         *
         * @return string|false The action name. False if no action was selected.
         */
        public function current_action()
        {
        }
        /**
         * Generates the required HTML for a list of row action links.
         *
         * @since 3.1.0
         *
         * @param string[] $actions        An array of action links.
         * @param bool     $always_visible Whether the actions should be always visible.
         * @return string The HTML for the row actions.
         */
        protected function row_actions($actions, $always_visible = \false)
        {
        }
        /**
         * Displays a dropdown for filtering items in the list table by month.
         *
         * @since 3.1.0
         *
         * @global wpdb      $wpdb      WordPress database abstraction object.
         * @global WP_Locale $wp_locale WordPress date and time locale object.
         *
         * @param string $post_type The post type.
         * @phpstan-return void
         */
        protected function months_dropdown($post_type)
        {
        }
        /**
         * Displays a view switcher.
         *
         * @since 3.1.0
         *
         * @param string $current_mode
         */
        protected function view_switcher($current_mode)
        {
        }
        /**
         * Displays a comment count bubble.
         *
         * @since 3.1.0
         *
         * @param int $post_id          The post ID.
         * @param int $pending_comments Number of pending comments.
         */
        protected function comments_bubble($post_id, $pending_comments)
        {
        }
        /**
         * Gets the current page number.
         *
         * @since 3.1.0
         *
         * @return int
         */
        public function get_pagenum()
        {
        }
        /**
         * Gets the number of items to display on a single page.
         *
         * @since 3.1.0
         *
         * @param string $option        User option name.
         * @param int    $default_value Optional. The number of items to display. Default 20.
         * @return int
         */
        protected function get_items_per_page($option, $default_value = 20)
        {
        }
        /**
         * Displays the pagination.
         *
         * @since 3.1.0
         *
         * @param string $which The location of the pagination: Either 'top' or 'bottom'.
         * @phpstan-param 'top'|'bottom' $which
         * @phpstan-return void
         */
        protected function pagination($which)
        {
        }
        /**
         * Gets a list of columns.
         *
         * The format is:
         * - `'internal-name' => 'Title'`
         *
         * @since 3.1.0
         * @abstract
         *
         * @return array
         */
        public function get_columns()
        {
        }
        /**
         * Gets a list of sortable columns.
         *
         * The format is:
         * - `'internal-name' => 'orderby'`
         * - `'internal-name' => array( 'orderby', bool, 'abbr', 'orderby-text', 'initially-sorted-column-order' )` -
         * - `'internal-name' => array( 'orderby', 'asc' )` - The second element sets the initial sorting order.
         * - `'internal-name' => array( 'orderby', true )`  - The second element makes the initial order descending.
         *
         * In the second format, passing true as second parameter will make the initial
         * sorting order be descending. Following parameters add a short column name to
         * be used as 'abbr' attribute, a translatable string for the current sorting,
         * and the initial order for the initial sorted column, 'asc' or 'desc' (default: false).
         *
         * @since 3.1.0
         * @since 6.3.0 Added 'abbr', 'orderby-text' and 'initially-sorted-column-order'.
         *
         * @return array
         */
        protected function get_sortable_columns()
        {
        }
        /**
         * Gets the name of the default primary column.
         *
         * @since 4.3.0
         *
         * @return string Name of the default primary column, in this case, an empty string.
         */
        protected function get_default_primary_column_name()
        {
        }
        /**
         * Gets the name of the primary column.
         *
         * Public wrapper for WP_List_Table::get_default_primary_column_name().
         *
         * @since 4.4.0
         *
         * @return string Name of the default primary column.
         */
        public function get_primary_column()
        {
        }
        /**
         * Gets the name of the primary column.
         *
         * @since 4.3.0
         *
         * @return string The name of the primary column.
         */
        protected function get_primary_column_name()
        {
        }
        /**
         * Gets a list of all, hidden, and sortable columns, with filter applied.
         *
         * @since 3.1.0
         *
         * @return array
         */
        protected function get_column_info()
        {
        }
        /**
         * Returns the number of visible columns.
         *
         * @since 3.1.0
         *
         * @return int
         */
        public function get_column_count()
        {
        }
        /**
         * Prints column headers, accounting for hidden and sortable columns.
         *
         * @since 3.1.0
         *
         * @param bool $with_id Whether to set the ID attribute or not
         */
        public function print_column_headers($with_id = \true)
        {
        }
        /**
         * Print a table description with information about current sorting and order.
         *
         * For the table initial view, information about initial orderby and order
         * should be provided via get_sortable_columns().
         *
         * @since 6.3.0
         * @access public
         * @phpstan-return void
         */
        public function print_table_description()
        {
        }
        /**
         * Displays the table.
         *
         * @since 3.1.0
         */
        public function display()
        {
        }
        /**
         * Gets a list of CSS classes for the WP_List_Table table tag.
         *
         * @since 3.1.0
         *
         * @return string[] Array of CSS classes for the table tag.
         */
        protected function get_table_classes()
        {
        }
        /**
         * Generates the table navigation above or below the table
         *
         * @since 3.1.0
         * @param string $which The location of the navigation: Either 'top' or 'bottom'.
         * @phpstan-param 'top'|'bottom' $which
         */
        protected function display_tablenav($which)
        {
        }
        /**
         * Displays extra controls between bulk actions and pagination.
         *
         * @since 3.1.0
         *
         * @param string $which
         */
        protected function extra_tablenav($which)
        {
        }
        /**
         * Generates the tbody element for the list table.
         *
         * @since 3.1.0
         */
        public function display_rows_or_placeholder()
        {
        }
        /**
         * Generates the list table rows.
         *
         * @since 3.1.0
         */
        public function display_rows()
        {
        }
        /**
         * Generates content for a single row of the table.
         *
         * @since 3.1.0
         *
         * @param object|array $item The current item
         */
        public function single_row($item)
        {
        }
        /**
         * @param object|array $item
         * @param string $column_name
         */
        protected function column_default($item, $column_name)
        {
        }
        /**
         * @param object|array $item
         */
        protected function column_cb($item)
        {
        }
        /**
         * Generates the columns for a single row of the table.
         *
         * @since 3.1.0
         *
         * @param object|array $item The current item.
         */
        protected function single_row_columns($item)
        {
        }
        /**
         * Generates and display row actions links for the list table.
         *
         * @since 4.3.0
         *
         * @param object|array $item        The item being acted upon.
         * @param string       $column_name Current column name.
         * @param string       $primary     Primary column name.
         * @return string The row actions HTML, or an empty string
         *                if the current column is not the primary column.
         */
        protected function handle_row_actions($item, $column_name, $primary)
        {
        }
        /**
         * Handles an incoming ajax request (called from admin-ajax.php)
         *
         * @since 3.1.0
         * @phpstan-return never
         */
        public function ajax_response()
        {
        }
        /**
         * Sends required variables to JavaScript land.
         *
         * @since 3.1.0
         */
        public function _js_vars()
        {
        }
    }
    /**
     * Class for displaying the list of application password items.
     *
     * @since 5.6.0
     *
     * @see WP_List_Table
     */
    class WP_Application_Passwords_List_Table extends \WP_List_Table
    {
        /**
         * Gets the list of columns.
         *
         * @since 5.6.0
         *
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         * Prepares the list of items for displaying.
         *
         * @since 5.6.0
         *
         * @global int $user_id User ID.
         */
        public function prepare_items()
        {
        }
        /**
         * Handles the name column output.
         *
         * @since 5.6.0
         *
         * @param array $item The current application password item.
         */
        public function column_name($item)
        {
        }
        /**
         * Handles the created column output.
         *
         * @since 5.6.0
         *
         * @param array $item The current application password item.
         */
        public function column_created($item)
        {
        }
        /**
         * Handles the last used column output.
         *
         * @since 5.6.0
         *
         * @param array $item The current application password item.
         */
        public function column_last_used($item)
        {
        }
        /**
         * Handles the last ip column output.
         *
         * @since 5.6.0
         *
         * @param array $item The current application password item.
         */
        public function column_last_ip($item)
        {
        }
        /**
         * Handles the revoke column output.
         *
         * @since 5.6.0
         *
         * @param array $item The current application password item.
         */
        public function column_revoke($item)
        {
        }
        /**
         * Generates content for a single row of the table
         *
         * @since 5.6.0
         *
         * @param array  $item        The current item.
         * @param string $column_name The current column name.
         */
        protected function column_default($item, $column_name)
        {
        }
        /**
         * Generates custom table navigation to prevent conflicting nonces.
         *
         * @since 5.6.0
         *
         * @param string $which The location of the bulk actions: Either 'top' or 'bottom'.
         * @phpstan-param 'top'|'bottom' $which
         */
        protected function display_tablenav($which)
        {
        }
        /**
         * Generates content for a single row of the table.
         *
         * @since 5.6.0
         *
         * @param array $item The current item.
         */
        public function single_row($item)
        {
        }
        /**
         * Gets the name of the default primary column.
         *
         * @since 5.6.0
         *
         * @return string Name of the default primary column, in this case, 'name'.
         */
        protected function get_default_primary_column_name()
        {
        }
        /**
         * Prints the JavaScript template for the new row item.
         *
         * @since 5.6.0
         */
        public function print_js_template_row()
        {
        }
    }
    /**
     * Core class used for handling automatic background updates.
     *
     * @since 3.7.0
     * @since 4.6.0 Moved to its own file from wp-admin/includes/class-wp-upgrader.php.
     */
    #[\AllowDynamicProperties]
    class WP_Automatic_Updater
    {
        /**
         * Tracks update results during processing.
         *
         * @var array
         */
        protected $update_results = array();
        /**
         * Determines whether the entire automatic updater is disabled.
         *
         * @since 3.7.0
         *
         * @return bool True if the automatic updater is disabled, false otherwise.
         */
        public function is_disabled()
        {
        }
        /**
         * Checks whether access to a given directory is allowed.
         *
         * This is used when detecting version control checkouts. Takes into account
         * the PHP `open_basedir` restrictions, so that WordPress does not try to access
         * directories it is not allowed to.
         *
         * @since 6.2.0
         *
         * @param string $dir The directory to check.
         * @return bool True if access to the directory is allowed, false otherwise.
         */
        public function is_allowed_dir($dir)
        {
        }
        /**
         * Checks for version control checkouts.
         *
         * Checks for Subversion, Git, Mercurial, and Bazaar. It recursively looks up the
         * filesystem to the top of the drive, erring on the side of detecting a VCS
         * checkout somewhere.
         *
         * ABSPATH is always checked in addition to whatever `$context` is (which may be the
         * wp-content directory, for example). The underlying assumption is that if you are
         * using version control *anywhere*, then you should be making decisions for
         * how things get updated.
         *
         * @since 3.7.0
         *
         * @param string $context The filesystem path to check, in addition to ABSPATH.
         * @return bool True if a VCS checkout was discovered at `$context` or ABSPATH,
         *              or anywhere higher. False otherwise.
         */
        public function is_vcs_checkout($context)
        {
        }
        /**
         * Tests to see if we can and should update a specific item.
         *
         * @since 3.7.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $type    The type of update being checked: 'core', 'theme',
         *                        'plugin', 'translation'.
         * @param object $item    The update offer.
         * @param string $context The filesystem context (a path) against which filesystem
         *                        access and status should be checked.
         * @return bool True if the item should be updated, false otherwise.
         */
        public function should_update($type, $item, $context)
        {
        }
        /**
         * Notifies an administrator of a core update.
         *
         * @since 3.7.0
         *
         * @param object $item The update offer.
         * @return bool True if the site administrator is notified of a core update,
         *              false otherwise.
         */
        protected function send_core_update_notification_email($item)
        {
        }
        /**
         * Updates an item, if appropriate.
         *
         * @since 3.7.0
         *
         * @param string $type The type of update being checked: 'core', 'theme', 'plugin', 'translation'.
         * @param object $item The update offer.
         * @return null|WP_Error
         */
        public function update($type, $item)
        {
        }
        /**
         * Kicks off the background update process, looping through all pending updates.
         *
         * @since 3.7.0
         * @phpstan-return void
         */
        public function run()
        {
        }
        /**
         * Checks whether to send an email and avoid processing future updates after
         * attempting a core update.
         *
         * @since 3.7.0
         *
         * @param object $update_result The result of the core update. Includes the update offer and result.
         * @phpstan-return void
         */
        protected function after_core_update($update_result)
        {
        }
        /**
         * Sends an email upon the completion or failure of a background core update.
         *
         * @since 3.7.0
         *
         * @param string $type        The type of email to send. Can be one of 'success', 'fail', 'manual', 'critical'.
         * @param object $core_update The update offer that was attempted.
         * @param mixed  $result      Optional. The result for the core update. Can be WP_Error.
         * @phpstan-return void
         */
        protected function send_email($type, $core_update, $result = \null)
        {
        }
        /**
         * Checks whether an email should be sent after attempting plugin or theme updates.
         *
         * @since 5.5.0
         *
         * @param array $update_results The results of update tasks.
         * @phpstan-return void
         */
        protected function after_plugin_theme_update($update_results)
        {
        }
        /**
         * Sends an email upon the completion or failure of a plugin or theme background update.
         *
         * @since 5.5.0
         *
         * @param string $type               The type of email to send. Can be one of 'success', 'fail', 'mixed'.
         * @param array  $successful_updates A list of updates that succeeded.
         * @param array  $failed_updates     A list of updates that failed.
         * @phpstan-return void
         */
        protected function send_plugin_theme_email($type, $successful_updates, $failed_updates)
        {
        }
        /**
         * Prepares and sends an email of a full log of background update results, useful for debugging and geekery.
         *
         * @since 3.7.0
         */
        protected function send_debug_email()
        {
        }
        /**
         * Performs a loopback request to check for potential fatal errors.
         *
         * Fatal errors cannot be detected unless maintenance mode is enabled.
         *
         * @since 6.6.0
         *
         * @global int $upgrading The Unix timestamp marking when upgrading WordPress began.
         *
         * @return bool Whether a fatal error was detected.
         */
        protected function has_fatal_error()
        {
        }
    }
    /**
     * Core class used to implement displaying comments in a list table.
     *
     * @since 3.1.0
     *
     * @see WP_List_Table
     */
    class WP_Comments_List_Table extends \WP_List_Table
    {
        public $checkbox = \true;
        public $pending_count = array();
        public $extra_items;
        /**
         * Constructor.
         *
         * @since 3.1.0
         *
         * @see WP_List_Table::__construct() for more information on default arguments.
         *
         * @global int $post_id
         *
         * @param array $args An associative array of arguments.
         */
        public function __construct($args = array())
        {
        }
        /**
         * Adds avatars to comment author names.
         *
         * @since 3.1.0
         *
         * @param string $name       Comment author name.
         * @param int    $comment_id Comment ID.
         * @return string Avatar with the user name.
         */
        public function floated_admin_avatar($name, $comment_id)
        {
        }
        /**
         * @return bool
         */
        public function ajax_user_can()
        {
        }
        /**
         * @global string $mode           List table view mode.
         * @global int    $post_id
         * @global string $comment_status
         * @global string $comment_type
         * @global string $search
         */
        public function prepare_items()
        {
        }
        /**
         * @param string $comment_status
         * @return int
         */
        public function get_per_page($comment_status = 'all')
        {
        }
        /**
         * @global string $comment_status
         */
        public function no_items()
        {
        }
        /**
         * @global int $post_id
         * @global string $comment_status
         * @global string $comment_type
         */
        protected function get_views()
        {
        }
        /**
         * @global string $comment_status
         *
         * @return array
         */
        protected function get_bulk_actions()
        {
        }
        /**
         * @global string $comment_status
         * @global string $comment_type
         *
         * @param string $which
         */
        protected function extra_tablenav($which)
        {
        }
        /**
         * @return string|false
         */
        public function current_action()
        {
        }
        /**
         * @global int $post_id
         *
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         * Displays a comment type drop-down for filtering on the Comments list table.
         *
         * @since 5.5.0
         * @since 5.6.0 Renamed from `comment_status_dropdown()` to `comment_type_dropdown()`.
         *
         * @param string $comment_type The current comment type slug.
         */
        protected function comment_type_dropdown($comment_type)
        {
        }
        /**
         * @return array
         */
        protected function get_sortable_columns()
        {
        }
        /**
         * Gets the name of the default primary column.
         *
         * @since 4.3.0
         *
         * @return string Name of the default primary column, in this case, 'comment'.
         */
        protected function get_default_primary_column_name()
        {
        }
        /**
         * Displays the comments table.
         *
         * Overrides the parent display() method to render extra comments.
         *
         * @since 3.1.0
         */
        public function display()
        {
        }
        /**
         * @global WP_Post    $post    Global post object.
         * @global WP_Comment $comment Global comment object.
         *
         * @param WP_Comment $item
         */
        public function single_row($item)
        {
        }
        /**
         * Generates and displays row actions links.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$comment` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @global string $comment_status Status for the current listed comments.
         *
         * @param WP_Comment $item        The comment object.
         * @param string     $column_name Current column name.
         * @param string     $primary     Primary column name.
         * @return string Row actions output for comments. An empty string
         *                if the current column is not the primary column,
         *                or if the current user cannot edit the comment.
         */
        protected function handle_row_actions($item, $column_name, $primary)
        {
        }
        /**
         * @since 5.9.0 Renamed `$comment` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Comment $item The comment object.
         */
        public function column_cb($item)
        {
        }
        /**
         * @param WP_Comment $comment The comment object.
         */
        public function column_comment($comment)
        {
        }
        /**
         * @global string $comment_status
         *
         * @param WP_Comment $comment The comment object.
         */
        public function column_author($comment)
        {
        }
        /**
         * @param WP_Comment $comment The comment object.
         */
        public function column_date($comment)
        {
        }
        /**
         * @param WP_Comment $comment The comment object.
         * @phpstan-return void
         */
        public function column_response($comment)
        {
        }
        /**
         * @since 5.9.0 Renamed `$comment` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Comment $item        The comment object.
         * @param string     $column_name The custom column's name.
         */
        public function column_default($item, $column_name)
        {
        }
    }
    /**
     * Class WP_Community_Events.
     *
     * A client for api.wordpress.org/events.
     *
     * @since 4.8.0
     */
    #[\AllowDynamicProperties]
    class WP_Community_Events
    {
        /**
         * ID for a WordPress user account.
         *
         * @since 4.8.0
         *
         * @var int
         */
        protected $user_id = 0;
        /**
         * Stores location data for the user.
         *
         * @since 4.8.0
         *
         * @var false|array
         */
        protected $user_location = \false;
        /**
         * Constructor for WP_Community_Events.
         *
         * @since 4.8.0
         *
         * @param int        $user_id       WP user ID.
         * @param false|array $user_location {
         *     Stored location data for the user. false to pass no location.
         *
         *     @type string $description The name of the location
         *     @type string $latitude    The latitude in decimal degrees notation, without the degree
         *                               symbol. e.g.: 47.615200.
         *     @type string $longitude   The longitude in decimal degrees notation, without the degree
         *                               symbol. e.g.: -122.341100.
         *     @type string $country     The ISO 3166-1 alpha-2 country code. e.g.: BR
         * }
         * @phpstan-param false|array{
         *   description?: string,
         *   latitude?: string,
         *   longitude?: string,
         *   country?: string,
         * } $user_location
         */
        public function __construct($user_id, $user_location = \false)
        {
        }
        /**
         * Gets data about events near a particular location.
         *
         * Cached events will be immediately returned if the `user_location` property
         * is set for the current user, and cached events exist for that location.
         *
         * Otherwise, this method sends a request to the w.org Events API with location
         * data. The API will send back a recognized location based on the data, along
         * with nearby events.
         *
         * The browser's request for events is proxied with this method, rather
         * than having the browser make the request directly to api.wordpress.org,
         * because it allows results to be cached server-side and shared with other
         * users and sites in the network. This makes the process more efficient,
         * since increasing the number of visits that get cached data means users
         * don't have to wait as often; if the user's browser made the request
         * directly, it would also need to make a second request to WP in order to
         * pass the data for caching. Having WP make the request also introduces
         * the opportunity to anonymize the IP before sending it to w.org, which
         * mitigates possible privacy concerns.
         *
         * @since 4.8.0
         * @since 5.5.2 Response no longer contains formatted date field. They're added
         *              in `wp.communityEvents.populateDynamicEventFields()` now.
         *
         * @param string $location_search Optional. City name to help determine the location.
         *                                e.g., "Seattle". Default empty string.
         * @param string $timezone        Optional. Timezone to help determine the location.
         *                                Default empty string.
         * @return array|WP_Error A WP_Error on failure; an array with location and events on
         *                        success.
         */
        public function get_events($location_search = '', $timezone = '')
        {
        }
        /**
         * Builds an array of args to use in an HTTP request to the w.org Events API.
         *
         * @since 4.8.0
         *
         * @param string $search   Optional. City search string. Default empty string.
         * @param string $timezone Optional. Timezone string. Default empty string.
         * @return array The request args.
         */
        protected function get_request_args($search = '', $timezone = '')
        {
        }
        /**
         * Determines the user's actual IP address and attempts to partially
         * anonymize an IP address by converting it to a network ID.
         *
         * Geolocating the network ID usually returns a similar location as the
         * actual IP, but provides some privacy for the user.
         *
         * $_SERVER['REMOTE_ADDR'] cannot be used in all cases, such as when the user
         * is making their request through a proxy, or when the web server is behind
         * a proxy. In those cases, $_SERVER['REMOTE_ADDR'] is set to the proxy address rather
         * than the user's actual address.
         *
         * Modified from https://stackoverflow.com/a/2031935/450127, MIT license.
         * Modified from https://github.com/geertw/php-ip-anonymizer, MIT license.
         *
         * SECURITY WARNING: This function is _NOT_ intended to be used in
         * circumstances where the authenticity of the IP address matters. This does
         * _NOT_ guarantee that the returned address is valid or accurate, and it can
         * be easily spoofed.
         *
         * @since 4.8.0
         *
         * @return string|false The anonymized address on success; the given address
         *                      or false on failure.
         */
        public static function get_unsafe_client_ip()
        {
        }
        /**
         * Test if two pairs of latitude/longitude coordinates match each other.
         *
         * @since 4.8.0
         *
         * @param array $a The first pair, with indexes 'latitude' and 'longitude'.
         * @param array $b The second pair, with indexes 'latitude' and 'longitude'.
         * @return bool True if they match, false if they don't.
         */
        protected function coordinates_match($a, $b)
        {
        }
        /**
         * Generates a transient key based on user location.
         *
         * This could be reduced to a one-liner in the calling functions, but it's
         * intentionally a separate function because it's called from multiple
         * functions, and having it abstracted keeps the logic consistent and DRY,
         * which is less prone to errors.
         *
         * @since 4.8.0
         *
         * @param array $location Should contain 'latitude' and 'longitude' indexes.
         * @return string|false Transient key on success, false on failure.
         */
        protected function get_events_transient_key($location)
        {
        }
        /**
         * Caches an array of events data from the Events API.
         *
         * @since 4.8.0
         *
         * @param array     $events     Response body from the API request.
         * @param int|false $expiration Optional. Amount of time to cache the events. Defaults to false.
         * @return bool true if events were cached; false if not.
         */
        protected function cache_events($events, $expiration = \false)
        {
        }
        /**
         * Gets cached events.
         *
         * @since 4.8.0
         * @since 5.5.2 Response no longer contains formatted date field. They're added
         *              in `wp.communityEvents.populateDynamicEventFields()` now.
         *
         * @return array|false An array containing `location` and `events` items
         *                     on success, false on failure.
         */
        public function get_cached_events()
        {
        }
        /**
         * Adds formatted date and time items for each event in an API response.
         *
         * This has to be called after the data is pulled from the cache, because
         * the cached events are shared by all users. If it was called before storing
         * the cache, then all users would see the events in the localized data/time
         * of the user who triggered the cache refresh, rather than their own.
         *
         * @since 4.8.0
         * @deprecated 5.6.0 No longer used in core.
         *
         * @param array $response_body The response which contains the events.
         * @return array The response with dates and times formatted.
         */
        protected function format_event_data_time($response_body)
        {
        }
        /**
         * Prepares the event list for presentation.
         *
         * Discards expired events, and makes WordCamps "sticky." Attendees need more
         * advanced notice about WordCamps than they do for meetups, so camps should
         * appear in the list sooner. If a WordCamp is coming up, the API will "stick"
         * it in the response, even if it wouldn't otherwise appear. When that happens,
         * the event will be at the end of the list, and will need to be moved into a
         * higher position, so that it doesn't get trimmed off.
         *
         * @since 4.8.0
         * @since 4.9.7 Stick a WordCamp to the final list.
         * @since 5.5.2 Accepts and returns only the events, rather than an entire HTTP response.
         * @since 6.0.0 Decode HTML entities from the event title.
         *
         * @param array $events The events that will be prepared.
         * @return array The response body with events trimmed.
         */
        protected function trim_events(array $events)
        {
        }
        /**
         * Logs responses to Events API requests.
         *
         * @since 4.8.0
         * @deprecated 4.9.0 Use a plugin instead. See #41217 for an example.
         *
         * @param string $message A description of what occurred.
         * @param array  $details Details that provide more context for the
         *                        log entry.
         * @phpstan-return void
         */
        protected function maybe_log_events_response($message, $details)
        {
        }
    }
    /**
     * Class for providing debug data based on a users WordPress environment.
     *
     * @package WordPress
     * @subpackage Site_Health
     * @since 5.2.0
     */
    #[\AllowDynamicProperties]
    class WP_Debug_Data
    {
        /**
         * Calls all core functions to check for updates.
         *
         * @since 5.2.0
         */
        public static function check_for_updates()
        {
        }
        /**
         * Static function for generating site debug data when required.
         *
         * @since 5.2.0
         * @since 5.3.0 Added database charset, database collation,
         *              and timezone information.
         * @since 5.5.0 Added pretty permalinks support information.
         * @since 6.7.0 Modularized into separate theme-oriented methods.
         *
         * @throws ImagickException
         *
         * @return array The debug data for the site.
         */
        public static function debug_data()
        {
        }
        /**
         * Returns the value of a MySQL system variable.
         *
         * @since 5.9.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $mysql_var Name of the MySQL system variable.
         * @return string|null The variable value on success. Null if the variable does not exist.
         */
        public static function get_mysql_var($mysql_var)
        {
        }
        /**
         * Formats the information gathered for debugging, in a manner suitable for copying to a forum or support ticket.
         *
         * @since 5.2.0
         *
         * @param array  $info_array Information gathered from the `WP_Debug_Data::debug_data()` function.
         * @param string $data_type  The data type to return, either 'info' or 'debug'.
         * @return string The formatted data.
         * @phpstan-param 'info'|'debug' $data_type
         */
        public static function format($info_array, $data_type)
        {
        }
        /**
         * Fetches the total size of all the database tables for the active database user.
         *
         * @since 5.2.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @return int The size of the database, in bytes.
         */
        public static function get_database_size()
        {
        }
        /**
         * Fetches the sizes of the WordPress directories: `wordpress` (ABSPATH), `plugins`, `themes`, and `uploads`.
         * Intended to supplement the array returned by `WP_Debug_Data::debug_data()`.
         *
         * @since 5.2.0
         *
         * @return array The sizes of the directories, also the database size and total installation size.
         */
        public static function get_sizes()
        {
        }
    }
    /**
     * Base WordPress Filesystem class which Filesystem implementations extend.
     *
     * @since 2.5.0
     */
    #[\AllowDynamicProperties]
    class WP_Filesystem_Base
    {
        /**
         * Whether to display debug data for the connection.
         *
         * @since 2.5.0
         * @var bool
         */
        public $verbose = \false;
        /**
         * Cached list of local filepaths to mapped remote filepaths.
         *
         * @since 2.7.0
         * @var array
         */
        public $cache = array();
        /**
         * The Access method of the current connection, Set automatically.
         *
         * @since 2.5.0
         * @var string
         */
        public $method = '';
        /**
         * @var WP_Error
         */
        public $errors = \null;
        /**
         */
        public $options = array();
        /**
         * Returns the path on the remote filesystem of ABSPATH.
         *
         * @since 2.7.0
         *
         * @return string The location of the remote path.
         */
        public function abspath()
        {
        }
        /**
         * Returns the path on the remote filesystem of WP_CONTENT_DIR.
         *
         * @since 2.7.0
         *
         * @return string The location of the remote path.
         */
        public function wp_content_dir()
        {
        }
        /**
         * Returns the path on the remote filesystem of WP_PLUGIN_DIR.
         *
         * @since 2.7.0
         *
         * @return string The location of the remote path.
         */
        public function wp_plugins_dir()
        {
        }
        /**
         * Returns the path on the remote filesystem of the Themes Directory.
         *
         * @since 2.7.0
         *
         * @param string|false $theme Optional. The theme stylesheet or template for the directory.
         *                            Default false.
         * @return string The location of the remote path.
         */
        public function wp_themes_dir($theme = \false)
        {
        }
        /**
         * Returns the path on the remote filesystem of WP_LANG_DIR.
         *
         * @since 3.2.0
         *
         * @return string The location of the remote path.
         */
        public function wp_lang_dir()
        {
        }
        /**
         * Locates a folder on the remote filesystem.
         *
         * @since 2.5.0
         * @deprecated 2.7.0 use WP_Filesystem_Base::abspath() or WP_Filesystem_Base::wp_*_dir() instead.
         * @see WP_Filesystem_Base::abspath()
         * @see WP_Filesystem_Base::wp_content_dir()
         * @see WP_Filesystem_Base::wp_plugins_dir()
         * @see WP_Filesystem_Base::wp_themes_dir()
         * @see WP_Filesystem_Base::wp_lang_dir()
         *
         * @param string $base    Optional. The folder to start searching from. Default '.'.
         * @param bool   $verbose Optional. True to display debug information. Default false.
         * @return string The location of the remote path.
         */
        public function find_base_dir($base = '.', $verbose = \false)
        {
        }
        /**
         * Locates a folder on the remote filesystem.
         *
         * @since 2.5.0
         * @deprecated 2.7.0 use WP_Filesystem_Base::abspath() or WP_Filesystem_Base::wp_*_dir() methods instead.
         * @see WP_Filesystem_Base::abspath()
         * @see WP_Filesystem_Base::wp_content_dir()
         * @see WP_Filesystem_Base::wp_plugins_dir()
         * @see WP_Filesystem_Base::wp_themes_dir()
         * @see WP_Filesystem_Base::wp_lang_dir()
         *
         * @param string $base    Optional. The folder to start searching from. Default '.'.
         * @param bool   $verbose Optional. True to display debug information. Default false.
         * @return string The location of the remote path.
         */
        public function get_base_dir($base = '.', $verbose = \false)
        {
        }
        /**
         * Locates a folder on the remote filesystem.
         *
         * Assumes that on Windows systems, Stripping off the Drive
         * letter is OK Sanitizes \\ to / in Windows filepaths.
         *
         * @since 2.7.0
         *
         * @param string $folder the folder to locate.
         * @return string|false The location of the remote path, false on failure.
         */
        public function find_folder($folder)
        {
        }
        /**
         * Locates a folder on the remote filesystem.
         *
         * Expects Windows sanitized path.
         *
         * @since 2.7.0
         *
         * @param string $folder The folder to locate.
         * @param string $base   The folder to start searching from.
         * @param bool   $loop   If the function has recursed. Internal use only.
         * @return string|false The location of the remote path, false to cease looping.
         */
        public function search_for_folder($folder, $base = '.', $loop = \false)
        {
        }
        /**
         * Returns the *nix-style file permissions for a file.
         *
         * From the PHP documentation page for fileperms().
         *
         * @link https://www.php.net/manual/en/function.fileperms.php
         *
         * @since 2.5.0
         *
         * @param string $file String filename.
         * @return string The *nix-style representation of permissions.
         */
        public function gethchmod($file)
        {
        }
        /**
         * Gets the permissions of the specified file or filepath in their octal format.
         *
         * @since 2.5.0
         *
         * @param string $file Path to the file.
         * @return string Mode of the file (the last 3 digits).
         */
        public function getchmod($file)
        {
        }
        /**
         * Converts *nix-style file permissions to an octal number.
         *
         * Converts '-rw-r--r--' to 0644
         * From "info at rvgate dot nl"'s comment on the PHP documentation for chmod()
         *
         * @link https://www.php.net/manual/en/function.chmod.php#49614
         *
         * @since 2.5.0
         *
         * @param string $mode string The *nix-style file permissions.
         * @return string Octal representation of permissions.
         */
        public function getnumchmodfromh($mode)
        {
        }
        /**
         * Determines if the string provided contains binary characters.
         *
         * @since 2.7.0
         *
         * @param string $text String to test against.
         * @return bool True if string is binary, false otherwise.
         */
        public function is_binary($text)
        {
        }
        /**
         * Changes the owner of a file or directory.
         *
         * Default behavior is to do nothing, override this in your subclass, if desired.
         *
         * @since 2.5.0
         *
         * @param string     $file      Path to the file or directory.
         * @param string|int $owner     A user name or number.
         * @param bool       $recursive Optional. If set to true, changes file owner recursively.
         *                              Default false.
         * @return bool True on success, false on failure.
         */
        public function chown($file, $owner, $recursive = \false)
        {
        }
        /**
         * Connects filesystem.
         *
         * @since 2.5.0
         * @abstract
         *
         * @return bool True on success, false on failure (always true for WP_Filesystem_Direct).
         */
        public function connect()
        {
        }
        /**
         * Reads entire file into a string.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $file Name of the file to read.
         * @return string|false Read data on success, false on failure.
         */
        public function get_contents($file)
        {
        }
        /**
         * Reads entire file into an array.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $file Path to the file.
         * @return array|false File contents in an array on success, false on failure.
         */
        public function get_contents_array($file)
        {
        }
        /**
         * Writes a string to a file.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string    $file     Remote path to the file where to write the data.
         * @param string    $contents The data to write.
         * @param int|false $mode     Optional. The file permissions as octal number, usually 0644.
         *                            Default false.
         * @return bool True on success, false on failure.
         */
        public function put_contents($file, $contents, $mode = \false)
        {
        }
        /**
         * Gets the current working directory.
         *
         * @since 2.5.0
         * @abstract
         *
         * @return string|false The current working directory on success, false on failure.
         */
        public function cwd()
        {
        }
        /**
         * Changes current directory.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $dir The new current directory.
         * @return bool True on success, false on failure.
         */
        public function chdir($dir)
        {
        }
        /**
         * Changes the file group.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string     $file      Path to the file.
         * @param string|int $group     A group name or number.
         * @param bool       $recursive Optional. If set to true, changes file group recursively.
         *                              Default false.
         * @return bool True on success, false on failure.
         */
        public function chgrp($file, $group, $recursive = \false)
        {
        }
        /**
         * Changes filesystem permissions.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string    $file      Path to the file.
         * @param int|false $mode      Optional. The permissions as octal number, usually 0644 for files,
         *                             0755 for directories. Default false.
         * @param bool      $recursive Optional. If set to true, changes file permissions recursively.
         *                             Default false.
         * @return bool True on success, false on failure.
         */
        public function chmod($file, $mode = \false, $recursive = \false)
        {
        }
        /**
         * Gets the file owner.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $file Path to the file.
         * @return string|false Username of the owner on success, false on failure.
         */
        public function owner($file)
        {
        }
        /**
         * Gets the file's group.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $file Path to the file.
         * @return string|false The group on success, false on failure.
         */
        public function group($file)
        {
        }
        /**
         * Copies a file.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string    $source      Path to the source file.
         * @param string    $destination Path to the destination file.
         * @param bool      $overwrite   Optional. Whether to overwrite the destination file if it exists.
         *                               Default false.
         * @param int|false $mode        Optional. The permissions as octal number, usually 0644 for files,
         *                               0755 for dirs. Default false.
         * @return bool True on success, false on failure.
         */
        public function copy($source, $destination, $overwrite = \false, $mode = \false)
        {
        }
        /**
         * Moves a file.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $source      Path to the source file.
         * @param string $destination Path to the destination file.
         * @param bool   $overwrite   Optional. Whether to overwrite the destination file if it exists.
         *                            Default false.
         * @return bool True on success, false on failure.
         */
        public function move($source, $destination, $overwrite = \false)
        {
        }
        /**
         * Deletes a file or directory.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string       $file      Path to the file or directory.
         * @param bool         $recursive Optional. If set to true, deletes files and folders recursively.
         *                                Default false.
         * @param string|false $type      Type of resource. 'f' for file, 'd' for directory.
         *                                Default false.
         * @return bool True on success, false on failure.
         */
        public function delete($file, $recursive = \false, $type = \false)
        {
        }
        /**
         * Checks if a file or directory exists.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $path Path to file or directory.
         * @return bool Whether $path exists or not.
         */
        public function exists($path)
        {
        }
        /**
         * Checks if resource is a file.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $file File path.
         * @return bool Whether $file is a file.
         */
        public function is_file($file)
        {
        }
        /**
         * Checks if resource is a directory.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $path Directory path.
         * @return bool Whether $path is a directory.
         */
        public function is_dir($path)
        {
        }
        /**
         * Checks if a file is readable.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $file Path to file.
         * @return bool Whether $file is readable.
         */
        public function is_readable($file)
        {
        }
        /**
         * Checks if a file or directory is writable.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $path Path to file or directory.
         * @return bool Whether $path is writable.
         */
        public function is_writable($path)
        {
        }
        /**
         * Gets the file's last access time.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $file Path to file.
         * @return int|false Unix timestamp representing last access time, false on failure.
         */
        public function atime($file)
        {
        }
        /**
         * Gets the file modification time.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $file Path to file.
         * @return int|false Unix timestamp representing modification time, false on failure.
         */
        public function mtime($file)
        {
        }
        /**
         * Gets the file size (in bytes).
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $file Path to file.
         * @return int|false Size of the file in bytes on success, false on failure.
         */
        public function size($file)
        {
        }
        /**
         * Sets the access and modification times of a file.
         *
         * Note: If $file doesn't exist, it will be created.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $file  Path to file.
         * @param int    $time  Optional. Modified time to set for file.
         *                      Default 0.
         * @param int    $atime Optional. Access time to set for file.
         *                      Default 0.
         * @return bool True on success, false on failure.
         */
        public function touch($file, $time = 0, $atime = 0)
        {
        }
        /**
         * Creates a directory.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string           $path  Path for new directory.
         * @param int|false        $chmod Optional. The permissions as octal number (or false to skip chmod).
         *                                Default false.
         * @param string|int|false $chown Optional. A user name or number (or false to skip chown).
         *                                Default false.
         * @param string|int|false $chgrp Optional. A group name or number (or false to skip chgrp).
         *                                Default false.
         * @return bool True on success, false on failure.
         */
        public function mkdir($path, $chmod = \false, $chown = \false, $chgrp = \false)
        {
        }
        /**
         * Deletes a directory.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $path      Path to directory.
         * @param bool   $recursive Optional. Whether to recursively remove files/directories.
         *                          Default false.
         * @return bool True on success, false on failure.
         */
        public function rmdir($path, $recursive = \false)
        {
        }
        /**
         * Gets details for files in a directory or a specific file.
         *
         * @since 2.5.0
         * @abstract
         *
         * @param string $path           Path to directory or file.
         * @param bool   $include_hidden Optional. Whether to include details of hidden ("." prefixed) files.
         *                               Default true.
         * @param bool   $recursive      Optional. Whether to recursively include file details in nested directories.
         *                               Default false.
         * @return array|false {
         *     Array of arrays containing file information. False if unable to list directory contents.
         *
         *     @type array ...$0 {
         *         Array of file information. Note that some elements may not be available on all filesystems.
         *
         *         @type string           $name        Name of the file or directory.
         *         @type string           $perms       *nix representation of permissions.
         *         @type string           $permsn      Octal representation of permissions.
         *         @type int|string|false $number      File number. May be a numeric string. False if not available.
         *         @type string|false     $owner       Owner name or ID, or false if not available.
         *         @type string|false     $group       File permissions group, or false if not available.
         *         @type int|string|false $size        Size of file in bytes. May be a numeric string.
         *                                             False if not available.
         *         @type int|string|false $lastmodunix Last modified unix timestamp. May be a numeric string.
         *                                             False if not available.
         *         @type string|false     $lastmod     Last modified month (3 letters) and day (without leading 0), or
         *                                             false if not available.
         *         @type string|false     $time        Last modified time, or false if not available.
         *         @type string           $type        Type of resource. 'f' for file, 'd' for directory, 'l' for link.
         *         @type array|false      $files       If a directory and `$recursive` is true, contains another array of
         *                                             files. False if unable to list directory contents.
         *     }
         * }
         * @phpstan-return false|array<int|string, array{
         *   name: string,
         *   perms: string,
         *   permsn: string,
         *   number: int|string|false,
         *   owner: string|false,
         *   group: string|false,
         *   size: int|string|false,
         *   lastmodunix: int|string|false,
         *   lastmod: string|false,
         *   time: string|false,
         *   type: string,
         *   files: array|false,
         * }>
         * @phpstan-return false|array<string, array{name: string, perms: string, permsn: string, owner: string|false, size: int|string|false, lastmodunix: int|string|false, lastmod: string|false, time: string|false, type: 'f'|'d'|'l', group: string|false, number: int|string|false, files?: array|false}>
         */
        public function dirlist($path, $include_hidden = \true, $recursive = \false)
        {
        }
    }
    /**
     * WordPress Filesystem Class for direct PHP file and folder manipulation.
     *
     * @since 2.5.0
     *
     * @see WP_Filesystem_Base
     */
    class WP_Filesystem_Direct extends \WP_Filesystem_Base
    {
        /**
         * Constructor.
         *
         * @since 2.5.0
         *
         * @param mixed $arg Not used.
         */
        public function __construct($arg)
        {
        }
        /**
         * Reads entire file into a string.
         *
         * @since 2.5.0
         *
         * @param string $file Name of the file to read.
         * @return string|false Read data on success, false on failure.
         */
        public function get_contents($file)
        {
        }
        /**
         * Reads entire file into an array.
         *
         * @since 2.5.0
         *
         * @param string $file Path to the file.
         * @return array|false File contents in an array on success, false on failure.
         */
        public function get_contents_array($file)
        {
        }
        /**
         * Writes a string to a file.
         *
         * @since 2.5.0
         *
         * @param string    $file     Remote path to the file where to write the data.
         * @param string    $contents The data to write.
         * @param int|false $mode     Optional. The file permissions as octal number, usually 0644.
         *                            Default false.
         * @return bool True on success, false on failure.
         */
        public function put_contents($file, $contents, $mode = \false)
        {
        }
        /**
         * Gets the current working directory.
         *
         * @since 2.5.0
         *
         * @return string|false The current working directory on success, false on failure.
         */
        public function cwd()
        {
        }
        /**
         * Changes current directory.
         *
         * @since 2.5.0
         *
         * @param string $dir The new current directory.
         * @return bool True on success, false on failure.
         */
        public function chdir($dir)
        {
        }
        /**
         * Changes the file group.
         *
         * @since 2.5.0
         *
         * @param string     $file      Path to the file.
         * @param string|int $group     A group name or number.
         * @param bool       $recursive Optional. If set to true, changes file group recursively.
         *                              Default false.
         * @return bool True on success, false on failure.
         */
        public function chgrp($file, $group, $recursive = \false)
        {
        }
        /**
         * Changes filesystem permissions.
         *
         * @since 2.5.0
         *
         * @param string    $file      Path to the file.
         * @param int|false $mode      Optional. The permissions as octal number, usually 0644 for files,
         *                             0755 for directories. Default false.
         * @param bool      $recursive Optional. If set to true, changes file permissions recursively.
         *                             Default false.
         * @return bool True on success, false on failure.
         */
        public function chmod($file, $mode = \false, $recursive = \false)
        {
        }
        /**
         * Changes the owner of a file or directory.
         *
         * @since 2.5.0
         *
         * @param string     $file      Path to the file or directory.
         * @param string|int $owner     A user name or number.
         * @param bool       $recursive Optional. If set to true, changes file owner recursively.
         *                              Default false.
         * @return bool True on success, false on failure.
         */
        public function chown($file, $owner, $recursive = \false)
        {
        }
        /**
         * Gets the file owner.
         *
         * @since 2.5.0
         *
         * @param string $file Path to the file.
         * @return string|false Username of the owner on success, false on failure.
         */
        public function owner($file)
        {
        }
        /**
         * Gets the permissions of the specified file or filepath in their octal format.
         *
         * FIXME does not handle errors in fileperms()
         *
         * @since 2.5.0
         *
         * @param string $file Path to the file.
         * @return string Mode of the file (the last 3 digits).
         */
        public function getchmod($file)
        {
        }
        /**
         * Gets the file's group.
         *
         * @since 2.5.0
         *
         * @param string $file Path to the file.
         * @return string|false The group on success, false on failure.
         */
        public function group($file)
        {
        }
        /**
         * Copies a file.
         *
         * @since 2.5.0
         *
         * @param string    $source      Path to the source file.
         * @param string    $destination Path to the destination file.
         * @param bool      $overwrite   Optional. Whether to overwrite the destination file if it exists.
         *                               Default false.
         * @param int|false $mode        Optional. The permissions as octal number, usually 0644 for files,
         *                               0755 for dirs. Default false.
         * @return bool True on success, false on failure.
         */
        public function copy($source, $destination, $overwrite = \false, $mode = \false)
        {
        }
        /**
         * Moves a file or directory.
         *
         * After moving files or directories, OPcache will need to be invalidated.
         *
         * If moving a directory fails, `copy_dir()` can be used for a recursive copy.
         *
         * Use `move_dir()` for moving directories with OPcache invalidation and a
         * fallback to `copy_dir()`.
         *
         * @since 2.5.0
         *
         * @param string $source      Path to the source file.
         * @param string $destination Path to the destination file.
         * @param bool   $overwrite   Optional. Whether to overwrite the destination file if it exists.
         *                            Default false.
         * @return bool True on success, false on failure.
         */
        public function move($source, $destination, $overwrite = \false)
        {
        }
        /**
         * Deletes a file or directory.
         *
         * @since 2.5.0
         *
         * @param string       $file      Path to the file or directory.
         * @param bool         $recursive Optional. If set to true, deletes files and folders recursively.
         *                                Default false.
         * @param string|false $type      Type of resource. 'f' for file, 'd' for directory.
         *                                Default false.
         * @return bool True on success, false on failure.
         */
        public function delete($file, $recursive = \false, $type = \false)
        {
        }
        /**
         * Checks if a file or directory exists.
         *
         * @since 2.5.0
         *
         * @param string $path Path to file or directory.
         * @return bool Whether $path exists or not.
         */
        public function exists($path)
        {
        }
        /**
         * Checks if resource is a file.
         *
         * @since 2.5.0
         *
         * @param string $file File path.
         * @return bool Whether $file is a file.
         */
        public function is_file($file)
        {
        }
        /**
         * Checks if resource is a directory.
         *
         * @since 2.5.0
         *
         * @param string $path Directory path.
         * @return bool Whether $path is a directory.
         */
        public function is_dir($path)
        {
        }
        /**
         * Checks if a file is readable.
         *
         * @since 2.5.0
         *
         * @param string $file Path to file.
         * @return bool Whether $file is readable.
         */
        public function is_readable($file)
        {
        }
        /**
         * Checks if a file or directory is writable.
         *
         * @since 2.5.0
         *
         * @param string $path Path to file or directory.
         * @return bool Whether $path is writable.
         */
        public function is_writable($path)
        {
        }
        /**
         * Gets the file's last access time.
         *
         * @since 2.5.0
         *
         * @param string $file Path to file.
         * @return int|false Unix timestamp representing last access time, false on failure.
         */
        public function atime($file)
        {
        }
        /**
         * Gets the file modification time.
         *
         * @since 2.5.0
         *
         * @param string $file Path to file.
         * @return int|false Unix timestamp representing modification time, false on failure.
         */
        public function mtime($file)
        {
        }
        /**
         * Gets the file size (in bytes).
         *
         * @since 2.5.0
         *
         * @param string $file Path to file.
         * @return int|false Size of the file in bytes on success, false on failure.
         */
        public function size($file)
        {
        }
        /**
         * Sets the access and modification times of a file.
         *
         * Note: If $file doesn't exist, it will be created.
         *
         * @since 2.5.0
         *
         * @param string $file  Path to file.
         * @param int    $time  Optional. Modified time to set for file.
         *                      Default 0.
         * @param int    $atime Optional. Access time to set for file.
         *                      Default 0.
         * @return bool True on success, false on failure.
         */
        public function touch($file, $time = 0, $atime = 0)
        {
        }
        /**
         * Creates a directory.
         *
         * @since 2.5.0
         *
         * @param string           $path  Path for new directory.
         * @param int|false        $chmod Optional. The permissions as octal number (or false to skip chmod).
         *                                Default false.
         * @param string|int|false $chown Optional. A user name or number (or false to skip chown).
         *                                Default false.
         * @param string|int|false $chgrp Optional. A group name or number (or false to skip chgrp).
         *                                Default false.
         * @return bool True on success, false on failure.
         */
        public function mkdir($path, $chmod = \false, $chown = \false, $chgrp = \false)
        {
        }
        /**
         * Deletes a directory.
         *
         * @since 2.5.0
         *
         * @param string $path      Path to directory.
         * @param bool   $recursive Optional. Whether to recursively remove files/directories.
         *                          Default false.
         * @return bool True on success, false on failure.
         */
        public function rmdir($path, $recursive = \false)
        {
        }
        /**
         * Gets details for files in a directory or a specific file.
         *
         * @since 2.5.0
         *
         * @param string $path           Path to directory or file.
         * @param bool   $include_hidden Optional. Whether to include details of hidden ("." prefixed) files.
         *                               Default true.
         * @param bool   $recursive      Optional. Whether to recursively include file details in nested directories.
         *                               Default false.
         * @return array|false {
         *     Array of arrays containing file information. False if unable to list directory contents.
         *
         *     @type array ...$0 {
         *         Array of file information. Note that some elements may not be available on all filesystems.
         *
         *         @type string           $name        Name of the file or directory.
         *         @type string           $perms       *nix representation of permissions.
         *         @type string           $permsn      Octal representation of permissions.
         *         @type false            $number      File number. Always false in this context.
         *         @type string|false     $owner       Owner name or ID, or false if not available.
         *         @type string|false     $group       File permissions group, or false if not available.
         *         @type int|string|false $size        Size of file in bytes. May be a numeric string.
         *                                             False if not available.
         *         @type int|string|false $lastmodunix Last modified unix timestamp. May be a numeric string.
         *                                             False if not available.
         *         @type string|false     $lastmod     Last modified month (3 letters) and day (without leading 0), or
         *                                             false if not available.
         *         @type string|false     $time        Last modified time, or false if not available.
         *         @type string           $type        Type of resource. 'f' for file, 'd' for directory, 'l' for link.
         *         @type array|false      $files       If a directory and `$recursive` is true, contains another array of
         *                                             files. False if unable to list directory contents.
         *     }
         * }
         * @phpstan-return false|array<int|string, array{
         *   name: string,
         *   perms: string,
         *   permsn: string,
         *   number: false,
         *   owner: string|false,
         *   group: string|false,
         *   size: int|string|false,
         *   lastmodunix: int|string|false,
         *   lastmod: string|false,
         *   time: string|false,
         *   type: string,
         *   files: array|false,
         * }>
         * @phpstan-return false|array<string, array{name: string, perms: string, permsn: string, owner: string|false, size: int|string|false, lastmodunix: int|string|false, lastmod: string|false, time: string|false, type: 'f'|'d'|'l', group: string|false, number: int|string|false, files?: array|false}>
         */
        public function dirlist($path, $include_hidden = \true, $recursive = \false)
        {
        }
    }
    /**
     * WordPress Filesystem Class for implementing FTP.
     *
     * @since 2.5.0
     *
     * @see WP_Filesystem_Base
     */
    class WP_Filesystem_FTPext extends \WP_Filesystem_Base
    {
        /**
         * @since 2.5.0
         * @var resource
         */
        public $link;
        /**
         * Constructor.
         *
         * @since 2.5.0
         *
         * @param array $opt
         * @phpstan-return void
         */
        public function __construct($opt = '')
        {
        }
        /**
         * Connects filesystem.
         *
         * @since 2.5.0
         *
         * @return bool True on success, false on failure.
         */
        public function connect()
        {
        }
        /**
         * Reads entire file into a string.
         *
         * @since 2.5.0
         *
         * @param string $file Name of the file to read.
         * @return string|false Read data on success, false if no temporary file could be opened,
         *                      or if the file couldn't be retrieved.
         */
        public function get_contents($file)
        {
        }
        /**
         * Reads entire file into an array.
         *
         * @since 2.5.0
         *
         * @param string $file Path to the file.
         * @return array|false File contents in an array on success, false on failure.
         */
        public function get_contents_array($file)
        {
        }
        /**
         * Writes a string to a file.
         *
         * @since 2.5.0
         *
         * @param string    $file     Remote path to the file where to write the data.
         * @param string    $contents The data to write.
         * @param int|false $mode     Optional. The file permissions as octal number, usually 0644.
         *                            Default false.
         * @return bool True on success, false on failure.
         */
        public function put_contents($file, $contents, $mode = \false)
        {
        }
        /**
         * Gets the current working directory.
         *
         * @since 2.5.0
         *
         * @return string|false The current working directory on success, false on failure.
         */
        public function cwd()
        {
        }
        /**
         * Changes current directory.
         *
         * @since 2.5.0
         *
         * @param string $dir The new current directory.
         * @return bool True on success, false on failure.
         */
        public function chdir($dir)
        {
        }
        /**
         * Changes filesystem permissions.
         *
         * @since 2.5.0
         *
         * @param string    $file      Path to the file.
         * @param int|false $mode      Optional. The permissions as octal number, usually 0644 for files,
         *                             0755 for directories. Default false.
         * @param bool      $recursive Optional. If set to true, changes file permissions recursively.
         *                             Default false.
         * @return bool True on success, false on failure.
         */
        public function chmod($file, $mode = \false, $recursive = \false)
        {
        }
        /**
         * Gets the file owner.
         *
         * @since 2.5.0
         *
         * @param string $file Path to the file.
         * @return string|false Username of the owner on success, false on failure.
         */
        public function owner($file)
        {
        }
        /**
         * Gets the permissions of the specified file or filepath in their octal format.
         *
         * @since 2.5.0
         *
         * @param string $file Path to the file.
         * @return string Mode of the file (the last 3 digits).
         */
        public function getchmod($file)
        {
        }
        /**
         * Gets the file's group.
         *
         * @since 2.5.0
         *
         * @param string $file Path to the file.
         * @return string|false The group on success, false on failure.
         */
        public function group($file)
        {
        }
        /**
         * Copies a file.
         *
         * @since 2.5.0
         *
         * @param string    $source      Path to the source file.
         * @param string    $destination Path to the destination file.
         * @param bool      $overwrite   Optional. Whether to overwrite the destination file if it exists.
         *                               Default false.
         * @param int|false $mode        Optional. The permissions as octal number, usually 0644 for files,
         *                               0755 for dirs. Default false.
         * @return bool True on success, false on failure.
         */
        public function copy($source, $destination, $overwrite = \false, $mode = \false)
        {
        }
        /**
         * Moves a file or directory.
         *
         * After moving files or directories, OPcache will need to be invalidated.
         *
         * If moving a directory fails, `copy_dir()` can be used for a recursive copy.
         *
         * Use `move_dir()` for moving directories with OPcache invalidation and a
         * fallback to `copy_dir()`.
         *
         * @since 2.5.0
         *
         * @param string $source      Path to the source file or directory.
         * @param string $destination Path to the destination file or directory.
         * @param bool   $overwrite   Optional. Whether to overwrite the destination if it exists.
         *                            Default false.
         * @return bool True on success, false on failure.
         */
        public function move($source, $destination, $overwrite = \false)
        {
        }
        /**
         * Deletes a file or directory.
         *
         * @since 2.5.0
         *
         * @param string       $file      Path to the file or directory.
         * @param bool         $recursive Optional. If set to true, deletes files and folders recursively.
         *                                Default false.
         * @param string|false $type      Type of resource. 'f' for file, 'd' for directory.
         *                                Default false.
         * @return bool True on success, false on failure.
         */
        public function delete($file, $recursive = \false, $type = \false)
        {
        }
        /**
         * Checks if a file or directory exists.
         *
         * @since 2.5.0
         * @since 6.3.0 Returns false for an empty path.
         *
         * @param string $path Path to file or directory.
         * @return bool Whether $path exists or not.
         */
        public function exists($path)
        {
        }
        /**
         * Checks if resource is a file.
         *
         * @since 2.5.0
         *
         * @param string $file File path.
         * @return bool Whether $file is a file.
         */
        public function is_file($file)
        {
        }
        /**
         * Checks if resource is a directory.
         *
         * @since 2.5.0
         *
         * @param string $path Directory path.
         * @return bool Whether $path is a directory.
         */
        public function is_dir($path)
        {
        }
        /**
         * Checks if a file is readable.
         *
         * @since 2.5.0
         *
         * @param string $file Path to file.
         * @return bool Whether $file is readable.
         */
        public function is_readable($file)
        {
        }
        /**
         * Checks if a file or directory is writable.
         *
         * @since 2.5.0
         *
         * @param string $path Path to file or directory.
         * @return bool Whether $path is writable.
         */
        public function is_writable($path)
        {
        }
        /**
         * Gets the file's last access time.
         *
         * @since 2.5.0
         *
         * @param string $file Path to file.
         * @return int|false Unix timestamp representing last access time, false on failure.
         */
        public function atime($file)
        {
        }
        /**
         * Gets the file modification time.
         *
         * @since 2.5.0
         *
         * @param string $file Path to file.
         * @return int|false Unix timestamp representing modification time, false on failure.
         */
        public function mtime($file)
        {
        }
        /**
         * Gets the file size (in bytes).
         *
         * @since 2.5.0
         *
         * @param string $file Path to file.
         * @return int|false Size of the file in bytes on success, false on failure.
         */
        public function size($file)
        {
        }
        /**
         * Sets the access and modification times of a file.
         *
         * Note: If $file doesn't exist, it will be created.
         *
         * @since 2.5.0
         *
         * @param string $file  Path to file.
         * @param int    $time  Optional. Modified time to set for file.
         *                      Default 0.
         * @param int    $atime Optional. Access time to set for file.
         *                      Default 0.
         * @return bool True on success, false on failure.
         */
        public function touch($file, $time = 0, $atime = 0)
        {
        }
        /**
         * Creates a directory.
         *
         * @since 2.5.0
         *
         * @param string           $path  Path for new directory.
         * @param int|false        $chmod Optional. The permissions as octal number (or false to skip chmod).
         *                                Default false.
         * @param string|int|false $chown Optional. A user name or number (or false to skip chown).
         *                                Default false.
         * @param string|int|false $chgrp Optional. A group name or number (or false to skip chgrp).
         *                                Default false.
         * @return bool True on success, false on failure.
         */
        public function mkdir($path, $chmod = \false, $chown = \false, $chgrp = \false)
        {
        }
        /**
         * Deletes a directory.
         *
         * @since 2.5.0
         *
         * @param string $path      Path to directory.
         * @param bool   $recursive Optional. Whether to recursively remove files/directories.
         *                          Default false.
         * @return bool True on success, false on failure.
         */
        public function rmdir($path, $recursive = \false)
        {
        }
        /**
         * @param string $line
         * @return array {
         *     Array of file information.
         *
         *     @type string       $name        Name of the file or directory.
         *     @type string       $perms       *nix representation of permissions.
         *     @type string       $permsn      Octal representation of permissions.
         *     @type string|false $number      File number as a string, or false if not available.
         *     @type string|false $owner       Owner name or ID, or false if not available.
         *     @type string|false $group       File permissions group, or false if not available.
         *     @type string|false $size        Size of file in bytes as a string, or false if not available.
         *     @type string|false $lastmodunix Last modified unix timestamp as a string, or false if not available.
         *     @type string|false $lastmod     Last modified month (3 letters) and day (without leading 0), or
         *                                     false if not available.
         *     @type string|false $time        Last modified time, or false if not available.
         *     @type string       $type        Type of resource. 'f' for file, 'd' for directory, 'l' for link.
         *     @type array|false  $files       If a directory and `$recursive` is true, contains another array of files.
         *                                     False if unable to list directory contents.
         * }
         * @phpstan-return array{
         *   name: string,
         *   perms: string,
         *   permsn: string,
         *   number: string|false,
         *   owner: string|false,
         *   group: string|false,
         *   size: string|false,
         *   lastmodunix: string|false,
         *   lastmod: string|false,
         *   time: string|false,
         *   type: string,
         *   files: array|false,
         * }
         */
        public function parselisting($line)
        {
        }
        /**
         * Gets details for files in a directory or a specific file.
         *
         * @since 2.5.0
         *
         * @param string $path           Path to directory or file.
         * @param bool   $include_hidden Optional. Whether to include details of hidden ("." prefixed) files.
         *                               Default true.
         * @param bool   $recursive      Optional. Whether to recursively include file details in nested directories.
         *                               Default false.
         * @return array|false {
         *     Array of arrays containing file information. False if unable to list directory contents.
         *
         *     @type array ...$0 {
         *         Array of file information. Note that some elements may not be available on all filesystems.
         *
         *         @type string           $name        Name of the file or directory.
         *         @type string           $perms       *nix representation of permissions.
         *         @type string           $permsn      Octal representation of permissions.
         *         @type int|string|false $number      File number. May be a numeric string. False if not available.
         *         @type string|false     $owner       Owner name or ID, or false if not available.
         *         @type string|false     $group       File permissions group, or false if not available.
         *         @type int|string|false $size        Size of file in bytes. May be a numeric string.
         *                                             False if not available.
         *         @type int|string|false $lastmodunix Last modified unix timestamp. May be a numeric string.
         *                                             False if not available.
         *         @type string|false     $lastmod     Last modified month (3 letters) and day (without leading 0), or
         *                                             false if not available.
         *         @type string|false     $time        Last modified time, or false if not available.
         *         @type string           $type        Type of resource. 'f' for file, 'd' for directory, 'l' for link.
         *         @type array|false      $files       If a directory and `$recursive` is true, contains another array of
         *                                             files. False if unable to list directory contents.
         *     }
         * }
         * @phpstan-return false|array<int|string, array{
         *   name: string,
         *   perms: string,
         *   permsn: string,
         *   number: int|string|false,
         *   owner: string|false,
         *   group: string|false,
         *   size: int|string|false,
         *   lastmodunix: int|string|false,
         *   lastmod: string|false,
         *   time: string|false,
         *   type: string,
         *   files: array|false,
         * }>
         * @phpstan-return false|array<string, array{name: string, perms: string, permsn: string, owner: string|false, size: int|string|false, lastmodunix: int|string|false, lastmod: string|false, time: string|false, type: 'f'|'d'|'l', group: string|false, number: int|string|false, files?: array|false}>
         */
        public function dirlist($path = '.', $include_hidden = \true, $recursive = \false)
        {
        }
        /**
         * Destructor.
         *
         * @since 2.5.0
         */
        public function __destruct()
        {
        }
    }
    /**
     * WordPress Filesystem Class for implementing FTP Sockets.
     *
     * @since 2.5.0
     *
     * @see WP_Filesystem_Base
     */
    class WP_Filesystem_ftpsockets extends \WP_Filesystem_Base
    {
        /**
         * @since 2.5.0
         * @var ftp
         */
        public $ftp;
        /**
         * Constructor.
         *
         * @since 2.5.0
         *
         * @param array $opt
         * @phpstan-return void
         */
        public function __construct($opt = '')
        {
        }
        /**
         * Connects filesystem.
         *
         * @since 2.5.0
         *
         * @return bool True on success, false on failure.
         */
        public function connect()
        {
        }
        /**
         * Reads entire file into a string.
         *
         * @since 2.5.0
         *
         * @param string $file Name of the file to read.
         * @return string|false Read data on success, false if no temporary file could be opened,
         *                      or if the file couldn't be retrieved.
         */
        public function get_contents($file)
        {
        }
        /**
         * Reads entire file into an array.
         *
         * @since 2.5.0
         *
         * @param string $file Path to the file.
         * @return array|false File contents in an array on success, false on failure.
         */
        public function get_contents_array($file)
        {
        }
        /**
         * Writes a string to a file.
         *
         * @since 2.5.0
         *
         * @param string    $file     Remote path to the file where to write the data.
         * @param string    $contents The data to write.
         * @param int|false $mode     Optional. The file permissions as octal number, usually 0644.
         *                            Default false.
         * @return bool True on success, false on failure.
         */
        public function put_contents($file, $contents, $mode = \false)
        {
        }
        /**
         * Gets the current working directory.
         *
         * @since 2.5.0
         *
         * @return string|false The current working directory on success, false on failure.
         */
        public function cwd()
        {
        }
        /**
         * Changes current directory.
         *
         * @since 2.5.0
         *
         * @param string $dir The new current directory.
         * @return bool True on success, false on failure.
         */
        public function chdir($dir)
        {
        }
        /**
         * Changes filesystem permissions.
         *
         * @since 2.5.0
         *
         * @param string    $file      Path to the file.
         * @param int|false $mode      Optional. The permissions as octal number, usually 0644 for files,
         *                             0755 for directories. Default false.
         * @param bool      $recursive Optional. If set to true, changes file permissions recursively.
         *                             Default false.
         * @return bool True on success, false on failure.
         */
        public function chmod($file, $mode = \false, $recursive = \false)
        {
        }
        /**
         * Gets the file owner.
         *
         * @since 2.5.0
         *
         * @param string $file Path to the file.
         * @return string|false Username of the owner on success, false on failure.
         */
        public function owner($file)
        {
        }
        /**
         * Gets the permissions of the specified file or filepath in their octal format.
         *
         * @since 2.5.0
         *
         * @param string $file Path to the file.
         * @return string Mode of the file (the last 3 digits).
         */
        public function getchmod($file)
        {
        }
        /**
         * Gets the file's group.
         *
         * @since 2.5.0
         *
         * @param string $file Path to the file.
         * @return string|false The group on success, false on failure.
         */
        public function group($file)
        {
        }
        /**
         * Copies a file.
         *
         * @since 2.5.0
         *
         * @param string    $source      Path to the source file.
         * @param string    $destination Path to the destination file.
         * @param bool      $overwrite   Optional. Whether to overwrite the destination file if it exists.
         *                               Default false.
         * @param int|false $mode        Optional. The permissions as octal number, usually 0644 for files,
         *                               0755 for dirs. Default false.
         * @return bool True on success, false on failure.
         */
        public function copy($source, $destination, $overwrite = \false, $mode = \false)
        {
        }
        /**
         * Moves a file or directory.
         *
         * After moving files or directories, OPcache will need to be invalidated.
         *
         * If moving a directory fails, `copy_dir()` can be used for a recursive copy.
         *
         * Use `move_dir()` for moving directories with OPcache invalidation and a
         * fallback to `copy_dir()`.
         *
         * @since 2.5.0
         *
         * @param string $source      Path to the source file or directory.
         * @param string $destination Path to the destination file or directory.
         * @param bool   $overwrite   Optional. Whether to overwrite the destination if it exists.
         *                            Default false.
         * @return bool True on success, false on failure.
         */
        public function move($source, $destination, $overwrite = \false)
        {
        }
        /**
         * Deletes a file or directory.
         *
         * @since 2.5.0
         *
         * @param string       $file      Path to the file or directory.
         * @param bool         $recursive Optional. If set to true, deletes files and folders recursively.
         *                                Default false.
         * @param string|false $type      Type of resource. 'f' for file, 'd' for directory.
         *                                Default false.
         * @return bool True on success, false on failure.
         */
        public function delete($file, $recursive = \false, $type = \false)
        {
        }
        /**
         * Checks if a file or directory exists.
         *
         * @since 2.5.0
         * @since 6.3.0 Returns false for an empty path.
         *
         * @param string $path Path to file or directory.
         * @return bool Whether $path exists or not.
         */
        public function exists($path)
        {
        }
        /**
         * Checks if resource is a file.
         *
         * @since 2.5.0
         *
         * @param string $file File path.
         * @return bool Whether $file is a file.
         */
        public function is_file($file)
        {
        }
        /**
         * Checks if resource is a directory.
         *
         * @since 2.5.0
         *
         * @param string $path Directory path.
         * @return bool Whether $path is a directory.
         */
        public function is_dir($path)
        {
        }
        /**
         * Checks if a file is readable.
         *
         * @since 2.5.0
         *
         * @param string $file Path to file.
         * @return bool Whether $file is readable.
         */
        public function is_readable($file)
        {
        }
        /**
         * Checks if a file or directory is writable.
         *
         * @since 2.5.0
         *
         * @param string $path Path to file or directory.
         * @return bool Whether $path is writable.
         */
        public function is_writable($path)
        {
        }
        /**
         * Gets the file's last access time.
         *
         * @since 2.5.0
         *
         * @param string $file Path to file.
         * @return int|false Unix timestamp representing last access time, false on failure.
         */
        public function atime($file)
        {
        }
        /**
         * Gets the file modification time.
         *
         * @since 2.5.0
         *
         * @param string $file Path to file.
         * @return int|false Unix timestamp representing modification time, false on failure.
         */
        public function mtime($file)
        {
        }
        /**
         * Gets the file size (in bytes).
         *
         * @since 2.5.0
         *
         * @param string $file Path to file.
         * @return int|false Size of the file in bytes on success, false on failure.
         */
        public function size($file)
        {
        }
        /**
         * Sets the access and modification times of a file.
         *
         * Note: If $file doesn't exist, it will be created.
         *
         * @since 2.5.0
         *
         * @param string $file  Path to file.
         * @param int    $time  Optional. Modified time to set for file.
         *                      Default 0.
         * @param int    $atime Optional. Access time to set for file.
         *                      Default 0.
         * @return bool True on success, false on failure.
         */
        public function touch($file, $time = 0, $atime = 0)
        {
        }
        /**
         * Creates a directory.
         *
         * @since 2.5.0
         *
         * @param string           $path  Path for new directory.
         * @param int|false        $chmod Optional. The permissions as octal number (or false to skip chmod).
         *                                Default false.
         * @param string|int|false $chown Optional. A user name or number (or false to skip chown).
         *                                Default false.
         * @param string|int|false $chgrp Optional. A group name or number (or false to skip chgrp).
         *                                Default false.
         * @return bool True on success, false on failure.
         */
        public function mkdir($path, $chmod = \false, $chown = \false, $chgrp = \false)
        {
        }
        /**
         * Deletes a directory.
         *
         * @since 2.5.0
         *
         * @param string $path      Path to directory.
         * @param bool   $recursive Optional. Whether to recursively remove files/directories.
         *                          Default false.
         * @return bool True on success, false on failure.
         */
        public function rmdir($path, $recursive = \false)
        {
        }
        /**
         * Gets details for files in a directory or a specific file.
         *
         * @since 2.5.0
         *
         * @param string $path           Path to directory or file.
         * @param bool   $include_hidden Optional. Whether to include details of hidden ("." prefixed) files.
         *                               Default true.
         * @param bool   $recursive      Optional. Whether to recursively include file details in nested directories.
         *                               Default false.
         * @return array|false {
         *     Array of arrays containing file information. False if unable to list directory contents.
         *
         *     @type array ...$0 {
         *         Array of file information. Note that some elements may not be available on all filesystems.
         *
         *         @type string           $name        Name of the file or directory.
         *         @type string           $perms       *nix representation of permissions.
         *         @type string           $permsn      Octal representation of permissions.
         *         @type int|string|false $number      File number. May be a numeric string. False if not available.
         *         @type string|false     $owner       Owner name or ID, or false if not available.
         *         @type string|false     $group       File permissions group, or false if not available.
         *         @type int|string|false $size        Size of file in bytes. May be a numeric string.
         *                                             False if not available.
         *         @type int|string|false $lastmodunix Last modified unix timestamp. May be a numeric string.
         *                                             False if not available.
         *         @type string|false     $lastmod     Last modified month (3 letters) and day (without leading 0), or
         *                                             false if not available.
         *         @type string|false     $time        Last modified time, or false if not available.
         *         @type string           $type        Type of resource. 'f' for file, 'd' for directory, 'l' for link.
         *         @type array|false      $files       If a directory and `$recursive` is true, contains another array of
         *                                             files. False if unable to list directory contents.
         *     }
         * }
         * @phpstan-return false|array<int|string, array{
         *   name: string,
         *   perms: string,
         *   permsn: string,
         *   number: int|string|false,
         *   owner: string|false,
         *   group: string|false,
         *   size: int|string|false,
         *   lastmodunix: int|string|false,
         *   lastmod: string|false,
         *   time: string|false,
         *   type: string,
         *   files: array|false,
         * }>
         * @phpstan-return false|array<string, array{name: string, perms: string, permsn: string, owner: string|false, size: int|string|false, lastmodunix: int|string|false, lastmod: string|false, time: string|false, type: 'f'|'d'|'l', group: string|false, number: int|string|false, files?: array|false}>
         */
        public function dirlist($path = '.', $include_hidden = \true, $recursive = \false)
        {
        }
        /**
         * Destructor.
         *
         * @since 2.5.0
         */
        public function __destruct()
        {
        }
    }
    /**
     * WordPress Filesystem Class for implementing SSH2
     *
     * To use this class you must follow these steps for PHP 5.2.6+
     *
     * {@link http://kevin.vanzonneveld.net/techblog/article/make_ssh_connections_with_php/ - Installation Notes}
     *
     * Compile libssh2 (Note: Only 0.14 is officially working with PHP 5.2.6+ right now, But many users have found the latest versions work)
     *
     * cd /usr/src
     * wget https://www.libssh2.org/download/libssh2-0.14.tar.gz
     * tar -zxvf libssh2-0.14.tar.gz
     * cd libssh2-0.14/
     * ./configure
     * make all install
     *
     * Note: Do not leave the directory yet!
     *
     * Enter: pecl install -f ssh2
     *
     * Copy the ssh.so file it creates to your PHP Module Directory.
     * Open up your PHP.INI file and look for where extensions are placed.
     * Add in your PHP.ini file: extension=ssh2.so
     *
     * Restart Apache!
     * Check phpinfo() streams to confirm that: ssh2.shell, ssh2.exec, ssh2.tunnel, ssh2.scp, ssh2.sftp  exist.
     *
     * Note: As of WordPress 2.8, this utilizes the PHP5+ function `stream_get_contents()`.
     *
     * @since 2.7.0
     *
     * @package WordPress
     * @subpackage Filesystem
     */
    class WP_Filesystem_SSH2 extends \WP_Filesystem_Base
    {
        /**
         * @since 2.7.0
         * @var resource
         */
        public $link = \false;
        /**
         * @since 2.7.0
         * @var resource
         */
        public $sftp_link;
        /**
         * @since 2.7.0
         * @var bool
         */
        public $keys = \false;
        /**
         * Constructor.
         *
         * @since 2.7.0
         *
         * @param array $opt
         * @phpstan-return void
         */
        public function __construct($opt = '')
        {
        }
        /**
         * Connects filesystem.
         *
         * @since 2.7.0
         *
         * @return bool True on success, false on failure.
         */
        public function connect()
        {
        }
        /**
         * Gets the ssh2.sftp PHP stream wrapper path to open for the given file.
         *
         * This method also works around a PHP bug where the root directory (/) cannot
         * be opened by PHP functions, causing a false failure. In order to work around
         * this, the path is converted to /./ which is semantically the same as /
         * See https://bugs.php.net/bug.php?id=64169 for more details.
         *
         * @since 4.4.0
         *
         * @param string $path The File/Directory path on the remote server to return
         * @return string The ssh2.sftp:// wrapped path to use.
         */
        public function sftp_path($path)
        {
        }
        /**
         * @since 2.7.0
         *
         * @param string $command
         * @param bool   $returnbool
         * @return bool|string True on success, false on failure. String if the command was executed, `$returnbool`
         *                     is false (default), and data from the resulting stream was retrieved.
         */
        public function run_command($command, $returnbool = \false)
        {
        }
        /**
         * Reads entire file into a string.
         *
         * @since 2.7.0
         *
         * @param string $file Name of the file to read.
         * @return string|false Read data on success, false if no temporary file could be opened,
         *                      or if the file couldn't be retrieved.
         */
        public function get_contents($file)
        {
        }
        /**
         * Reads entire file into an array.
         *
         * @since 2.7.0
         *
         * @param string $file Path to the file.
         * @return array|false File contents in an array on success, false on failure.
         */
        public function get_contents_array($file)
        {
        }
        /**
         * Writes a string to a file.
         *
         * @since 2.7.0
         *
         * @param string    $file     Remote path to the file where to write the data.
         * @param string    $contents The data to write.
         * @param int|false $mode     Optional. The file permissions as octal number, usually 0644.
         *                            Default false.
         * @return bool True on success, false on failure.
         */
        public function put_contents($file, $contents, $mode = \false)
        {
        }
        /**
         * Gets the current working directory.
         *
         * @since 2.7.0
         *
         * @return string|false The current working directory on success, false on failure.
         */
        public function cwd()
        {
        }
        /**
         * Changes current directory.
         *
         * @since 2.7.0
         *
         * @param string $dir The new current directory.
         * @return bool True on success, false on failure.
         */
        public function chdir($dir)
        {
        }
        /**
         * Changes the file group.
         *
         * @since 2.7.0
         *
         * @param string     $file      Path to the file.
         * @param string|int $group     A group name or number.
         * @param bool       $recursive Optional. If set to true, changes file group recursively.
         *                              Default false.
         * @return bool True on success, false on failure.
         */
        public function chgrp($file, $group, $recursive = \false)
        {
        }
        /**
         * Changes filesystem permissions.
         *
         * @since 2.7.0
         *
         * @param string    $file      Path to the file.
         * @param int|false $mode      Optional. The permissions as octal number, usually 0644 for files,
         *                             0755 for directories. Default false.
         * @param bool      $recursive Optional. If set to true, changes file permissions recursively.
         *                             Default false.
         * @return bool True on success, false on failure.
         */
        public function chmod($file, $mode = \false, $recursive = \false)
        {
        }
        /**
         * Changes the owner of a file or directory.
         *
         * @since 2.7.0
         *
         * @param string     $file      Path to the file or directory.
         * @param string|int $owner     A user name or number.
         * @param bool       $recursive Optional. If set to true, changes file owner recursively.
         *                              Default false.
         * @return bool True on success, false on failure.
         */
        public function chown($file, $owner, $recursive = \false)
        {
        }
        /**
         * Gets the file owner.
         *
         * @since 2.7.0
         *
         * @param string $file Path to the file.
         * @return string|false Username of the owner on success, false on failure.
         */
        public function owner($file)
        {
        }
        /**
         * Gets the permissions of the specified file or filepath in their octal format.
         *
         * @since 2.7.0
         *
         * @param string $file Path to the file.
         * @return string Mode of the file (the last 3 digits).
         */
        public function getchmod($file)
        {
        }
        /**
         * Gets the file's group.
         *
         * @since 2.7.0
         *
         * @param string $file Path to the file.
         * @return string|false The group on success, false on failure.
         */
        public function group($file)
        {
        }
        /**
         * Copies a file.
         *
         * @since 2.7.0
         *
         * @param string    $source      Path to the source file.
         * @param string    $destination Path to the destination file.
         * @param bool      $overwrite   Optional. Whether to overwrite the destination file if it exists.
         *                               Default false.
         * @param int|false $mode        Optional. The permissions as octal number, usually 0644 for files,
         *                               0755 for dirs. Default false.
         * @return bool True on success, false on failure.
         */
        public function copy($source, $destination, $overwrite = \false, $mode = \false)
        {
        }
        /**
         * Moves a file or directory.
         *
         * After moving files or directories, OPcache will need to be invalidated.
         *
         * If moving a directory fails, `copy_dir()` can be used for a recursive copy.
         *
         * Use `move_dir()` for moving directories with OPcache invalidation and a
         * fallback to `copy_dir()`.
         *
         * @since 2.7.0
         *
         * @param string $source      Path to the source file or directory.
         * @param string $destination Path to the destination file or directory.
         * @param bool   $overwrite   Optional. Whether to overwrite the destination if it exists.
         *                            Default false.
         * @return bool True on success, false on failure.
         */
        public function move($source, $destination, $overwrite = \false)
        {
        }
        /**
         * Deletes a file or directory.
         *
         * @since 2.7.0
         *
         * @param string       $file      Path to the file or directory.
         * @param bool         $recursive Optional. If set to true, deletes files and folders recursively.
         *                                Default false.
         * @param string|false $type      Type of resource. 'f' for file, 'd' for directory.
         *                                Default false.
         * @return bool True on success, false on failure.
         */
        public function delete($file, $recursive = \false, $type = \false)
        {
        }
        /**
         * Checks if a file or directory exists.
         *
         * @since 2.7.0
         *
         * @param string $path Path to file or directory.
         * @return bool Whether $path exists or not.
         */
        public function exists($path)
        {
        }
        /**
         * Checks if resource is a file.
         *
         * @since 2.7.0
         *
         * @param string $file File path.
         * @return bool Whether $file is a file.
         */
        public function is_file($file)
        {
        }
        /**
         * Checks if resource is a directory.
         *
         * @since 2.7.0
         *
         * @param string $path Directory path.
         * @return bool Whether $path is a directory.
         */
        public function is_dir($path)
        {
        }
        /**
         * Checks if a file is readable.
         *
         * @since 2.7.0
         *
         * @param string $file Path to file.
         * @return bool Whether $file is readable.
         */
        public function is_readable($file)
        {
        }
        /**
         * Checks if a file or directory is writable.
         *
         * @since 2.7.0
         *
         * @param string $path Path to file or directory.
         * @return bool Whether $path is writable.
         */
        public function is_writable($path)
        {
        }
        /**
         * Gets the file's last access time.
         *
         * @since 2.7.0
         *
         * @param string $file Path to file.
         * @return int|false Unix timestamp representing last access time, false on failure.
         */
        public function atime($file)
        {
        }
        /**
         * Gets the file modification time.
         *
         * @since 2.7.0
         *
         * @param string $file Path to file.
         * @return int|false Unix timestamp representing modification time, false on failure.
         */
        public function mtime($file)
        {
        }
        /**
         * Gets the file size (in bytes).
         *
         * @since 2.7.0
         *
         * @param string $file Path to file.
         * @return int|false Size of the file in bytes on success, false on failure.
         */
        public function size($file)
        {
        }
        /**
         * Sets the access and modification times of a file.
         *
         * Note: Not implemented.
         *
         * @since 2.7.0
         *
         * @param string $file  Path to file.
         * @param int    $time  Optional. Modified time to set for file.
         *                      Default 0.
         * @param int    $atime Optional. Access time to set for file.
         *                      Default 0.
         */
        public function touch($file, $time = 0, $atime = 0)
        {
        }
        /**
         * Creates a directory.
         *
         * @since 2.7.0
         *
         * @param string           $path  Path for new directory.
         * @param int|false        $chmod Optional. The permissions as octal number (or false to skip chmod).
         *                                Default false.
         * @param string|int|false $chown Optional. A user name or number (or false to skip chown).
         *                                Default false.
         * @param string|int|false $chgrp Optional. A group name or number (or false to skip chgrp).
         *                                Default false.
         * @return bool True on success, false on failure.
         */
        public function mkdir($path, $chmod = \false, $chown = \false, $chgrp = \false)
        {
        }
        /**
         * Deletes a directory.
         *
         * @since 2.7.0
         *
         * @param string $path      Path to directory.
         * @param bool   $recursive Optional. Whether to recursively remove files/directories.
         *                          Default false.
         * @return bool True on success, false on failure.
         */
        public function rmdir($path, $recursive = \false)
        {
        }
        /**
         * Gets details for files in a directory or a specific file.
         *
         * @since 2.7.0
         *
         * @param string $path           Path to directory or file.
         * @param bool   $include_hidden Optional. Whether to include details of hidden ("." prefixed) files.
         *                               Default true.
         * @param bool   $recursive      Optional. Whether to recursively include file details in nested directories.
         *                               Default false.
         * @return array|false {
         *     Array of arrays containing file information. False if unable to list directory contents.
         *
         *     @type array ...$0 {
         *         Array of file information. Note that some elements may not be available on all filesystems.
         *
         *         @type string           $name        Name of the file or directory.
         *         @type string           $perms       *nix representation of permissions.
         *         @type string           $permsn      Octal representation of permissions.
         *         @type false            $number      File number. Always false in this context.
         *         @type string|false     $owner       Owner name or ID, or false if not available.
         *         @type string|false     $group       File permissions group, or false if not available.
         *         @type int|string|false $size        Size of file in bytes. May be a numeric string.
         *                                             False if not available.
         *         @type int|string|false $lastmodunix Last modified unix timestamp. May be a numeric string.
         *                                             False if not available.
         *         @type string|false     $lastmod     Last modified month (3 letters) and day (without leading 0), or
         *                                             false if not available.
         *         @type string|false     $time        Last modified time, or false if not available.
         *         @type string           $type        Type of resource. 'f' for file, 'd' for directory, 'l' for link.
         *         @type array|false      $files       If a directory and `$recursive` is true, contains another array of
         *                                             files. False if unable to list directory contents.
         *     }
         * }
         * @phpstan-return false|array<int|string, array{
         *   name: string,
         *   perms: string,
         *   permsn: string,
         *   number: false,
         *   owner: string|false,
         *   group: string|false,
         *   size: int|string|false,
         *   lastmodunix: int|string|false,
         *   lastmod: string|false,
         *   time: string|false,
         *   type: string,
         *   files: array|false,
         * }>
         * @phpstan-return false|array<string, array{name: string, perms: string, permsn: string, owner: string|false, size: int|string|false, lastmodunix: int|string|false, lastmod: string|false, time: string|false, type: 'f'|'d'|'l', group: string|false, number: int|string|false, files?: array|false}>
         */
        public function dirlist($path, $include_hidden = \true, $recursive = \false)
        {
        }
    }
    /**
     * WP_Importer base class
     */
    #[\AllowDynamicProperties]
    class WP_Importer
    {
        /**
         * Class Constructor
         */
        public function __construct()
        {
        }
        /**
         * Returns array with imported permalinks from WordPress database.
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $importer_name
         * @param string $blog_id
         * @return array
         */
        public function get_imported_posts($importer_name, $blog_id)
        {
        }
        /**
         * Returns count of imported permalinks from WordPress database.
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $importer_name
         * @param string $blog_id
         * @return int
         */
        public function count_imported_posts($importer_name, $blog_id)
        {
        }
        /**
         * Sets array with imported comments from WordPress database.
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $blog_id
         * @return array
         */
        public function get_imported_comments($blog_id)
        {
        }
        /**
         * @param int $blog_id
         * @return int|void
         */
        public function set_blog($blog_id)
        {
        }
        /**
         * @param int $user_id
         * @return int|void
         */
        public function set_user($user_id)
        {
        }
        /**
         * Sorts by strlen, longest string first.
         *
         * @param string $a
         * @param string $b
         * @return int
         */
        public function cmpr_strlen($a, $b)
        {
        }
        /**
         * Gets URL.
         *
         * @param string $url
         * @param string $username
         * @param string $password
         * @param bool   $head
         * @return array
         */
        public function get_page($url, $username = '', $password = '', $head = \false)
        {
        }
        /**
         * Bumps up the request timeout for http requests.
         *
         * @param int $val
         * @return int
         */
        public function bump_request_timeout($val)
        {
        }
        /**
         * Checks if user has exceeded disk quota.
         *
         * @return bool
         */
        public function is_user_over_quota()
        {
        }
        /**
         * Replaces newlines, tabs, and multiple spaces with a single space.
         *
         * @param string $text
         * @return string
         */
        public function min_whitespace($text)
        {
        }
        /**
         * Resets global variables that grow out of control during imports.
         *
         * @since 3.0.0
         *
         * @global wpdb  $wpdb       WordPress database abstraction object.
         * @global int[] $wp_actions
         */
        public function stop_the_insanity()
        {
        }
    }
    /**
     * Core class used to implement an internal admin pointers API.
     *
     * @since 3.3.0
     */
    #[\AllowDynamicProperties]
    final class WP_Internal_Pointers
    {
        /**
         * Initializes the new feature pointers.
         *
         * @since 3.3.0
         *
         * All pointers can be disabled using the following:
         *     remove_action( 'admin_enqueue_scripts', array( 'WP_Internal_Pointers', 'enqueue_scripts' ) );
         *
         * Individual pointers (e.g. wp390_widgets) can be disabled using the following:
         *
         *    function yourprefix_remove_pointers() {
         *        remove_action(
         *            'admin_print_footer_scripts',
         *            array( 'WP_Internal_Pointers', 'pointer_wp390_widgets' )
         *        );
         *    }
         *    add_action( 'admin_enqueue_scripts', 'yourprefix_remove_pointers', 11 );
         *
         * @param string $hook_suffix The current admin page.
         * @phpstan-return void
         */
        public static function enqueue_scripts($hook_suffix)
        {
        }
        public static function pointer_wp330_toolbar()
        {
        }
        public static function pointer_wp330_media_uploader()
        {
        }
        public static function pointer_wp330_saving_widgets()
        {
        }
        public static function pointer_wp340_customize_current_theme_link()
        {
        }
        public static function pointer_wp340_choose_image_from_library()
        {
        }
        public static function pointer_wp350_media()
        {
        }
        public static function pointer_wp360_revisions()
        {
        }
        public static function pointer_wp360_locks()
        {
        }
        public static function pointer_wp390_widgets()
        {
        }
        public static function pointer_wp410_dfw()
        {
        }
        public static function pointer_wp496_privacy()
        {
        }
        /**
         * Prevents new users from seeing existing 'new feature' pointers.
         *
         * @since 3.3.0
         *
         * @param int $user_id User ID.
         */
        public static function dismiss_pointers_for_new_users($user_id)
        {
        }
    }
    /**
     * Core class used to implement displaying links in a list table.
     *
     * @since 3.1.0
     *
     * @see WP_List_Table
     */
    class WP_Links_List_Table extends \WP_List_Table
    {
        /**
         * Constructor.
         *
         * @since 3.1.0
         *
         * @see WP_List_Table::__construct() for more information on default arguments.
         *
         * @param array $args An associative array of arguments.
         */
        public function __construct($args = array())
        {
        }
        /**
         * @return bool
         */
        public function ajax_user_can()
        {
        }
        /**
         * @global int    $cat_id
         * @global string $s
         * @global string $orderby
         * @global string $order
         */
        public function prepare_items()
        {
        }
        /**
         */
        public function no_items()
        {
        }
        /**
         * @return array
         */
        protected function get_bulk_actions()
        {
        }
        /**
         * @global int $cat_id
         * @param string $which
         * @phpstan-return void
         */
        protected function extra_tablenav($which)
        {
        }
        /**
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         * @return array
         */
        protected function get_sortable_columns()
        {
        }
        /**
         * Gets the name of the default primary column.
         *
         * @since 4.3.0
         *
         * @return string Name of the default primary column, in this case, 'name'.
         */
        protected function get_default_primary_column_name()
        {
        }
        /**
         * Handles the checkbox column output.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$link` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param object $item The current link object.
         */
        public function column_cb($item)
        {
        }
        /**
         * Handles the link name column output.
         *
         * @since 4.3.0
         *
         * @param object $link The current link object.
         */
        public function column_name($link)
        {
        }
        /**
         * Handles the link URL column output.
         *
         * @since 4.3.0
         *
         * @param object $link The current link object.
         */
        public function column_url($link)
        {
        }
        /**
         * Handles the link categories column output.
         *
         * @since 4.3.0
         *
         * @global int $cat_id
         *
         * @param object $link The current link object.
         */
        public function column_categories($link)
        {
        }
        /**
         * Handles the link relation column output.
         *
         * @since 4.3.0
         *
         * @param object $link The current link object.
         */
        public function column_rel($link)
        {
        }
        /**
         * Handles the link visibility column output.
         *
         * @since 4.3.0
         *
         * @param object $link The current link object.
         */
        public function column_visible($link)
        {
        }
        /**
         * Handles the link rating column output.
         *
         * @since 4.3.0
         *
         * @param object $link The current link object.
         */
        public function column_rating($link)
        {
        }
        /**
         * Handles the default column output.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$link` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param object $item        Link object.
         * @param string $column_name Current column name.
         */
        public function column_default($item, $column_name)
        {
        }
        /**
         * Generates the list table rows.
         *
         * @since 3.1.0
         */
        public function display_rows()
        {
        }
        /**
         * Generates and displays row action links.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$link` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param object $item        Link being acted upon.
         * @param string $column_name Current column name.
         * @param string $primary     Primary column name.
         * @return string Row actions output for links, or an empty string
         *                if the current column is not the primary column.
         */
        protected function handle_row_actions($item, $column_name, $primary)
        {
        }
    }
    /**
     * Helper class to be used only by back compat functions.
     *
     * @since 3.1.0
     */
    class _WP_List_Table_Compat extends \WP_List_Table
    {
        public $_screen;
        public $_columns;
        /**
         * Constructor.
         *
         * @since 3.1.0
         *
         * @param string|WP_Screen $screen  The screen hook name or screen object.
         * @param string[]         $columns An array of columns with column IDs as the keys
         *                                  and translated column names as the values.
         */
        public function __construct($screen, $columns = array())
        {
        }
        /**
         * Gets a list of all, hidden, and sortable columns.
         *
         * @since 3.1.0
         *
         * @return array
         */
        protected function get_column_info()
        {
        }
        /**
         * Gets a list of columns.
         *
         * @since 3.1.0
         *
         * @return array
         */
        public function get_columns()
        {
        }
    }
    /**
     * Core class used to implement displaying media items in a list table.
     *
     * @since 3.1.0
     *
     * @see WP_List_Table
     */
    class WP_Media_List_Table extends \WP_List_Table
    {
        /**
         * Holds the number of pending comments for each post.
         *
         * @since 4.4.0
         * @var array
         */
        protected $comment_pending_count = array();
        /**
         * Constructor.
         *
         * @since 3.1.0
         *
         * @see WP_List_Table::__construct() for more information on default arguments.
         *
         * @param array $args An associative array of arguments.
         */
        public function __construct($args = array())
        {
        }
        /**
         * @return bool
         */
        public function ajax_user_can()
        {
        }
        /**
         * @global string   $mode                  List table view mode.
         * @global WP_Query $wp_query              WordPress Query object.
         * @global array    $post_mime_types
         * @global array    $avail_post_mime_types
         */
        public function prepare_items()
        {
        }
        /**
         * @global array $post_mime_types
         * @global array $avail_post_mime_types
         * @return array
         */
        protected function get_views()
        {
        }
        /**
         * @return array
         */
        protected function get_bulk_actions()
        {
        }
        /**
         * @param string $which
         * @phpstan-return void
         */
        protected function extra_tablenav($which)
        {
        }
        /**
         * @return string
         */
        public function current_action()
        {
        }
        /**
         * @return bool
         */
        public function has_items()
        {
        }
        /**
         */
        public function no_items()
        {
        }
        /**
         * Overrides parent views to use the filter bar display.
         *
         * @global string $mode List table view mode.
         */
        public function views()
        {
        }
        /**
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         * @return array
         */
        protected function get_sortable_columns()
        {
        }
        /**
         * Handles the checkbox column output.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$post` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Post $item The current WP_Post object.
         */
        public function column_cb($item)
        {
        }
        /**
         * Handles the title column output.
         *
         * @since 4.3.0
         *
         * @param WP_Post $post The current WP_Post object.
         */
        public function column_title($post)
        {
        }
        /**
         * Handles the author column output.
         *
         * @since 4.3.0
         *
         * @param WP_Post $post The current WP_Post object.
         */
        public function column_author($post)
        {
        }
        /**
         * Handles the description column output.
         *
         * @since 4.3.0
         * @deprecated 6.2.0
         *
         * @param WP_Post $post The current WP_Post object.
         */
        public function column_desc($post)
        {
        }
        /**
         * Handles the date column output.
         *
         * @since 4.3.0
         *
         * @param WP_Post $post The current WP_Post object.
         */
        public function column_date($post)
        {
        }
        /**
         * Handles the parent column output.
         *
         * @since 4.3.0
         *
         * @param WP_Post $post The current WP_Post object.
         */
        public function column_parent($post)
        {
        }
        /**
         * Handles the comments column output.
         *
         * @since 4.3.0
         *
         * @param WP_Post $post The current WP_Post object.
         */
        public function column_comments($post)
        {
        }
        /**
         * Handles output for the default column.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$post` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Post $item        The current WP_Post object.
         * @param string  $column_name Current column name.
         * @phpstan-return void
         */
        public function column_default($item, $column_name)
        {
        }
        /**
         * Generates the list table rows.
         *
         * @since 3.1.0
         *
         * @global WP_Post  $post     Global post object.
         * @global WP_Query $wp_query WordPress Query object.
         */
        public function display_rows()
        {
        }
        /**
         * Gets the name of the default primary column.
         *
         * @since 4.3.0
         *
         * @return string Name of the default primary column, in this case, 'title'.
         */
        protected function get_default_primary_column_name()
        {
        }
        /**
         * Generates and displays row action links.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$post` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Post $item        Attachment being acted upon.
         * @param string  $column_name Current column name.
         * @param string  $primary     Primary column name.
         * @return string Row actions output for media attachments, or an empty string
         *                if the current column is not the primary column.
         */
        protected function handle_row_actions($item, $column_name, $primary)
        {
        }
    }
    /**
     * Core class used to implement displaying sites in a list table for the network admin.
     *
     * @since 3.1.0
     *
     * @see WP_List_Table
     */
    class WP_MS_Sites_List_Table extends \WP_List_Table
    {
        /**
         * Site status list.
         *
         * @since 4.3.0
         * @var array
         */
        public $status_list;
        /**
         * Constructor.
         *
         * @since 3.1.0
         *
         * @see WP_List_Table::__construct() for more information on default arguments.
         *
         * @param array $args An associative array of arguments.
         */
        public function __construct($args = array())
        {
        }
        /**
         * @return bool
         */
        public function ajax_user_can()
        {
        }
        /**
         * Prepares the list of sites for display.
         *
         * @since 3.1.0
         *
         * @global string $mode List table view mode.
         * @global string $s
         * @global wpdb   $wpdb WordPress database abstraction object.
         */
        public function prepare_items()
        {
        }
        /**
         */
        public function no_items()
        {
        }
        /**
         * Gets links to filter sites by status.
         *
         * @since 5.3.0
         *
         * @return array
         */
        protected function get_views()
        {
        }
        /**
         * @return array
         */
        protected function get_bulk_actions()
        {
        }
        /**
         * @global string $mode List table view mode.
         *
         * @param string $which The location of the pagination nav markup: Either 'top' or 'bottom'.
         * @phpstan-param 'top'|'bottom' $which
         */
        protected function pagination($which)
        {
        }
        /**
         * Displays extra controls between bulk actions and pagination.
         *
         * @since 5.3.0
         *
         * @param string $which The location of the extra table nav markup: Either 'top' or 'bottom'.
         * @phpstan-param 'top'|'bottom' $which
         */
        protected function extra_tablenav($which)
        {
        }
        /**
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         * @return array
         */
        protected function get_sortable_columns()
        {
        }
        /**
         * Handles the checkbox column output.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$blog` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param array $item Current site.
         */
        public function column_cb($item)
        {
        }
        /**
         * Handles the ID column output.
         *
         * @since 4.4.0
         *
         * @param array $blog Current site.
         */
        public function column_id($blog)
        {
        }
        /**
         * Handles the site name column output.
         *
         * @since 4.3.0
         *
         * @global string $mode List table view mode.
         *
         * @param array $blog Current site.
         */
        public function column_blogname($blog)
        {
        }
        /**
         * Handles the lastupdated column output.
         *
         * @since 4.3.0
         *
         * @global string $mode List table view mode.
         *
         * @param array $blog Current site.
         */
        public function column_lastupdated($blog)
        {
        }
        /**
         * Handles the registered column output.
         *
         * @since 4.3.0
         *
         * @global string $mode List table view mode.
         *
         * @param array $blog Current site.
         */
        public function column_registered($blog)
        {
        }
        /**
         * Handles the users column output.
         *
         * @since 4.3.0
         *
         * @param array $blog Current site.
         */
        public function column_users($blog)
        {
        }
        /**
         * Handles the plugins column output.
         *
         * @since 4.3.0
         *
         * @param array $blog Current site.
         */
        public function column_plugins($blog)
        {
        }
        /**
         * Handles output for the default column.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$blog` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param array  $item        Current site.
         * @param string $column_name Current column name.
         */
        public function column_default($item, $column_name)
        {
        }
        /**
         * Generates the list table rows.
         *
         * @since 3.1.0
         */
        public function display_rows()
        {
        }
        /**
         * Determines whether to output comma-separated site states.
         *
         * @since 5.3.0
         *
         * @param array $site
         */
        protected function site_states($site)
        {
        }
        /**
         * Gets the name of the default primary column.
         *
         * @since 4.3.0
         *
         * @return string Name of the default primary column, in this case, 'blogname'.
         */
        protected function get_default_primary_column_name()
        {
        }
        /**
         * Generates and displays row action links.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$blog` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param array  $item        Site being acted upon.
         * @param string $column_name Current column name.
         * @param string $primary     Primary column name.
         * @return string Row actions output for sites in Multisite, or an empty string
         *                if the current column is not the primary column.
         */
        protected function handle_row_actions($item, $column_name, $primary)
        {
        }
    }
    /**
     * Core class used to implement displaying themes in a list table for the network admin.
     *
     * @since 3.1.0
     *
     * @see WP_List_Table
     */
    class WP_MS_Themes_List_Table extends \WP_List_Table
    {
        public $site_id;
        public $is_site_themes;
        /**
         * Whether to show the auto-updates UI.
         *
         * @since 5.5.0
         *
         * @var bool True if auto-updates UI is to be shown, false otherwise.
         */
        protected $show_autoupdates = \true;
        /**
         * Constructor.
         *
         * @since 3.1.0
         *
         * @see WP_List_Table::__construct() for more information on default arguments.
         *
         * @global string $status
         * @global int    $page
         *
         * @param array $args An associative array of arguments.
         */
        public function __construct($args = array())
        {
        }
        /**
         * @return array
         */
        protected function get_table_classes()
        {
        }
        /**
         * @return bool
         */
        public function ajax_user_can()
        {
        }
        /**
         * @global string $status
         * @global array $totals
         * @global int $page
         * @global string $orderby
         * @global string $order
         * @global string $s
         */
        public function prepare_items()
        {
        }
        /**
         * @param WP_Theme $theme
         * @return bool
         */
        public function _search_callback($theme)
        {
        }
        /**
         * @global string $orderby
         * @global string $order
         * @param array $theme_a
         * @param array $theme_b
         * @return int
         */
        public function _order_callback($theme_a, $theme_b)
        {
        }
        /**
         */
        public function no_items()
        {
        }
        /**
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         * @return array
         */
        protected function get_sortable_columns()
        {
        }
        /**
         * Gets the name of the primary column.
         *
         * @since 4.3.0
         *
         * @return string Unalterable name of the primary column name, in this case, 'name'.
         */
        protected function get_primary_column_name()
        {
        }
        /**
         * @global array $totals
         * @global string $status
         * @return array
         */
        protected function get_views()
        {
        }
        /**
         * @global string $status
         *
         * @return array
         */
        protected function get_bulk_actions()
        {
        }
        /**
         * Generates the list table rows.
         *
         * @since 3.1.0
         */
        public function display_rows()
        {
        }
        /**
         * Handles the checkbox column output.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$theme` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Theme $item The current WP_Theme object.
         */
        public function column_cb($item)
        {
        }
        /**
         * Handles the name column output.
         *
         * @since 4.3.0
         *
         * @global string $status
         * @global int    $page
         * @global string $s
         *
         * @param WP_Theme $theme The current WP_Theme object.
         */
        public function column_name($theme)
        {
        }
        /**
         * Handles the description column output.
         *
         * @since 4.3.0
         *
         * @global string $status
         * @global array  $totals
         *
         * @param WP_Theme $theme The current WP_Theme object.
         */
        public function column_description($theme)
        {
        }
        /**
         * Handles the auto-updates column output.
         *
         * @since 5.5.0
         *
         * @global string $status
         * @global int  $page
         *
         * @param WP_Theme $theme The current WP_Theme object.
         */
        public function column_autoupdates($theme)
        {
        }
        /**
         * Handles default column output.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$theme` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Theme $item        The current WP_Theme object.
         * @param string   $column_name The current column name.
         */
        public function column_default($item, $column_name)
        {
        }
        /**
         * Handles the output for a single table row.
         *
         * @since 4.3.0
         *
         * @param WP_Theme $item The current WP_Theme object.
         */
        public function single_row_columns($item)
        {
        }
        /**
         * @global string $status
         * @global array  $totals
         *
         * @param WP_Theme $theme
         */
        public function single_row($theme)
        {
        }
    }
    /**
     * Core class used to implement displaying users in a list table for the network admin.
     *
     * @since 3.1.0
     *
     * @see WP_List_Table
     */
    class WP_MS_Users_List_Table extends \WP_List_Table
    {
        /**
         * @return bool
         */
        public function ajax_user_can()
        {
        }
        /**
         * @global string $mode       List table view mode.
         * @global string $usersearch
         * @global string $role
         */
        public function prepare_items()
        {
        }
        /**
         * @return array
         */
        protected function get_bulk_actions()
        {
        }
        /**
         */
        public function no_items()
        {
        }
        /**
         * @global string $role
         * @return array
         */
        protected function get_views()
        {
        }
        /**
         * @global string $mode List table view mode.
         *
         * @param string $which
         */
        protected function pagination($which)
        {
        }
        /**
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         * @return array
         */
        protected function get_sortable_columns()
        {
        }
        /**
         * Handles the checkbox column output.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$user` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_User $item The current WP_User object.
         * @phpstan-return void
         */
        public function column_cb($item)
        {
        }
        /**
         * Handles the ID column output.
         *
         * @since 4.4.0
         *
         * @param WP_User $user The current WP_User object.
         */
        public function column_id($user)
        {
        }
        /**
         * Handles the username column output.
         *
         * @since 4.3.0
         *
         * @param WP_User $user The current WP_User object.
         */
        public function column_username($user)
        {
        }
        /**
         * Handles the name column output.
         *
         * @since 4.3.0
         *
         * @param WP_User $user The current WP_User object.
         */
        public function column_name($user)
        {
        }
        /**
         * Handles the email column output.
         *
         * @since 4.3.0
         *
         * @param WP_User $user The current WP_User object.
         */
        public function column_email($user)
        {
        }
        /**
         * Handles the registered date column output.
         *
         * @since 4.3.0
         *
         * @global string $mode List table view mode.
         *
         * @param WP_User $user The current WP_User object.
         */
        public function column_registered($user)
        {
        }
        /**
         * @since 4.3.0
         *
         * @param WP_User $user
         * @param string  $classes
         * @param string  $data
         * @param string  $primary
         */
        protected function _column_blogs($user, $classes, $data, $primary)
        {
        }
        /**
         * Handles the sites column output.
         *
         * @since 4.3.0
         *
         * @param WP_User $user The current WP_User object.
         * @phpstan-return void
         */
        public function column_blogs($user)
        {
        }
        /**
         * Handles the default column output.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$user` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_User $item        The current WP_User object.
         * @param string  $column_name The current column name.
         */
        public function column_default($item, $column_name)
        {
        }
        /**
         * Generates the list table rows.
         *
         * @since 3.1.0
         */
        public function display_rows()
        {
        }
        /**
         * Gets the name of the default primary column.
         *
         * @since 4.3.0
         *
         * @return string Name of the default primary column, in this case, 'username'.
         */
        protected function get_default_primary_column_name()
        {
        }
        /**
         * Generates and displays row action links.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$user` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_User $item        User being acted upon.
         * @param string  $column_name Current column name.
         * @param string  $primary     Primary column name.
         * @return string Row actions output for users in Multisite, or an empty string
         *                if the current column is not the primary column.
         */
        protected function handle_row_actions($item, $column_name, $primary)
        {
        }
    }
    /**
     * Core class used to implement displaying plugins to install in a list table.
     *
     * @since 3.1.0
     *
     * @see WP_List_Table
     */
    class WP_Plugin_Install_List_Table extends \WP_List_Table
    {
        public $order = 'ASC';
        public $orderby = \null;
        public $groups = array();
        /**
         * @return bool
         */
        public function ajax_user_can()
        {
        }
        /**
         * Returns the list of known plugins.
         *
         * Uses the transient data from the updates API to determine the known
         * installed plugins.
         *
         * @since 4.9.0
         * @access protected
         *
         * @return array
         */
        protected function get_installed_plugins()
        {
        }
        /**
         * Returns a list of slugs of installed plugins, if known.
         *
         * Uses the transient data from the updates API to determine the slugs of
         * known installed plugins. This might be better elsewhere, perhaps even
         * within get_plugins().
         *
         * @since 4.0.0
         *
         * @return array
         */
        protected function get_installed_plugin_slugs()
        {
        }
        /**
         * @global array  $tabs
         * @global string $tab
         * @global int    $paged
         * @global string $type
         * @global string $term
         * @phpstan-return void
         */
        public function prepare_items()
        {
        }
        /**
         */
        public function no_items()
        {
        }
        /**
         * @global array $tabs
         * @global string $tab
         *
         * @return array
         */
        protected function get_views()
        {
        }
        /**
         * Overrides parent views so we can use the filter bar display.
         */
        public function views()
        {
        }
        /**
         * Displays the plugin install table.
         *
         * Overrides the parent display() method to provide a different container.
         *
         * @since 4.0.0
         */
        public function display()
        {
        }
        /**
         * @global string $tab
         *
         * @param string $which
         * @phpstan-return void
         */
        protected function display_tablenav($which)
        {
        }
        /**
         * @return array
         */
        protected function get_table_classes()
        {
        }
        /**
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         * Generates the list table rows.
         *
         * @since 3.1.0
         */
        public function display_rows()
        {
        }
        /**
         * Returns a notice containing a list of dependencies required by the plugin.
         *
         * @since 6.5.0
         *
         * @param array  $plugin_data An array of plugin data. See {@see plugins_api()}
         *                            for the list of possible values.
         * @return string A notice containing a list of dependencies required by the plugin,
         *                or an empty string if none is required.
         * @phpstan-param object|array{
         *   slug?: string,
         *   per_page?: int,
         *   page?: int,
         *   number?: int,
         *   search?: string,
         *   tag?: string,
         *   author?: string,
         *   user?: string,
         *   browse?: string,
         *   locale?: string,
         *   installed_plugins?: string,
         *   is_ssl?: bool,
         *   fields?: array{
         *     short_description?: bool,
         *     description?: bool,
         *     sections?: bool,
         *     tested?: bool,
         *     requires?: bool,
         *     requires_php?: bool,
         *     rating?: bool,
         *     ratings?: bool,
         *     downloaded?: bool,
         *     downloadlink?: bool,
         *     last_updated?: bool,
         *     added?: bool,
         *     tags?: bool,
         *     compatibility?: bool,
         *     homepage?: bool,
         *     versions?: bool,
         *     donate_link?: bool,
         *     reviews?: bool,
         *     banners?: bool,
         *     icons?: bool,
         *     active_installs?: bool,
         *     contributors?: bool,
         *   },
         * } $plugin_data See plugins_api()
         */
        protected function get_dependencies_notice($plugin_data)
        {
        }
        /**
         * Creates a 'More details' link for the plugin.
         *
         * @since 6.5.0
         *
         * @param string $name The plugin's name.
         * @param string $slug The plugin's slug.
         * @return string The 'More details' link for the plugin.
         */
        protected function get_more_details_link($name, $slug)
        {
        }
    }
    /**
     * Core class used to implement displaying installed plugins in a list table.
     *
     * @since 3.1.0
     *
     * @see WP_List_Table
     */
    class WP_Plugins_List_Table extends \WP_List_Table
    {
        /**
         * Whether to show the auto-updates UI.
         *
         * @since 5.5.0
         *
         * @var bool True if auto-updates UI is to be shown, false otherwise.
         */
        protected $show_autoupdates = \true;
        /**
         * Constructor.
         *
         * @since 3.1.0
         *
         * @see WP_List_Table::__construct() for more information on default arguments.
         *
         * @global string $status
         * @global int    $page
         *
         * @param array $args An associative array of arguments.
         */
        public function __construct($args = array())
        {
        }
        /**
         * @return array
         */
        protected function get_table_classes()
        {
        }
        /**
         * @return bool
         */
        public function ajax_user_can()
        {
        }
        /**
         * @global string $status
         * @global array  $plugins
         * @global array  $totals
         * @global int    $page
         * @global string $orderby
         * @global string $order
         * @global string $s
         */
        public function prepare_items()
        {
        }
        /**
         * @global string $s URL encoded search term.
         *
         * @param array $plugin
         * @return bool
         */
        public function _search_callback($plugin)
        {
        }
        /**
         * @global string $orderby
         * @global string $order
         * @param array $plugin_a
         * @param array $plugin_b
         * @return int
         */
        public function _order_callback($plugin_a, $plugin_b)
        {
        }
        /**
         * @global array $plugins
         */
        public function no_items()
        {
        }
        /**
         * Displays the search box.
         *
         * @since 4.6.0
         *
         * @param string $text     The 'submit' button label.
         * @param string $input_id ID attribute value for the search input field.
         * @phpstan-return void
         */
        public function search_box($text, $input_id)
        {
        }
        /**
         * @global string $status
         *
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         * @return array
         */
        protected function get_sortable_columns()
        {
        }
        /**
         * @global array $totals
         * @global string $status
         * @return array
         */
        protected function get_views()
        {
        }
        /**
         * @global string $status
         * @return array
         */
        protected function get_bulk_actions()
        {
        }
        /**
         * @global string $status
         * @param string $which
         * @phpstan-return void
         */
        public function bulk_actions($which = '')
        {
        }
        /**
         * @global string $status
         * @param string $which
         * @phpstan-return void
         */
        protected function extra_tablenav($which)
        {
        }
        /**
         * @return string
         */
        public function current_action()
        {
        }
        /**
         * Generates the list table rows.
         *
         * @since 3.1.0
         *
         * @global string $status
         * @phpstan-return void
         */
        public function display_rows()
        {
        }
        /**
         * @global string $status
         * @global int $page
         * @global string $s
         * @global array $totals
         *
         * @param array $item
         */
        public function single_row($item)
        {
        }
        /**
         * Gets the name of the primary column for this specific list table.
         *
         * @since 4.3.0
         *
         * @return string Unalterable name for the primary column, in this case, 'name'.
         */
        protected function get_primary_column_name()
        {
        }
        /**
         * Prints a list of other plugins that depend on the plugin.
         *
         * @since 6.5.0
         *
         * @param string $dependency The dependency's filepath, relative to the plugins directory.
         * @phpstan-return void
         */
        protected function add_dependents_to_dependency_plugin_row($dependency)
        {
        }
        /**
         * Prints a list of other plugins that the plugin depends on.
         *
         * @since 6.5.0
         *
         * @param string $dependent The dependent plugin's filepath, relative to the plugins directory.
         * @phpstan-return void
         */
        protected function add_dependencies_to_dependent_plugin_row($dependent)
        {
        }
        /**
         * Returns a 'View details' like link for a dependency.
         *
         * @since 6.5.0
         *
         * @param string $name The dependency's name.
         * @param string $slug The dependency's slug.
         * @return string A 'View details' link for the dependency.
         */
        protected function get_dependency_view_details_link($name, $slug)
        {
        }
        /**
         * Returns a 'View details' link for the plugin.
         *
         * @since 6.5.0
         *
         * @param string $name The plugin's name.
         * @param string $slug The plugin's slug.
         * @return string A 'View details' link for the plugin.
         */
        protected function get_view_details_link($name, $slug)
        {
        }
    }
    /**
     * Core class used to implement displaying post comments in a list table.
     *
     * @since 3.1.0
     *
     * @see WP_Comments_List_Table
     */
    class WP_Post_Comments_List_Table extends \WP_Comments_List_Table
    {
        /**
         * @return array
         */
        protected function get_column_info()
        {
        }
        /**
         * @return array
         */
        protected function get_table_classes()
        {
        }
        /**
         * @param bool $output_empty
         */
        public function display($output_empty = \false)
        {
        }
        /**
         * @param bool $comment_status
         * @return int
         */
        public function get_per_page($comment_status = \false)
        {
        }
    }
    /**
     * Core class used to implement displaying posts in a list table.
     *
     * @since 3.1.0
     *
     * @see WP_List_Table
     */
    class WP_Posts_List_Table extends \WP_List_Table
    {
        /**
         * Whether the items should be displayed hierarchically or linearly.
         *
         * @since 3.1.0
         * @var bool
         */
        protected $hierarchical_display;
        /**
         * Holds the number of pending comments for each post.
         *
         * @since 3.1.0
         * @var array
         */
        protected $comment_pending_count;
        /**
         * Current level for output.
         *
         * @since 4.3.0
         * @var int
         */
        protected $current_level = 0;
        /**
         * Constructor.
         *
         * @since 3.1.0
         *
         * @see WP_List_Table::__construct() for more information on default arguments.
         *
         * @global WP_Post_Type $post_type_object Global post type object.
         * @global wpdb         $wpdb             WordPress database abstraction object.
         *
         * @param array $args An associative array of arguments.
         */
        public function __construct($args = array())
        {
        }
        /**
         * Sets whether the table layout should be hierarchical or not.
         *
         * @since 4.2.0
         *
         * @param bool $display Whether the table layout should be hierarchical.
         */
        public function set_hierarchical_display($display)
        {
        }
        /**
         * @return bool
         */
        public function ajax_user_can()
        {
        }
        /**
         * @global string   $mode             List table view mode.
         * @global array    $avail_post_stati
         * @global WP_Query $wp_query         WordPress Query object.
         * @global int      $per_page
         */
        public function prepare_items()
        {
        }
        /**
         * @return bool
         */
        public function has_items()
        {
        }
        /**
         */
        public function no_items()
        {
        }
        /**
         * Determines if the current view is the "All" view.
         *
         * @since 4.2.0
         *
         * @return bool Whether the current view is the "All" view.
         */
        protected function is_base_request()
        {
        }
        /**
         * Creates a link to edit.php with params.
         *
         * @since 4.4.0
         *
         * @param string[] $args      Associative array of URL parameters for the link.
         * @param string   $link_text Link text.
         * @param string   $css_class Optional. Class attribute. Default empty string.
         * @return string The formatted link string.
         */
        protected function get_edit_link($args, $link_text, $css_class = '')
        {
        }
        /**
         * @global array $locked_post_status This seems to be deprecated.
         * @global array $avail_post_stati
         * @return array
         */
        protected function get_views()
        {
        }
        /**
         * @return array
         */
        protected function get_bulk_actions()
        {
        }
        /**
         * Displays a categories drop-down for filtering on the Posts list table.
         *
         * @since 4.6.0
         *
         * @global int $cat Currently selected category.
         *
         * @param string $post_type Post type slug.
         * @phpstan-return void
         */
        protected function categories_dropdown($post_type)
        {
        }
        /**
         * Displays a formats drop-down for filtering items.
         *
         * @since 5.2.0
         * @access protected
         *
         * @param string $post_type Post type slug.
         * @phpstan-return void
         */
        protected function formats_dropdown($post_type)
        {
        }
        /**
         * @param string $which
         */
        protected function extra_tablenav($which)
        {
        }
        /**
         * @return string
         */
        public function current_action()
        {
        }
        /**
         * @global string $mode List table view mode.
         *
         * @return array
         */
        protected function get_table_classes()
        {
        }
        /**
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         * @return array
         */
        protected function get_sortable_columns()
        {
        }
        /**
         * Generates the list table rows.
         *
         * @since 3.1.0
         *
         * @global WP_Query $wp_query WordPress Query object.
         * @global int      $per_page
         *
         * @param array $posts
         * @param int   $level
         */
        public function display_rows($posts = array(), $level = 0)
        {
        }
        /**
         * Handles the checkbox column output.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$post` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Post $item The current WP_Post object.
         */
        public function column_cb($item)
        {
        }
        /**
         * @since 4.3.0
         *
         * @param WP_Post $post
         * @param string  $classes
         * @param string  $data
         * @param string  $primary
         */
        protected function _column_title($post, $classes, $data, $primary)
        {
        }
        /**
         * Handles the title column output.
         *
         * @since 4.3.0
         *
         * @global string $mode List table view mode.
         *
         * @param WP_Post $post The current WP_Post object.
         */
        public function column_title($post)
        {
        }
        /**
         * Handles the post date column output.
         *
         * @since 4.3.0
         *
         * @global string $mode List table view mode.
         *
         * @param WP_Post $post The current WP_Post object.
         */
        public function column_date($post)
        {
        }
        /**
         * Handles the comments column output.
         *
         * @since 4.3.0
         *
         * @param WP_Post $post The current WP_Post object.
         */
        public function column_comments($post)
        {
        }
        /**
         * Handles the post author column output.
         *
         * @since 4.3.0
         *
         * @param WP_Post $post The current WP_Post object.
         */
        public function column_author($post)
        {
        }
        /**
         * Handles the default column output.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$post` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Post $item        The current WP_Post object.
         * @param string  $column_name The current column name.
         * @phpstan-return void
         */
        public function column_default($item, $column_name)
        {
        }
        /**
         * @global WP_Post $post Global post object.
         *
         * @param int|WP_Post $post
         * @param int         $level
         */
        public function single_row($post, $level = 0)
        {
        }
        /**
         * Gets the name of the default primary column.
         *
         * @since 4.3.0
         *
         * @return string Name of the default primary column, in this case, 'title'.
         */
        protected function get_default_primary_column_name()
        {
        }
        /**
         * Generates and displays row action links.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$post` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Post $item        Post being acted upon.
         * @param string  $column_name Current column name.
         * @param string  $primary     Primary column name.
         * @return string Row actions output for posts, or an empty string
         *                if the current column is not the primary column.
         */
        protected function handle_row_actions($item, $column_name, $primary)
        {
        }
        /**
         * Outputs the hidden row displayed when inline editing
         *
         * @since 3.1.0
         *
         * @global string $mode List table view mode.
         */
        public function inline_edit()
        {
        }
    }
    /**
     * List Table API: WP_Privacy_Requests_Table class
     *
     * @package WordPress
     * @subpackage Administration
     * @since 4.9.6
     */
    abstract class WP_Privacy_Requests_Table extends \WP_List_Table
    {
        /**
         * Action name for the requests this table will work with. Classes
         * which inherit from WP_Privacy_Requests_Table should define this.
         *
         * Example: 'export_personal_data'.
         *
         * @since 4.9.6
         *
         * @var string $request_type Name of action.
         */
        protected $request_type = 'INVALID';
        /**
         * Post type to be used.
         *
         * @since 4.9.6
         *
         * @var string $post_type The post type.
         */
        protected $post_type = 'INVALID';
        /**
         * Gets columns to show in the list table.
         *
         * @since 4.9.6
         *
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         * Normalizes the admin URL to the current page (by request_type).
         *
         * @since 5.3.0
         *
         * @return string URL to the current admin page.
         */
        protected function get_admin_url()
        {
        }
        /**
         * Gets a list of sortable columns.
         *
         * @since 4.9.6
         *
         * @return array Default sortable columns.
         */
        protected function get_sortable_columns()
        {
        }
        /**
         * Returns the default primary column.
         *
         * @since 4.9.6
         *
         * @return string Default primary column name.
         */
        protected function get_default_primary_column_name()
        {
        }
        /**
         * Counts the number of requests for each status.
         *
         * @since 4.9.6
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @return object Number of posts for each status.
         */
        protected function get_request_counts()
        {
        }
        /**
         * Gets an associative array ( id => link ) with the list of views available on this table.
         *
         * @since 4.9.6
         *
         * @return string[] An array of HTML links keyed by their view.
         */
        protected function get_views()
        {
        }
        /**
         * Gets bulk actions.
         *
         * @since 4.9.6
         *
         * @return array Array of bulk action labels keyed by their action.
         */
        protected function get_bulk_actions()
        {
        }
        /**
         * Process bulk actions.
         *
         * @since 4.9.6
         * @since 5.6.0 Added support for the `complete` action.
         * @phpstan-return void
         */
        public function process_bulk_action()
        {
        }
        /**
         * Prepares items to output.
         *
         * @since 4.9.6
         * @since 5.1.0 Added support for column sorting.
         */
        public function prepare_items()
        {
        }
        /**
         * Returns the markup for the Checkbox column.
         *
         * @since 4.9.6
         *
         * @param WP_User_Request $item Item being shown.
         * @return string Checkbox column markup.
         */
        public function column_cb($item)
        {
        }
        /**
         * Status column.
         *
         * @since 4.9.6
         *
         * @param WP_User_Request $item Item being shown.
         * @return string Status column markup.
         */
        public function column_status($item)
        {
        }
        /**
         * Converts a timestamp for display.
         *
         * @since 4.9.6
         *
         * @param int $timestamp Event timestamp.
         * @return string Human readable date.
         */
        protected function get_timestamp_as_date($timestamp)
        {
        }
        /**
         * Handles the default column.
         *
         * @since 4.9.6
         * @since 5.7.0 Added `manage_{$this->screen->id}_custom_column` action.
         *
         * @param WP_User_Request $item        Item being shown.
         * @param string          $column_name Name of column being shown.
         */
        public function column_default($item, $column_name)
        {
        }
        /**
         * Returns the markup for the Created timestamp column. Overridden by children.
         *
         * @since 5.7.0
         *
         * @param WP_User_Request $item Item being shown.
         * @return string Human readable date.
         */
        public function column_created_timestamp($item)
        {
        }
        /**
         * Actions column. Overridden by children.
         *
         * @since 4.9.6
         *
         * @param WP_User_Request $item Item being shown.
         * @return string Email column markup.
         */
        public function column_email($item)
        {
        }
        /**
         * Returns the markup for the next steps column. Overridden by children.
         *
         * @since 4.9.6
         *
         * @param WP_User_Request $item Item being shown.
         */
        public function column_next_steps($item)
        {
        }
        /**
         * Generates content for a single row of the table,
         *
         * @since 4.9.6
         *
         * @param WP_User_Request $item The current item.
         */
        public function single_row($item)
        {
        }
        /**
         * Embeds scripts used to perform actions. Overridden by children.
         *
         * @since 4.9.6
         */
        public function embed_scripts()
        {
        }
    }
    /**
     * WP_Privacy_Data_Export_Requests_Table class.
     *
     * @since 4.9.6
     */
    class WP_Privacy_Data_Export_Requests_List_Table extends \WP_Privacy_Requests_Table
    {
        /**
         * Action name for the requests this table will work with.
         *
         * @since 4.9.6
         *
         * @var string $request_type Name of action.
         */
        protected $request_type = 'export_personal_data';
        /**
         * Post type for the requests.
         *
         * @since 4.9.6
         *
         * @var string $post_type The post type.
         */
        protected $post_type = 'user_request';
        /**
         * Actions column.
         *
         * @since 4.9.6
         *
         * @param WP_User_Request $item Item being shown.
         * @return string Email column markup.
         */
        public function column_email($item)
        {
        }
        /**
         * Displays the next steps column.
         *
         * @since 4.9.6
         *
         * @param WP_User_Request $item Item being shown.
         */
        public function column_next_steps($item)
        {
        }
    }
    /**
     * WP_Privacy_Data_Removal_Requests_List_Table class.
     *
     * @since 4.9.6
     */
    class WP_Privacy_Data_Removal_Requests_List_Table extends \WP_Privacy_Requests_Table
    {
        /**
         * Action name for the requests this table will work with.
         *
         * @since 4.9.6
         *
         * @var string $request_type Name of action.
         */
        protected $request_type = 'remove_personal_data';
        /**
         * Post type for the requests.
         *
         * @since 4.9.6
         *
         * @var string $post_type The post type.
         */
        protected $post_type = 'user_request';
        /**
         * Outputs the Actions column.
         *
         * @since 4.9.6
         *
         * @param WP_User_Request $item Item being shown.
         * @return string Email column markup.
         */
        public function column_email($item)
        {
        }
        /**
         * Outputs the Next steps column.
         *
         * @since 4.9.6
         *
         * @param WP_User_Request $item Item being shown.
         */
        public function column_next_steps($item)
        {
        }
    }
    /**
     * WP_Privacy_Policy_Content class.
     *
     * @package WordPress
     * @subpackage Administration
     * @since 4.9.6
     */
    #[\AllowDynamicProperties]
    final class WP_Privacy_Policy_Content
    {
        /**
         * Adds content to the postbox shown when editing the privacy policy.
         *
         * Plugins and themes should suggest text for inclusion in the site's privacy policy.
         * The suggested text should contain information about any functionality that affects user privacy,
         * and will be shown in the Suggested Privacy Policy Content postbox.
         *
         * Intended for use from `wp_add_privacy_policy_content()`.
         *
         * @since 4.9.6
         *
         * @param string $plugin_name The name of the plugin or theme that is suggesting content for the site's privacy policy.
         * @param string $policy_text The suggested content for inclusion in the policy.
         * @phpstan-return void
         */
        public static function add($plugin_name, $policy_text)
        {
        }
        /**
         * Performs a quick check to determine whether any privacy info has changed.
         *
         * @since 4.9.6
         */
        public static function text_change_check()
        {
        }
        /**
         * Outputs a warning when some privacy info has changed.
         *
         * @since 4.9.6
         * @phpstan-return void
         */
        public static function policy_text_changed_notice()
        {
        }
        /**
         * Updates the cached policy info when the policy page is updated.
         *
         * @since 4.9.6
         * @access private
         *
         * @param int $post_id The ID of the updated post.
         * @phpstan-return void
         */
        public static function _policy_page_updated($post_id)
        {
        }
        /**
         * Checks for updated, added or removed privacy policy information from plugins.
         *
         * Caches the current info in post_meta of the policy page.
         *
         * @since 4.9.6
         *
         * @return array The privacy policy text/information added by core and plugins.
         */
        public static function get_suggested_policy_text()
        {
        }
        /**
         * Adds a notice with a link to the guide when editing the privacy policy page.
         *
         * @since 4.9.6
         * @since 5.0.0 The `$post` parameter was made optional.
         *
         * @global WP_Post $post Global post object.
         *
         * @param WP_Post|null $post The currently edited post. Default null.
         * @phpstan-return void
         */
        public static function notice($post = \null)
        {
        }
        /**
         * Outputs the privacy policy guide together with content from the theme and plugins.
         *
         * @since 4.9.6
         */
        public static function privacy_policy_guide()
        {
        }
        /**
         * Returns the default suggested privacy policy content.
         *
         * @since 4.9.6
         * @since 5.0.0 Added the `$blocks` parameter.
         *
         * @param bool $description Whether to include the descriptions under the section headings. Default false.
         * @param bool $blocks      Whether to format the content for the block editor. Default true.
         * @return string The default policy content.
         */
        public static function get_default_content($description = \false, $blocks = \true)
        {
        }
        /**
         * Adds the suggested privacy policy text to the policy postbox.
         *
         * @since 4.9.6
         */
        public static function add_suggested_content()
        {
        }
    }
    /**
     * Core class used to implement an admin screen API.
     *
     * @since 3.3.0
     */
    #[\AllowDynamicProperties]
    final class WP_Screen
    {
        /**
         * Any action associated with the screen.
         *
         * 'add' for *-add.php and *-new.php screens. Empty otherwise.
         *
         * @since 3.3.0
         * @var string
         */
        public $action;
        /**
         * The base type of the screen.
         *
         * This is typically the same as `$id` but with any post types and taxonomies stripped.
         * For example, for an `$id` of 'edit-post' the base is 'edit'.
         *
         * @since 3.3.0
         * @var string
         */
        public $base;
        /**
         * The unique ID of the screen.
         *
         * @since 3.3.0
         * @var string
         */
        public $id;
        /**
         * Whether the screen is in the network admin.
         *
         * Deprecated. Use in_admin() instead.
         *
         * @since 3.3.0
         * @deprecated 3.5.0
         * @var bool
         */
        public $is_network;
        /**
         * Whether the screen is in the user admin.
         *
         * Deprecated. Use in_admin() instead.
         *
         * @since 3.3.0
         * @deprecated 3.5.0
         * @var bool
         */
        public $is_user;
        /**
         * The base menu parent.
         *
         * This is derived from `$parent_file` by removing the query string and any .php extension.
         * `$parent_file` values of 'edit.php?post_type=page' and 'edit.php?post_type=post'
         * have a `$parent_base` of 'edit'.
         *
         * @since 3.3.0
         * @var string|null
         */
        public $parent_base;
        /**
         * The parent_file for the screen per the admin menu system.
         *
         * Some `$parent_file` values are 'edit.php?post_type=page', 'edit.php', and 'options-general.php'.
         *
         * @since 3.3.0
         * @var string|null
         */
        public $parent_file;
        /**
         * The post type associated with the screen, if any.
         *
         * The 'edit.php?post_type=page' screen has a post type of 'page'.
         * The 'edit-tags.php?taxonomy=$taxonomy&post_type=page' screen has a post type of 'page'.
         *
         * @since 3.3.0
         * @var string
         */
        public $post_type;
        /**
         * The taxonomy associated with the screen, if any.
         *
         * The 'edit-tags.php?taxonomy=category' screen has a taxonomy of 'category'.
         *
         * @since 3.3.0
         * @var string
         */
        public $taxonomy;
        /**
         * Whether the screen is using the block editor.
         *
         * @since 5.0.0
         * @var bool
         */
        public $is_block_editor = \false;
        /**
         * Fetches a screen object.
         *
         * @since 3.3.0
         *
         * @global string $hook_suffix
         *
         * @param string|WP_Screen $hook_name Optional. The hook name (also known as the hook suffix) used to determine the screen.
         *                                    Defaults to the current $hook_suffix global.
         * @return WP_Screen Screen object.
         */
        public static function get($hook_name = '')
        {
        }
        /**
         * Makes the screen object the current screen.
         *
         * @see set_current_screen()
         * @since 3.3.0
         *
         * @global WP_Screen $current_screen WordPress current screen object.
         * @global string    $typenow        The post type of the current screen.
         * @global string    $taxnow         The taxonomy of the current screen.
         */
        public function set_current_screen()
        {
        }
        /**
         * Indicates whether the screen is in a particular admin.
         *
         * @since 3.5.0
         *
         * @param string $admin The admin to check against (network | user | site).
         *                      If empty any of the three admins will result in true.
         * @return bool True if the screen is in the indicated admin, false otherwise.
         */
        public function in_admin($admin = \null)
        {
        }
        /**
         * Sets or returns whether the block editor is loading on the current screen.
         *
         * @since 5.0.0
         *
         * @param bool $set Optional. Sets whether the block editor is loading on the current screen or not.
         * @return bool True if the block editor is being loaded, false otherwise.
         */
        public function is_block_editor($set = \null)
        {
        }
        /**
         * Sets the old string-based contextual help for the screen for backward compatibility.
         *
         * @since 3.3.0
         *
         * @param WP_Screen $screen A screen object.
         * @param string    $help   Help text.
         */
        public static function add_old_compat_help($screen, $help)
        {
        }
        /**
         * Sets the parent information for the screen.
         *
         * This is called in admin-header.php after the menu parent for the screen has been determined.
         *
         * @since 3.3.0
         *
         * @param string $parent_file The parent file of the screen. Typically the $parent_file global.
         */
        public function set_parentage($parent_file)
        {
        }
        /**
         * Adds an option for the screen.
         *
         * Call this in template files after admin.php is loaded and before admin-header.php is loaded
         * to add screen options.
         *
         * @since 3.3.0
         *
         * @param string $option Option ID.
         * @param mixed  $args   Option-dependent arguments.
         */
        public function add_option($option, $args = array())
        {
        }
        /**
         * Removes an option from the screen.
         *
         * @since 3.8.0
         *
         * @param string $option Option ID.
         */
        public function remove_option($option)
        {
        }
        /**
         * Removes all options from the screen.
         *
         * @since 3.8.0
         */
        public function remove_options()
        {
        }
        /**
         * Gets the options registered for the screen.
         *
         * @since 3.8.0
         *
         * @return array Options with arguments.
         */
        public function get_options()
        {
        }
        /**
         * Gets the arguments for an option for the screen.
         *
         * @since 3.3.0
         *
         * @param string       $option Option name.
         * @param string|false $key    Optional. Specific array key for when the option is an array.
         *                             Default false.
         * @return string The option value if set, null otherwise.
         */
        public function get_option($option, $key = \false)
        {
        }
        /**
         * Gets the help tabs registered for the screen.
         *
         * @since 3.4.0
         * @since 4.4.0 Help tabs are ordered by their priority.
         *
         * @return array Help tabs with arguments.
         */
        public function get_help_tabs()
        {
        }
        /**
         * Gets the arguments for a help tab.
         *
         * @since 3.4.0
         *
         * @param string $id Help Tab ID.
         * @return array Help tab arguments.
         */
        public function get_help_tab($id)
        {
        }
        /**
         * Adds a help tab to the contextual help for the screen.
         *
         * Call this on the `load-$pagenow` hook for the relevant screen,
         * or fetch the `$current_screen` object, or use get_current_screen()
         * and then call the method from the object.
         *
         * You may need to filter `$current_screen` using an if or switch statement
         * to prevent new help tabs from being added to ALL admin screens.
         *
         * @since 3.3.0
         * @since 4.4.0 The `$priority` argument was added.
         *
         * @param array $args {
         *     Array of arguments used to display the help tab.
         *
         *     @type string   $title    Title for the tab. Default false.
         *     @type string   $id       Tab ID. Must be HTML-safe and should be unique for this menu.
         *                              It is NOT allowed to contain any empty spaces. Default false.
         *     @type string   $content  Optional. Help tab content in plain text or HTML. Default empty string.
         *     @type callable $callback Optional. A callback to generate the tab content. Default false.
         *     @type int      $priority Optional. The priority of the tab, used for ordering. Default 10.
         * }
         * @phpstan-param array{
         *   title?: string,
         *   id?: string,
         *   content?: string,
         *   callback?: callable,
         *   priority?: int,
         * } $args
         * @phpstan-return void
         */
        public function add_help_tab($args)
        {
        }
        /**
         * Removes a help tab from the contextual help for the screen.
         *
         * @since 3.3.0
         *
         * @param string $id The help tab ID.
         */
        public function remove_help_tab($id)
        {
        }
        /**
         * Removes all help tabs from the contextual help for the screen.
         *
         * @since 3.3.0
         */
        public function remove_help_tabs()
        {
        }
        /**
         * Gets the content from a contextual help sidebar.
         *
         * @since 3.4.0
         *
         * @return string Contents of the help sidebar.
         */
        public function get_help_sidebar()
        {
        }
        /**
         * Adds a sidebar to the contextual help for the screen.
         *
         * Call this in template files after admin.php is loaded and before admin-header.php is loaded
         * to add a sidebar to the contextual help.
         *
         * @since 3.3.0
         *
         * @param string $content Sidebar content in plain text or HTML.
         */
        public function set_help_sidebar($content)
        {
        }
        /**
         * Gets the number of layout columns the user has selected.
         *
         * The layout_columns option controls the max number and default number of
         * columns. This method returns the number of columns within that range selected
         * by the user via Screen Options. If no selection has been made, the default
         * provisioned in layout_columns is returned. If the screen does not support
         * selecting the number of layout columns, 0 is returned.
         *
         * @since 3.4.0
         *
         * @return int Number of columns to display.
         */
        public function get_columns()
        {
        }
        /**
         * Gets the accessible hidden headings and text used in the screen.
         *
         * @since 4.4.0
         *
         * @see set_screen_reader_content() For more information on the array format.
         *
         * @return string[] An associative array of screen reader text strings.
         */
        public function get_screen_reader_content()
        {
        }
        /**
         * Gets a screen reader text string.
         *
         * @since 4.4.0
         *
         * @param string $key Screen reader text array named key.
         * @return string Screen reader text string.
         */
        public function get_screen_reader_text($key)
        {
        }
        /**
         * Adds accessible hidden headings and text for the screen.
         *
         * @since 4.4.0
         *
         * @param array $content {
         *     An associative array of screen reader text strings.
         *
         *     @type string $heading_views      Screen reader text for the filter links heading.
         *                                      Default 'Filter items list'.
         *     @type string $heading_pagination Screen reader text for the pagination heading.
         *                                      Default 'Items list navigation'.
         *     @type string $heading_list       Screen reader text for the items list heading.
         *                                      Default 'Items list'.
         * }
         * @phpstan-param array{
         *   heading_views?: string,
         *   heading_pagination?: string,
         *   heading_list?: string,
         * } $content
         */
        public function set_screen_reader_content($content = array())
        {
        }
        /**
         * Removes all the accessible hidden headings and text for the screen.
         *
         * @since 4.4.0
         */
        public function remove_screen_reader_content()
        {
        }
        /**
         * Renders the screen's help section.
         *
         * This will trigger the deprecated filters for backward compatibility.
         *
         * @since 3.3.0
         *
         * @global string $screen_layout_columns
         * @phpstan-return void
         */
        public function render_screen_meta()
        {
        }
        /**
         * @global array $wp_meta_boxes Global meta box state.
         *
         * @return bool
         */
        public function show_screen_options()
        {
        }
        /**
         * Renders the screen options tab.
         *
         * @since 3.3.0
         *
         * @param array $options {
         *     Options for the tab.
         *
         *     @type bool $wrap Whether the screen-options-wrap div will be included. Defaults to true.
         * }
         * @phpstan-param array{
         *   wrap?: bool,
         * } $options
         */
        public function render_screen_options($options = array())
        {
        }
        /**
         * Renders the meta boxes preferences.
         *
         * @since 4.4.0
         *
         * @global array $wp_meta_boxes Global meta box state.
         * @phpstan-return void
         */
        public function render_meta_boxes_preferences()
        {
        }
        /**
         * Renders the list table columns preferences.
         *
         * @since 4.4.0
         * @phpstan-return void
         */
        public function render_list_table_columns_preferences()
        {
        }
        /**
         * Renders the option for number of columns on the page.
         *
         * @since 3.3.0
         * @phpstan-return void
         */
        public function render_screen_layout()
        {
        }
        /**
         * Renders the items per page option.
         *
         * @since 3.3.0
         * @phpstan-return void
         */
        public function render_per_page_options()
        {
        }
        /**
         * Renders the list table view mode preferences.
         *
         * @since 4.4.0
         *
         * @global string $mode List table view mode.
         * @phpstan-return void
         */
        public function render_view_mode()
        {
        }
        /**
         * Renders screen reader text.
         *
         * @since 4.4.0
         *
         * @param string $key The screen reader text array named key.
         * @param string $tag Optional. The HTML tag to wrap the screen reader text. Default h2.
         * @phpstan-return void
         */
        public function render_screen_reader_content($key = '', $tag = 'h2')
        {
        }
    }
    /**
     * Class for testing automatic updates in the WordPress code.
     *
     * @package WordPress
     * @subpackage Site_Health
     * @since 5.2.0
     */
    #[\AllowDynamicProperties]
    class WP_Site_Health_Auto_Updates
    {
        /**
         * WP_Site_Health_Auto_Updates constructor.
         *
         * @since 5.2.0
         */
        public function __construct()
        {
        }
        /**
         * Runs tests to determine if auto-updates can run.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function run_tests()
        {
        }
        /**
         * Tests if auto-updates related constants are set correctly.
         *
         * @since 5.2.0
         * @since 5.5.1 The `$value` parameter can accept an array.
         *
         * @param string $constant         The name of the constant to check.
         * @param bool|string|array $value The value that the constant should be, if set,
         *                                 or an array of acceptable values.
         * @return array The test results.
         */
        public function test_constants($constant, $value)
        {
        }
        /**
         * Checks if updates are intercepted by a filter.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function test_wp_version_check_attached()
        {
        }
        /**
         * Checks if automatic updates are disabled by a filter.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function test_filters_automatic_updater_disabled()
        {
        }
        /**
         * Checks if automatic updates are disabled.
         *
         * @since 5.3.0
         *
         * @return array|false The test results. False if auto-updates are enabled.
         */
        public function test_wp_automatic_updates_disabled()
        {
        }
        /**
         * Checks if automatic updates have tried to run, but failed, previously.
         *
         * @since 5.2.0
         *
         * @return array|false The test results. False if the auto-updates failed.
         */
        public function test_if_failed_update()
        {
        }
        /**
         * Checks if WordPress is controlled by a VCS (Git, Subversion etc).
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function test_vcs_abspath()
        {
        }
        /**
         * Checks if we can access files without providing credentials.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function test_check_wp_filesystem_method()
        {
        }
        /**
         * Checks if core files are writable by the web user/group.
         *
         * @since 5.2.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @return array|false The test results. False if they're not writeable.
         */
        public function test_all_files_writable()
        {
        }
        /**
         * Checks if the install is using a development branch and can use nightly packages.
         *
         * @since 5.2.0
         *
         * @return array|false The test results. False if it isn't a development version.
         */
        public function test_accepts_dev_updates()
        {
        }
        /**
         * Checks if the site supports automatic minor updates.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function test_accepts_minor_updates()
        {
        }
    }
    /**
     * Class for looking up a site's health based on a user's WordPress environment.
     *
     * @package WordPress
     * @subpackage Site_Health
     * @since 5.2.0
     */
    #[\AllowDynamicProperties]
    class WP_Site_Health
    {
        public $is_mariadb = \false;
        public $php_memory_limit;
        public $schedules;
        public $crons;
        public $last_missed_cron = \null;
        public $last_late_cron = \null;
        /**
         * WP_Site_Health constructor.
         *
         * @since 5.2.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the content of a tab in the Site Health screen.
         *
         * @since 5.8.0
         *
         * @param string $tab Slug of the current tab being displayed.
         */
        public function show_site_health_tab($tab)
        {
        }
        /**
         * Returns an instance of the WP_Site_Health class, or create one if none exist yet.
         *
         * @since 5.4.0
         *
         * @return WP_Site_Health|null
         */
        public static function get_instance()
        {
        }
        /**
         * Enqueues the site health scripts.
         *
         * @since 5.2.0
         * @phpstan-return void
         */
        public function enqueue_scripts()
        {
        }
        /**
         * Tests whether `wp_version_check` is blocked.
         *
         * It's possible to block updates with the `wp_version_check` filter, but this can't be checked
         * during an Ajax call, as the filter is never introduced then.
         *
         * This filter overrides a standard page request if it's made by an admin through the Ajax call
         * with the right query argument to check for this.
         *
         * @since 5.2.0
         * @phpstan-return void
         */
        public function check_wp_version_check_exists()
        {
        }
        /**
         * Tests for WordPress version and outputs it.
         *
         * Gives various results depending on what kind of updates are available, if any, to encourage
         * the user to install security updates as a priority.
         *
         * @since 5.2.0
         *
         * @return array The test result.
         */
        public function get_test_wordpress_version()
        {
        }
        /**
         * Tests if plugins are outdated, or unnecessary.
         *
         * The test checks if your plugins are up to date, and encourages you to remove any
         * that are not in use.
         *
         * @since 5.2.0
         *
         * @return array The test result.
         */
        public function get_test_plugin_version()
        {
        }
        /**
         * Tests if themes are outdated, or unnecessary.
         *
         * Checks if your site has a default theme (to fall back on if there is a need),
         * if your themes are up to date and, finally, encourages you to remove any themes
         * that are not needed.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function get_test_theme_version()
        {
        }
        /**
         * Tests if the supplied PHP version is supported.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function get_test_php_version()
        {
        }
        /**
         * Tests if required PHP modules are installed on the host.
         *
         * This test builds on the recommendations made by the WordPress Hosting Team
         * as seen at https://make.wordpress.org/hosting/handbook/handbook/server-environment/#php-extensions
         *
         * @since 5.2.0
         *
         * @return array
         */
        public function get_test_php_extensions()
        {
        }
        /**
         * Tests if the PHP default timezone is set to UTC.
         *
         * @since 5.3.1
         *
         * @return array The test results.
         */
        public function get_test_php_default_timezone()
        {
        }
        /**
         * Tests if there's an active PHP session that can affect loopback requests.
         *
         * @since 5.5.0
         *
         * @return array The test results.
         */
        public function get_test_php_sessions()
        {
        }
        /**
         * Tests if the SQL server is up to date.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function get_test_sql_server()
        {
        }
        /**
         * Tests if the site can communicate with WordPress.org.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function get_test_dotorg_communication()
        {
        }
        /**
         * Tests if debug information is enabled.
         *
         * When WP_DEBUG is enabled, errors and information may be disclosed to site visitors,
         * or logged to a publicly accessible file.
         *
         * Debugging is also frequently left enabled after looking for errors on a site,
         * as site owners do not understand the implications of this.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function get_test_is_in_debug_mode()
        {
        }
        /**
         * Tests if the site is serving content over HTTPS.
         *
         * Many sites have varying degrees of HTTPS support, the most common of which is sites that have it
         * enabled, but only if you visit the right site address.
         *
         * @since 5.2.0
         * @since 5.7.0 Updated to rely on {@see wp_is_using_https()} and {@see wp_is_https_supported()}.
         *
         * @return array The test results.
         */
        public function get_test_https_status()
        {
        }
        /**
         * Checks if the HTTP API can handle SSL/TLS requests.
         *
         * @since 5.2.0
         *
         * @return array The test result.
         */
        public function get_test_ssl_support()
        {
        }
        /**
         * Tests if scheduled events run as intended.
         *
         * If scheduled events are not running, this may indicate something with WP_Cron is not working
         * as intended, or that there are orphaned events hanging around from older code.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function get_test_scheduled_events()
        {
        }
        /**
         * Tests if WordPress can run automated background updates.
         *
         * Background updates in WordPress are primarily used for minor releases and security updates.
         * It's important to either have these working, or be aware that they are intentionally disabled
         * for whatever reason.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function get_test_background_updates()
        {
        }
        /**
         * Tests if plugin and theme auto-updates appear to be configured correctly.
         *
         * @since 5.5.0
         *
         * @return array The test results.
         */
        public function get_test_plugin_theme_auto_updates()
        {
        }
        /**
         * Tests available disk space for updates.
         *
         * @since 6.3.0
         *
         * @return array The test results.
         */
        public function get_test_available_updates_disk_space()
        {
        }
        /**
         * Tests if plugin and theme temporary backup directories are writable or can be created.
         *
         * @since 6.3.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @return array The test results.
         */
        public function get_test_update_temp_backup_writable()
        {
        }
        /**
         * Tests if loopbacks work as expected.
         *
         * A loopback is when WordPress queries itself, for example to start a new WP_Cron instance,
         * or when editing a plugin or theme. This has shown itself to be a recurring issue,
         * as code can very easily break this interaction.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function get_test_loopback_requests()
        {
        }
        /**
         * Tests if HTTP requests are blocked.
         *
         * It's possible to block all outgoing communication (with the possibility of allowing certain
         * hosts) via the HTTP API. This may create problems for users as many features are running as
         * services these days.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function get_test_http_requests()
        {
        }
        /**
         * Tests if the REST API is accessible.
         *
         * Various security measures may block the REST API from working, or it may have been disabled in general.
         * This is required for the new block editor to work, so we explicitly test for this.
         *
         * @since 5.2.0
         *
         * @return array The test results.
         */
        public function get_test_rest_availability()
        {
        }
        /**
         * Tests if 'file_uploads' directive in PHP.ini is turned off.
         *
         * @since 5.5.0
         *
         * @return array The test results.
         */
        public function get_test_file_uploads()
        {
        }
        /**
         * Tests if the Authorization header has the expected values.
         *
         * @since 5.6.0
         *
         * @return array
         */
        public function get_test_authorization_header()
        {
        }
        /**
         * Tests if a full page cache is available.
         *
         * @since 6.1.0
         *
         * @return array The test result.
         */
        public function get_test_page_cache()
        {
        }
        /**
         * Tests if the site uses persistent object cache and recommends to use it if not.
         *
         * @since 6.1.0
         *
         * @return array The test result.
         */
        public function get_test_persistent_object_cache()
        {
        }
        /**
         * Calculates total amount of autoloaded data.
         *
         * @since 6.6.0
         *
         * @return int Autoloaded data in bytes.
         */
        public function get_autoloaded_options_size()
        {
        }
        /**
         * Tests the number of autoloaded options.
         *
         * @since 6.6.0
         *
         * @return array The test results.
         */
        public function get_test_autoloaded_options()
        {
        }
        /**
         * Returns a set of tests that belong to the site status page.
         *
         * Each site status test is defined here, they may be `direct` tests, that run on page load, or `async` tests
         * which will run later down the line via JavaScript calls to improve page performance and hopefully also user
         * experiences.
         *
         * @since 5.2.0
         * @since 5.6.0 Added support for `has_rest` and `permissions`.
         *
         * @return array The list of tests to run.
         */
        public static function get_tests()
        {
        }
        /**
         * Adds a class to the body HTML tag.
         *
         * Filters the body class string for admin pages and adds our own class for easier styling.
         *
         * @since 5.2.0
         *
         * @param string $body_class The body class string.
         * @return string The modified body class string.
         */
        public function admin_body_class($body_class)
        {
        }
        /**
         * Checks if any scheduled tasks have been missed.
         *
         * Returns a boolean value of `true` if a scheduled task has been missed and ends processing.
         *
         * If the list of crons is an instance of WP_Error, returns the instance instead of a boolean value.
         *
         * @since 5.2.0
         *
         * @return bool|WP_Error True if a cron was missed, false if not. WP_Error if the cron is set to that.
         */
        public function has_missed_cron()
        {
        }
        /**
         * Checks if any scheduled tasks are late.
         *
         * Returns a boolean value of `true` if a scheduled task is late and ends processing.
         *
         * If the list of crons is an instance of WP_Error, returns the instance instead of a boolean value.
         *
         * @since 5.3.0
         *
         * @return bool|WP_Error True if a cron is late, false if not. WP_Error if the cron is set to that.
         */
        public function has_late_cron()
        {
        }
        /**
         * Checks for potential issues with plugin and theme auto-updates.
         *
         * Though there is no way to 100% determine if plugin and theme auto-updates are configured
         * correctly, a few educated guesses could be made to flag any conditions that would
         * potentially cause unexpected behaviors.
         *
         * @since 5.5.0
         *
         * @return object The test results.
         */
        public function detect_plugin_theme_auto_update_issues()
        {
        }
        /**
         * Runs a loopback test on the site.
         *
         * Loopbacks are what WordPress uses to communicate with itself to start up WP_Cron, scheduled posts,
         * make sure plugin or theme edits don't cause site failures and similar.
         *
         * @since 5.2.0
         *
         * @return object The test results.
         */
        public function can_perform_loopback()
        {
        }
        /**
         * Creates a weekly cron event, if one does not already exist.
         *
         * @since 5.4.0
         */
        public function maybe_create_scheduled_event()
        {
        }
        /**
         * Runs the scheduled event to check and update the latest site health status for the website.
         *
         * @since 5.4.0
         */
        public function wp_cron_scheduled_check()
        {
        }
        /**
         * Checks if the current environment type is set to 'development' or 'local'.
         *
         * @since 5.6.0
         *
         * @return bool True if it is a development environment, false if not.
         */
        public function is_development_environment()
        {
        }
        /**
         * Returns a list of headers and its verification callback to verify if page cache is enabled or not.
         *
         * Note: key is header name and value could be callable function to verify header value.
         * Empty value mean existence of header detect page cache is enabled.
         *
         * @since 6.1.0
         *
         * @return array List of client caching headers and their (optional) verification callbacks.
         */
        public function get_page_cache_headers()
        {
        }
        /**
         * Determines whether to suggest using a persistent object cache.
         *
         * @since 6.1.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @return bool Whether to suggest using a persistent object cache.
         */
        public function should_suggest_persistent_object_cache()
        {
        }
    }
    /**
     * Core class used to implement site icon functionality.
     *
     * @since 4.3.0
     */
    #[\AllowDynamicProperties]
    class WP_Site_Icon
    {
        /**
         * The minimum size of the site icon.
         *
         * @since 4.3.0
         * @var int
         */
        public $min_size = 512;
        /**
         * The size to which to crop the image so that we can display it in the UI nicely.
         *
         * @since 4.3.0
         * @var int
         */
        public $page_crop = 512;
        /**
         * List of site icon sizes.
         *
         * @since 4.3.0
         * @var int[]
         */
        public $site_icon_sizes = array(
            /*
             * Square, medium sized tiles for IE11+.
             *
             * See https://msdn.microsoft.com/library/dn455106(v=vs.85).aspx
             */
            270,
            /*
             * App icon for Android/Chrome.
             *
             * @link https://developers.google.com/web/updates/2014/11/Support-for-theme-color-in-Chrome-39-for-Android
             * @link https://developer.chrome.com/multidevice/android/installtohomescreen
             */
            192,
            /*
             * App icons up to iPhone 6 Plus.
             *
             * See https://developer.apple.com/library/prerelease/ios/documentation/UserExperience/Conceptual/MobileHIG/IconMatrix.html
             */
            180,
            // Our regular Favicon.
            32,
        );
        /**
         * Registers actions and filters.
         *
         * @since 4.3.0
         */
        public function __construct()
        {
        }
        /**
         * Creates an attachment 'object'.
         *
         * @since 4.3.0
         * @deprecated 6.5.0
         *
         * @param string $cropped              Cropped image URL.
         * @param int    $parent_attachment_id Attachment ID of parent image.
         * @return array An array with attachment object data.
         */
        public function create_attachment_object($cropped, $parent_attachment_id)
        {
        }
        /**
         * Inserts an attachment.
         *
         * @since 4.3.0
         *
         * @param array  $attachment An array with attachment object data.
         * @param string $file       File path of the attached image.
         * @return int               Attachment ID.
         */
        public function insert_attachment($attachment, $file)
        {
        }
        /**
         * Adds additional sizes to be made when creating the site icon images.
         *
         * @since 4.3.0
         *
         * @param array[] $sizes Array of arrays containing information for additional sizes.
         * @return array[] Array of arrays containing additional image sizes.
         */
        public function additional_sizes($sizes = array())
        {
        }
        /**
         * Adds Site Icon sizes to the array of image sizes on demand.
         *
         * @since 4.3.0
         *
         * @param string[] $sizes Array of image size names.
         * @return string[] Array of image size names.
         */
        public function intermediate_image_sizes($sizes = array())
        {
        }
        /**
         * Deletes the Site Icon when the image file is deleted.
         *
         * @since 4.3.0
         *
         * @param int $post_id Attachment ID.
         */
        public function delete_attachment_data($post_id)
        {
        }
        /**
         * Adds custom image sizes when meta data for an image is requested, that happens to be used as Site Icon.
         *
         * @since 4.3.0
         *
         * @param null|array|string $value    The value get_metadata() should return a single metadata value, or an
         *                                    array of values.
         * @param int               $post_id  Post ID.
         * @param string            $meta_key Meta key.
         * @param bool              $single   Whether to return only the first value of the specified `$meta_key`.
         * @return array|null|string The attachment metadata value, array of values, or null.
         */
        public function get_post_metadata($value, $post_id, $meta_key, $single)
        {
        }
    }
    /**
     * Core class used to implement displaying terms in a list table.
     *
     * @since 3.1.0
     *
     * @see WP_List_Table
     */
    class WP_Terms_List_Table extends \WP_List_Table
    {
        public $callback_args;
        /**
         * Constructor.
         *
         * @since 3.1.0
         *
         * @see WP_List_Table::__construct() for more information on default arguments.
         *
         * @global string $post_type Global post type.
         * @global string $taxonomy  Global taxonomy.
         * @global string $action
         * @global object $tax
         *
         * @param array $args An associative array of arguments.
         */
        public function __construct($args = array())
        {
        }
        /**
         * @return bool
         */
        public function ajax_user_can()
        {
        }
        /**
         */
        public function prepare_items()
        {
        }
        /**
         */
        public function no_items()
        {
        }
        /**
         * @return array
         */
        protected function get_bulk_actions()
        {
        }
        /**
         * @return string
         */
        public function current_action()
        {
        }
        /**
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         * @return array
         */
        protected function get_sortable_columns()
        {
        }
        /**
         * @phpstan-return void
         */
        public function display_rows_or_placeholder()
        {
        }
        /**
         * @global string $taxonomy Global taxonomy.
         *
         * @param WP_Term $tag   Term object.
         * @param int     $level
         */
        public function single_row($tag, $level = 0)
        {
        }
        /**
         * @since 5.9.0 Renamed `$tag` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Term $item Term object.
         * @return string
         */
        public function column_cb($item)
        {
        }
        /**
         * @param WP_Term $tag Term object.
         * @return string
         */
        public function column_name($tag)
        {
        }
        /**
         * Gets the name of the default primary column.
         *
         * @since 4.3.0
         *
         * @return string Name of the default primary column, in this case, 'name'.
         */
        protected function get_default_primary_column_name()
        {
        }
        /**
         * Generates and displays row action links.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$tag` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Term $item        Tag being acted upon.
         * @param string  $column_name Current column name.
         * @param string  $primary     Primary column name.
         * @return string Row actions output for terms, or an empty string
         *                if the current column is not the primary column.
         */
        protected function handle_row_actions($item, $column_name, $primary)
        {
        }
        /**
         * @param WP_Term $tag Term object.
         * @return string
         */
        public function column_description($tag)
        {
        }
        /**
         * @param WP_Term $tag Term object.
         * @return string
         */
        public function column_slug($tag)
        {
        }
        /**
         * @param WP_Term $tag Term object.
         * @return string
         */
        public function column_posts($tag)
        {
        }
        /**
         * @param WP_Term $tag Term object.
         * @return string
         */
        public function column_links($tag)
        {
        }
        /**
         * @since 5.9.0 Renamed `$tag` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Term $item        Term object.
         * @param string  $column_name Name of the column.
         * @return string
         */
        public function column_default($item, $column_name)
        {
        }
        /**
         * Outputs the hidden row displayed when inline editing
         *
         * @since 3.1.0
         * @phpstan-return void
         */
        public function inline_edit()
        {
        }
    }
    /**
     * Core class used to implement displaying installed themes in a list table.
     *
     * @since 3.1.0
     *
     * @see WP_List_Table
     */
    class WP_Themes_List_Table extends \WP_List_Table
    {
        protected $search_terms = array();
        public $features = array();
        /**
         * Constructor.
         *
         * @since 3.1.0
         *
         * @see WP_List_Table::__construct() for more information on default arguments.
         *
         * @param array $args An associative array of arguments.
         */
        public function __construct($args = array())
        {
        }
        /**
         * @return bool
         */
        public function ajax_user_can()
        {
        }
        /**
         */
        public function prepare_items()
        {
        }
        /**
         * @phpstan-return void
         */
        public function no_items()
        {
        }
        /**
         * @param string $which
         * @phpstan-return void
         */
        public function tablenav($which = 'top')
        {
        }
        /**
         * Displays the themes table.
         *
         * Overrides the parent display() method to provide a different container.
         *
         * @since 3.1.0
         */
        public function display()
        {
        }
        /**
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         */
        public function display_rows_or_placeholder()
        {
        }
        /**
         * Generates the list table rows.
         *
         * @since 3.1.0
         */
        public function display_rows()
        {
        }
        /**
         * @param WP_Theme $theme
         * @return bool
         */
        public function search_theme($theme)
        {
        }
        /**
         * Send required variables to JavaScript land
         *
         * @since 3.4.0
         *
         * @param array $extra_args
         */
        public function _js_vars($extra_args = array())
        {
        }
    }
    /**
     * Core class used to implement displaying themes to install in a list table.
     *
     * @since 3.1.0
     *
     * @see WP_Themes_List_Table
     */
    class WP_Theme_Install_List_Table extends \WP_Themes_List_Table
    {
        public $features = array();
        /**
         * @return bool
         */
        public function ajax_user_can()
        {
        }
        /**
         * @global array  $tabs
         * @global string $tab
         * @global int    $paged
         * @global string $type
         * @global array  $theme_field_defaults
         * @phpstan-return void
         */
        public function prepare_items()
        {
        }
        /**
         */
        public function no_items()
        {
        }
        /**
         * @global array $tabs
         * @global string $tab
         * @return array
         */
        protected function get_views()
        {
        }
        /**
         * Displays the theme install table.
         *
         * Overrides the parent display() method to provide a different container.
         *
         * @since 3.1.0
         */
        public function display()
        {
        }
        /**
         * Generates the list table rows.
         *
         * @since 3.1.0
         */
        public function display_rows()
        {
        }
        /**
         * Prints a theme from the WordPress.org API.
         *
         * @since 3.1.0
         *
         * @global array $themes_allowedtags
         *
         * @param stdClass $theme {
         *     An object that contains theme data returned by the WordPress.org API.
         *
         *     @type string $name           Theme name, e.g. 'Twenty Twenty-One'.
         *     @type string $slug           Theme slug, e.g. 'twentytwentyone'.
         *     @type string $version        Theme version, e.g. '1.1'.
         *     @type string $author         Theme author username, e.g. 'melchoyce'.
         *     @type string $preview_url    Preview URL, e.g. 'https://2021.wordpress.net/'.
         *     @type string $screenshot_url Screenshot URL, e.g. 'https://wordpress.org/themes/twentytwentyone/'.
         *     @type float  $rating         Rating score.
         *     @type int    $num_ratings    The number of ratings.
         *     @type string $homepage       Theme homepage, e.g. 'https://wordpress.org/themes/twentytwentyone/'.
         *     @type string $description    Theme description.
         *     @type string $download_link  Theme ZIP download URL.
         * }
         * @phpstan-param object{
         *   name?: string,
         *   slug?: string,
         *   version?: string,
         *   author?: string,
         *   preview_url?: string,
         *   screenshot_url?: string,
         *   rating?: float,
         *   num_ratings?: int,
         *   homepage?: string,
         *   description?: string,
         *   download_link?: string,
         * } $theme
         * @phpstan-return void
         */
        public function single_row($theme)
        {
        }
        /**
         * Prints the wrapper for the theme installer.
         */
        public function theme_installer()
        {
        }
        /**
         * Prints the wrapper for the theme installer with a provided theme's data.
         * Used to make the theme installer work for no-js.
         *
         * @param stdClass $theme A WordPress.org Theme API object.
         */
        public function theme_installer_single($theme)
        {
        }
        /**
         * Prints the info for a theme (to be used in the theme installer modal).
         *
         * @global array $themes_allowedtags
         *
         * @param stdClass $theme A WordPress.org Theme API object.
         * @phpstan-return void
         */
        public function install_theme_info($theme)
        {
        }
        /**
         * Send required variables to JavaScript land
         *
         * @since 3.4.0
         *
         * @global string $tab  Current tab within Themes->Install screen
         * @global string $type Type of search.
         *
         * @param array $extra_args Unused.
         */
        public function _js_vars($extra_args = array())
        {
        }
    }
    /**
     * Core class used to implement displaying users in a list table.
     *
     * @since 3.1.0
     *
     * @see WP_List_Table
     */
    class WP_Users_List_Table extends \WP_List_Table
    {
        /**
         * Site ID to generate the Users list table for.
         *
         * @since 3.1.0
         * @var int
         */
        public $site_id;
        /**
         * Whether or not the current Users list table is for Multisite.
         *
         * @since 3.1.0
         * @var bool
         */
        public $is_site_users;
        /**
         * Constructor.
         *
         * @since 3.1.0
         *
         * @see WP_List_Table::__construct() for more information on default arguments.
         *
         * @param array $args An associative array of arguments.
         */
        public function __construct($args = array())
        {
        }
        /**
         * Checks the current user's permissions.
         *
         * @since 3.1.0
         *
         * @return bool
         */
        public function ajax_user_can()
        {
        }
        /**
         * Prepares the users list for display.
         *
         * @since 3.1.0
         *
         * @global string $role
         * @global string $usersearch
         */
        public function prepare_items()
        {
        }
        /**
         * Outputs 'no users' message.
         *
         * @since 3.1.0
         */
        public function no_items()
        {
        }
        /**
         * Returns an associative array listing all the views that can be used
         * with this table.
         *
         * Provides a list of roles and user count for that role for easy
         * filtering of the user table.
         *
         * @since 3.1.0
         *
         * @global string $role
         *
         * @return string[] An array of HTML links keyed by their view.
         */
        protected function get_views()
        {
        }
        /**
         * Retrieves an associative array of bulk actions available on this table.
         *
         * @since 3.1.0
         *
         * @return array Array of bulk action labels keyed by their action.
         */
        protected function get_bulk_actions()
        {
        }
        /**
         * Outputs the controls to allow user roles to be changed in bulk.
         *
         * @since 3.1.0
         *
         * @param string $which Whether this is being invoked above ("top")
         *                      or below the table ("bottom").
         */
        protected function extra_tablenav($which)
        {
        }
        /**
         * Captures the bulk action required, and return it.
         *
         * Overridden from the base class implementation to capture
         * the role change drop-down.
         *
         * @since 3.1.0
         *
         * @return string The bulk action required.
         */
        public function current_action()
        {
        }
        /**
         * Gets a list of columns for the list table.
         *
         * @since 3.1.0
         *
         * @return string[] Array of column titles keyed by their column name.
         */
        public function get_columns()
        {
        }
        /**
         * Gets a list of sortable columns for the list table.
         *
         * @since 3.1.0
         *
         * @return array Array of sortable columns.
         */
        protected function get_sortable_columns()
        {
        }
        /**
         * Generates the list table rows.
         *
         * @since 3.1.0
         */
        public function display_rows()
        {
        }
        /**
         * Generates HTML for a single row on the users.php admin panel.
         *
         * @since 3.1.0
         * @since 4.2.0 The `$style` parameter was deprecated.
         * @since 4.4.0 The `$role` parameter was deprecated.
         *
         * @param WP_User $user_object The current user object.
         * @param string  $style       Deprecated. Not used.
         * @param string  $role        Deprecated. Not used.
         * @param int     $numposts    Optional. Post count to display for this user. Defaults
         *                             to zero, as in, a new user has made zero posts.
         * @return string Output for a single row.
         */
        public function single_row($user_object, $style = '', $role = '', $numposts = 0)
        {
        }
        /**
         * Gets the name of the default primary column.
         *
         * @since 4.3.0
         *
         * @return string Name of the default primary column, in this case, 'username'.
         */
        protected function get_default_primary_column_name()
        {
        }
        /**
         * Returns an array of translated user role names for a given user object.
         *
         * @since 4.4.0
         *
         * @param WP_User $user_object The WP_User object.
         * @return string[] An array of user role names keyed by role.
         */
        protected function get_role_list($user_object)
        {
        }
    }
    /**
     * WordPress User Search class.
     *
     * @since 2.1.0
     * @deprecated 3.1.0 Use WP_User_Query
     */
    class WP_User_Search
    {
        /**
         * {@internal Missing Description}}
         *
         * @since 2.1.0
         * @access private
         * @var mixed
         */
        var $results;
        /**
         * {@internal Missing Description}}
         *
         * @since 2.1.0
         * @access private
         * @var string
         */
        var $search_term;
        /**
         * Page number.
         *
         * @since 2.1.0
         * @access private
         * @var int
         */
        var $page;
        /**
         * Role name that users have.
         *
         * @since 2.5.0
         * @access private
         * @var string
         */
        var $role;
        /**
         * Raw page number.
         *
         * @since 2.1.0
         * @access private
         * @var int|bool
         */
        var $raw_page;
        /**
         * Amount of users to display per page.
         *
         * @since 2.1.0
         * @access public
         * @var int
         */
        var $users_per_page = 50;
        /**
         * {@internal Missing Description}}
         *
         * @since 2.1.0
         * @access private
         * @var int
         */
        var $first_user;
        /**
         * {@internal Missing Description}}
         *
         * @since 2.1.0
         * @access private
         * @var int
         */
        var $last_user;
        /**
         * {@internal Missing Description}}
         *
         * @since 2.1.0
         * @access private
         * @var string
         */
        var $query_limit;
        /**
         * {@internal Missing Description}}
         *
         * @since 3.0.0
         * @access private
         * @var string
         */
        var $query_orderby;
        /**
         * {@internal Missing Description}}
         *
         * @since 3.0.0
         * @access private
         * @var string
         */
        var $query_from;
        /**
         * {@internal Missing Description}}
         *
         * @since 3.0.0
         * @access private
         * @var string
         */
        var $query_where;
        /**
         * {@internal Missing Description}}
         *
         * @since 2.1.0
         * @access private
         * @var int
         */
        var $total_users_for_query = 0;
        /**
         * {@internal Missing Description}}
         *
         * @since 2.1.0
         * @access private
         * @var bool
         */
        var $too_many_total_users = \false;
        /**
         * {@internal Missing Description}}
         *
         * @since 2.1.0
         * @access private
         * @var WP_Error
         */
        var $search_errors;
        /**
         * {@internal Missing Description}}
         *
         * @since 2.7.0
         * @access private
         * @var string
         */
        var $paging_text;
        /**
         * PHP5 Constructor - Sets up the object properties.
         *
         * @since 2.1.0
         *
         * @param string $search_term Search terms string.
         * @param int $page Optional. Page ID.
         * @param string $role Role name.
         * @return WP_User_Search
         */
        function __construct($search_term = '', $page = '', $role = '')
        {
        }
        /**
         * PHP4 Constructor - Sets up the object properties.
         *
         * @since 2.1.0
         *
         * @param string $search_term Search terms string.
         * @param int $page Optional. Page ID.
         * @param string $role Role name.
         * @return WP_User_Search
         */
        public function WP_User_Search($search_term = '', $page = '', $role = '')
        {
        }
        /**
         * Prepares the user search query (legacy).
         *
         * @since 2.1.0
         * @access public
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         */
        public function prepare_query()
        {
        }
        /**
         * Executes the user search query.
         *
         * @since 2.1.0
         * @access public
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         */
        public function query()
        {
        }
        /**
         * Prepares variables for use in templates.
         *
         * @since 2.1.0
         * @access public
         */
        function prepare_vars_for_template_usage()
        {
        }
        /**
         * Handles paging for the user search query.
         *
         * @since 2.1.0
         * @access public
         */
        public function do_paging()
        {
        }
        /**
         * Retrieves the user search query results.
         *
         * @since 2.1.0
         * @access public
         *
         * @return array
         */
        public function get_results()
        {
        }
        /**
         * Displaying paging text.
         *
         * @see do_paging() Builds paging text.
         *
         * @since 2.1.0
         * @access public
         */
        function page_links()
        {
        }
        /**
         * Whether paging is enabled.
         *
         * @see do_paging() Builds paging text.
         *
         * @since 2.1.0
         * @access public
         *
         * @return bool
         */
        function results_are_paged()
        {
        }
        /**
         * Whether there are search terms.
         *
         * @since 2.1.0
         * @access public
         *
         * @return bool
         */
        function is_search()
        {
        }
    }
    /**
     * Previous class for list table for privacy data export requests.
     *
     * @since 4.9.6
     * @deprecated 5.3.0
     */
    class WP_Privacy_Data_Export_Requests_Table extends \WP_Privacy_Data_Export_Requests_List_Table
    {
        function __construct($args)
        {
        }
    }
    /**
     * Previous class for list table for privacy data erasure requests.
     *
     * @since 4.9.6
     * @deprecated 5.3.0
     */
    class WP_Privacy_Data_Removal_Requests_Table extends \WP_Privacy_Data_Removal_Requests_List_Table
    {
        function __construct($args)
        {
        }
    }
    class getid3_lib
    {
        /**
         * @param string      $string
         * @param bool        $hex
         * @param bool        $spaces
         * @param string|bool $htmlencoding
         *
         * @return string
         */
        public static function PrintHexBytes($string, $hex = \true, $spaces = \true, $htmlencoding = 'UTF-8')
        {
        }
        /**
         * Truncates a floating-point number at the decimal point.
         *
         * @param float $floatnumber
         *
         * @return float|int returns int (if possible, otherwise float)
         */
        public static function trunc($floatnumber)
        {
        }
        /**
         * @param int|null $variable
         * @param int      $increment
         *
         * @return bool
         */
        public static function safe_inc(&$variable, $increment = 1)
        {
        }
        /**
         * @param int|float $floatnum
         *
         * @return int|float
         */
        public static function CastAsInt($floatnum)
        {
        }
        /**
         * @param int $num
         *
         * @return bool
         */
        public static function intValueSupported($num)
        {
        }
        /**
         * Perform a division, guarding against division by zero
         *
         * @param float|int $numerator
         * @param float|int $denominator
         * @param float|int $fallback
         * @return float|int
         */
        public static function SafeDiv($numerator, $denominator, $fallback = 0)
        {
        }
        /**
         * @param string $fraction
         *
         * @return float
         */
        public static function DecimalizeFraction($fraction)
        {
        }
        /**
         * @param string $binarynumerator
         *
         * @return float
         */
        public static function DecimalBinary2Float($binarynumerator)
        {
        }
        /**
         * @link http://www.scri.fsu.edu/~jac/MAD3401/Backgrnd/binary.html
         *
         * @param string $binarypointnumber
         * @param int    $maxbits
         *
         * @return array
         */
        public static function NormalizeBinaryPoint($binarypointnumber, $maxbits = 52)
        {
        }
        /**
         * @link http://www.scri.fsu.edu/~jac/MAD3401/Backgrnd/binary.html
         *
         * @param float $floatvalue
         *
         * @return string
         */
        public static function Float2BinaryDecimal($floatvalue)
        {
        }
        /**
         * @link http://www.scri.fsu.edu/~jac/MAD3401/Backgrnd/ieee-expl.html
         *
         * @param float $floatvalue
         * @param int $bits
         *
         * @return string|false
         */
        public static function Float2String($floatvalue, $bits)
        {
        }
        /**
         * @param string $byteword
         *
         * @return float|false
         */
        public static function LittleEndian2Float($byteword)
        {
        }
        /**
         * ANSI/IEEE Standard 754-1985, Standard for Binary Floating Point Arithmetic
         *
         * @link https://web.archive.org/web/20120325162206/http://www.psc.edu/general/software/packages/ieee/ieee.php
         * @link http://www.scri.fsu.edu/~jac/MAD3401/Backgrnd/ieee.html
         *
         * @param string $byteword
         *
         * @return float|false
         */
        public static function BigEndian2Float($byteword)
        {
        }
        /**
         * @param string $byteword
         * @param bool   $synchsafe
         * @param bool   $signed
         *
         * @return int|float|false
         * @throws Exception
         */
        public static function BigEndian2Int($byteword, $synchsafe = \false, $signed = \false)
        {
        }
        /**
         * @param string $byteword
         * @param bool   $signed
         *
         * @return int|float|false
         */
        public static function LittleEndian2Int($byteword, $signed = \false)
        {
        }
        /**
         * @param string $byteword
         *
         * @return string
         */
        public static function LittleEndian2Bin($byteword)
        {
        }
        /**
         * @param string $byteword
         *
         * @return string
         */
        public static function BigEndian2Bin($byteword)
        {
        }
        /**
         * @param int  $number
         * @param int  $minbytes
         * @param bool $synchsafe
         * @param bool $signed
         *
         * @return string
         * @throws Exception
         */
        public static function BigEndian2String($number, $minbytes = 1, $synchsafe = \false, $signed = \false)
        {
        }
        /**
         * @param int $number
         *
         * @return string
         */
        public static function Dec2Bin($number)
        {
        }
        /**
         * @param string $binstring
         * @param bool   $signed
         *
         * @return int|float
         */
        public static function Bin2Dec($binstring, $signed = \false)
        {
        }
        /**
         * @param string $binstring
         *
         * @return string
         */
        public static function Bin2String($binstring)
        {
        }
        /**
         * @param int  $number
         * @param int  $minbytes
         * @param bool $synchsafe
         *
         * @return string
         */
        public static function LittleEndian2String($number, $minbytes = 1, $synchsafe = \false)
        {
        }
        /**
         * @param mixed $array1
         * @param mixed $array2
         *
         * @return array|false
         */
        public static function array_merge_clobber($array1, $array2)
        {
        }
        /**
         * @param mixed $array1
         * @param mixed $array2
         *
         * @return array|false
         */
        public static function array_merge_noclobber($array1, $array2)
        {
        }
        /**
         * @param mixed $array1
         * @param mixed $array2
         *
         * @return array|false|null
         */
        public static function flipped_array_merge_noclobber($array1, $array2)
        {
        }
        /**
         * @param array $theArray
         *
         * @return bool
         */
        public static function ksort_recursive(&$theArray)
        {
        }
        /**
         * @param string $filename
         * @param int    $numextensions
         *
         * @return string
         */
        public static function fileextension($filename, $numextensions = 1)
        {
        }
        /**
         * @param int $seconds
         *
         * @return string
         */
        public static function PlaytimeString($seconds)
        {
        }
        /**
         * @param int $macdate
         *
         * @return int|float
         */
        public static function DateMac2Unix($macdate)
        {
        }
        /**
         * @param string $rawdata
         *
         * @return float
         */
        public static function FixedPoint8_8($rawdata)
        {
        }
        /**
         * @param string $rawdata
         *
         * @return float
         */
        public static function FixedPoint16_16($rawdata)
        {
        }
        /**
         * @param string $rawdata
         *
         * @return float
         */
        public static function FixedPoint2_30($rawdata)
        {
        }
        /**
         * @param string $ArrayPath
         * @param string $Separator
         * @param mixed $Value
         *
         * @return array
         */
        public static function CreateDeepArray($ArrayPath, $Separator, $Value)
        {
        }
        /**
         * @param array $arraydata
         * @param bool  $returnkey
         *
         * @return int|false
         */
        public static function array_max($arraydata, $returnkey = \false)
        {
        }
        /**
         * @param array $arraydata
         * @param bool  $returnkey
         *
         * @return int|false
         */
        public static function array_min($arraydata, $returnkey = \false)
        {
        }
        /**
         * @param string $XMLstring
         *
         * @return array|false
         */
        public static function XML2array($XMLstring)
        {
        }
        /**
         * @param SimpleXMLElement|array|mixed $XMLobject
         *
         * @return mixed
         */
        public static function SimpleXMLelement2array($XMLobject)
        {
        }
        /**
         * Returns checksum for a file from starting position to absolute end position.
         *
         * @param string $file
         * @param int    $offset
         * @param int    $end
         * @param string $algorithm
         *
         * @return string|false
         * @throws getid3_exception
         */
        public static function hash_data($file, $offset, $end, $algorithm)
        {
        }
        /**
         * @param string $filename_source
         * @param string $filename_dest
         * @param int    $offset
         * @param int    $length
         *
         * @return bool
         * @throws Exception
         *
         * @deprecated Unused, may be removed in future versions of getID3
         */
        public static function CopyFileParts($filename_source, $filename_dest, $offset, $length)
        {
        }
        /**
         * @param int $charval
         *
         * @return string
         */
        public static function iconv_fallback_int_utf8($charval)
        {
        }
        /**
         * ISO-8859-1 => UTF-8
         *
         * @param string $string
         * @param bool   $bom
         *
         * @return string
         */
        public static function iconv_fallback_iso88591_utf8($string, $bom = \false)
        {
        }
        /**
         * ISO-8859-1 => UTF-16BE
         *
         * @param string $string
         * @param bool   $bom
         *
         * @return string
         */
        public static function iconv_fallback_iso88591_utf16be($string, $bom = \false)
        {
        }
        /**
         * ISO-8859-1 => UTF-16LE
         *
         * @param string $string
         * @param bool   $bom
         *
         * @return string
         */
        public static function iconv_fallback_iso88591_utf16le($string, $bom = \false)
        {
        }
        /**
         * ISO-8859-1 => UTF-16LE (BOM)
         *
         * @param string $string
         *
         * @return string
         */
        public static function iconv_fallback_iso88591_utf16($string)
        {
        }
        /**
         * UTF-8 => ISO-8859-1
         *
         * @param string $string
         *
         * @return string
         */
        public static function iconv_fallback_utf8_iso88591($string)
        {
        }
        /**
         * UTF-8 => UTF-16BE
         *
         * @param string $string
         * @param bool   $bom
         *
         * @return string
         */
        public static function iconv_fallback_utf8_utf16be($string, $bom = \false)
        {
        }
        /**
         * UTF-8 => UTF-16LE
         *
         * @param string $string
         * @param bool   $bom
         *
         * @return string
         */
        public static function iconv_fallback_utf8_utf16le($string, $bom = \false)
        {
        }
        /**
         * UTF-8 => UTF-16LE (BOM)
         *
         * @param string $string
         *
         * @return string
         */
        public static function iconv_fallback_utf8_utf16($string)
        {
        }
        /**
         * UTF-16BE => UTF-8
         *
         * @param string $string
         *
         * @return string
         */
        public static function iconv_fallback_utf16be_utf8($string)
        {
        }
        /**
         * UTF-16LE => UTF-8
         *
         * @param string $string
         *
         * @return string
         */
        public static function iconv_fallback_utf16le_utf8($string)
        {
        }
        /**
         * UTF-16BE => ISO-8859-1
         *
         * @param string $string
         *
         * @return string
         */
        public static function iconv_fallback_utf16be_iso88591($string)
        {
        }
        /**
         * UTF-16LE => ISO-8859-1
         *
         * @param string $string
         *
         * @return string
         */
        public static function iconv_fallback_utf16le_iso88591($string)
        {
        }
        /**
         * UTF-16 (BOM) => ISO-8859-1
         *
         * @param string $string
         *
         * @return string
         */
        public static function iconv_fallback_utf16_iso88591($string)
        {
        }
        /**
         * UTF-16 (BOM) => UTF-8
         *
         * @param string $string
         *
         * @return string
         */
        public static function iconv_fallback_utf16_utf8($string)
        {
        }
        /**
         * @param string $in_charset
         * @param string $out_charset
         * @param string $string
         *
         * @return string
         * @throws Exception
         */
        public static function iconv_fallback($in_charset, $out_charset, $string)
        {
        }
        /**
         * @param mixed  $data
         * @param string $charset
         *
         * @return mixed
         */
        public static function recursiveMultiByteCharString2HTML($data, $charset = 'ISO-8859-1')
        {
        }
        /**
         * @param string|int|float $string
         * @param string           $charset
         *
         * @return string
         */
        public static function MultiByteCharString2HTML($string, $charset = 'ISO-8859-1')
        {
        }
        /**
         * @param int $namecode
         *
         * @return string
         */
        public static function RGADnameLookup($namecode)
        {
        }
        /**
         * @param int $originatorcode
         *
         * @return string
         */
        public static function RGADoriginatorLookup($originatorcode)
        {
        }
        /**
         * @param int $rawadjustment
         * @param int $signbit
         *
         * @return float
         */
        public static function RGADadjustmentLookup($rawadjustment, $signbit)
        {
        }
        /**
         * @param int $namecode
         * @param int $originatorcode
         * @param int $replaygain
         *
         * @return string
         */
        public static function RGADgainString($namecode, $originatorcode, $replaygain)
        {
        }
        /**
         * @param float $amplitude
         *
         * @return float
         */
        public static function RGADamplitude2dB($amplitude)
        {
        }
        /**
         * @param string $imgData
         * @param array  $imageinfo
         *
         * @return array|false
         */
        public static function GetDataImageSize($imgData, &$imageinfo = array())
        {
        }
        /**
         * @param string $mime_type
         *
         * @return string
         */
        public static function ImageExtFromMime($mime_type)
        {
        }
        /**
         * @param array $ThisFileInfo
         * @param bool  $option_tags_html default true (just as in the main getID3 class)
         *
         * @return bool
         */
        public static function CopyTagsToComments(&$ThisFileInfo, $option_tags_html = \true)
        {
        }
        /**
         * @param string $key
         * @param int    $begin
         * @param int    $end
         * @param string $file
         * @param string $name
         *
         * @return string
         */
        public static function EmbeddedLookup($key, $begin, $end, $file, $name)
        {
        }
        /**
         * @param string $filename
         * @param string $sourcefile
         * @param bool   $DieOnFailure
         *
         * @return bool
         * @throws Exception
         */
        public static function IncludeDependency($filename, $sourcefile, $DieOnFailure = \false)
        {
        }
        /**
         * @param string $string
         *
         * @return string
         */
        public static function trimNullByte($string)
        {
        }
        /**
         * @param string $path
         *
         * @return float|bool
         */
        public static function getFileSizeSyscall($path)
        {
        }
        /**
         * @param string $filename
         *
         * @return string|false
         */
        public static function truepath($filename)
        {
        }
        /**
         * Workaround for Bug #37268 (https://bugs.php.net/bug.php?id=37268)
         *
         * @param string $path A path.
         * @param string $suffix If the name component ends in suffix this will also be cut off.
         *
         * @return string
         */
        public static function mb_basename($path, $suffix = '')
        {
        }
    }
    class getID3
    {
        /**
         * CASE SENSITIVE! - i.e. (must be supported by iconv()). Examples:  ISO-8859-1  UTF-8  UTF-16  UTF-16BE
         *
         * @var string
         */
        public $encoding = 'UTF-8';
        /**
         * Should always be 'ISO-8859-1', but some tags may be written in other encodings such as 'EUC-CN' or 'CP1252'
         *
         * @var string
         */
        public $encoding_id3v1 = 'ISO-8859-1';
        /**
         * ID3v1 should always be 'ISO-8859-1', but some tags may be written in other encodings such as 'Windows-1251' or 'KOI8-R'. If true attempt to detect these encodings, but may return incorrect values for some tags actually in ISO-8859-1 encoding
         *
         * @var bool
         */
        public $encoding_id3v1_autodetect = \false;
        /**
         * Read and process ID3v1 tags
         *
         * @var bool
         */
        public $option_tag_id3v1 = \true;
        /**
         * Read and process ID3v2 tags
         *
         * @var bool
         */
        public $option_tag_id3v2 = \true;
        /**
         * Read and process Lyrics3 tags
         *
         * @var bool
         */
        public $option_tag_lyrics3 = \true;
        /**
         * Read and process APE tags
         *
         * @var bool
         */
        public $option_tag_apetag = \true;
        /**
         * Copy tags to root key 'tags' and encode to $this->encoding
         *
         * @var bool
         */
        public $option_tags_process = \true;
        /**
         * Copy tags to root key 'tags_html' properly translated from various encodings to HTML entities
         *
         * @var bool
         */
        public $option_tags_html = \true;
        /**
         * Calculate additional info such as bitrate, channelmode etc
         *
         * @var bool
         */
        public $option_extra_info = \true;
        /**
         * Defaults to true (ATTACHMENTS_INLINE) for backward compatibility
         *
         * @var bool|string
         */
        public $option_save_attachments = \true;
        /**
         * Get MD5 sum of data part - slow
         *
         * @var bool
         */
        public $option_md5_data = \false;
        /**
         * Use MD5 of source file if available - only FLAC and OptimFROG
         *
         * @var bool
         */
        public $option_md5_data_source = \false;
        /**
         * Get SHA1 sum of data part - slow
         *
         * @var bool
         */
        public $option_sha1_data = \false;
        /**
         * Check whether file is larger than 2GB and thus not supported by 32-bit PHP (null: auto-detect based on
         * PHP_INT_MAX)
         *
         * @var bool|null
         */
        public $option_max_2gb_check;
        /**
         * Read buffer size in bytes
         *
         * @var int
         */
        public $option_fread_buffer_size = 32768;
        /** archive.rar
         * if true use PHP RarArchive extension, if false (non-extension parsing not yet written in getID3)
         *
         * @var bool
         */
        public $options_archive_rar_use_php_rar_extension = \true;
        /** archive.gzip
         * Optional file list - disable for speed.
         * Decode gzipped files, if possible, and parse recursively (.tar.gz for example).
         *
         * @var bool
         */
        public $options_archive_gzip_parse_contents = \false;
        /** audio.midi
         * if false only parse most basic information, much faster for some files but may be inaccurate
         *
         * @var bool
         */
        public $options_audio_midi_scanwholefile = \true;
        /** audio.mp3
         * Forces getID3() to scan the file byte-by-byte and log all the valid audio frame headers - extremely slow,
         * unrecommended, but may provide data from otherwise-unusable files.
         *
         * @var bool
         */
        public $options_audio_mp3_allow_bruteforce = \false;
        /** audio.mp3
         * number of frames to scan to determine if MPEG-audio sequence is valid
         * Lower this number to 5-20 for faster scanning
         * Increase this number to 50+ for most accurate detection of valid VBR/CBR mpeg-audio streams
         *
         * @var int
         */
        public $options_audio_mp3_mp3_valid_check_frames = 50;
        /** audio.wavpack
         * Avoid scanning all frames (break after finding ID_RIFF_HEADER and ID_CONFIG_BLOCK,
         * significantly faster for very large files but other data may be missed
         *
         * @var bool
         */
        public $options_audio_wavpack_quick_parsing = \false;
        /** audio-video.flv
         * Break out of the loop if too many frames have been scanned; only scan this
         * many if meta frame does not contain useful duration.
         *
         * @var int
         */
        public $options_audiovideo_flv_max_frames = 100000;
        /** audio-video.matroska
         * If true, do not return information about CLUSTER chunks, since there's a lot of them
         * and they're not usually useful [default: TRUE].
         *
         * @var bool
         */
        public $options_audiovideo_matroska_hide_clusters = \true;
        /** audio-video.matroska
         * True to parse the whole file, not only header [default: FALSE].
         *
         * @var bool
         */
        public $options_audiovideo_matroska_parse_whole_file = \false;
        /** audio-video.quicktime
         * return all parsed data from all atoms if true, otherwise just returned parsed metadata
         *
         * @var bool
         */
        public $options_audiovideo_quicktime_ReturnAtomData = \false;
        /** audio-video.quicktime
         * return all parsed data from all atoms if true, otherwise just returned parsed metadata
         *
         * @var bool
         */
        public $options_audiovideo_quicktime_ParseAllPossibleAtoms = \false;
        /** audio-video.swf
         * return all parsed tags if true, otherwise do not return tags not parsed by getID3
         *
         * @var bool
         */
        public $options_audiovideo_swf_ReturnAllTagData = \false;
        /** graphic.bmp
         * return BMP palette
         *
         * @var bool
         */
        public $options_graphic_bmp_ExtractPalette = \false;
        /** graphic.bmp
         * return image data
         *
         * @var bool
         */
        public $options_graphic_bmp_ExtractData = \false;
        /** graphic.png
         * If data chunk is larger than this do not read it completely (getID3 only needs the first
         * few dozen bytes for parsing).
         *
         * @var int
         */
        public $options_graphic_png_max_data_bytes = 10000000;
        /** misc.pdf
         * return full details of PDF Cross-Reference Table (XREF)
         *
         * @var bool
         */
        public $options_misc_pdf_returnXREF = \false;
        /** misc.torrent
         * Assume all .torrent files are less than 1MB and just read entire thing into memory for easy processing.
         * Override this value if you need to process files larger than 1MB
         *
         * @var int
         */
        public $options_misc_torrent_max_torrent_filesize = 1048576;
        /**
         * Filename of file being analysed.
         *
         * @var string
         */
        public $filename;
        /**
         * Filepointer to file being analysed.
         *
         * @var resource
         */
        public $fp;
        /**
         * Result array.
         *
         * @var array
         */
        public $info;
        /**
         * @var string
         */
        public $tempdir = \GETID3_TEMP_DIR;
        /**
         * @var int
         */
        public $memory_limit = 0;
        /**
         * @var string
         */
        protected $startup_error = '';
        /**
         * @var string
         */
        protected $startup_warning = '';
        const VERSION = '1.9.23-202310190849';
        const FREAD_BUFFER_SIZE = 32768;
        const ATTACHMENTS_NONE = \false;
        const ATTACHMENTS_INLINE = \true;
        /**
         * @throws getid3_exception
         * @phpstan-return void
         */
        public function __construct()
        {
        }
        /**
         * @return string
         */
        public function version()
        {
        }
        /**
         * @return int
         */
        public function fread_buffer_size()
        {
        }
        /**
         * @param array $optArray
         *
         * @return bool
         */
        public function setOption($optArray)
        {
        }
        /**
         * @param string   $filename
         * @param int      $filesize
         * @param resource $fp
         *
         * @return bool
         *
         * @throws getid3_exception
         */
        public function openfile($filename, $filesize = \null, $fp = \null)
        {
        }
        /**
         * analyze file
         *
         * @param string   $filename
         * @param int      $filesize
         * @param string   $original_filename
         * @param resource $fp
         *
         * @return array
         */
        public function analyze($filename, $filesize = \null, $original_filename = '', $fp = \null)
        {
        }
        /**
         * Error handling.
         *
         * @param string $message
         *
         * @return array
         */
        public function error($message)
        {
        }
        /**
         * Warning handling.
         *
         * @param string $message
         *
         * @return bool
         */
        public function warning($message)
        {
        }
        /**
         * Return array containing information about all supported formats.
         *
         * @return array
         */
        public function GetFileFormatArray()
        {
        }
        /**
         * @param string $filedata
         * @param string $filename
         *
         * @return mixed|false
         */
        public function GetFileFormat(&$filedata, $filename = '')
        {
        }
        /**
         * Converts array to $encoding charset from $this->encoding.
         *
         * @param array  $array
         * @param string $encoding
         * @phpstan-return void
         */
        public function CharConvert(&$array, $encoding)
        {
        }
        /**
         * @return bool
         */
        public function HandleAllTags()
        {
        }
        /**
         * Calls getid3_lib::CopyTagsToComments() but passes in the option_tags_html setting from this instance of getID3
         *
         * @param array $ThisFileInfo
         *
         * @return bool
         */
        public function CopyTagsToComments(&$ThisFileInfo)
        {
        }
        /**
         * @param string $algorithm
         *
         * @return array|bool
         */
        public function getHashdata($algorithm)
        {
        }
        public function ChannelsBitratePlaytimeCalculations()
        {
        }
        /**
         * @return bool
         */
        public function CalculateCompressionRatioVideo()
        {
        }
        /**
         * @return bool
         */
        public function CalculateCompressionRatioAudio()
        {
        }
        /**
         * @return bool
         */
        public function CalculateReplayGain()
        {
        }
        /**
         * @return bool
         */
        public function ProcessAudioStreams()
        {
        }
        /**
         * @return string|bool
         */
        public function getid3_tempnam()
        {
        }
        /**
         * @param string $name
         *
         * @return bool
         *
         * @throws getid3_exception
         */
        public function include_module($name)
        {
        }
        /**
         * @param string $filename
         *
         * @return bool
         */
        public static function is_writable($filename)
        {
        }
    }
    abstract class getid3_handler
    {
        /**
         * @var getID3
         */
        protected $getid3;
        /**
         * Analyzing filepointer or string.
         *
         * @var bool
         */
        protected $data_string_flag = \false;
        /**
         * String to analyze.
         *
         * @var string
         */
        protected $data_string = '';
        /**
         * Seek position in string.
         *
         * @var int
         */
        protected $data_string_position = 0;
        /**
         * String length.
         *
         * @var int
         */
        protected $data_string_length = 0;
        /**
         * getid3_handler constructor.
         *
         * @param getID3 $getid3
         * @param string $call_module
         */
        public function __construct(\getID3 $getid3, $call_module = \null)
        {
        }
        /**
         * Analyze from file pointer.
         *
         * @return bool
         */
        public abstract function Analyze();
        /**
         * Analyze from string instead.
         *
         * @param string $string
         */
        public function AnalyzeString($string)
        {
        }
        /**
         * @param string $string
         */
        public function setStringMode($string)
        {
        }
        /**
         * @phpstan-impure
         *
         * @return int|bool
         */
        protected function ftell()
        {
        }
        /**
         * @param int $bytes
         *
         * @phpstan-impure
         *
         * @return string|false
         *
         * @throws getid3_exception
         */
        protected function fread($bytes)
        {
        }
        /**
         * @param int $bytes
         * @param int $whence
         *
         * @phpstan-impure
         *
         * @return int
         *
         * @throws getid3_exception
         */
        protected function fseek($bytes, $whence = \SEEK_SET)
        {
        }
        /**
         * @phpstan-impure
         *
         * @return string|false
         *
         * @throws getid3_exception
         */
        protected function fgets()
        {
        }
        /**
         * @phpstan-impure
         *
         * @return bool
         */
        protected function feof()
        {
        }
        /**
         * @param string $module
         *
         * @return bool
         */
        protected final function isDependencyFor($module)
        {
        }
        /**
         * @param string $text
         *
         * @return bool
         */
        protected function error($text)
        {
        }
        /**
         * @param string $text
         *
         * @return bool
         */
        protected function warning($text)
        {
        }
        /**
         * @param string $text
         */
        protected function notice($text)
        {
        }
        /**
         * @param string $name
         * @param int    $offset
         * @param int    $length
         * @param string $image_mime
         *
         * @return string|null
         *
         * @throws Exception
         * @throws getid3_exception
         */
        public function saveAttachment($name, $offset, $length, $image_mime = \null)
        {
        }
    }
    class getid3_exception extends \Exception
    {
        public $message;
    }
    class getid3_asf extends \getid3_handler
    {
        protected static $ASFIndexParametersObjectIndexSpecifiersIndexTypes = array(1 => 'Nearest Past Data Packet', 2 => 'Nearest Past Media Object', 3 => 'Nearest Past Cleanpoint');
        protected static $ASFMediaObjectIndexParametersObjectIndexSpecifiersIndexTypes = array(1 => 'Nearest Past Data Packet', 2 => 'Nearest Past Media Object', 3 => 'Nearest Past Cleanpoint', 0xff => 'Frame Number Offset');
        protected static $ASFTimecodeIndexParametersObjectIndexSpecifiersIndexTypes = array(2 => 'Nearest Past Media Object', 3 => 'Nearest Past Cleanpoint');
        /**
         * @param getID3 $getid3
         */
        public function __construct(\getID3 $getid3)
        {
        }
        /**
         * @return bool
         */
        public function Analyze()
        {
        }
        /**
         * @param int $CodecListType
         *
         * @return string
         */
        public static function codecListObjectTypeLookup($CodecListType)
        {
        }
        /**
         * @return array
         */
        public static function KnownGUIDs()
        {
        }
        /**
         * @param string $GUIDstring
         *
         * @return string|false
         */
        public static function GUIDname($GUIDstring)
        {
        }
        /**
         * @param int $id
         *
         * @return string
         */
        public static function ASFIndexObjectIndexTypeLookup($id)
        {
        }
        /**
         * @param string $GUIDstring
         *
         * @return string
         */
        public static function GUIDtoBytestring($GUIDstring)
        {
        }
        /**
         * @param string $Bytestring
         *
         * @return string
         */
        public static function BytestringToGUID($Bytestring)
        {
        }
        /**
         * @param int  $FILETIME
         * @param bool $round
         *
         * @return float|int
         */
        public static function FILETIMEtoUNIXtime($FILETIME, $round = \true)
        {
        }
        /**
         * @param int $WMpictureType
         *
         * @return string
         */
        public static function WMpictureTypeLookup($WMpictureType)
        {
        }
        /**
         * @param string $asf_header_extension_object_data
         * @param int    $unhandled_sections
         *
         * @return array
         */
        public function HeaderExtensionObjectDataParse(&$asf_header_extension_object_data, &$unhandled_sections)
        {
        }
        /**
         * @param int $id
         *
         * @return string
         */
        public static function metadataLibraryObjectDataTypeLookup($id)
        {
        }
        /**
         * @param string $data
         *
         * @return array
         */
        public function ASF_WMpicture(&$data)
        {
        }
        /**
         * Remove terminator 00 00 and convert UTF-16LE to Latin-1.
         *
         * @param string $string
         *
         * @return string
         */
        public static function TrimConvert($string)
        {
        }
        /**
         * Remove terminator 00 00.
         *
         * @param string $string
         *
         * @return string
         */
        public static function TrimTerm($string)
        {
        }
    }
    class getid3_flv extends \getid3_handler
    {
        const magic = 'FLV';
        /**
         * Break out of the loop if too many frames have been scanned; only scan this
         * many if meta frame does not contain useful duration.
         *
         * @var int
         */
        public $max_frames = 100000;
        /**
         * @return bool
         */
        public function Analyze()
        {
        }
        /**
         * @param int $id
         *
         * @return string|false
         */
        public static function audioFormatLookup($id)
        {
        }
        /**
         * @param int $id
         *
         * @return int|false
         */
        public static function audioRateLookup($id)
        {
        }
        /**
         * @param int $id
         *
         * @return int|false
         */
        public static function audioBitDepthLookup($id)
        {
        }
        /**
         * @param int $id
         *
         * @return string|false
         */
        public static function videoCodecLookup($id)
        {
        }
    }
    class AMFStream
    {
        /**
         * @var string
         */
        public $bytes;
        /**
         * @var int
         */
        public $pos;
        /**
         * @param string $bytes
         */
        public function __construct(&$bytes)
        {
        }
        /**
         * @return int
         */
        public function readByte()
        {
        }
        /**
         * @return int
         */
        public function readInt()
        {
        }
        /**
         * @return int
         */
        public function readLong()
        {
        }
        /**
         * @return float|false
         */
        public function readDouble()
        {
        }
        /**
         * @return string
         */
        public function readUTF()
        {
        }
        /**
         * @return string
         */
        public function readLongUTF()
        {
        }
        /**
         * @param int $length
         *
         * @return string
         */
        public function read($length)
        {
        }
        /**
         * @return int
         */
        public function peekByte()
        {
        }
        /**
         * @return int
         */
        public function peekInt()
        {
        }
        /**
         * @return int
         */
        public function peekLong()
        {
        }
        /**
         * @return float|false
         */
        public function peekDouble()
        {
        }
        /**
         * @return string
         */
        public function peekUTF()
        {
        }
        /**
         * @return string
         */
        public function peekLongUTF()
        {
        }
    }
    class AMFReader
    {
        /**
         * @var AMFStream
         */
        public $stream;
        /**
         * @param AMFStream $stream
         */
        public function __construct(\AMFStream $stream)
        {
        }
        /**
         * @return mixed
         */
        public function readData()
        {
        }
        /**
         * @return float|false
         */
        public function readDouble()
        {
        }
        /**
         * @return bool
         */
        public function readBoolean()
        {
        }
        /**
         * @return string
         */
        public function readString()
        {
        }
        /**
         * @return array
         */
        public function readObject()
        {
        }
        /**
         * @return array
         */
        public function readMixedArray()
        {
        }
        /**
         * @return array
         */
        public function readArray()
        {
        }
        /**
         * @return float|false
         */
        public function readDate()
        {
        }
        /**
         * @return string
         */
        public function readLongString()
        {
        }
        /**
         * @return string
         */
        public function readXML()
        {
        }
        /**
         * @return array
         */
        public function readTypedObject()
        {
        }
    }
    class AVCSequenceParameterSetReader
    {
        /**
         * @var string
         */
        public $sps;
        public $start = 0;
        public $currentBytes = 0;
        public $currentBits = 0;
        /**
         * @var int
         */
        public $width;
        /**
         * @var int
         */
        public $height;
        /**
         * @param string $sps
         */
        public function __construct($sps)
        {
        }
        public function readData()
        {
        }
        /**
         * @param int $bits
         */
        public function skipBits($bits)
        {
        }
        /**
         * @return int
         */
        public function getBit()
        {
        }
        /**
         * @param int $bits
         *
         * @return int
         */
        public function getBits($bits)
        {
        }
        /**
         * @return int
         */
        public function expGolombUe()
        {
        }
        /**
         * @return int
         */
        public function expGolombSe()
        {
        }
        /**
         * @return int
         */
        public function getWidth()
        {
        }
        /**
         * @return int
         */
        public function getHeight()
        {
        }
    }
    /**
    * @tutorial http://www.matroska.org/technical/specs/index.html
    *
    * @todo Rewrite EBML parser to reduce it's size and honor default element values
    * @todo After rewrite implement stream size calculation, that will provide additional useful info and enable AAC/FLAC audio bitrate detection
    */
    class getid3_matroska extends \getid3_handler
    {
        /**
         * If true, do not return information about CLUSTER chunks, since there's a lot of them
         * and they're not usually useful [default: TRUE].
         *
         * @var bool
         */
        public $hide_clusters = \true;
        /**
         * True to parse the whole file, not only header [default: FALSE].
         *
         * @var bool
         */
        public $parse_whole_file = \false;
        /**
         * @return bool
         */
        public function Analyze()
        {
        }
        /**
         * @param int $target_type
         *
         * @return string|int
         */
        public static function TargetTypeValue($target_type)
        {
        }
        /**
         * @param int $lacingtype
         *
         * @return string|int
         */
        public static function BlockLacingType($lacingtype)
        {
        }
        /**
         * @param string $codecid
         *
         * @return string
         */
        public static function CodecIDtoCommonName($codecid)
        {
        }
        /**
         * @param int $value
         *
         * @return string
         */
        public static function displayUnit($value)
        {
        }
    }
    class getid3_quicktime extends \getid3_handler
    {
        /** audio-video.quicktime
         * return all parsed data from all atoms if true, otherwise just returned parsed metadata
         *
         * @var bool
         */
        public $ReturnAtomData = \false;
        /** audio-video.quicktime
         * return all parsed data from all atoms if true, otherwise just returned parsed metadata
         *
         * @var bool
         */
        public $ParseAllPossibleAtoms = \false;
        /**
         * @return bool
         */
        public function Analyze()
        {
        }
        /**
         * @param string $atomname
         * @param int    $atomsize
         * @param string $atom_data
         * @param int    $baseoffset
         * @param array  $atomHierarchy
         * @param bool   $ParseAllPossibleAtoms
         *
         * @return array|false
         */
        public function QuicktimeParseAtom($atomname, $atomsize, $atom_data, $baseoffset, &$atomHierarchy, $ParseAllPossibleAtoms)
        {
        }
        /**
         * @param string $atom_data
         * @param int    $baseoffset
         * @param array  $atomHierarchy
         * @param bool   $ParseAllPossibleAtoms
         *
         * @return array|false
         */
        public function QuicktimeParseContainerAtom($atom_data, $baseoffset, &$atomHierarchy, $ParseAllPossibleAtoms)
        {
        }
        /**
         * @param string $data
         * @param int    $offset
         *
         * @return int
         */
        public function quicktime_read_mp4_descr_length($data, &$offset)
        {
        }
        /**
         * @param int $languageid
         *
         * @return string
         */
        public function QuicktimeLanguageLookup($languageid)
        {
        }
        /**
         * @param string $codecid
         *
         * @return string
         */
        public function QuicktimeVideoCodecLookup($codecid)
        {
        }
        /**
         * @param string $codecid
         *
         * @return mixed|string
         */
        public function QuicktimeAudioCodecLookup($codecid)
        {
        }
        /**
         * @param string $compressionid
         *
         * @return string
         */
        public function QuicktimeDCOMLookup($compressionid)
        {
        }
        /**
         * @param int $colordepthid
         *
         * @return string
         */
        public function QuicktimeColorNameLookup($colordepthid)
        {
        }
        /**
         * @param int $stik
         *
         * @return string
         */
        public function QuicktimeSTIKLookup($stik)
        {
        }
        /**
         * @param int $audio_profile_id
         *
         * @return string
         */
        public function QuicktimeIODSaudioProfileName($audio_profile_id)
        {
        }
        /**
         * @param int $video_profile_id
         *
         * @return string
         */
        public function QuicktimeIODSvideoProfileName($video_profile_id)
        {
        }
        /**
         * @param int $rtng
         *
         * @return string
         */
        public function QuicktimeContentRatingLookup($rtng)
        {
        }
        /**
         * @param int $akid
         *
         * @return string
         */
        public function QuicktimeStoreAccountTypeLookup($akid)
        {
        }
        /**
         * @param int $sfid
         *
         * @return string
         */
        public function QuicktimeStoreFrontCodeLookup($sfid)
        {
        }
        /**
         * @param string $keyname
         * @param string|array $data
         * @param string $boxname
         *
         * @return bool
         */
        public function CopyToAppropriateCommentsSection($keyname, $data, $boxname = '')
        {
        }
        /**
         * @param string $lstring
         * @param int    $count
         *
         * @return string
         */
        public function LociString($lstring, &$count)
        {
        }
        /**
         * @param string $nullterminatedstring
         *
         * @return string
         */
        public function NoNullString($nullterminatedstring)
        {
        }
        /**
         * @param string $pascalstring
         *
         * @return string
         */
        public function Pascal2String($pascalstring)
        {
        }
        /**
         * @param string $pascalstring
         *
         * @return string
         */
        public function MaybePascal2String($pascalstring)
        {
        }
        /**
         * Helper functions for m4b audiobook chapters
         * code by Steffen Hartmann 2015-Nov-08.
         *
         * @param array  $info
         * @param string $tag
         * @param string $history
         * @param array  $result
         */
        public function search_tag_by_key($info, $tag, $history, &$result)
        {
        }
        /**
         * @param array  $info
         * @param string $k
         * @param string $v
         * @param string $history
         * @param array  $result
         */
        public function search_tag_by_pair($info, $k, $v, $history, &$result)
        {
        }
        /**
         * @param array $info
         *
         * @return array
         */
        public function quicktime_time_to_sample_table($info)
        {
        }
        /**
         * @param array $info
         *
         * @return int
         */
        public function quicktime_bookmark_time_scale($info)
        {
        }
        /*
        // END helper functions for m4b audiobook chapters
        */
    }
    class getid3_riff extends \getid3_handler
    {
        protected $container = 'riff';
        /**
         * @return bool
         *
         * @throws getid3_exception
         */
        public function Analyze()
        {
        }
        /**
         * @param int $startoffset
         * @param int $maxoffset
         *
         * @return array|false
         *
         * @throws Exception
         * @throws getid3_exception
         */
        public function ParseRIFFAMV($startoffset, $maxoffset)
        {
        }
        /**
         * @param int $startoffset
         * @param int $maxoffset
         *
         * @return array|false
         * @throws getid3_exception
         */
        public function ParseRIFF($startoffset, $maxoffset)
        {
        }
        /**
         * @param string $RIFFdata
         *
         * @return bool
         */
        public function ParseRIFFdata(&$RIFFdata)
        {
        }
        /**
         * @param array $RIFFinfoArray
         * @param array $CommentsTargetArray
         *
         * @return bool
         */
        public static function parseComments(&$RIFFinfoArray, &$CommentsTargetArray)
        {
        }
        /**
         * @param string $WaveFormatExData
         *
         * @return array
         */
        public static function parseWAVEFORMATex($WaveFormatExData)
        {
        }
        /**
         * @param string $WavPackChunkData
         *
         * @return bool
         */
        public function parseWavPackHeader($WavPackChunkData)
        {
        }
        /**
         * @param string $BITMAPINFOHEADER
         * @param bool   $littleEndian
         *
         * @return array
         */
        public static function ParseBITMAPINFOHEADER($BITMAPINFOHEADER, $littleEndian = \true)
        {
        }
        /**
         * @param string $DIVXTAG
         * @param bool   $raw
         *
         * @return array
         */
        public static function ParseDIVXTAG($DIVXTAG, $raw = \false)
        {
        }
        /**
         * @param string $tagshortname
         *
         * @return string
         */
        public static function waveSNDMtagLookup($tagshortname)
        {
        }
        /**
         * @param int $wFormatTag
         *
         * @return string
         */
        public static function wFormatTagLookup($wFormatTag)
        {
        }
        /**
         * @param string $fourcc
         *
         * @return string
         */
        public static function fourccLookup($fourcc)
        {
        }
    }
    class getid3_ac3 extends \getid3_handler
    {
        const syncword = 0xb77;
        /**
         * @return bool
         */
        public function Analyze()
        {
        }
        /**
         * @param int $fscod
         *
         * @return int|string|false
         */
        public static function sampleRateCodeLookup($fscod)
        {
        }
        /**
         * @param int $fscod2
         *
         * @return int|string|false
         */
        public static function sampleRateCodeLookup2($fscod2)
        {
        }
        /**
         * @param int $bsmod
         * @param int $acmod
         *
         * @return string|false
         */
        public static function serviceTypeLookup($bsmod, $acmod)
        {
        }
        /**
         * @param int $acmod
         *
         * @return array|false
         */
        public static function audioCodingModeLookup($acmod)
        {
        }
        /**
         * @param int $cmixlev
         *
         * @return int|float|string|false
         */
        public static function centerMixLevelLookup($cmixlev)
        {
        }
        /**
         * @param int $surmixlev
         *
         * @return int|float|string|false
         */
        public static function surroundMixLevelLookup($surmixlev)
        {
        }
        /**
         * @param int $dsurmod
         *
         * @return string|false
         */
        public static function dolbySurroundModeLookup($dsurmod)
        {
        }
        /**
         * @param int  $acmod
         * @param bool $lfeon
         *
         * @return array
         */
        public static function channelsEnabledLookup($acmod, $lfeon)
        {
        }
        /**
         * @param int $compre
         *
         * @return float|int
         */
        public static function heavyCompression($compre)
        {
        }
        /**
         * @param int $roomtyp
         *
         * @return string|false
         */
        public static function roomTypeLookup($roomtyp)
        {
        }
        /**
         * @param int $frmsizecod
         * @param int $fscod
         *
         * @return int|false
         */
        public static function frameSizeLookup($frmsizecod, $fscod)
        {
        }
        /**
         * @param int $frmsizecod
         *
         * @return int|false
         */
        public static function bitrateLookup($frmsizecod)
        {
        }
        /**
         * @param int $numblkscod
         *
         * @return int|false
         */
        public static function blocksPerSyncFrame($numblkscod)
        {
        }
    }
    /**
    * @tutorial http://wiki.multimedia.cx/index.php?title=DTS
    */
    class getid3_dts extends \getid3_handler
    {
        /**
         * Default DTS syncword used in native .cpt or .dts formats.
         */
        const syncword = "\xfe\x80\x01";
        /**
         * Possible syncwords indicating bitstream encoding.
         */
        public static $syncwords = array(
            0 => "\xfe\x80\x01",
            // raw big-endian
            1 => "\xfe\x01\x80",
            // raw little-endian
            2 => "\x1f\xff\xe8\x00",
            // 14-bit big-endian
            3 => "\xff\x1f\x00\xe8",
        );
        /**
         * @return bool
         */
        public function Analyze()
        {
        }
        /**
         * @param int $index
         *
         * @return int|string|false
         */
        public static function bitrateLookup($index)
        {
        }
        /**
         * @param int $index
         *
         * @return int|string|false
         */
        public static function sampleRateLookup($index)
        {
        }
        /**
         * @param int $index
         *
         * @return int|false
         */
        public static function bitPerSampleLookup($index)
        {
        }
        /**
         * @param int $index
         *
         * @return int|false
         */
        public static function numChannelsLookup($index)
        {
        }
        /**
         * @param int $index
         *
         * @return string
         */
        public static function channelArrangementLookup($index)
        {
        }
        /**
         * @param int $index
         * @param int $version
         *
         * @return int|false
         */
        public static function dialogNormalization($index, $version)
        {
        }
    }
    /**
    * @tutorial http://flac.sourceforge.net/format.html
    */
    class getid3_flac extends \getid3_handler
    {
        const syncword = 'fLaC';
        /**
         * @return bool
         */
        public function Analyze()
        {
        }
        /**
         * @return bool
         */
        public function parseMETAdata()
        {
        }
        /**
         * @param string $BlockData
         *
         * @return array
         */
        public static function parseSTREAMINFOdata($BlockData)
        {
        }
        /**
         * Parse METADATA_BLOCK_PICTURE flac structure and extract attachment
         * External usage: audio.ogg
         *
         * @return bool
         */
        public function parsePICTURE()
        {
        }
        /**
         * @param int $blocktype
         *
         * @return string
         */
        public static function metaBlockTypeLookup($blocktype)
        {
        }
        /**
         * @param int $applicationid
         *
         * @return string
         */
        public static function applicationIDLookup($applicationid)
        {
        }
        /**
         * @param int $type_id
         *
         * @return string
         */
        public static function pictureTypeLookup($type_id)
        {
        }
    }
    class getid3_mp3 extends \getid3_handler
    {
        /**
         * Forces getID3() to scan the file byte-by-byte and log all the valid audio frame headers - extremely slow,
         * unrecommended, but may provide data from otherwise-unusable files.
         *
         * @var bool
         */
        public $allow_bruteforce = \false;
        /**
         * number of frames to scan to determine if MPEG-audio sequence is valid
         * Lower this number to 5-20 for faster scanning
         * Increase this number to 50+ for most accurate detection of valid VBR/CBR mpeg-audio streams
         *
         * @var int
         */
        public $mp3_valid_check_frames = 50;
        /**
         * @return bool
         */
        public function Analyze()
        {
        }
        /**
         * @return string
         */
        public function GuessEncoderOptions()
        {
        }
        /**
         * @param int   $offset
         * @param array $info
         * @param bool  $recursivesearch
         * @param bool  $ScanAsCBR
         * @param bool  $FastMPEGheaderScan
         *
         * @return bool
         */
        public function decodeMPEGaudioHeader($offset, &$info, $recursivesearch = \true, $ScanAsCBR = \false, $FastMPEGheaderScan = \false)
        {
        }
        /**
         * @param int $offset
         * @param int $nextframetestoffset
         * @param bool $ScanAsCBR
         *
         * @return bool
         */
        public function RecursiveFrameScanning(&$offset, &$nextframetestoffset, $ScanAsCBR)
        {
        }
        /**
         * @param int  $offset
         * @param bool $deepscan
         *
         * @return int|false
         */
        public function FreeFormatFrameLength($offset, $deepscan = \false)
        {
        }
        /**
         * @return bool
         */
        public function getOnlyMPEGaudioInfoBruteForce()
        {
        }
        /**
         * @param int  $avdataoffset
         * @param bool $BitrateHistogram
         *
         * @return bool
         */
        public function getOnlyMPEGaudioInfo($avdataoffset, $BitrateHistogram = \false)
        {
        }
        /**
         * @return array
         */
        public static function MPEGaudioVersionArray()
        {
        }
        /**
         * @return array
         */
        public static function MPEGaudioLayerArray()
        {
        }
        /**
         * @return array
         */
        public static function MPEGaudioBitrateArray()
        {
        }
        /**
         * @return array
         */
        public static function MPEGaudioFrequencyArray()
        {
        }
        /**
         * @return array
         */
        public static function MPEGaudioChannelModeArray()
        {
        }
        /**
         * @return array
         */
        public static function MPEGaudioModeExtensionArray()
        {
        }
        /**
         * @return array
         */
        public static function MPEGaudioEmphasisArray()
        {
        }
        /**
         * @param string $head4
         * @param bool   $allowBitrate15
         *
         * @return bool
         */
        public static function MPEGaudioHeaderBytesValid($head4, $allowBitrate15 = \false)
        {
        }
        /**
         * @param array $rawarray
         * @param bool  $echoerrors
         * @param bool  $allowBitrate15
         *
         * @return bool
         */
        public static function MPEGaudioHeaderValid($rawarray, $echoerrors = \false, $allowBitrate15 = \false)
        {
        }
        /**
         * @param string $Header4Bytes
         *
         * @return array|false
         */
        public static function MPEGaudioHeaderDecode($Header4Bytes)
        {
        }
        /**
         * @param int|string $bitrate
         * @param string     $version
         * @param string     $layer
         * @param bool       $padding
         * @param int        $samplerate
         *
         * @return int|false
         */
        public static function MPEGaudioFrameLength(&$bitrate, &$version, &$layer, $padding, &$samplerate)
        {
        }
        /**
         * @param float|int $bit_rate
         *
         * @return int|float|string
         */
        public static function ClosestStandardMP3Bitrate($bit_rate)
        {
        }
        /**
         * @param string $version
         * @param string $channelmode
         *
         * @return int
         */
        public static function XingVBRidOffset($version, $channelmode)
        {
        }
        /**
         * @param int $VBRmethodID
         *
         * @return string
         */
        public static function LAMEvbrMethodLookup($VBRmethodID)
        {
        }
        /**
         * @param int $StereoModeID
         *
         * @return string
         */
        public static function LAMEmiscStereoModeLookup($StereoModeID)
        {
        }
        /**
         * @param int $SourceSampleFrequencyID
         *
         * @return string
         */
        public static function LAMEmiscSourceSampleFrequencyLookup($SourceSampleFrequencyID)
        {
        }
        /**
         * @param int $SurroundInfoID
         *
         * @return string
         */
        public static function LAMEsurroundInfoLookup($SurroundInfoID)
        {
        }
        /**
         * @param array $LAMEtag
         *
         * @return string
         */
        public static function LAMEpresetUsedLookup($LAMEtag)
        {
        }
    }
    class getid3_ogg extends \getid3_handler
    {
        /**
         * @link http://xiph.org/vorbis/doc/Vorbis_I_spec.html
         *
         * @return bool
         */
        public function Analyze()
        {
        }
        /**
         * @param string $filedata
         * @param int    $filedataoffset
         * @param array  $oggpageinfo
         *
         * @return bool
         */
        public function ParseVorbisPageHeader(&$filedata, &$filedataoffset, &$oggpageinfo)
        {
        }
        /**
         * @link http://tools.ietf.org/html/draft-ietf-codec-oggopus-03
         *
         * @param string $filedata
         * @param int    $filedataoffset
         * @param array  $oggpageinfo
         *
         * @return bool
         */
        public function ParseOpusPageHeader(&$filedata, &$filedataoffset, &$oggpageinfo)
        {
        }
        /**
         * @return array|false
         */
        public function ParseOggPageHeader()
        {
        }
        /**
         * @link http://xiph.org/vorbis/doc/Vorbis_I_spec.html#x1-810005
         *
         * @return bool
         */
        public function ParseVorbisComments()
        {
        }
        /**
         * @param int $mode
         *
         * @return string|null
         */
        public static function SpeexBandModeLookup($mode)
        {
        }
        /**
         * @param array $OggInfoArray
         * @param int   $SegmentNumber
         *
         * @return int
         */
        public static function OggPageSegmentLength($OggInfoArray, $SegmentNumber = 1)
        {
        }
        /**
         * @param int $nominal_bitrate
         *
         * @return float
         */
        public static function get_quality_from_nominal_bitrate($nominal_bitrate)
        {
        }
        /**
         * @param int $colorspace_id
         *
         * @return string|null
         */
        public static function TheoraColorSpace($colorspace_id)
        {
        }
        /**
         * @param int $pixelformat_id
         *
         * @return string|null
         */
        public static function TheoraPixelFormat($pixelformat_id)
        {
        }
    }
    class getid3_apetag extends \getid3_handler
    {
        /**
         * true: return full data for all attachments;
         * false: return no data for all attachments;
         * integer: return data for attachments <= than this;
         * string: save as file to this directory.
         *
         * @var int|bool|string
         */
        public $inline_attachments = \true;
        public $overrideendoffset = 0;
        /**
         * @return bool
         */
        public function Analyze()
        {
        }
        /**
         * @param string $APEheaderFooterData
         *
         * @return array|false
         */
        public function parseAPEheaderFooter($APEheaderFooterData)
        {
        }
        /**
         * @param int $rawflagint
         *
         * @return array
         */
        public function parseAPEtagFlags($rawflagint)
        {
        }
        /**
         * @param int $contenttypeid
         *
         * @return string
         */
        public function APEcontentTypeFlagLookup($contenttypeid)
        {
        }
        /**
         * @param string $itemkey
         *
         * @return bool
         */
        public function APEtagItemIsUTF8Lookup($itemkey)
        {
        }
    }
    class getid3_id3v1 extends \getid3_handler
    {
        /**
         * @return bool
         */
        public function Analyze()
        {
        }
        /**
         * @param string $str
         *
         * @return string
         */
        public static function cutfield($str)
        {
        }
        /**
         * @param bool $allowSCMPXextended
         *
         * @return string[]
         */
        public static function ArrayOfGenres($allowSCMPXextended = \false)
        {
        }
        /**
         * @param string $genreid
         * @param bool   $allowSCMPXextended
         *
         * @return string|false
         */
        public static function LookupGenreName($genreid, $allowSCMPXextended = \true)
        {
        }
        /**
         * @param string $genre
         * @param bool   $allowSCMPXextended
         *
         * @return string|false
         */
        public static function LookupGenreID($genre, $allowSCMPXextended = \false)
        {
        }
        /**
         * @param string $OriginalGenre
         *
         * @return string|false
         */
        public static function StandardiseID3v1GenreName($OriginalGenre)
        {
        }
        /**
         * @param string     $title
         * @param string     $artist
         * @param string     $album
         * @param string     $year
         * @param int        $genreid
         * @param string     $comment
         * @param int|string $track
         *
         * @return string
         */
        public static function GenerateID3v1Tag($title, $artist, $album, $year, $genreid, $comment, $track = '')
        {
        }
    }
    class getid3_id3v2 extends \getid3_handler
    {
        public $StartingOffset = 0;
        /**
         * @return bool
         */
        public function Analyze()
        {
        }
        /**
         * @param string $genrestring
         *
         * @return array
         */
        public function ParseID3v2GenreString($genrestring)
        {
        }
        /**
         * @param array $parsedFrame
         *
         * @return bool
         */
        public function ParseID3v2Frame(&$parsedFrame)
        {
        }
        /**
         * @param string $data
         *
         * @return string
         */
        public function DeUnsynchronise($data)
        {
        }
        /**
         * @param int $index
         *
         * @return string
         */
        public function LookupExtendedHeaderRestrictionsTagSizeLimits($index)
        {
        }
        /**
         * @param int $index
         *
         * @return string
         */
        public function LookupExtendedHeaderRestrictionsTextEncodings($index)
        {
        }
        /**
         * @param int $index
         *
         * @return string
         */
        public function LookupExtendedHeaderRestrictionsTextFieldSize($index)
        {
        }
        /**
         * @param int $index
         *
         * @return string
         */
        public function LookupExtendedHeaderRestrictionsImageEncoding($index)
        {
        }
        /**
         * @param int $index
         *
         * @return string
         */
        public function LookupExtendedHeaderRestrictionsImageSizeSize($index)
        {
        }
        /**
         * @param string $currencyid
         *
         * @return string
         */
        public function LookupCurrencyUnits($currencyid)
        {
        }
        /**
         * @param string $currencyid
         *
         * @return string
         */
        public function LookupCurrencyCountry($currencyid)
        {
        }
        /**
         * @param string $languagecode
         * @param bool   $casesensitive
         *
         * @return string
         */
        public static function LanguageLookup($languagecode, $casesensitive = \false)
        {
        }
        /**
         * @param int $index
         *
         * @return string
         */
        public static function ETCOEventLookup($index)
        {
        }
        /**
         * @param int $index
         *
         * @return string
         */
        public static function SYTLContentTypeLookup($index)
        {
        }
        /**
         * @param int   $index
         * @param bool $returnarray
         *
         * @return array|string
         */
        public static function APICPictureTypeLookup($index, $returnarray = \false)
        {
        }
        /**
         * @param int $index
         *
         * @return string
         */
        public static function COMRReceivedAsLookup($index)
        {
        }
        /**
         * @param int $index
         *
         * @return string
         */
        public static function RVA2ChannelTypeLookup($index)
        {
        }
        /**
         * @param string $framename
         *
         * @return string
         */
        public static function FrameNameLongLookup($framename)
        {
        }
        /**
         * @param string $framename
         *
         * @return string
         */
        public static function FrameNameShortLookup($framename)
        {
        }
        /**
         * @param string $encoding
         *
         * @return string
         */
        public static function TextEncodingTerminatorLookup($encoding)
        {
        }
        /**
         * @param int $encoding
         *
         * @return string
         */
        public static function TextEncodingNameLookup($encoding)
        {
        }
        /**
         * @param string $string
         * @param string $terminator
         *
         * @return string
         */
        public static function RemoveStringTerminator($string, $terminator)
        {
        }
        /**
         * @param string $string
         *
         * @return string
         */
        public static function MakeUTF16emptyStringEmpty($string)
        {
        }
        /**
         * @param string $framename
         * @param int    $id3v2majorversion
         *
         * @return bool|int
         */
        public static function IsValidID3v2FrameName($framename, $id3v2majorversion)
        {
        }
        /**
         * @param string $numberstring
         * @param bool   $allowdecimal
         * @param bool   $allownegative
         *
         * @return bool
         */
        public static function IsANumber($numberstring, $allowdecimal = \false, $allownegative = \false)
        {
        }
        /**
         * @param string $datestamp
         *
         * @return bool
         */
        public static function IsValidDateStampString($datestamp)
        {
        }
        /**
         * @param int $majorversion
         *
         * @return int
         */
        public static function ID3v2HeaderLength($majorversion)
        {
        }
        /**
         * @param string $frame_name
         *
         * @return string|false
         */
        public static function ID3v22iTunesBrokenFrameName($frame_name)
        {
        }
    }
    class getid3_lyrics3 extends \getid3_handler
    {
        /**
         * @return bool
         */
        public function Analyze()
        {
        }
        /**
         * @param int $endoffset
         * @param int $version
         * @param int $length
         *
         * @return bool
         */
        public function getLyrics3Data($endoffset, $version, $length)
        {
        }
        /**
         * @param string $rawtimestamp
         *
         * @return int|false
         */
        public function Lyrics3Timestamp2Seconds($rawtimestamp)
        {
        }
        /**
         * @param array $Lyrics3data
         *
         * @return bool
         */
        public function Lyrics3LyricsTimestampParse(&$Lyrics3data)
        {
        }
        /**
         * @param string $char
         *
         * @return bool|null
         */
        public function IntString2Bool($char)
        {
        }
    }
    /**
     * IXR_Base64
     *
     * @package IXR
     * @since 1.5.0
     */
    class IXR_Base64
    {
        var $data;
        /**
         * PHP5 constructor.
         */
        function __construct($data)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function IXR_Base64($data)
        {
        }
        function getXml()
        {
        }
    }
    /**
     * IXR_Client
     *
     * @package IXR
     * @since 1.5.0
     *
     */
    class IXR_Client
    {
        var $server;
        var $port;
        var $path;
        var $useragent;
        var $response;
        var $message = \false;
        var $debug = \false;
        var $timeout;
        var $headers = array();
        var $error = \false;
        /**
         * PHP5 constructor.
         */
        function __construct($server, $path = \false, $port = 80, $timeout = 15)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function IXR_Client($server, $path = \false, $port = 80, $timeout = 15)
        {
        }
        /**
         * @since 1.5.0
         * @since 5.5.0 Formalized the existing `...$args` parameter by adding it
         *              to the function signature.
         *
         * @return bool
         */
        function query(...$args)
        {
        }
        function getResponse()
        {
        }
        function isError()
        {
        }
        function getErrorCode()
        {
        }
        function getErrorMessage()
        {
        }
    }
    /**
     * IXR_ClientMulticall
     *
     * @package IXR
     * @since 1.5.0
     */
    class IXR_ClientMulticall extends \IXR_Client
    {
        var $calls = array();
        /**
         * PHP5 constructor.
         */
        function __construct($server, $path = \false, $port = 80)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function IXR_ClientMulticall($server, $path = \false, $port = 80)
        {
        }
        /**
         * @since 1.5.0
         * @since 5.5.0 Formalized the existing `...$args` parameter by adding it
         *              to the function signature.
         */
        function addCall(...$args)
        {
        }
        /**
         * @since 1.5.0
         * @since 5.5.0 Formalized the existing `...$args` parameter by adding it
         *              to the function signature.
         *
         * @return bool
         */
        function query(...$args)
        {
        }
    }
    /**
     * IXR_Date
     *
     * @package IXR
     * @since 1.5.0
     */
    class IXR_Date
    {
        var $year;
        var $month;
        var $day;
        var $hour;
        var $minute;
        var $second;
        var $timezone;
        /**
         * PHP5 constructor.
         */
        function __construct($time)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function IXR_Date($time)
        {
        }
        function parseTimestamp($timestamp)
        {
        }
        function parseIso($iso)
        {
        }
        function getIso()
        {
        }
        function getXml()
        {
        }
        function getTimestamp()
        {
        }
    }
    /**
     * IXR_Error
     *
     * @package IXR
     * @since 1.5.0
     */
    class IXR_Error
    {
        var $code;
        var $message;
        /**
         * PHP5 constructor.
         */
        function __construct($code, $message)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function IXR_Error($code, $message)
        {
        }
        function getXml()
        {
        }
    }
    /**
     * IXR_Server
     *
     * @package IXR
     * @since 1.5.0
     */
    class IXR_Server
    {
        var $data;
        var $callbacks = array();
        var $message;
        var $capabilities;
        /**
         * PHP5 constructor.
         */
        function __construct($callbacks = \false, $data = \false, $wait = \false)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function IXR_Server($callbacks = \false, $data = \false, $wait = \false)
        {
        }
        function serve($data = \false)
        {
        }
        function call($methodname, $args)
        {
        }
        function error($error, $message = \false)
        {
        }
        function output($xml)
        {
        }
        function hasMethod($method)
        {
        }
        function setCapabilities()
        {
        }
        function getCapabilities($args)
        {
        }
        function setCallbacks()
        {
        }
        function listMethods($args)
        {
        }
        function multiCall($methodcalls)
        {
        }
    }
    /**
     * IXR_IntrospectionServer
     *
     * @package IXR
     * @since 1.5.0
     */
    class IXR_IntrospectionServer extends \IXR_Server
    {
        var $signatures;
        var $help;
        /**
         * PHP5 constructor.
         */
        function __construct()
        {
        }
        /**
         * PHP4 constructor.
         */
        public function IXR_IntrospectionServer()
        {
        }
        function addCallback($method, $callback, $args, $help)
        {
        }
        function call($methodname, $args)
        {
        }
        function methodSignature($method)
        {
        }
        function methodHelp($method)
        {
        }
    }
    /**
     * IXR_MESSAGE
     *
     * @package IXR
     * @since 1.5.0
     *
     */
    class IXR_Message
    {
        var $message = \false;
        var $messageType = \false;
        var $faultCode = \false;
        var $faultString = \false;
        var $methodName = '';
        var $params = array();
        var $_arraystructs = array();
        var $_arraystructstypes = array();
        var $_currentStructName = array();
        var $_param;
        var $_value;
        var $_currentTag;
        var $_currentTagContents;
        var $_parser;
        /**
         * PHP5 constructor.
         */
        function __construct($message)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function IXR_Message($message)
        {
        }
        function parse()
        {
        }
        function tag_open($parser, $tag, $attr)
        {
        }
        function cdata($parser, $cdata)
        {
        }
        function tag_close($parser, $tag)
        {
        }
    }
    /**
     * IXR_Request
     *
     * @package IXR
     * @since 1.5.0
     */
    class IXR_Request
    {
        var $method;
        var $args;
        var $xml;
        /**
         * PHP5 constructor.
         */
        function __construct($method, $args)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function IXR_Request($method, $args)
        {
        }
        function getLength()
        {
        }
        function getXml()
        {
        }
    }
    /**
     * IXR_Value
     *
     * @package IXR
     * @since 1.5.0
     */
    class IXR_Value
    {
        var $data;
        var $type;
        /**
         * PHP5 constructor.
         */
        function __construct($data, $type = \false)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function IXR_Value($data, $type = \false)
        {
        }
        function calculateType()
        {
        }
        function getXml()
        {
        }
        /**
         * Checks whether or not the supplied array is a struct or not
         *
         * @param array $array
         * @return bool
         */
        function isStruct($array)
        {
        }
    }
}
namespace PHPMailer\PHPMailer {
    /**
     * PHPMailer exception handler.
     *
     * @author Marcus Bointon <phpmailer@synchromedia.co.uk>
     */
    class Exception extends \Exception
    {
        /**
         * Prettify error message output.
         *
         * @return string
         */
        public function errorMessage()
        {
        }
    }
    /**
     * PHPMailer - PHP email creation and transport class.
     *
     * @author Marcus Bointon (Synchro/coolbru) <phpmailer@synchromedia.co.uk>
     * @author Jim Jagielski (jimjag) <jimjag@gmail.com>
     * @author Andy Prevost (codeworxtech) <codeworxtech@users.sourceforge.net>
     * @author Brent R. Matzelle (original founder)
     */
    class PHPMailer
    {
        const CHARSET_ASCII = 'us-ascii';
        const CHARSET_ISO88591 = 'iso-8859-1';
        const CHARSET_UTF8 = 'utf-8';
        const CONTENT_TYPE_PLAINTEXT = 'text/plain';
        const CONTENT_TYPE_TEXT_CALENDAR = 'text/calendar';
        const CONTENT_TYPE_TEXT_HTML = 'text/html';
        const CONTENT_TYPE_MULTIPART_ALTERNATIVE = 'multipart/alternative';
        const CONTENT_TYPE_MULTIPART_MIXED = 'multipart/mixed';
        const CONTENT_TYPE_MULTIPART_RELATED = 'multipart/related';
        const ENCODING_7BIT = '7bit';
        const ENCODING_8BIT = '8bit';
        const ENCODING_BASE64 = 'base64';
        const ENCODING_BINARY = 'binary';
        const ENCODING_QUOTED_PRINTABLE = 'quoted-printable';
        const ENCRYPTION_STARTTLS = 'tls';
        const ENCRYPTION_SMTPS = 'ssl';
        const ICAL_METHOD_REQUEST = 'REQUEST';
        const ICAL_METHOD_PUBLISH = 'PUBLISH';
        const ICAL_METHOD_REPLY = 'REPLY';
        const ICAL_METHOD_ADD = 'ADD';
        const ICAL_METHOD_CANCEL = 'CANCEL';
        const ICAL_METHOD_REFRESH = 'REFRESH';
        const ICAL_METHOD_COUNTER = 'COUNTER';
        const ICAL_METHOD_DECLINECOUNTER = 'DECLINECOUNTER';
        /**
         * Email priority.
         * Options: null (default), 1 = High, 3 = Normal, 5 = low.
         * When null, the header is not set at all.
         *
         * @var int|null
         */
        public $Priority;
        /**
         * The character set of the message.
         *
         * @var string
         */
        public $CharSet = self::CHARSET_ISO88591;
        /**
         * The MIME Content-type of the message.
         *
         * @var string
         */
        public $ContentType = self::CONTENT_TYPE_PLAINTEXT;
        /**
         * The message encoding.
         * Options: "8bit", "7bit", "binary", "base64", and "quoted-printable".
         *
         * @var string
         */
        public $Encoding = self::ENCODING_8BIT;
        /**
         * Holds the most recent mailer error message.
         *
         * @var string
         */
        public $ErrorInfo = '';
        /**
         * The From email address for the message.
         *
         * @var string
         */
        public $From = '';
        /**
         * The From name of the message.
         *
         * @var string
         */
        public $FromName = '';
        /**
         * The envelope sender of the message.
         * This will usually be turned into a Return-Path header by the receiver,
         * and is the address that bounces will be sent to.
         * If not empty, will be passed via `-f` to sendmail or as the 'MAIL FROM' value over SMTP.
         *
         * @var string
         */
        public $Sender = '';
        /**
         * The Subject of the message.
         *
         * @var string
         */
        public $Subject = '';
        /**
         * An HTML or plain text message body.
         * If HTML then call isHTML(true).
         *
         * @var string
         */
        public $Body = '';
        /**
         * The plain-text message body.
         * This body can be read by mail clients that do not have HTML email
         * capability such as mutt & Eudora.
         * Clients that can read HTML will view the normal Body.
         *
         * @var string
         */
        public $AltBody = '';
        /**
         * An iCal message part body.
         * Only supported in simple alt or alt_inline message types
         * To generate iCal event structures, use classes like EasyPeasyICS or iCalcreator.
         *
         * @see https://kigkonsult.se/iCalcreator/
         *
         * @var string
         */
        public $Ical = '';
        /**
         * Value-array of "method" in Contenttype header "text/calendar"
         *
         * @var string[]
         */
        protected static $IcalMethods = [self::ICAL_METHOD_REQUEST, self::ICAL_METHOD_PUBLISH, self::ICAL_METHOD_REPLY, self::ICAL_METHOD_ADD, self::ICAL_METHOD_CANCEL, self::ICAL_METHOD_REFRESH, self::ICAL_METHOD_COUNTER, self::ICAL_METHOD_DECLINECOUNTER];
        /**
         * The complete compiled MIME message body.
         *
         * @var string
         */
        protected $MIMEBody = '';
        /**
         * The complete compiled MIME message headers.
         *
         * @var string
         */
        protected $MIMEHeader = '';
        /**
         * Extra headers that createHeader() doesn't fold in.
         *
         * @var string
         */
        protected $mailHeader = '';
        /**
         * Word-wrap the message body to this number of chars.
         * Set to 0 to not wrap. A useful value here is 78, for RFC2822 section 2.1.1 compliance.
         *
         * @see static::STD_LINE_LENGTH
         *
         * @var int
         */
        public $WordWrap = 0;
        /**
         * Which method to use to send mail.
         * Options: "mail", "sendmail", or "smtp".
         *
         * @var string
         */
        public $Mailer = 'mail';
        /**
         * The path to the sendmail program.
         *
         * @var string
         */
        public $Sendmail = '/usr/sbin/sendmail';
        /**
         * Whether mail() uses a fully sendmail-compatible MTA.
         * One which supports sendmail's "-oi -f" options.
         *
         * @var bool
         */
        public $UseSendmailOptions = true;
        /**
         * The email address that a reading confirmation should be sent to, also known as read receipt.
         *
         * @var string
         */
        public $ConfirmReadingTo = '';
        /**
         * The hostname to use in the Message-ID header and as default HELO string.
         * If empty, PHPMailer attempts to find one with, in order,
         * $_SERVER['SERVER_NAME'], gethostname(), php_uname('n'), or the value
         * 'localhost.localdomain'.
         *
         * @see PHPMailer::$Helo
         *
         * @var string
         */
        public $Hostname = '';
        /**
         * An ID to be used in the Message-ID header.
         * If empty, a unique id will be generated.
         * You can set your own, but it must be in the format "<id@domain>",
         * as defined in RFC5322 section 3.6.4 or it will be ignored.
         *
         * @see https://tools.ietf.org/html/rfc5322#section-3.6.4
         *
         * @var string
         */
        public $MessageID = '';
        /**
         * The message Date to be used in the Date header.
         * If empty, the current date will be added.
         *
         * @var string
         */
        public $MessageDate = '';
        /**
         * SMTP hosts.
         * Either a single hostname or multiple semicolon-delimited hostnames.
         * You can also specify a different port
         * for each host by using this format: [hostname:port]
         * (e.g. "smtp1.example.com:25;smtp2.example.com").
         * You can also specify encryption type, for example:
         * (e.g. "tls://smtp1.example.com:587;ssl://smtp2.example.com:465").
         * Hosts will be tried in order.
         *
         * @var string
         */
        public $Host = 'localhost';
        /**
         * The default SMTP server port.
         *
         * @var int
         */
        public $Port = 25;
        /**
         * The SMTP HELO/EHLO name used for the SMTP connection.
         * Default is $Hostname. If $Hostname is empty, PHPMailer attempts to find
         * one with the same method described above for $Hostname.
         *
         * @see PHPMailer::$Hostname
         *
         * @var string
         */
        public $Helo = '';
        /**
         * What kind of encryption to use on the SMTP connection.
         * Options: '', static::ENCRYPTION_STARTTLS, or static::ENCRYPTION_SMTPS.
         *
         * @var string
         */
        public $SMTPSecure = '';
        /**
         * Whether to enable TLS encryption automatically if a server supports it,
         * even if `SMTPSecure` is not set to 'tls'.
         * Be aware that in PHP >= 5.6 this requires that the server's certificates are valid.
         *
         * @var bool
         */
        public $SMTPAutoTLS = true;
        /**
         * Whether to use SMTP authentication.
         * Uses the Username and Password properties.
         *
         * @see PHPMailer::$Username
         * @see PHPMailer::$Password
         *
         * @var bool
         */
        public $SMTPAuth = false;
        /**
         * Options array passed to stream_context_create when connecting via SMTP.
         *
         * @var array
         */
        public $SMTPOptions = [];
        /**
         * SMTP username.
         *
         * @var string
         */
        public $Username = '';
        /**
         * SMTP password.
         *
         * @var string
         */
        public $Password = '';
        /**
         * SMTP authentication type. Options are CRAM-MD5, LOGIN, PLAIN, XOAUTH2.
         * If not specified, the first one from that list that the server supports will be selected.
         *
         * @var string
         */
        public $AuthType = '';
        /**
         * SMTP SMTPXClient command attributes
         *
         * @var array
         */
        protected $SMTPXClient = [];
        /**
         * An implementation of the PHPMailer OAuthTokenProvider interface.
         *
         * @var OAuthTokenProvider
         */
        protected $oauth;
        /**
         * The SMTP server timeout in seconds.
         * Default of 5 minutes (300sec) is from RFC2821 section 4.5.3.2.
         *
         * @var int
         */
        public $Timeout = 300;
        /**
         * Comma separated list of DSN notifications
         * 'NEVER' under no circumstances a DSN must be returned to the sender.
         *         If you use NEVER all other notifications will be ignored.
         * 'SUCCESS' will notify you when your mail has arrived at its destination.
         * 'FAILURE' will arrive if an error occurred during delivery.
         * 'DELAY'   will notify you if there is an unusual delay in delivery, but the actual
         *           delivery's outcome (success or failure) is not yet decided.
         *
         * @see https://tools.ietf.org/html/rfc3461 See section 4.1 for more information about NOTIFY
         */
        public $dsn = '';
        /**
         * SMTP class debug output mode.
         * Debug output level.
         * Options:
         * @see SMTP::DEBUG_OFF: No output
         * @see SMTP::DEBUG_CLIENT: Client messages
         * @see SMTP::DEBUG_SERVER: Client and server messages
         * @see SMTP::DEBUG_CONNECTION: As SERVER plus connection status
         * @see SMTP::DEBUG_LOWLEVEL: Noisy, low-level data output, rarely needed
         *
         * @see SMTP::$do_debug
         *
         * @var int
         */
        public $SMTPDebug = 0;
        /**
         * How to handle debug output.
         * Options:
         * * `echo` Output plain-text as-is, appropriate for CLI
         * * `html` Output escaped, line breaks converted to `<br>`, appropriate for browser output
         * * `error_log` Output to error log as configured in php.ini
         * By default PHPMailer will use `echo` if run from a `cli` or `cli-server` SAPI, `html` otherwise.
         * Alternatively, you can provide a callable expecting two params: a message string and the debug level:
         *
         * ```php
         * $mail->Debugoutput = function($str, $level) {echo "debug level $level; message: $str";};
         * ```
         *
         * Alternatively, you can pass in an instance of a PSR-3 compatible logger, though only `debug`
         * level output is used:
         *
         * ```php
         * $mail->Debugoutput = new myPsr3Logger;
         * ```
         *
         * @see SMTP::$Debugoutput
         *
         * @var string|callable|\Psr\Log\LoggerInterface
         */
        public $Debugoutput = 'echo';
        /**
         * Whether to keep the SMTP connection open after each message.
         * If this is set to true then the connection will remain open after a send,
         * and closing the connection will require an explicit call to smtpClose().
         * It's a good idea to use this if you are sending multiple messages as it reduces overhead.
         * See the mailing list example for how to use it.
         *
         * @var bool
         */
        public $SMTPKeepAlive = false;
        /**
         * Whether to split multiple to addresses into multiple messages
         * or send them all in one message.
         * Only supported in `mail` and `sendmail` transports, not in SMTP.
         *
         * @var bool
         *
         * @deprecated 6.0.0 PHPMailer isn't a mailing list manager!
         */
        public $SingleTo = false;
        /**
         * Storage for addresses when SingleTo is enabled.
         *
         * @var array
         */
        protected $SingleToArray = [];
        /**
         * Whether to generate VERP addresses on send.
         * Only applicable when sending via SMTP.
         *
         * @see https://en.wikipedia.org/wiki/Variable_envelope_return_path
         * @see https://www.postfix.org/VERP_README.html Postfix VERP info
         *
         * @var bool
         */
        public $do_verp = false;
        /**
         * Whether to allow sending messages with an empty body.
         *
         * @var bool
         */
        public $AllowEmpty = false;
        /**
         * DKIM selector.
         *
         * @var string
         */
        public $DKIM_selector = '';
        /**
         * DKIM Identity.
         * Usually the email address used as the source of the email.
         *
         * @var string
         */
        public $DKIM_identity = '';
        /**
         * DKIM passphrase.
         * Used if your key is encrypted.
         *
         * @var string
         */
        public $DKIM_passphrase = '';
        /**
         * DKIM signing domain name.
         *
         * @example 'example.com'
         *
         * @var string
         */
        public $DKIM_domain = '';
        /**
         * DKIM Copy header field values for diagnostic use.
         *
         * @var bool
         */
        public $DKIM_copyHeaderFields = true;
        /**
         * DKIM Extra signing headers.
         *
         * @example ['List-Unsubscribe', 'List-Help']
         *
         * @var array
         */
        public $DKIM_extraHeaders = [];
        /**
         * DKIM private key file path.
         *
         * @var string
         */
        public $DKIM_private = '';
        /**
         * DKIM private key string.
         *
         * If set, takes precedence over `$DKIM_private`.
         *
         * @var string
         */
        public $DKIM_private_string = '';
        /**
         * Callback Action function name.
         *
         * The function that handles the result of the send email action.
         * It is called out by send() for each email sent.
         *
         * Value can be any php callable: https://www.php.net/is_callable
         *
         * Parameters:
         *   bool $result           result of the send action
         *   array   $to            email addresses of the recipients
         *   array   $cc            cc email addresses
         *   array   $bcc           bcc email addresses
         *   string  $subject       the subject
         *   string  $body          the email body
         *   string  $from          email address of sender
         *   string  $extra         extra information of possible use
         *                          "smtp_transaction_id' => last smtp transaction id
         *
         * @var string
         */
        public $action_function = '';
        /**
         * What to put in the X-Mailer header.
         * Options: An empty string for PHPMailer default, whitespace/null for none, or a string to use.
         *
         * @var string|null
         */
        public $XMailer = '';
        /**
         * Which validator to use by default when validating email addresses.
         * May be a callable to inject your own validator, but there are several built-in validators.
         * The default validator uses PHP's FILTER_VALIDATE_EMAIL filter_var option.
         *
         * @see PHPMailer::validateAddress()
         *
         * @var string|callable
         */
        public static $validator = 'php';
        /**
         * An instance of the SMTP sender class.
         *
         * @var SMTP
         */
        protected $smtp;
        /**
         * The array of 'to' names and addresses.
         *
         * @var array
         */
        protected $to = [];
        /**
         * The array of 'cc' names and addresses.
         *
         * @var array
         */
        protected $cc = [];
        /**
         * The array of 'bcc' names and addresses.
         *
         * @var array
         */
        protected $bcc = [];
        /**
         * The array of reply-to names and addresses.
         *
         * @var array
         */
        protected $ReplyTo = [];
        /**
         * An array of all kinds of addresses.
         * Includes all of $to, $cc, $bcc.
         *
         * @see PHPMailer::$to
         * @see PHPMailer::$cc
         * @see PHPMailer::$bcc
         *
         * @var array
         */
        protected $all_recipients = [];
        /**
         * An array of names and addresses queued for validation.
         * In send(), valid and non duplicate entries are moved to $all_recipients
         * and one of $to, $cc, or $bcc.
         * This array is used only for addresses with IDN.
         *
         * @see PHPMailer::$to
         * @see PHPMailer::$cc
         * @see PHPMailer::$bcc
         * @see PHPMailer::$all_recipients
         *
         * @var array
         */
        protected $RecipientsQueue = [];
        /**
         * An array of reply-to names and addresses queued for validation.
         * In send(), valid and non duplicate entries are moved to $ReplyTo.
         * This array is used only for addresses with IDN.
         *
         * @see PHPMailer::$ReplyTo
         *
         * @var array
         */
        protected $ReplyToQueue = [];
        /**
         * The array of attachments.
         *
         * @var array
         */
        protected $attachment = [];
        /**
         * The array of custom headers.
         *
         * @var array
         */
        protected $CustomHeader = [];
        /**
         * The most recent Message-ID (including angular brackets).
         *
         * @var string
         */
        protected $lastMessageID = '';
        /**
         * The message's MIME type.
         *
         * @var string
         */
        protected $message_type = '';
        /**
         * The array of MIME boundary strings.
         *
         * @var array
         */
        protected $boundary = [];
        /**
         * The array of available text strings for the current language.
         *
         * @var array
         */
        protected $language = [];
        /**
         * The number of errors encountered.
         *
         * @var int
         */
        protected $error_count = 0;
        /**
         * The S/MIME certificate file path.
         *
         * @var string
         */
        protected $sign_cert_file = '';
        /**
         * The S/MIME key file path.
         *
         * @var string
         */
        protected $sign_key_file = '';
        /**
         * The optional S/MIME extra certificates ("CA Chain") file path.
         *
         * @var string
         */
        protected $sign_extracerts_file = '';
        /**
         * The S/MIME password for the key.
         * Used only if the key is encrypted.
         *
         * @var string
         */
        protected $sign_key_pass = '';
        /**
         * Whether to throw exceptions for errors.
         *
         * @var bool
         */
        protected $exceptions = false;
        /**
         * Unique ID used for message ID and boundaries.
         *
         * @var string
         */
        protected $uniqueid = '';
        /**
         * The PHPMailer Version number.
         *
         * @var string
         */
        const VERSION = '6.9.2';
        /**
         * Error severity: message only, continue processing.
         *
         * @var int
         */
        const STOP_MESSAGE = 0;
        /**
         * Error severity: message, likely ok to continue processing.
         *
         * @var int
         */
        const STOP_CONTINUE = 1;
        /**
         * Error severity: message, plus full stop, critical error reached.
         *
         * @var int
         */
        const STOP_CRITICAL = 2;
        /**
         * The SMTP standard CRLF line break.
         * If you want to change line break format, change static::$LE, not this.
         */
        const CRLF = "\r\n";
        /**
         * "Folding White Space" a white space string used for line folding.
         */
        const FWS = ' ';
        /**
         * SMTP RFC standard line ending; Carriage Return, Line Feed.
         *
         * @var string
         */
        protected static $LE = self::CRLF;
        /**
         * The maximum line length supported by mail().
         *
         * Background: mail() will sometimes corrupt messages
         * with headers longer than 65 chars, see #818.
         *
         * @var int
         */
        const MAIL_MAX_LINE_LENGTH = 63;
        /**
         * The maximum line length allowed by RFC 2822 section 2.1.1.
         *
         * @var int
         */
        const MAX_LINE_LENGTH = 998;
        /**
         * The lower maximum line length allowed by RFC 2822 section 2.1.1.
         * This length does NOT include the line break
         * 76 means that lines will be 77 or 78 chars depending on whether
         * the line break format is LF or CRLF; both are valid.
         *
         * @var int
         */
        const STD_LINE_LENGTH = 76;
        /**
         * Constructor.
         *
         * @param bool $exceptions Should we throw external exceptions?
         */
        public function __construct($exceptions = null)
        {
        }
        /**
         * Destructor.
         */
        public function __destruct()
        {
        }
        /**
         * Output debugging info via a user-defined method.
         * Only generates output if debug output is enabled.
         *
         * @see PHPMailer::$Debugoutput
         * @see PHPMailer::$SMTPDebug
         *
         * @param string $str
         * @phpstan-return void
         */
        protected function edebug($str)
        {
        }
        /**
         * Sets message type to HTML or plain.
         *
         * @param bool $isHtml True for HTML mode
         */
        public function isHTML($isHtml = true)
        {
        }
        /**
         * Send messages using SMTP.
         */
        public function isSMTP()
        {
        }
        /**
         * Send messages using PHP's mail() function.
         */
        public function isMail()
        {
        }
        /**
         * Send messages using $Sendmail.
         */
        public function isSendmail()
        {
        }
        /**
         * Send messages using qmail.
         */
        public function isQmail()
        {
        }
        /**
         * Add a "To" address.
         *
         * @param string $address The email address to send to
         * @param string $name
         *
         * @throws Exception
         *
         * @return bool true on success, false if address already used or invalid in some way
         */
        public function addAddress($address, $name = '')
        {
        }
        /**
         * Add a "CC" address.
         *
         * @param string $address The email address to send to
         * @param string $name
         *
         * @throws Exception
         *
         * @return bool true on success, false if address already used or invalid in some way
         */
        public function addCC($address, $name = '')
        {
        }
        /**
         * Add a "BCC" address.
         *
         * @param string $address The email address to send to
         * @param string $name
         *
         * @throws Exception
         *
         * @return bool true on success, false if address already used or invalid in some way
         */
        public function addBCC($address, $name = '')
        {
        }
        /**
         * Add a "Reply-To" address.
         *
         * @param string $address The email address to reply to
         * @param string $name
         *
         * @throws Exception
         *
         * @return bool true on success, false if address already used or invalid in some way
         */
        public function addReplyTo($address, $name = '')
        {
        }
        /**
         * Add an address to one of the recipient arrays or to the ReplyTo array. Because PHPMailer
         * can't validate addresses with an IDN without knowing the PHPMailer::$CharSet (that can still
         * be modified after calling this function), addition of such addresses is delayed until send().
         * Addresses that have been added already return false, but do not throw exceptions.
         *
         * @param string $kind    One of 'to', 'cc', 'bcc', or 'Reply-To'
         * @param string $address The email address
         * @param string $name    An optional username associated with the address
         *
         * @throws Exception
         *
         * @return bool true on success, false if address already used or invalid in some way
         * @phpstan-param 'to'|'cc'|'bcc'|'Reply-To' $kind
         */
        protected function addOrEnqueueAnAddress($kind, $address, $name)
        {
        }
        /**
         * Set the boundaries to use for delimiting MIME parts.
         * If you override this, ensure you set all 3 boundaries to unique values.
         * The default boundaries include a "=_" sequence which cannot occur in quoted-printable bodies,
         * as suggested by https://www.rfc-editor.org/rfc/rfc2045#section-6.7
         *
         * @return void
         */
        public function setBoundaries()
        {
        }
        /**
         * Add an address to one of the recipient arrays or to the ReplyTo array.
         * Addresses that have been added already return false, but do not throw exceptions.
         *
         * @param string $kind    One of 'to', 'cc', 'bcc', or 'ReplyTo'
         * @param string $address The email address to send, resp. to reply to
         * @param string $name
         *
         * @throws Exception
         *
         * @return bool true on success, false if address already used or invalid in some way
         * @phpstan-param 'to'|'cc'|'bcc'|'ReplyTo' $kind
         */
        protected function addAnAddress($kind, $address, $name = '')
        {
        }
        /**
         * Parse and validate a string containing one or more RFC822-style comma-separated email addresses
         * of the form "display name <address>" into an array of name/address pairs.
         * Uses the imap_rfc822_parse_adrlist function if the IMAP extension is available.
         * Note that quotes in the name part are removed.
         *
         * @see https://www.andrew.cmu.edu/user/agreen1/testing/mrbs/web/Mail/RFC822.php A more careful implementation
         *
         * @param string $addrstr The address list string
         * @param bool   $useimap Whether to use the IMAP extension to parse the list
         * @param string $charset The charset to use when decoding the address list string.
         *
         * @return array
         */
        public static function parseAddresses($addrstr, $useimap = true, $charset = self::CHARSET_ISO88591)
        {
        }
        /**
         * Set the From and FromName properties.
         *
         * @param string $address
         * @param string $name
         * @param bool   $auto    Whether to also set the Sender address, defaults to true
         *
         * @throws Exception
         *
         * @return bool
         */
        public function setFrom($address, $name = '', $auto = true)
        {
        }
        /**
         * Return the Message-ID header of the last email.
         * Technically this is the value from the last time the headers were created,
         * but it's also the message ID of the last sent message except in
         * pathological cases.
         *
         * @return string
         */
        public function getLastMessageID()
        {
        }
        /**
         * Check that a string looks like an email address.
         * Validation patterns supported:
         * * `auto` Pick best pattern automatically;
         * * `pcre8` Use the squiloople.com pattern, requires PCRE > 8.0;
         * * `pcre` Use old PCRE implementation;
         * * `php` Use PHP built-in FILTER_VALIDATE_EMAIL;
         * * `html5` Use the pattern given by the HTML5 spec for 'email' type form input elements.
         * * `noregex` Don't use a regex: super fast, really dumb.
         * Alternatively you may pass in a callable to inject your own validator, for example:
         *
         * ```php
         * PHPMailer::validateAddress('user@example.com', function($address) {
         *     return (strpos($address, '@') !== false);
         * });
         * ```
         *
         * You can also set the PHPMailer::$validator static to a callable, allowing built-in methods to use your validator.
         *
         * @param string          $address       The email address to check
         * @param string|callable $patternselect Which pattern to use
         *
         * @return bool
         */
        public static function validateAddress($address, $patternselect = null)
        {
        }
        /**
         * Tells whether IDNs (Internationalized Domain Names) are supported or not. This requires the
         * `intl` and `mbstring` PHP extensions.
         *
         * @return bool `true` if required functions for IDN support are present
         */
        public static function idnSupported()
        {
        }
        /**
         * Converts IDN in given email address to its ASCII form, also known as punycode, if possible.
         * Important: Address must be passed in same encoding as currently set in PHPMailer::$CharSet.
         * This function silently returns unmodified address if:
         * - No conversion is necessary (i.e. domain name is not an IDN, or is already in ASCII form)
         * - Conversion to punycode is impossible (e.g. required PHP functions are not available)
         *   or fails for any reason (e.g. domain contains characters not allowed in an IDN).
         *
         * @see PHPMailer::$CharSet
         *
         * @param string $address The email address to convert
         *
         * @return string The encoded address in ASCII form
         */
        public function punyencodeAddress($address)
        {
        }
        /**
         * Create a message and send it.
         * Uses the sending method specified by $Mailer.
         *
         * @throws Exception
         *
         * @return bool false on error - See the ErrorInfo property for details of the error
         */
        public function send()
        {
        }
        /**
         * Prepare a message for sending.
         *
         * @throws Exception
         *
         * @return bool
         */
        public function preSend()
        {
        }
        /**
         * Actually send a message via the selected mechanism.
         *
         * @throws Exception
         *
         * @return bool
         */
        public function postSend()
        {
        }
        /**
         * Send mail using the $Sendmail program.
         *
         * @see PHPMailer::$Sendmail
         *
         * @param string $header The message headers
         * @param string $body   The message body
         *
         * @throws Exception
         *
         * @return bool
         */
        protected function sendmailSend($header, $body)
        {
        }
        /**
         * Fix CVE-2016-10033 and CVE-2016-10045 by disallowing potentially unsafe shell characters.
         * Note that escapeshellarg and escapeshellcmd are inadequate for our purposes, especially on Windows.
         *
         * @see https://github.com/PHPMailer/PHPMailer/issues/924 CVE-2016-10045 bug report
         *
         * @param string $string The string to be validated
         *
         * @return bool
         */
        protected static function isShellSafe($string)
        {
        }
        /**
         * Check whether a file path is of a permitted type.
         * Used to reject URLs and phar files from functions that access local file paths,
         * such as addAttachment.
         *
         * @param string $path A relative or absolute path to a file
         *
         * @return bool
         */
        protected static function isPermittedPath($path)
        {
        }
        /**
         * Check whether a file path is safe, accessible, and readable.
         *
         * @param string $path A relative or absolute path to a file
         *
         * @return bool
         */
        protected static function fileIsAccessible($path)
        {
        }
        /**
         * Send mail using the PHP mail() function.
         *
         * @see https://www.php.net/manual/en/book.mail.php
         *
         * @param string $header The message headers
         * @param string $body   The message body
         *
         * @throws Exception
         *
         * @return bool
         */
        protected function mailSend($header, $body)
        {
        }
        /**
         * Get an instance to use for SMTP operations.
         * Override this function to load your own SMTP implementation,
         * or set one with setSMTPInstance.
         *
         * @return SMTP
         */
        public function getSMTPInstance()
        {
        }
        /**
         * Provide an instance to use for SMTP operations.
         *
         * @return SMTP
         */
        public function setSMTPInstance(\PHPMailer\PHPMailer\SMTP $smtp)
        {
        }
        /**
         * Provide SMTP XCLIENT attributes
         *
         * @param string $name  Attribute name
         * @param ?string $value Attribute value
         *
         * @return bool
         */
        public function setSMTPXclientAttribute($name, $value)
        {
        }
        /**
         * Get SMTP XCLIENT attributes
         *
         * @return array
         */
        public function getSMTPXclientAttributes()
        {
        }
        /**
         * Send mail via SMTP.
         * Returns false if there is a bad MAIL FROM, RCPT, or DATA input.
         *
         * @see PHPMailer::setSMTPInstance() to use a different class.
         *
         * @uses \PHPMailer\PHPMailer\SMTP
         *
         * @param string $header The message headers
         * @param string $body   The message body
         *
         * @throws Exception
         *
         * @return bool
         */
        protected function smtpSend($header, $body)
        {
        }
        /**
         * Initiate a connection to an SMTP server.
         * Returns false if the operation failed.
         *
         * @param array $options An array of options compatible with stream_context_create()
         *
         * @throws Exception
         *
         * @uses \PHPMailer\PHPMailer\SMTP
         *
         * @return bool
         */
        public function smtpConnect($options = null)
        {
        }
        /**
         * Close the active SMTP session if one exists.
         */
        public function smtpClose()
        {
        }
        /**
         * Set the language for error messages.
         * The default language is English.
         *
         * @param string $langcode  ISO 639-1 2-character language code (e.g. French is "fr")
         *                          Optionally, the language code can be enhanced with a 4-character
         *                          script annotation and/or a 2-character country annotation.
         * @param string $lang_path Path to the language file directory, with trailing separator (slash)
         *                          Do not set this from user input!
         *
         * @return bool Returns true if the requested language was loaded, false otherwise.
         */
        public function setLanguage($langcode = 'en', $lang_path = '')
        {
        }
        /**
         * Get the array of strings for the current language.
         *
         * @return array
         */
        public function getTranslations()
        {
        }
        /**
         * Create recipient headers.
         *
         * @param string $type
         * @param array  $addr An array of recipients,
         *                     where each recipient is a 2-element indexed array with element 0 containing an address
         *                     and element 1 containing a name, like:
         *                     [['joe@example.com', 'Joe User'], ['zoe@example.com', 'Zoe User']]
         *
         * @return string
         */
        public function addrAppend($type, $addr)
        {
        }
        /**
         * Format an address for use in a message header.
         *
         * @param array $addr A 2-element indexed array, element 0 containing an address, element 1 containing a name like
         *                    ['joe@example.com', 'Joe User']
         *
         * @return string
         */
        public function addrFormat($addr)
        {
        }
        /**
         * Word-wrap message.
         * For use with mailers that do not automatically perform wrapping
         * and for quoted-printable encoded messages.
         * Original written by philippe.
         *
         * @param string $message The message to wrap
         * @param int    $length  The line length to wrap to
         * @param bool   $qp_mode Whether to run in Quoted-Printable mode
         *
         * @return string
         */
        public function wrapText($message, $length, $qp_mode = false)
        {
        }
        /**
         * Find the last character boundary prior to $maxLength in a utf-8
         * quoted-printable encoded string.
         * Original written by Colin Brown.
         *
         * @param string $encodedText utf-8 QP text
         * @param int    $maxLength   Find the last character boundary prior to this length
         *
         * @return int
         */
        public function utf8CharBoundary($encodedText, $maxLength)
        {
        }
        /**
         * Apply word wrapping to the message body.
         * Wraps the message body to the number of chars set in the WordWrap property.
         * You should only do this to plain-text bodies as wrapping HTML tags may break them.
         * This is called automatically by createBody(), so you don't need to call it yourself.
         * @phpstan-return void
         */
        public function setWordWrap()
        {
        }
        /**
         * Assemble message headers.
         *
         * @return string The assembled headers
         */
        public function createHeader()
        {
        }
        /**
         * Get the message MIME type headers.
         *
         * @return string
         */
        public function getMailMIME()
        {
        }
        /**
         * Returns the whole MIME message.
         * Includes complete headers and body.
         * Only valid post preSend().
         *
         * @see PHPMailer::preSend()
         *
         * @return string
         */
        public function getSentMIMEMessage()
        {
        }
        /**
         * Create a unique ID to use for boundaries.
         *
         * @return string
         */
        protected function generateId()
        {
        }
        /**
         * Assemble the message body.
         * Returns an empty string on failure.
         *
         * @throws Exception
         *
         * @return string The assembled message body
         */
        public function createBody()
        {
        }
        /**
         * Get the boundaries that this message will use
         * @return array
         */
        public function getBoundaries()
        {
        }
        /**
         * Return the start of a message boundary.
         *
         * @param string $boundary
         * @param string $charSet
         * @param string $contentType
         * @param string $encoding
         *
         * @return string
         */
        protected function getBoundary($boundary, $charSet, $contentType, $encoding)
        {
        }
        /**
         * Return the end of a message boundary.
         *
         * @param string $boundary
         *
         * @return string
         */
        protected function endBoundary($boundary)
        {
        }
        /**
         * Set the message type.
         * PHPMailer only supports some preset message types, not arbitrary MIME structures.
         */
        protected function setMessageType()
        {
        }
        /**
         * Format a header line.
         *
         * @param string     $name
         * @param string|int $value
         *
         * @return string
         */
        public function headerLine($name, $value)
        {
        }
        /**
         * Return a formatted mail line.
         *
         * @param string $value
         *
         * @return string
         */
        public function textLine($value)
        {
        }
        /**
         * Add an attachment from a path on the filesystem.
         * Never use a user-supplied path to a file!
         * Returns false if the file could not be found or read.
         * Explicitly *does not* support passing URLs; PHPMailer is not an HTTP client.
         * If you need to do that, fetch the resource yourself and pass it in via a local file or string.
         *
         * @param string $path        Path to the attachment
         * @param string $name        Overrides the attachment name
         * @param string $encoding    File encoding (see $Encoding)
         * @param string $type        MIME type, e.g. `image/jpeg`; determined automatically from $path if not specified
         * @param string $disposition Disposition to use
         *
         * @throws Exception
         *
         * @return bool
         */
        public function addAttachment($path, $name = '', $encoding = self::ENCODING_BASE64, $type = '', $disposition = 'attachment')
        {
        }
        /**
         * Return the array of attachments.
         *
         * @return array
         */
        public function getAttachments()
        {
        }
        /**
         * Attach all file, string, and binary attachments to the message.
         * Returns an empty string on failure.
         *
         * @param string $disposition_type
         * @param string $boundary
         *
         * @throws Exception
         *
         * @return string
         */
        protected function attachAll($disposition_type, $boundary)
        {
        }
        /**
         * Encode a file attachment in requested format.
         * Returns an empty string on failure.
         *
         * @param string $path     The full path to the file
         * @param string $encoding The encoding to use; one of 'base64', '7bit', '8bit', 'binary', 'quoted-printable'
         *
         * @return string
         */
        protected function encodeFile($path, $encoding = self::ENCODING_BASE64)
        {
        }
        /**
         * Encode a string in requested format.
         * Returns an empty string on failure.
         *
         * @param string $str      The text to encode
         * @param string $encoding The encoding to use; one of 'base64', '7bit', '8bit', 'binary', 'quoted-printable'
         *
         * @throws Exception
         *
         * @return string
         */
        public function encodeString($str, $encoding = self::ENCODING_BASE64)
        {
        }
        /**
         * Encode a header value (not including its label) optimally.
         * Picks shortest of Q, B, or none. Result includes folding if needed.
         * See RFC822 definitions for phrase, comment and text positions.
         *
         * @param string $str      The header value to encode
         * @param string $position What context the string will be used in
         *
         * @return string
         */
        public function encodeHeader($str, $position = 'text')
        {
        }
        /**
         * Check if a string contains multi-byte characters.
         *
         * @param string $str multi-byte text to wrap encode
         *
         * @return bool
         */
        public function hasMultiBytes($str)
        {
        }
        /**
         * Does a string contain any 8-bit chars (in any charset)?
         *
         * @param string $text
         *
         * @return bool
         */
        public function has8bitChars($text)
        {
        }
        /**
         * Encode and wrap long multibyte strings for mail headers
         * without breaking lines within a character.
         * Adapted from a function by paravoid.
         *
         * @see https://www.php.net/manual/en/function.mb-encode-mimeheader.php#60283
         *
         * @param string $str       multi-byte text to wrap encode
         * @param string $linebreak string to use as linefeed/end-of-line
         *
         * @return string
         */
        public function base64EncodeWrapMB($str, $linebreak = null)
        {
        }
        /**
         * Encode a string in quoted-printable format.
         * According to RFC2045 section 6.7.
         *
         * @param string $string The text to encode
         *
         * @return string
         */
        public function encodeQP($string)
        {
        }
        /**
         * Encode a string using Q encoding.
         *
         * @see https://www.rfc-editor.org/rfc/rfc2047#section-4.2
         *
         * @param string $str      the text to encode
         * @param string $position Where the text is going to be used, see the RFC for what that means
         *
         * @return string
         */
        public function encodeQ($str, $position = 'text')
        {
        }
        /**
         * Add a string or binary attachment (non-filesystem).
         * This method can be used to attach ascii or binary data,
         * such as a BLOB record from a database.
         *
         * @param string $string      String attachment data
         * @param string $filename    Name of the attachment
         * @param string $encoding    File encoding (see $Encoding)
         * @param string $type        File extension (MIME) type
         * @param string $disposition Disposition to use
         *
         * @throws Exception
         *
         * @return bool True on successfully adding an attachment
         */
        public function addStringAttachment($string, $filename, $encoding = self::ENCODING_BASE64, $type = '', $disposition = 'attachment')
        {
        }
        /**
         * Add an embedded (inline) attachment from a file.
         * This can include images, sounds, and just about any other document type.
         * These differ from 'regular' attachments in that they are intended to be
         * displayed inline with the message, not just attached for download.
         * This is used in HTML messages that embed the images
         * the HTML refers to using the `$cid` value in `img` tags, for example `<img src="cid:mylogo">`.
         * Never use a user-supplied path to a file!
         *
         * @param string $path        Path to the attachment
         * @param string $cid         Content ID of the attachment; Use this to reference
         *                            the content when using an embedded image in HTML
         * @param string $name        Overrides the attachment filename
         * @param string $encoding    File encoding (see $Encoding) defaults to `base64`
         * @param string $type        File MIME type (by default mapped from the `$path` filename's extension)
         * @param string $disposition Disposition to use: `inline` (default) or `attachment`
         *                            (unlikely you want this – {@see `addAttachment()`} instead)
         *
         * @return bool True on successfully adding an attachment
         * @throws Exception
         *
         */
        public function addEmbeddedImage($path, $cid, $name = '', $encoding = self::ENCODING_BASE64, $type = '', $disposition = 'inline')
        {
        }
        /**
         * Add an embedded stringified attachment.
         * This can include images, sounds, and just about any other document type.
         * If your filename doesn't contain an extension, be sure to set the $type to an appropriate MIME type.
         *
         * @param string $string      The attachment binary data
         * @param string $cid         Content ID of the attachment; Use this to reference
         *                            the content when using an embedded image in HTML
         * @param string $name        A filename for the attachment. If this contains an extension,
         *                            PHPMailer will attempt to set a MIME type for the attachment.
         *                            For example 'file.jpg' would get an 'image/jpeg' MIME type.
         * @param string $encoding    File encoding (see $Encoding), defaults to 'base64'
         * @param string $type        MIME type - will be used in preference to any automatically derived type
         * @param string $disposition Disposition to use
         *
         * @throws Exception
         *
         * @return bool True on successfully adding an attachment
         */
        public function addStringEmbeddedImage($string, $cid, $name = '', $encoding = self::ENCODING_BASE64, $type = '', $disposition = 'inline')
        {
        }
        /**
         * Validate encodings.
         *
         * @param string $encoding
         *
         * @return bool
         */
        protected function validateEncoding($encoding)
        {
        }
        /**
         * Check if an embedded attachment is present with this cid.
         *
         * @param string $cid
         *
         * @return bool
         */
        protected function cidExists($cid)
        {
        }
        /**
         * Check if an inline attachment is present.
         *
         * @return bool
         */
        public function inlineImageExists()
        {
        }
        /**
         * Check if an attachment (non-inline) is present.
         *
         * @return bool
         */
        public function attachmentExists()
        {
        }
        /**
         * Check if this message has an alternative body set.
         *
         * @return bool
         */
        public function alternativeExists()
        {
        }
        /**
         * Clear queued addresses of given kind.
         *
         * @param string $kind 'to', 'cc', or 'bcc'
         */
        public function clearQueuedAddresses($kind)
        {
        }
        /**
         * Clear all To recipients.
         */
        public function clearAddresses()
        {
        }
        /**
         * Clear all CC recipients.
         */
        public function clearCCs()
        {
        }
        /**
         * Clear all BCC recipients.
         */
        public function clearBCCs()
        {
        }
        /**
         * Clear all ReplyTo recipients.
         */
        public function clearReplyTos()
        {
        }
        /**
         * Clear all recipient types.
         */
        public function clearAllRecipients()
        {
        }
        /**
         * Clear all filesystem, string, and binary attachments.
         */
        public function clearAttachments()
        {
        }
        /**
         * Clear all custom headers.
         */
        public function clearCustomHeaders()
        {
        }
        /**
         * Clear a specific custom header by name or name and value.
         * $name value can be overloaded to contain
         * both header name and value (name:value).
         *
         * @param string      $name  Custom header name
         * @param string|null $value Header value
         *
         * @return bool True if a header was replaced successfully
         */
        public function clearCustomHeader($name, $value = null)
        {
        }
        /**
         * Replace a custom header.
         * $name value can be overloaded to contain
         * both header name and value (name:value).
         *
         * @param string      $name  Custom header name
         * @param string|null $value Header value
         *
         * @return bool True if a header was replaced successfully
         * @throws Exception
         */
        public function replaceCustomHeader($name, $value = null)
        {
        }
        /**
         * Add an error message to the error container.
         *
         * @param string $msg
         */
        protected function setError($msg)
        {
        }
        /**
         * Return an RFC 822 formatted date.
         *
         * @return string
         */
        public static function rfcDate()
        {
        }
        /**
         * Get the server hostname.
         * Returns 'localhost.localdomain' if unknown.
         *
         * @return string
         */
        protected function serverHostname()
        {
        }
        /**
         * Validate whether a string contains a valid value to use as a hostname or IP address.
         * IPv6 addresses must include [], e.g. `[::1]`, not just `::1`.
         *
         * @param string $host The host name or IP address to check
         *
         * @return bool
         */
        public static function isValidHost($host)
        {
        }
        /**
         * Get an error message in the current language.
         *
         * @param string $key
         *
         * @return string
         */
        protected function lang($key)
        {
        }
        /**
         * Check if an error occurred.
         *
         * @return bool True if an error did occur
         */
        public function isError()
        {
        }
        /**
         * Add a custom header.
         * $name value can be overloaded to contain
         * both header name and value (name:value).
         *
         * @param string      $name  Custom header name
         * @param string|null $value Header value
         *
         * @return bool True if a header was set successfully
         * @throws Exception
         */
        public function addCustomHeader($name, $value = null)
        {
        }
        /**
         * Returns all custom headers.
         *
         * @return array
         */
        public function getCustomHeaders()
        {
        }
        /**
         * Create a message body from an HTML string.
         * Automatically inlines images and creates a plain-text version by converting the HTML,
         * overwriting any existing values in Body and AltBody.
         * Do not source $message content from user input!
         * $basedir is prepended when handling relative URLs, e.g. <img src="/images/a.png"> and must not be empty
         * will look for an image file in $basedir/images/a.png and convert it to inline.
         * If you don't provide a $basedir, relative paths will be left untouched (and thus probably break in email)
         * Converts data-uri images into embedded attachments.
         * If you don't want to apply these transformations to your HTML, just set Body and AltBody directly.
         *
         * @param string        $message  HTML message string
         * @param string        $basedir  Absolute path to a base directory to prepend to relative paths to images
         * @param bool|callable $advanced Whether to use the internal HTML to text converter
         *                                or your own custom converter
         * @return string The transformed message body
         *
         * @throws Exception
         *
         * @see PHPMailer::html2text()
         */
        public function msgHTML($message, $basedir = '', $advanced = false)
        {
        }
        /**
         * Convert an HTML string into plain text.
         * This is used by msgHTML().
         * Note - older versions of this function used a bundled advanced converter
         * which was removed for license reasons in #232.
         * Example usage:
         *
         * ```php
         * //Use default conversion
         * $plain = $mail->html2text($html);
         * //Use your own custom converter
         * $plain = $mail->html2text($html, function($html) {
         *     $converter = new MyHtml2text($html);
         *     return $converter->get_text();
         * });
         * ```
         *
         * @param string        $html     The HTML text to convert
         * @param bool|callable $advanced Any boolean value to use the internal converter,
         *                                or provide your own callable for custom conversion.
         *                                *Never* pass user-supplied data into this parameter
         *
         * @return string
         */
        public function html2text($html, $advanced = false)
        {
        }
        /**
         * Get the MIME type for a file extension.
         *
         * @param string $ext File extension
         *
         * @return string MIME type of file
         */
        public static function _mime_types($ext = '')
        {
        }
        /**
         * Map a file name to a MIME type.
         * Defaults to 'application/octet-stream', i.e.. arbitrary binary data.
         *
         * @param string $filename A file name or full path, does not need to exist as a file
         *
         * @return string
         */
        public static function filenameToType($filename)
        {
        }
        /**
         * Multi-byte-safe pathinfo replacement.
         * Drop-in replacement for pathinfo(), but multibyte- and cross-platform-safe.
         *
         * @see https://www.php.net/manual/en/function.pathinfo.php#107461
         *
         * @param string     $path    A filename or path, does not need to exist as a file
         * @param int|string $options Either a PATHINFO_* constant,
         *                            or a string name to return only the specified piece
         *
         * @return string|array
         */
        public static function mb_pathinfo($path, $options = null)
        {
        }
        /**
         * Set or reset instance properties.
         * You should avoid this function - it's more verbose, less efficient, more error-prone and
         * harder to debug than setting properties directly.
         * Usage Example:
         * `$mail->set('SMTPSecure', static::ENCRYPTION_STARTTLS);`
         *   is the same as:
         * `$mail->SMTPSecure = static::ENCRYPTION_STARTTLS;`.
         *
         * @param string $name  The property name to set
         * @param mixed  $value The value to set the property to
         *
         * @return bool
         */
        public function set($name, $value = '')
        {
        }
        /**
         * Strip newlines to prevent header injection.
         *
         * @param string $str
         *
         * @return string
         */
        public function secureHeader($str)
        {
        }
        /**
         * Normalize line breaks in a string.
         * Converts UNIX LF, Mac CR and Windows CRLF line breaks into a single line break format.
         * Defaults to CRLF (for message bodies) and preserves consecutive breaks.
         *
         * @param string $text
         * @param string $breaktype What kind of line break to use; defaults to static::$LE
         *
         * @return string
         */
        public static function normalizeBreaks($text, $breaktype = null)
        {
        }
        /**
         * Remove trailing whitespace from a string.
         *
         * @param string $text
         *
         * @return string The text to remove whitespace from
         */
        public static function stripTrailingWSP($text)
        {
        }
        /**
         * Strip trailing line breaks from a string.
         *
         * @param string $text
         *
         * @return string The text to remove breaks from
         */
        public static function stripTrailingBreaks($text)
        {
        }
        /**
         * Return the current line break format string.
         *
         * @return string
         */
        public static function getLE()
        {
        }
        /**
         * Set the line break format string, e.g. "\r\n".
         *
         * @param string $le
         */
        protected static function setLE($le)
        {
        }
        /**
         * Set the public and private key files and password for S/MIME signing.
         *
         * @param string $cert_filename
         * @param string $key_filename
         * @param string $key_pass            Password for private key
         * @param string $extracerts_filename Optional path to chain certificate
         */
        public function sign($cert_filename, $key_filename, $key_pass, $extracerts_filename = '')
        {
        }
        /**
         * Quoted-Printable-encode a DKIM header.
         *
         * @param string $txt
         *
         * @return string
         */
        public function DKIM_QP($txt)
        {
        }
        /**
         * Generate a DKIM signature.
         *
         * @param string $signHeader
         *
         * @throws Exception
         *
         * @return string The DKIM signature value
         */
        public function DKIM_Sign($signHeader)
        {
        }
        /**
         * Generate a DKIM canonicalization header.
         * Uses the 'relaxed' algorithm from RFC6376 section 3.4.2.
         * Canonicalized headers should *always* use CRLF, regardless of mailer setting.
         *
         * @see https://tools.ietf.org/html/rfc6376#section-3.4.2
         *
         * @param string $signHeader Header
         *
         * @return string
         */
        public function DKIM_HeaderC($signHeader)
        {
        }
        /**
         * Generate a DKIM canonicalization body.
         * Uses the 'simple' algorithm from RFC6376 section 3.4.3.
         * Canonicalized bodies should *always* use CRLF, regardless of mailer setting.
         *
         * @see https://tools.ietf.org/html/rfc6376#section-3.4.3
         *
         * @param string $body Message Body
         *
         * @return string
         */
        public function DKIM_BodyC($body)
        {
        }
        /**
         * Create the DKIM header and body in a new message header.
         *
         * @param string $headers_line Header lines
         * @param string $subject      Subject
         * @param string $body         Body
         *
         * @throws Exception
         *
         * @return string
         */
        public function DKIM_Add($headers_line, $subject, $body)
        {
        }
        /**
         * Detect if a string contains a line longer than the maximum line length
         * allowed by RFC 2822 section 2.1.1.
         *
         * @param string $str
         *
         * @return bool
         */
        public static function hasLineLongerThanMax($str)
        {
        }
        /**
         * If a string contains any "special" characters, double-quote the name,
         * and escape any double quotes with a backslash.
         *
         * @param string $str
         *
         * @return string
         *
         * @see RFC822 3.4.1
         */
        public static function quotedString($str)
        {
        }
        /**
         * Allows for public read access to 'to' property.
         * Before the send() call, queued addresses (i.e. with IDN) are not yet included.
         *
         * @return array
         */
        public function getToAddresses()
        {
        }
        /**
         * Allows for public read access to 'cc' property.
         * Before the send() call, queued addresses (i.e. with IDN) are not yet included.
         *
         * @return array
         */
        public function getCcAddresses()
        {
        }
        /**
         * Allows for public read access to 'bcc' property.
         * Before the send() call, queued addresses (i.e. with IDN) are not yet included.
         *
         * @return array
         */
        public function getBccAddresses()
        {
        }
        /**
         * Allows for public read access to 'ReplyTo' property.
         * Before the send() call, queued addresses (i.e. with IDN) are not yet included.
         *
         * @return array
         */
        public function getReplyToAddresses()
        {
        }
        /**
         * Allows for public read access to 'all_recipients' property.
         * Before the send() call, queued addresses (i.e. with IDN) are not yet included.
         *
         * @return array
         */
        public function getAllRecipientAddresses()
        {
        }
        /**
         * Perform a callback.
         *
         * @param bool   $isSent
         * @param array  $to
         * @param array  $cc
         * @param array  $bcc
         * @param string $subject
         * @param string $body
         * @param string $from
         * @param array  $extra
         */
        protected function doCallback($isSent, $to, $cc, $bcc, $subject, $body, $from, $extra)
        {
        }
        /**
         * Get the OAuthTokenProvider instance.
         *
         * @return OAuthTokenProvider
         */
        public function getOAuth()
        {
        }
        /**
         * Set an OAuthTokenProvider instance.
         */
        public function setOAuth(\PHPMailer\PHPMailer\OAuthTokenProvider $oauth)
        {
        }
    }
    /**
     * PHPMailer RFC821 SMTP email transport class.
     * Implements RFC 821 SMTP commands and provides some utility methods for sending mail to an SMTP server.
     *
     * @author Chris Ryan
     * @author Marcus Bointon <phpmailer@synchromedia.co.uk>
     */
    class SMTP
    {
        /**
         * The PHPMailer SMTP version number.
         *
         * @var string
         */
        const VERSION = '6.9.2';
        /**
         * SMTP line break constant.
         *
         * @var string
         */
        const LE = "\r\n";
        /**
         * The SMTP port to use if one is not specified.
         *
         * @var int
         */
        const DEFAULT_PORT = 25;
        /**
         * The SMTPs port to use if one is not specified.
         *
         * @var int
         */
        const DEFAULT_SECURE_PORT = 465;
        /**
         * The maximum line length allowed by RFC 5321 section 4.5.3.1.6,
         * *excluding* a trailing CRLF break.
         *
         * @see https://tools.ietf.org/html/rfc5321#section-4.5.3.1.6
         *
         * @var int
         */
        const MAX_LINE_LENGTH = 998;
        /**
         * The maximum line length allowed for replies in RFC 5321 section 4.5.3.1.5,
         * *including* a trailing CRLF line break.
         *
         * @see https://tools.ietf.org/html/rfc5321#section-4.5.3.1.5
         *
         * @var int
         */
        const MAX_REPLY_LENGTH = 512;
        /**
         * Debug level for no output.
         *
         * @var int
         */
        const DEBUG_OFF = 0;
        /**
         * Debug level to show client -> server messages.
         *
         * @var int
         */
        const DEBUG_CLIENT = 1;
        /**
         * Debug level to show client -> server and server -> client messages.
         *
         * @var int
         */
        const DEBUG_SERVER = 2;
        /**
         * Debug level to show connection status, client -> server and server -> client messages.
         *
         * @var int
         */
        const DEBUG_CONNECTION = 3;
        /**
         * Debug level to show all messages.
         *
         * @var int
         */
        const DEBUG_LOWLEVEL = 4;
        /**
         * Debug output level.
         * Options:
         * * self::DEBUG_OFF (`0`) No debug output, default
         * * self::DEBUG_CLIENT (`1`) Client commands
         * * self::DEBUG_SERVER (`2`) Client commands and server responses
         * * self::DEBUG_CONNECTION (`3`) As DEBUG_SERVER plus connection status
         * * self::DEBUG_LOWLEVEL (`4`) Low-level data output, all messages.
         *
         * @var int
         */
        public $do_debug = self::DEBUG_OFF;
        /**
         * How to handle debug output.
         * Options:
         * * `echo` Output plain-text as-is, appropriate for CLI
         * * `html` Output escaped, line breaks converted to `<br>`, appropriate for browser output
         * * `error_log` Output to error log as configured in php.ini
         * Alternatively, you can provide a callable expecting two params: a message string and the debug level:
         *
         * ```php
         * $smtp->Debugoutput = function($str, $level) {echo "debug level $level; message: $str";};
         * ```
         *
         * Alternatively, you can pass in an instance of a PSR-3 compatible logger, though only `debug`
         * level output is used:
         *
         * ```php
         * $mail->Debugoutput = new myPsr3Logger;
         * ```
         *
         * @var string|callable|\Psr\Log\LoggerInterface
         */
        public $Debugoutput = 'echo';
        /**
         * Whether to use VERP.
         *
         * @see https://en.wikipedia.org/wiki/Variable_envelope_return_path
         * @see https://www.postfix.org/VERP_README.html Info on VERP
         *
         * @var bool
         */
        public $do_verp = false;
        /**
         * The timeout value for connection, in seconds.
         * Default of 5 minutes (300sec) is from RFC2821 section 4.5.3.2.
         * This needs to be quite high to function correctly with hosts using greetdelay as an anti-spam measure.
         *
         * @see https://www.rfc-editor.org/rfc/rfc2821#section-4.5.3.2
         *
         * @var int
         */
        public $Timeout = 300;
        /**
         * How long to wait for commands to complete, in seconds.
         * Default of 5 minutes (300sec) is from RFC2821 section 4.5.3.2.
         *
         * @var int
         */
        public $Timelimit = 300;
        /**
         * Patterns to extract an SMTP transaction id from reply to a DATA command.
         * The first capture group in each regex will be used as the ID.
         * MS ESMTP returns the message ID, which may not be correct for internal tracking.
         *
         * @var string[]
         */
        protected $smtp_transaction_id_patterns = ['exim' => '/[\\d]{3} OK id=(.*)/', 'sendmail' => '/[\\d]{3} 2\\.0\\.0 (.*) Message/', 'postfix' => '/[\\d]{3} 2\\.0\\.0 Ok: queued as (.*)/', 'Microsoft_ESMTP' => '/[0-9]{3} 2\\.[\\d]\\.0 (.*)@(?:.*) Queued mail for delivery/', 'Amazon_SES' => '/[\\d]{3} Ok (.*)/', 'SendGrid' => '/[\\d]{3} Ok: queued as (.*)/', 'CampaignMonitor' => '/[\\d]{3} 2\\.0\\.0 OK:([a-zA-Z\\d]{48})/', 'Haraka' => '/[\\d]{3} Message Queued \\((.*)\\)/', 'ZoneMTA' => '/[\\d]{3} Message queued as (.*)/', 'Mailjet' => '/[\\d]{3} OK queued as (.*)/'];
        /**
         * Allowed SMTP XCLIENT attributes.
         * Must be allowed by the SMTP server. EHLO response is not checked.
         *
         * @see https://www.postfix.org/XCLIENT_README.html
         *
         * @var array
         */
        public static $xclient_allowed_attributes = ['NAME', 'ADDR', 'PORT', 'PROTO', 'HELO', 'LOGIN', 'DESTADDR', 'DESTPORT'];
        /**
         * The last transaction ID issued in response to a DATA command,
         * if one was detected.
         *
         * @var string|bool|null
         */
        protected $last_smtp_transaction_id;
        /**
         * The socket for the server connection.
         *
         * @var ?resource
         */
        protected $smtp_conn;
        /**
         * Error information, if any, for the last SMTP command.
         *
         * @var array
         */
        protected $error = ['error' => '', 'detail' => '', 'smtp_code' => '', 'smtp_code_ex' => ''];
        /**
         * The reply the server sent to us for HELO.
         * If null, no HELO string has yet been received.
         *
         * @var string|null
         */
        protected $helo_rply;
        /**
         * The set of SMTP extensions sent in reply to EHLO command.
         * Indexes of the array are extension names.
         * Value at index 'HELO' or 'EHLO' (according to command that was sent)
         * represents the server name. In case of HELO it is the only element of the array.
         * Other values can be boolean TRUE or an array containing extension options.
         * If null, no HELO/EHLO string has yet been received.
         *
         * @var array|null
         */
        protected $server_caps;
        /**
         * The most recent reply received from the server.
         *
         * @var string
         */
        protected $last_reply = '';
        /**
         * Output debugging info via a user-selected method.
         *
         * @param string $str   Debug string to output
         * @param int    $level The debug level of this message; see DEBUG_* constants
         *
         * @see SMTP::$Debugoutput
         * @see SMTP::$do_debug
         * @phpstan-return void
         */
        protected function edebug($str, $level = 0)
        {
        }
        /**
         * Connect to an SMTP server.
         *
         * @param string $host    SMTP server IP or host name
         * @param int    $port    The port number to connect to
         * @param int    $timeout How long to wait for the connection to open
         * @param array  $options An array of options for stream_context_create()
         *
         * @return bool
         */
        public function connect($host, $port = null, $timeout = 30, $options = [])
        {
        }
        /**
         * Create connection to the SMTP server.
         *
         * @param string $host    SMTP server IP or host name
         * @param int    $port    The port number to connect to
         * @param int    $timeout How long to wait for the connection to open
         * @param array  $options An array of options for stream_context_create()
         *
         * @return false|resource
         */
        protected function getSMTPConnection($host, $port = null, $timeout = 30, $options = [])
        {
        }
        /**
         * Initiate a TLS (encrypted) session.
         *
         * @return bool
         */
        public function startTLS()
        {
        }
        /**
         * Perform SMTP authentication.
         * Must be run after hello().
         *
         * @see    hello()
         *
         * @param string $username The user name
         * @param string $password The password
         * @param string $authtype The auth type (CRAM-MD5, PLAIN, LOGIN, XOAUTH2)
         * @param OAuthTokenProvider $OAuth An optional OAuthTokenProvider instance for XOAUTH2 authentication
         *
         * @return bool True if successfully authenticated
         */
        public function authenticate($username, $password, $authtype = null, $OAuth = null)
        {
        }
        /**
         * Calculate an MD5 HMAC hash.
         * Works like hash_hmac('md5', $data, $key)
         * in case that function is not available.
         *
         * @param string $data The data to hash
         * @param string $key  The key to hash with
         *
         * @return string
         */
        protected function hmac($data, $key)
        {
        }
        /**
         * Check connection state.
         *
         * @return bool True if connected
         */
        public function connected()
        {
        }
        /**
         * Close the socket and clean up the state of the class.
         * Don't use this function without first trying to use QUIT.
         *
         * @see quit()
         */
        public function close()
        {
        }
        /**
         * Send an SMTP DATA command.
         * Issues a data command and sends the msg_data to the server,
         * finalizing the mail transaction. $msg_data is the message
         * that is to be sent with the headers. Each header needs to be
         * on a single line followed by a <CRLF> with the message headers
         * and the message body being separated by an additional <CRLF>.
         * Implements RFC 821: DATA <CRLF>.
         *
         * @param string $msg_data Message data to send
         *
         * @return bool
         */
        public function data($msg_data)
        {
        }
        /**
         * Send an SMTP HELO or EHLO command.
         * Used to identify the sending server to the receiving server.
         * This makes sure that client and server are in a known state.
         * Implements RFC 821: HELO <SP> <domain> <CRLF>
         * and RFC 2821 EHLO.
         *
         * @param string $host The host name or IP to connect to
         *
         * @return bool
         */
        public function hello($host = '')
        {
        }
        /**
         * Send an SMTP HELO or EHLO command.
         * Low-level implementation used by hello().
         *
         * @param string $hello The HELO string
         * @param string $host  The hostname to say we are
         *
         * @return bool
         *
         * @see hello()
         */
        protected function sendHello($hello, $host)
        {
        }
        /**
         * Parse a reply to HELO/EHLO command to discover server extensions.
         * In case of HELO, the only parameter that can be discovered is a server name.
         *
         * @param string $type `HELO` or `EHLO`
         */
        protected function parseHelloFields($type)
        {
        }
        /**
         * Send an SMTP MAIL command.
         * Starts a mail transaction from the email address specified in
         * $from. Returns true if successful or false otherwise. If True
         * the mail transaction is started and then one or more recipient
         * commands may be called followed by a data command.
         * Implements RFC 821: MAIL <SP> FROM:<reverse-path> <CRLF>.
         *
         * @param string $from Source address of this message
         *
         * @return bool
         */
        public function mail($from)
        {
        }
        /**
         * Send an SMTP QUIT command.
         * Closes the socket if there is no error or the $close_on_error argument is true.
         * Implements from RFC 821: QUIT <CRLF>.
         *
         * @param bool $close_on_error Should the connection close if an error occurs?
         *
         * @return bool
         */
        public function quit($close_on_error = true)
        {
        }
        /**
         * Send an SMTP RCPT command.
         * Sets the TO argument to $toaddr.
         * Returns true if the recipient was accepted false if it was rejected.
         * Implements from RFC 821: RCPT <SP> TO:<forward-path> <CRLF>.
         *
         * @param string $address The address the message is being sent to
         * @param string $dsn     Comma separated list of DSN notifications. NEVER, SUCCESS, FAILURE
         *                        or DELAY. If you specify NEVER all other notifications are ignored.
         *
         * @return bool
         */
        public function recipient($address, $dsn = '')
        {
        }
        /**
         * Send SMTP XCLIENT command to server and check its return code.
         *
         * @return bool True on success
         */
        public function xclient(array $vars)
        {
        }
        /**
         * Send an SMTP RSET command.
         * Abort any transaction that is currently in progress.
         * Implements RFC 821: RSET <CRLF>.
         *
         * @return bool True on success
         */
        public function reset()
        {
        }
        /**
         * Send a command to an SMTP server and check its return code.
         *
         * @param string    $command       The command name - not sent to the server
         * @param string    $commandstring The actual command to send
         * @param int|array $expect        One or more expected integer success codes
         *
         * @return bool True on success
         */
        protected function sendCommand($command, $commandstring, $expect)
        {
        }
        /**
         * Send an SMTP SAML command.
         * Starts a mail transaction from the email address specified in $from.
         * Returns true if successful or false otherwise. If True
         * the mail transaction is started and then one or more recipient
         * commands may be called followed by a data command. This command
         * will send the message to the users terminal if they are logged
         * in and send them an email.
         * Implements RFC 821: SAML <SP> FROM:<reverse-path> <CRLF>.
         *
         * @param string $from The address the message is from
         *
         * @return bool
         */
        public function sendAndMail($from)
        {
        }
        /**
         * Send an SMTP VRFY command.
         *
         * @param string $name The name to verify
         *
         * @return bool
         */
        public function verify($name)
        {
        }
        /**
         * Send an SMTP NOOP command.
         * Used to keep keep-alives alive, doesn't actually do anything.
         *
         * @return bool
         */
        public function noop()
        {
        }
        /**
         * Send an SMTP TURN command.
         * This is an optional command for SMTP that this class does not support.
         * This method is here to make the RFC821 Definition complete for this class
         * and _may_ be implemented in future.
         * Implements from RFC 821: TURN <CRLF>.
         *
         * @return bool
         */
        public function turn()
        {
        }
        /**
         * Send raw data to the server.
         *
         * @param string $data    The data to send
         * @param string $command Optionally, the command this is part of, used only for controlling debug output
         *
         * @return int|bool The number of bytes sent to the server or false on error
         */
        public function client_send($data, $command = '')
        {
        }
        /**
         * Get the latest error.
         *
         * @return array
         */
        public function getError()
        {
        }
        /**
         * Get SMTP extensions available on the server.
         *
         * @return array|null
         */
        public function getServerExtList()
        {
        }
        /**
         * Get metadata about the SMTP server from its HELO/EHLO response.
         * The method works in three ways, dependent on argument value and current state:
         *   1. HELO/EHLO has not been sent - returns null and populates $this->error.
         *   2. HELO has been sent -
         *     $name == 'HELO': returns server name
         *     $name == 'EHLO': returns boolean false
         *     $name == any other string: returns null and populates $this->error
         *   3. EHLO has been sent -
         *     $name == 'HELO'|'EHLO': returns the server name
         *     $name == any other string: if extension $name exists, returns True
         *       or its options (e.g. AUTH mechanisms supported). Otherwise returns False.
         *
         * @param string $name Name of SMTP extension or 'HELO'|'EHLO'
         *
         * @return string|bool|null
         */
        public function getServerExt($name)
        {
        }
        /**
         * Get the last reply from the server.
         *
         * @return string
         */
        public function getLastReply()
        {
        }
        /**
         * Read the SMTP server's response.
         * Either before eof or socket timeout occurs on the operation.
         * With SMTP we can tell if we have more lines to read if the
         * 4th character is '-' symbol. If it is a space then we don't
         * need to read anything else.
         *
         * @return string
         */
        protected function get_lines()
        {
        }
        /**
         * Enable or disable VERP address generation.
         *
         * @param bool $enabled
         */
        public function setVerp($enabled = false)
        {
        }
        /**
         * Get VERP address generation mode.
         *
         * @return bool
         */
        public function getVerp()
        {
        }
        /**
         * Set error messages and codes.
         *
         * @param string $message      The error message
         * @param string $detail       Further detail on the error
         * @param string $smtp_code    An associated SMTP error code
         * @param string $smtp_code_ex Extended SMTP code
         */
        protected function setError($message, $detail = '', $smtp_code = '', $smtp_code_ex = '')
        {
        }
        /**
         * Set debug output method.
         *
         * @param string|callable $method The name of the mechanism to use for debugging output, or a callable to handle it
         */
        public function setDebugOutput($method = 'echo')
        {
        }
        /**
         * Get debug output method.
         *
         * @return string
         */
        public function getDebugOutput()
        {
        }
        /**
         * Set debug output level.
         *
         * @param int $level
         */
        public function setDebugLevel($level = 0)
        {
        }
        /**
         * Get debug output level.
         *
         * @return int
         */
        public function getDebugLevel()
        {
        }
        /**
         * Set SMTP timeout.
         *
         * @param int $timeout The timeout duration in seconds
         */
        public function setTimeout($timeout = 0)
        {
        }
        /**
         * Get SMTP timeout.
         *
         * @return int
         */
        public function getTimeout()
        {
        }
        /**
         * Reports an error number and string.
         *
         * @param int    $errno   The error number returned by PHP
         * @param string $errmsg  The error message returned by PHP
         * @param string $errfile The file the error occurred in
         * @param int    $errline The line number the error occurred on
         */
        protected function errorHandler($errno, $errmsg, $errfile = '', $errline = 0)
        {
        }
        /**
         * Extract and return the ID of the last SMTP transaction based on
         * a list of patterns provided in SMTP::$smtp_transaction_id_patterns.
         * Relies on the host providing the ID in response to a DATA command.
         * If no reply has been received yet, it will return null.
         * If no pattern was matched, it will return false.
         *
         * @return bool|string|null
         */
        protected function recordLastTransactionID()
        {
        }
        /**
         * Get the queue/transaction ID of the last SMTP transaction
         * If no reply has been received yet, it will return null.
         * If no pattern was matched, it will return false.
         *
         * @return bool|string|null
         *
         * @see recordLastTransactionID()
         */
        public function getLastTransactionID()
        {
        }
    }
}
namespace WpOrg\Requests {
    /**
     * Authentication provider interface
     *
     * Implement this interface to act as an authentication provider.
     *
     * Parameters should be passed via the constructor where possible, as this
     * makes it much easier for users to use your provider.
     *
     * @see \WpOrg\Requests\Hooks
     *
     * @package Requests\Authentication
     */
    interface Auth
    {
        /**
         * Register hooks as needed
         *
         * This method is called in {@see \WpOrg\Requests\Requests::request()} when the user
         * has set an instance as the 'auth' option. Use this callback to register all the
         * hooks you'll need.
         *
         * @see \WpOrg\Requests\Hooks::register()
         * @param \WpOrg\Requests\Hooks $hooks Hook system
         */
        public function register(\WpOrg\Requests\Hooks $hooks);
    }
}
namespace WpOrg\Requests\Auth {
    /**
     * Basic Authentication provider
     *
     * Provides a handler for Basic HTTP authentication via the Authorization
     * header.
     *
     * @package Requests\Authentication
     */
    class Basic implements \WpOrg\Requests\Auth
    {
        /**
         * Username
         *
         * @var string
         */
        public $user;
        /**
         * Password
         *
         * @var string
         */
        public $pass;
        /**
         * Constructor
         *
         * @since 2.0 Throws an `InvalidArgument` exception.
         * @since 2.0 Throws an `ArgumentCount` exception instead of the Requests base `Exception.
         *
         * @param array|null $args Array of user and password. Must have exactly two elements
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed argument is not an array or null.
         * @throws \WpOrg\Requests\Exception\ArgumentCount   On incorrect number of array elements (`authbasicbadargs`).
         * @phpstan-return void
         */
        public function __construct($args = null)
        {
        }
        /**
         * Register the necessary callbacks
         *
         * @see \WpOrg\Requests\Auth\Basic::curl_before_send()
         * @see \WpOrg\Requests\Auth\Basic::fsockopen_header()
         * @param \WpOrg\Requests\Hooks $hooks Hook system
         */
        public function register(\WpOrg\Requests\Hooks $hooks)
        {
        }
        /**
         * Set cURL parameters before the data is sent
         *
         * @param resource|\CurlHandle $handle cURL handle
         */
        public function curl_before_send(&$handle)
        {
        }
        /**
         * Add extra headers to the request before sending
         *
         * @param string $out HTTP header string
         */
        public function fsockopen_header(&$out)
        {
        }
        /**
         * Get the authentication string (user:pass)
         *
         * @return string
         */
        public function getAuthString()
        {
        }
    }
}
namespace WpOrg\Requests {
    /**
     * Autoloader for Requests for PHP.
     *
     * This autoloader supports the PSR-4 based Requests 2.0.0 classes in a case-sensitive manner
     * as the most common server OS-es are case-sensitive and the file names are in mixed case.
     *
     * For the PSR-0 Requests 1.x BC-layer, requested classes will be treated case-insensitively.
     *
     * @package Requests
     */
    final class Autoload
    {
        /**
         * Register the autoloader.
         *
         * Note: the autoloader is *prepended* in the autoload queue.
         * This is done to ensure that the Requests 2.0 autoloader takes precedence
         * over a potentially (dependency-registered) Requests 1.x autoloader.
         *
         * @internal This method contains a safeguard against the autoloader being
         * registered multiple times. This safeguard uses a global constant to
         * (hopefully/in most cases) still function correctly, even if the
         * class would be renamed.
         *
         * @return void
         */
        public static function register()
        {
        }
        /**
         * Autoloader.
         *
         * @param string $class_name Name of the class name to load.
         *
         * @return bool Whether a class was loaded or not.
         */
        public static function load($class_name)
        {
        }
    }
    /**
     * Capability interface declaring the known capabilities.
     *
     * This is used as the authoritative source for which capabilities can be queried.
     *
     * @package Requests\Utilities
     */
    interface Capability
    {
        /**
         * Support for SSL.
         *
         * @var string
         */
        const SSL = 'ssl';
        /**
         * Collection of all capabilities supported in Requests.
         *
         * Note: this does not automatically mean that the capability will be supported for your chosen transport!
         *
         * @var string[]
         */
        const ALL = [self::SSL];
    }
    /**
     * Cookie storage object
     *
     * @package Requests\Cookies
     */
    class Cookie
    {
        /**
         * Cookie name.
         *
         * @var string
         */
        public $name;
        /**
         * Cookie value.
         *
         * @var string
         */
        public $value;
        /**
         * Cookie attributes
         *
         * Valid keys are `'path'`, `'domain'`, `'expires'`, `'max-age'`, `'secure'` and
         * `'httponly'`.
         *
         * @var \WpOrg\Requests\Utility\CaseInsensitiveDictionary|array Array-like object
         */
        public $attributes = [];
        /**
         * Cookie flags
         *
         * Valid keys are `'creation'`, `'last-access'`, `'persistent'` and `'host-only'`.
         *
         * @var array
         */
        public $flags = [];
        /**
         * Reference time for relative calculations
         *
         * This is used in place of `time()` when calculating Max-Age expiration and
         * checking time validity.
         *
         * @var int
         */
        public $reference_time = 0;
        /**
         * Create a new cookie object
         *
         * @param string                                                  $name           The name of the cookie.
         * @param string                                                  $value          The value for the cookie.
         * @param array|\WpOrg\Requests\Utility\CaseInsensitiveDictionary $attributes Associative array of attribute data
         * @param array                                                   $flags          The flags for the cookie.
         *                                                                                Valid keys are `'creation'`, `'last-access'`,
         *                                                                                `'persistent'` and `'host-only'`.
         * @param int|null                                                $reference_time Reference time for relative calculations.
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $name argument is not a string.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $value argument is not a string.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $attributes argument is not an array or iterable object with array access.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $flags argument is not an array.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $reference_time argument is not an integer or null.
         */
        public function __construct($name, $value, $attributes = [], $flags = [], $reference_time = null)
        {
        }
        /**
         * Get the cookie value
         *
         * Attributes and other data can be accessed via methods.
         */
        public function __toString()
        {
        }
        /**
         * Check if a cookie is expired.
         *
         * Checks the age against $this->reference_time to determine if the cookie
         * is expired.
         *
         * @return boolean True if expired, false if time is valid.
         */
        public function is_expired()
        {
        }
        /**
         * Check if a cookie is valid for a given URI
         *
         * @param \WpOrg\Requests\Iri $uri URI to check
         * @return boolean Whether the cookie is valid for the given URI
         */
        public function uri_matches(\WpOrg\Requests\Iri $uri)
        {
        }
        /**
         * Check if a cookie is valid for a given domain
         *
         * @param string $domain Domain to check
         * @return boolean Whether the cookie is valid for the given domain
         */
        public function domain_matches($domain)
        {
        }
        /**
         * Check if a cookie is valid for a given path
         *
         * From the path-match check in RFC 6265 section 5.1.4
         *
         * @param string $request_path Path to check
         * @return boolean Whether the cookie is valid for the given path
         */
        public function path_matches($request_path)
        {
        }
        /**
         * Normalize cookie and attributes
         *
         * @return boolean Whether the cookie was successfully normalized
         */
        public function normalize()
        {
        }
        /**
         * Parse an individual cookie attribute
         *
         * Handles parsing individual attributes from the cookie values.
         *
         * @param string $name Attribute name
         * @param string|int|bool $value Attribute value (string/integer value, or true if empty/flag)
         * @return mixed Value if available, or null if the attribute value is invalid (and should be skipped)
         */
        protected function normalize_attribute($name, $value)
        {
        }
        /**
         * Format a cookie for a Cookie header
         *
         * This is used when sending cookies to a server.
         *
         * @return string Cookie formatted for Cookie header
         */
        public function format_for_header()
        {
        }
        /**
         * Format a cookie for a Set-Cookie header
         *
         * This is used when sending cookies to clients. This isn't really
         * applicable to client-side usage, but might be handy for debugging.
         *
         * @return string Cookie formatted for Set-Cookie header
         */
        public function format_for_set_cookie()
        {
        }
        /**
         * Parse a cookie string into a cookie object
         *
         * Based on Mozilla's parsing code in Firefox and related projects, which
         * is an intentional deviation from RFC 2109 and RFC 2616. RFC 6265
         * specifies some of this handling, but not in a thorough manner.
         *
         * @param string $cookie_header Cookie header value (from a Set-Cookie header)
         * @param string $name
         * @param int|null $reference_time
         * @return \WpOrg\Requests\Cookie Parsed cookie object
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $cookie_header argument is not a string.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $name argument is not a string.
         */
        public static function parse($cookie_header, $name = '', $reference_time = null)
        {
        }
        /**
         * Parse all Set-Cookie headers from request headers
         *
         * @param \WpOrg\Requests\Response\Headers $headers Headers to parse from
         * @param \WpOrg\Requests\Iri|null $origin URI for comparing cookie origins
         * @param int|null $time Reference time for expiration calculation
         * @return array
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $origin argument is not null or an instance of the Iri class.
         */
        public static function parse_from_headers(\WpOrg\Requests\Response\Headers $headers, $origin = null, $time = null)
        {
        }
    }
}
namespace WpOrg\Requests\Cookie {
    /**
     * Cookie holder object
     *
     * @package Requests\Cookies
     */
    class Jar implements \ArrayAccess, \IteratorAggregate
    {
        /**
         * Actual item data
         *
         * @var array
         */
        protected $cookies = [];
        /**
         * Create a new jar
         *
         * @param array $cookies Existing cookie values
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed argument is not an array.
         */
        public function __construct($cookies = [])
        {
        }
        /**
         * Normalise cookie data into a \WpOrg\Requests\Cookie
         *
         * @param string|\WpOrg\Requests\Cookie $cookie Cookie header value, possibly pre-parsed (object).
         * @param string                        $key    Optional. The name for this cookie.
         * @return \WpOrg\Requests\Cookie
         */
        public function normalize_cookie($cookie, $key = '')
        {
        }
        /**
         * Check if the given item exists
         *
         * @param string $offset Item key
         * @return boolean Does the item exist?
         */
        #[\ReturnTypeWillChange]
        public function offsetExists($offset)
        {
        }
        /**
         * Get the value for the item
         *
         * @param string $offset Item key
         * @return string|null Item value (null if offsetExists is false)
         */
        #[\ReturnTypeWillChange]
        public function offsetGet($offset)
        {
        }
        /**
         * Set the given item
         *
         * @param string $offset Item name
         * @param string $value Item value
         *
         * @throws \WpOrg\Requests\Exception On attempting to use dictionary as list (`invalidset`)
         */
        #[\ReturnTypeWillChange]
        public function offsetSet($offset, $value)
        {
        }
        /**
         * Unset the given header
         *
         * @param string $offset The key for the item to unset.
         */
        #[\ReturnTypeWillChange]
        public function offsetUnset($offset)
        {
        }
        /**
         * Get an iterator for the data
         *
         * @return \ArrayIterator
         */
        #[\ReturnTypeWillChange]
        public function getIterator()
        {
        }
        /**
         * Register the cookie handler with the request's hooking system
         *
         * @param \WpOrg\Requests\HookManager $hooks Hooking system
         */
        public function register(\WpOrg\Requests\HookManager $hooks)
        {
        }
        /**
         * Add Cookie header to a request if we have any
         *
         * As per RFC 6265, cookies are separated by '; '
         *
         * @param string $url
         * @param array $headers
         * @param array $data
         * @param string $type
         * @param array $options
         */
        public function before_request($url, &$headers, &$data, &$type, &$options)
        {
        }
        /**
         * Parse all cookies from a response and attach them to the response
         *
         * @param \WpOrg\Requests\Response $response Response as received.
         */
        public function before_redirect_check(\WpOrg\Requests\Response $response)
        {
        }
    }
}
namespace WpOrg\Requests {
    /**
     * Exception for HTTP requests
     *
     * @package Requests\Exceptions
     */
    class Exception extends \Exception
    {
        /**
         * Type of exception
         *
         * @var string
         */
        protected $type;
        /**
         * Data associated with the exception
         *
         * @var mixed
         */
        protected $data;
        /**
         * Create a new exception
         *
         * @param string $message Exception message
         * @param string $type Exception type
         * @param mixed $data Associated data
         * @param integer $code Exception numerical code, if applicable
         */
        public function __construct($message, $type, $data = null, $code = 0)
        {
        }
        /**
         * Like {@see \Exception::getCode()}, but a string code.
         *
         * @codeCoverageIgnore
         * @return string
         */
        public function getType()
        {
        }
        /**
         * Gives any relevant data
         *
         * @codeCoverageIgnore
         * @return mixed
         */
        public function getData()
        {
        }
    }
}
namespace WpOrg\Requests\Exception {
    /**
     * Exception for when an incorrect number of arguments are passed to a method.
     *
     * Typically, this exception is used when all arguments for a method are optional,
     * but certain arguments need to be passed together, i.e. a method which can be called
     * with no arguments or with two arguments, but not with one argument.
     *
     * Along the same lines, this exception is also used if a method expects an array
     * with a certain number of elements and the provided number of elements does not comply.
     *
     * @package Requests\Exceptions
     * @since   2.0.0
     */
    final class ArgumentCount extends \WpOrg\Requests\Exception
    {
        /**
         * Create a new argument count exception with a standardized text.
         *
         * @param string $expected The argument count expected as a phrase.
         *                         For example: `at least 2 arguments` or `exactly 1 argument`.
         * @param int    $received The actual argument count received.
         * @param string $type     Exception type.
         *
         * @return \WpOrg\Requests\Exception\ArgumentCount
         */
        public static function create($expected, $received, $type)
        {
        }
    }
    /**
     * Exception based on HTTP response
     *
     * @package Requests\Exceptions
     */
    class Http extends \WpOrg\Requests\Exception
    {
        /**
         * HTTP status code
         *
         * @var integer
         */
        protected $code = 0;
        /**
         * Reason phrase
         *
         * @var string
         */
        protected $reason = 'Unknown';
        /**
         * Create a new exception
         *
         * There is no mechanism to pass in the status code, as this is set by the
         * subclass used. Reason phrases can vary, however.
         *
         * @param string|null $reason Reason phrase
         * @param mixed $data Associated data
         */
        public function __construct($reason = null, $data = null)
        {
        }
        /**
         * Get the status message.
         *
         * @return string
         */
        public function getReason()
        {
        }
        /**
         * Get the correct exception class for a given error code
         *
         * @param int|bool $code HTTP status code, or false if unavailable
         * @return string Exception class name to use
         */
        public static function get_class($code)
        {
        }
    }
}
namespace WpOrg\Requests\Exception\Http {
    /**
     * Exception for 304 Not Modified responses
     *
     * @package Requests\Exceptions
     */
    final class Status304 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 305 Use Proxy responses
     *
     * @package Requests\Exceptions
     */
    final class Status305 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 306 Switch Proxy responses
     *
     * @package Requests\Exceptions
     */
    final class Status306 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 400 Bad Request responses
     *
     * @package Requests\Exceptions
     */
    final class Status400 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 401 Unauthorized responses
     *
     * @package Requests\Exceptions
     */
    final class Status401 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 402 Payment Required responses
     *
     * @package Requests\Exceptions
     */
    final class Status402 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 403 Forbidden responses
     *
     * @package Requests\Exceptions
     */
    final class Status403 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 404 Not Found responses
     *
     * @package Requests\Exceptions
     */
    final class Status404 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 405 Method Not Allowed responses
     *
     * @package Requests\Exceptions
     */
    final class Status405 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 406 Not Acceptable responses
     *
     * @package Requests\Exceptions
     */
    final class Status406 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 407 Proxy Authentication Required responses
     *
     * @package Requests\Exceptions
     */
    final class Status407 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 408 Request Timeout responses
     *
     * @package Requests\Exceptions
     */
    final class Status408 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 409 Conflict responses
     *
     * @package Requests\Exceptions
     */
    final class Status409 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 410 Gone responses
     *
     * @package Requests\Exceptions
     */
    final class Status410 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 411 Length Required responses
     *
     * @package Requests\Exceptions
     */
    final class Status411 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 412 Precondition Failed responses
     *
     * @package Requests\Exceptions
     */
    final class Status412 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 413 Request Entity Too Large responses
     *
     * @package Requests\Exceptions
     */
    final class Status413 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 414 Request-URI Too Large responses
     *
     * @package Requests\Exceptions
     */
    final class Status414 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 415 Unsupported Media Type responses
     *
     * @package Requests\Exceptions
     */
    final class Status415 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 416 Requested Range Not Satisfiable responses
     *
     * @package Requests\Exceptions
     */
    final class Status416 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 417 Expectation Failed responses
     *
     * @package Requests\Exceptions
     */
    final class Status417 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 418 I'm A Teapot responses
     *
     * @link https://tools.ietf.org/html/rfc2324
     *
     * @package Requests\Exceptions
     */
    final class Status418 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 428 Precondition Required responses
     *
     * @link https://tools.ietf.org/html/rfc6585
     *
     * @package Requests\Exceptions
     */
    final class Status428 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 429 Too Many Requests responses
     *
     * @link https://tools.ietf.org/html/draft-nottingham-http-new-status-04
     *
     * @package Requests\Exceptions
     */
    final class Status429 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 431 Request Header Fields Too Large responses
     *
     * @link https://tools.ietf.org/html/rfc6585
     *
     * @package Requests\Exceptions
     */
    final class Status431 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 500 Internal Server Error responses
     *
     * @package Requests\Exceptions
     */
    final class Status500 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 501 Not Implemented responses
     *
     * @package Requests\Exceptions
     */
    final class Status501 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 502 Bad Gateway responses
     *
     * @package Requests\Exceptions
     */
    final class Status502 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 503 Service Unavailable responses
     *
     * @package Requests\Exceptions
     */
    final class Status503 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 504 Gateway Timeout responses
     *
     * @package Requests\Exceptions
     */
    final class Status504 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 505 HTTP Version Not Supported responses
     *
     * @package Requests\Exceptions
     */
    final class Status505 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for 511 Network Authentication Required responses
     *
     * @link https://tools.ietf.org/html/rfc6585
     *
     * @package Requests\Exceptions
     */
    final class Status511 extends \WpOrg\Requests\Exception\Http
    {
    }
    /**
     * Exception for unknown status responses
     *
     * @package Requests\Exceptions
     */
    final class StatusUnknown extends \WpOrg\Requests\Exception\Http
    {
        /**
         * Create a new exception
         *
         * If `$data` is an instance of {@see \WpOrg\Requests\Response}, uses the status
         * code from it. Otherwise, sets as 0
         *
         * @param string|null $reason Reason phrase
         * @param mixed $data Associated data
         */
        public function __construct($reason = null, $data = null)
        {
        }
    }
}
namespace WpOrg\Requests\Exception {
    /**
     * Exception for an invalid argument passed.
     *
     * @package Requests\Exceptions
     * @since   2.0.0
     */
    final class InvalidArgument extends \InvalidArgumentException
    {
        /**
         * Create a new invalid argument exception with a standardized text.
         *
         * @param int    $position The argument position in the function signature. 1-based.
         * @param string $name     The argument name in the function signature.
         * @param string $expected The argument type expected as a string.
         * @param string $received The actual argument type received.
         *
         * @return \WpOrg\Requests\Exception\InvalidArgument
         */
        public static function create($position, $name, $expected, $received)
        {
        }
    }
    /**
     * Transport Exception
     *
     * @package Requests\Exceptions
     */
    class Transport extends \WpOrg\Requests\Exception
    {
    }
}
namespace WpOrg\Requests\Exception\Transport {
    /**
     * CURL Transport Exception.
     *
     * @package Requests\Exceptions
     */
    final class Curl extends \WpOrg\Requests\Exception\Transport
    {
        const EASY = 'cURLEasy';
        const MULTI = 'cURLMulti';
        const SHARE = 'cURLShare';
        /**
         * Create a new exception.
         *
         * @param string $message Exception message.
         * @param string $type    Exception type.
         * @param mixed  $data    Associated data, if applicable.
         * @param int    $code    Exception numerical code, if applicable.
         */
        public function __construct($message, $type, $data = null, $code = 0)
        {
        }
        /**
         * Get the error message.
         *
         * @return string
         */
        public function getReason()
        {
        }
    }
}
namespace WpOrg\Requests {
    /**
     * Event dispatcher
     *
     * @package Requests\EventDispatcher
     */
    interface HookManager
    {
        /**
         * Register a callback for a hook
         *
         * @param string $hook Hook name
         * @param callable $callback Function/method to call on event
         * @param int $priority Priority number. <0 is executed earlier, >0 is executed later
         */
        public function register($hook, $callback, $priority = 0);
        /**
         * Dispatch a message
         *
         * @param string $hook Hook name
         * @param array $parameters Parameters to pass to callbacks
         * @return boolean Successfulness
         */
        public function dispatch($hook, $parameters = []);
    }
    /**
     * Handles adding and dispatching events
     *
     * @package Requests\EventDispatcher
     */
    class Hooks implements \WpOrg\Requests\HookManager
    {
        /**
         * Registered callbacks for each hook
         *
         * @var array
         */
        protected $hooks = [];
        /**
         * Register a callback for a hook
         *
         * @param string $hook Hook name
         * @param callable $callback Function/method to call on event
         * @param int $priority Priority number. <0 is executed earlier, >0 is executed later
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $hook argument is not a string.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $callback argument is not callable.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $priority argument is not an integer.
         */
        public function register($hook, $callback, $priority = 0)
        {
        }
        /**
         * Dispatch a message
         *
         * @param string $hook Hook name
         * @param array $parameters Parameters to pass to callbacks
         * @return boolean Successfulness
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $hook argument is not a string.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $parameters argument is not an array.
         */
        public function dispatch($hook, $parameters = [])
        {
        }
        public function __wakeup()
        {
        }
    }
    /**
     * IDNA URL encoder
     *
     * Note: Not fully compliant, as nameprep does nothing yet.
     *
     * @package Requests\Utilities
     *
     * @link https://tools.ietf.org/html/rfc3490 IDNA specification
     * @link https://tools.ietf.org/html/rfc3492 Punycode/Bootstrap specification
     */
    class IdnaEncoder
    {
        /**
         * ACE prefix used for IDNA
         *
         * @link https://tools.ietf.org/html/rfc3490#section-5
         * @var string
         */
        const ACE_PREFIX = 'xn--';
        /**
         * Maximum length of a IDNA URL in ASCII.
         *
         * @see \WpOrg\Requests\IdnaEncoder::to_ascii()
         *
         * @since 2.0.0
         *
         * @var int
         */
        const MAX_LENGTH = 64;
        /**#@+
         * Bootstrap constant for Punycode
         *
         * @link https://tools.ietf.org/html/rfc3492#section-5
         * @var int
         */
        const BOOTSTRAP_BASE = 36;
        const BOOTSTRAP_TMIN = 1;
        const BOOTSTRAP_TMAX = 26;
        const BOOTSTRAP_SKEW = 38;
        const BOOTSTRAP_DAMP = 700;
        const BOOTSTRAP_INITIAL_BIAS = 72;
        const BOOTSTRAP_INITIAL_N = 128;
        /**#@-*/
        /**
         * Encode a hostname using Punycode
         *
         * @param string|Stringable $hostname Hostname
         * @return string Punycode-encoded hostname
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed argument is not a string or a stringable object.
         */
        public static function encode($hostname)
        {
        }
        /**
         * Convert a UTF-8 text string to an ASCII string using Punycode
         *
         * @param string $text ASCII or UTF-8 string (max length 64 characters)
         * @return string ASCII string
         *
         * @throws \WpOrg\Requests\Exception Provided string longer than 64 ASCII characters (`idna.provided_too_long`)
         * @throws \WpOrg\Requests\Exception Prepared string longer than 64 ASCII characters (`idna.prepared_too_long`)
         * @throws \WpOrg\Requests\Exception Provided string already begins with xn-- (`idna.provided_is_prefixed`)
         * @throws \WpOrg\Requests\Exception Encoded string longer than 64 ASCII characters (`idna.encoded_too_long`)
         */
        public static function to_ascii($text)
        {
        }
        /**
         * Check whether a given text string contains only ASCII characters
         *
         * @internal (Testing found regex was the fastest implementation)
         *
         * @param string $text Text to examine.
         * @return bool Is the text string ASCII-only?
         */
        protected static function is_ascii($text)
        {
        }
        /**
         * Prepare a text string for use as an IDNA name
         *
         * @todo Implement this based on RFC 3491 and the newer 5891
         * @param string $text Text to prepare.
         * @return string Prepared string
         */
        protected static function nameprep($text)
        {
        }
        /**
         * Convert a UTF-8 string to a UCS-4 codepoint array
         *
         * Based on \WpOrg\Requests\Iri::replace_invalid_with_pct_encoding()
         *
         * @param string $input Text to convert.
         * @return array Unicode code points
         *
         * @throws \WpOrg\Requests\Exception Invalid UTF-8 codepoint (`idna.invalidcodepoint`)
         */
        protected static function utf8_to_codepoints($input)
        {
        }
        /**
         * RFC3492-compliant encoder
         *
         * @internal Pseudo-code from Section 6.3 is commented with "#" next to relevant code
         *
         * @param string $input UTF-8 encoded string to encode
         * @return string Punycode-encoded string
         *
         * @throws \WpOrg\Requests\Exception On character outside of the domain (never happens with Punycode) (`idna.character_outside_domain`)
         */
        public static function punycode_encode($input)
        {
        }
        /**
         * Convert a digit to its respective character
         *
         * @link https://tools.ietf.org/html/rfc3492#section-5
         *
         * @param int $digit Digit in the range 0-35
         * @return string Single character corresponding to digit
         *
         * @throws \WpOrg\Requests\Exception On invalid digit (`idna.invalid_digit`)
         */
        protected static function digit_to_char($digit)
        {
        }
        /**
         * Adapt the bias
         *
         * @link https://tools.ietf.org/html/rfc3492#section-6.1
         * @param int $delta
         * @param int $numpoints
         * @param bool $firsttime
         * @return int|float New bias
         *
         * function adapt(delta,numpoints,firsttime):
         */
        protected static function adapt($delta, $numpoints, $firsttime)
        {
        }
    }
    /**
     * Class to validate and to work with IPv6 addresses
     *
     * This was originally based on the PEAR class of the same name, but has been
     * entirely rewritten.
     *
     * @package Requests\Utilities
     */
    final class Ipv6
    {
        /**
         * Uncompresses an IPv6 address
         *
         * RFC 4291 allows you to compress consecutive zero pieces in an address to
         * '::'. This method expects a valid IPv6 address and expands the '::' to
         * the required number of zero pieces.
         *
         * Example:  FF01::101   ->  FF01:0:0:0:0:0:0:101
         *           ::1         ->  0:0:0:0:0:0:0:1
         *
         * @author Alexander Merz <alexander.merz@web.de>
         * @author elfrink at introweb dot nl
         * @author Josh Peck <jmp at joshpeck dot org>
         * @copyright 2003-2005 The PHP Group
         * @license https://opensource.org/licenses/bsd-license.php
         *
         * @param string|Stringable $ip An IPv6 address
         * @return string The uncompressed IPv6 address
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed argument is not a string or a stringable object.
         */
        public static function uncompress($ip)
        {
        }
        /**
         * Compresses an IPv6 address
         *
         * RFC 4291 allows you to compress consecutive zero pieces in an address to
         * '::'. This method expects a valid IPv6 address and compresses consecutive
         * zero pieces to '::'.
         *
         * Example:  FF01:0:0:0:0:0:0:101   ->  FF01::101
         *           0:0:0:0:0:0:0:1        ->  ::1
         *
         * @see \WpOrg\Requests\Ipv6::uncompress()
         *
         * @param string $ip An IPv6 address
         * @return string The compressed IPv6 address
         */
        public static function compress($ip)
        {
        }
        /**
         * Checks an IPv6 address
         *
         * Checks if the given IP is a valid IPv6 address
         *
         * @param string $ip An IPv6 address
         * @return bool true if $ip is a valid IPv6 address
         */
        public static function check_ipv6($ip)
        {
        }
    }
    /**
     * IRI parser/serialiser/normaliser
     *
     * Copyright (c) 2007-2010, Geoffrey Sneddon and Steve Minutillo.
     * All rights reserved.
     *
     * Redistribution and use in source and binary forms, with or without
     * modification, are permitted provided that the following conditions are met:
     *
     *  * Redistributions of source code must retain the above copyright notice,
     *       this list of conditions and the following disclaimer.
     *
     *  * Redistributions in binary form must reproduce the above copyright notice,
     *       this list of conditions and the following disclaimer in the documentation
     *       and/or other materials provided with the distribution.
     *
     *  * Neither the name of the SimplePie Team nor the names of its contributors
     *       may be used to endorse or promote products derived from this software
     *       without specific prior written permission.
     *
     * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
     * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
     * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
     * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS AND CONTRIBUTORS BE
     * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
     * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
     * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
     * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
     * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
     * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
     * POSSIBILITY OF SUCH DAMAGE.
     *
     * @package Requests\Utilities
     * @author Geoffrey Sneddon
     * @author Steve Minutillo
     * @copyright 2007-2009 Geoffrey Sneddon and Steve Minutillo
     * @license https://opensource.org/licenses/bsd-license.php
     * @link http://hg.gsnedders.com/iri/
     *
     * @property string $iri IRI we're working with
     * @property-read string $uri IRI in URI form, {@see \WpOrg\Requests\Iri::to_uri()}
     * @property string $scheme Scheme part of the IRI
     * @property string $authority Authority part, formatted for a URI (userinfo + host + port)
     * @property string $iauthority Authority part of the IRI (userinfo + host + port)
     * @property string $userinfo Userinfo part, formatted for a URI (after '://' and before '@')
     * @property string $iuserinfo Userinfo part of the IRI (after '://' and before '@')
     * @property string $host Host part, formatted for a URI
     * @property string $ihost Host part of the IRI
     * @property string $port Port part of the IRI (after ':')
     * @property string $path Path part, formatted for a URI (after first '/')
     * @property string $ipath Path part of the IRI (after first '/')
     * @property string $query Query part, formatted for a URI (after '?')
     * @property string $iquery Query part of the IRI (after '?')
     * @property string $fragment Fragment, formatted for a URI (after '#')
     * @property string $ifragment Fragment part of the IRI (after '#')
     */
    class Iri
    {
        /**
         * Scheme
         *
         * @var string|null
         */
        protected $scheme = null;
        /**
         * User Information
         *
         * @var string|null
         */
        protected $iuserinfo = null;
        /**
         * ihost
         *
         * @var string|null
         */
        protected $ihost = null;
        /**
         * Port
         *
         * @var string|null
         */
        protected $port = null;
        /**
         * ipath
         *
         * @var string
         */
        protected $ipath = '';
        /**
         * iquery
         *
         * @var string|null
         */
        protected $iquery = null;
        /**
         * ifragment|null
         *
         * @var string
         */
        protected $ifragment = null;
        /**
         * Normalization database
         *
         * Each key is the scheme, each value is an array with each key as the IRI
         * part and value as the default value for that part.
         *
         * @var array
         */
        protected $normalization = array('acap' => array('port' => \WpOrg\Requests\Port::ACAP), 'dict' => array('port' => \WpOrg\Requests\Port::DICT), 'file' => array('ihost' => 'localhost'), 'http' => array('port' => \WpOrg\Requests\Port::HTTP), 'https' => array('port' => \WpOrg\Requests\Port::HTTPS));
        /**
         * Return the entire IRI when you try and read the object as a string
         *
         * @return string
         */
        public function __toString()
        {
        }
        /**
         * Overload __set() to provide access via properties
         *
         * @param string $name Property name
         * @param mixed $value Property value
         */
        public function __set($name, $value)
        {
        }
        /**
         * Overload __get() to provide access via properties
         *
         * @param string $name Property name
         * @return mixed
         */
        public function __get($name)
        {
        }
        /**
         * Overload __isset() to provide access via properties
         *
         * @param string $name Property name
         * @return bool
         */
        public function __isset($name)
        {
        }
        /**
         * Overload __unset() to provide access via properties
         *
         * @param string $name Property name
         */
        public function __unset($name)
        {
        }
        /**
         * Create a new IRI object, from a specified string
         *
         * @param string|Stringable|null $iri
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $iri argument is not a string, Stringable or null.
         */
        public function __construct($iri = null)
        {
        }
        /**
         * Create a new IRI object by resolving a relative IRI
         *
         * Returns false if $base is not absolute, otherwise an IRI.
         *
         * @param \WpOrg\Requests\Iri|string $base (Absolute) Base IRI
         * @param \WpOrg\Requests\Iri|string $relative Relative IRI
         * @return \WpOrg\Requests\Iri|false
         */
        public static function absolutize($base, $relative)
        {
        }
        /**
         * Parse an IRI into scheme/authority/path/query/fragment segments
         *
         * @param string $iri
         * @return array
         */
        protected function parse_iri($iri)
        {
        }
        /**
         * Remove dot segments from a path
         *
         * @param string $input
         * @return string
         */
        protected function remove_dot_segments($input)
        {
        }
        /**
         * Replace invalid character with percent encoding
         *
         * @param string $text Input string
         * @param string $extra_chars Valid characters not in iunreserved or
         *                            iprivate (this is ASCII-only)
         * @param bool $iprivate Allow iprivate
         * @return string
         */
        protected function replace_invalid_with_pct_encoding($text, $extra_chars, $iprivate = false)
        {
        }
        /**
         * Callback function for preg_replace_callback.
         *
         * Removes sequences of percent encoded bytes that represent UTF-8
         * encoded characters in iunreserved
         *
         * @param array $regex_match PCRE match
         * @return string Replacement
         */
        protected function remove_iunreserved_percent_encoded($regex_match)
        {
        }
        protected function scheme_normalization()
        {
        }
        /**
         * Check if the object represents a valid IRI. This needs to be done on each
         * call as some things change depending on another part of the IRI.
         *
         * @return bool
         */
        public function is_valid()
        {
        }
        public function __wakeup()
        {
        }
        /**
         * Set the entire IRI. Returns true on success, false on failure (if there
         * are any invalid characters).
         *
         * @param string $iri
         * @return bool
         */
        protected function set_iri($iri)
        {
        }
        /**
         * Set the scheme. Returns true on success, false on failure (if there are
         * any invalid characters).
         *
         * @param string $scheme
         * @return bool
         */
        protected function set_scheme($scheme)
        {
        }
        /**
         * Set the authority. Returns true on success, false on failure (if there are
         * any invalid characters).
         *
         * @param string $authority
         * @return bool
         */
        protected function set_authority($authority)
        {
        }
        /**
         * Set the iuserinfo.
         *
         * @param string $iuserinfo
         * @return bool
         */
        protected function set_userinfo($iuserinfo)
        {
        }
        /**
         * Set the ihost. Returns true on success, false on failure (if there are
         * any invalid characters).
         *
         * @param string $ihost
         * @return bool
         */
        protected function set_host($ihost)
        {
        }
        /**
         * Set the port. Returns true on success, false on failure (if there are
         * any invalid characters).
         *
         * @param string $port
         * @return bool
         */
        protected function set_port($port)
        {
        }
        /**
         * Set the ipath.
         *
         * @param string $ipath
         * @return bool
         */
        protected function set_path($ipath)
        {
        }
        /**
         * Set the iquery.
         *
         * @param string $iquery
         * @return bool
         */
        protected function set_query($iquery)
        {
        }
        /**
         * Set the ifragment.
         *
         * @param string $ifragment
         * @return bool
         */
        protected function set_fragment($ifragment)
        {
        }
        /**
         * Convert an IRI to a URI (or parts thereof)
         *
         * @param string|bool $iri IRI to convert (or false from {@see \WpOrg\Requests\Iri::get_iri()})
         * @return string|false URI if IRI is valid, false otherwise.
         */
        protected function to_uri($iri)
        {
        }
        /**
         * Get the complete IRI
         *
         * @return string|false
         */
        protected function get_iri()
        {
        }
        /**
         * Get the complete URI
         *
         * @return string
         */
        protected function get_uri()
        {
        }
        /**
         * Get the complete iauthority
         *
         * @return string|null
         */
        protected function get_iauthority()
        {
        }
        /**
         * Get the complete authority
         *
         * @return string
         */
        protected function get_authority()
        {
        }
    }
    /**
     * Find the correct port depending on the Request type.
     *
     * @package Requests\Utilities
     * @since   2.0.0
     */
    final class Port
    {
        /**
         * Port to use with Acap requests.
         *
         * @var int
         */
        const ACAP = 674;
        /**
         * Port to use with Dictionary requests.
         *
         * @var int
         */
        const DICT = 2628;
        /**
         * Port to use with HTTP requests.
         *
         * @var int
         */
        const HTTP = 80;
        /**
         * Port to use with HTTP over SSL requests.
         *
         * @var int
         */
        const HTTPS = 443;
        /**
         * Retrieve the port number to use.
         *
         * @param string $type Request type.
         *                     The following requests types are supported:
         *                     'acap', 'dict', 'http' and 'https'.
         *
         * @return int
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When a non-string input has been passed.
         * @throws \WpOrg\Requests\Exception                 When a non-supported port is requested ('portnotsupported').
         * @phpstan-param 'acap'|'dict'|'http'|'https' $type
         */
        public static function get($type)
        {
        }
    }
    /**
     * Proxy connection interface
     *
     * Implement this interface to handle proxy settings and authentication
     *
     * Parameters should be passed via the constructor where possible, as this
     * makes it much easier for users to use your provider.
     *
     * @see \WpOrg\Requests\Hooks
     *
     * @package Requests\Proxy
     * @since   1.6
     */
    interface Proxy
    {
        /**
         * Register hooks as needed
         *
         * This method is called in {@see \WpOrg\Requests\Requests::request()} when the user
         * has set an instance as the 'auth' option. Use this callback to register all the
         * hooks you'll need.
         *
         * @see \WpOrg\Requests\Hooks::register()
         * @param \WpOrg\Requests\Hooks $hooks Hook system
         */
        public function register(\WpOrg\Requests\Hooks $hooks);
    }
}
namespace WpOrg\Requests\Proxy {
    /**
     * HTTP Proxy connection interface
     *
     * Provides a handler for connection via an HTTP proxy
     *
     * @package Requests\Proxy
     * @since   1.6
     */
    final class Http implements \WpOrg\Requests\Proxy
    {
        /**
         * Proxy host and port
         *
         * Notation: "host:port" (eg 127.0.0.1:8080 or someproxy.com:3128)
         *
         * @var string
         */
        public $proxy;
        /**
         * Username
         *
         * @var string
         */
        public $user;
        /**
         * Password
         *
         * @var string
         */
        public $pass;
        /**
         * Do we need to authenticate? (ie username & password have been provided)
         *
         * @var boolean
         */
        public $use_authentication;
        /**
         * Constructor
         *
         * @since 1.6
         *
         * @param array|string|null $args Proxy as a string or an array of proxy, user and password.
         *                                When passed as an array, must have exactly one (proxy)
         *                                or three elements (proxy, user, password).
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed argument is not an array, a string or null.
         * @throws \WpOrg\Requests\Exception\ArgumentCount On incorrect number of arguments (`proxyhttpbadargs`)
         */
        public function __construct($args = null)
        {
        }
        /**
         * Register the necessary callbacks
         *
         * @since 1.6
         * @see \WpOrg\Requests\Proxy\Http::curl_before_send()
         * @see \WpOrg\Requests\Proxy\Http::fsockopen_remote_socket()
         * @see \WpOrg\Requests\Proxy\Http::fsockopen_remote_host_path()
         * @see \WpOrg\Requests\Proxy\Http::fsockopen_header()
         * @param \WpOrg\Requests\Hooks $hooks Hook system
         */
        public function register(\WpOrg\Requests\Hooks $hooks)
        {
        }
        /**
         * Set cURL parameters before the data is sent
         *
         * @since 1.6
         * @param resource|\CurlHandle $handle cURL handle
         */
        public function curl_before_send(&$handle)
        {
        }
        /**
         * Alter remote socket information before opening socket connection
         *
         * @since 1.6
         * @param string $remote_socket Socket connection string
         */
        public function fsockopen_remote_socket(&$remote_socket)
        {
        }
        /**
         * Alter remote path before getting stream data
         *
         * @since 1.6
         * @param string $path Path to send in HTTP request string ("GET ...")
         * @param string $url Full URL we're requesting
         */
        public function fsockopen_remote_host_path(&$path, $url)
        {
        }
        /**
         * Add extra headers to the request before sending
         *
         * @since 1.6
         * @param string $out HTTP header string
         */
        public function fsockopen_header(&$out)
        {
        }
        /**
         * Get the authentication string (user:pass)
         *
         * @since 1.6
         * @return string
         */
        public function get_auth_string()
        {
        }
    }
}
namespace WpOrg\Requests {
    /**
     * Requests for PHP
     *
     * Inspired by Requests for Python.
     *
     * Based on concepts from SimplePie_File, RequestCore and WP_Http.
     *
     * @package Requests
     */
    class Requests
    {
        /**
         * POST method
         *
         * @var string
         */
        const POST = 'POST';
        /**
         * PUT method
         *
         * @var string
         */
        const PUT = 'PUT';
        /**
         * GET method
         *
         * @var string
         */
        const GET = 'GET';
        /**
         * HEAD method
         *
         * @var string
         */
        const HEAD = 'HEAD';
        /**
         * DELETE method
         *
         * @var string
         */
        const DELETE = 'DELETE';
        /**
         * OPTIONS method
         *
         * @var string
         */
        const OPTIONS = 'OPTIONS';
        /**
         * TRACE method
         *
         * @var string
         */
        const TRACE = 'TRACE';
        /**
         * PATCH method
         *
         * @link https://tools.ietf.org/html/rfc5789
         * @var string
         */
        const PATCH = 'PATCH';
        /**
         * Default size of buffer size to read streams
         *
         * @var integer
         */
        const BUFFER_SIZE = 1160;
        /**
         * Option defaults.
         *
         * @see \WpOrg\Requests\Requests::get_default_options()
         * @see \WpOrg\Requests\Requests::request() for values returned by this method
         *
         * @since 2.0.0
         *
         * @var array
         */
        const OPTION_DEFAULTS = ['timeout' => 10, 'connect_timeout' => 10, 'useragent' => 'php-requests/' . self::VERSION, 'protocol_version' => 1.1, 'redirected' => 0, 'redirects' => 10, 'follow_redirects' => true, 'blocking' => true, 'type' => self::GET, 'filename' => false, 'auth' => false, 'proxy' => false, 'cookies' => false, 'max_bytes' => false, 'idn' => true, 'hooks' => null, 'transport' => null, 'verify' => null, 'verifyname' => true];
        /**
         * Default supported Transport classes.
         *
         * @since 2.0.0
         *
         * @var array
         */
        const DEFAULT_TRANSPORTS = [\WpOrg\Requests\Transport\Curl::class => \WpOrg\Requests\Transport\Curl::class, \WpOrg\Requests\Transport\Fsockopen::class => \WpOrg\Requests\Transport\Fsockopen::class];
        /**
         * Current version of Requests
         *
         * @var string
         */
        const VERSION = '2.0.11';
        /**
         * Selected transport name
         *
         * Use {@see \WpOrg\Requests\Requests::get_transport()} instead
         *
         * @var array
         */
        public static $transport = [];
        /**
         * Registered transport classes
         *
         * @var array
         */
        protected static $transports = [];
        /**
         * Default certificate path.
         *
         * @see \WpOrg\Requests\Requests::get_certificate_path()
         * @see \WpOrg\Requests\Requests::set_certificate_path()
         *
         * @var string
         */
        protected static $certificate_path = __DIR__ . '/../certificates/cacert.pem';
        /**
         * Register a transport
         *
         * @param string $transport Transport class to add, must support the \WpOrg\Requests\Transport interface
         */
        public static function add_transport($transport)
        {
        }
        /**
         * Get the fully qualified class name (FQCN) for a working transport.
         *
         * @param array<string, bool> $capabilities Optional. Associative array of capabilities to test against, i.e. `['<capability>' => true]`.
         * @return string FQCN of the transport to use, or an empty string if no transport was
         *                found which provided the requested capabilities.
         */
        protected static function get_transport_class(array $capabilities = [])
        {
        }
        /**
         * Get a working transport.
         *
         * @param array<string, bool> $capabilities Optional. Associative array of capabilities to test against, i.e. `['<capability>' => true]`.
         * @return \WpOrg\Requests\Transport
         * @throws \WpOrg\Requests\Exception If no valid transport is found (`notransport`).
         */
        protected static function get_transport(array $capabilities = [])
        {
        }
        /**
         * Checks to see if we have a transport for the capabilities requested.
         *
         * Supported capabilities can be found in the {@see \WpOrg\Requests\Capability}
         * interface as constants.
         *
         * Example usage:
         * `Requests::has_capabilities([Capability::SSL => true])`.
         *
         * @param array<string, bool> $capabilities Optional. Associative array of capabilities to test against, i.e. `['<capability>' => true]`.
         * @return bool Whether the transport has the requested capabilities.
         */
        public static function has_capabilities(array $capabilities = [])
        {
        }
        /**#@+
         * @see \WpOrg\Requests\Requests::request()
         * @param string $url
         * @param array $headers
         * @param array $options
         * @return \WpOrg\Requests\Response
         */
        /**
         * Send a GET request
         */
        public static function get($url, $headers = [], $options = [])
        {
        }
        /**
         * Send a HEAD request
         */
        public static function head($url, $headers = [], $options = [])
        {
        }
        /**
         * Send a DELETE request
         */
        public static function delete($url, $headers = [], $options = [])
        {
        }
        /**
         * Send a TRACE request
         */
        public static function trace($url, $headers = [], $options = [])
        {
        }
        /**#@-*/
        /**#@+
         * @see \WpOrg\Requests\Requests::request()
         * @param string $url
         * @param array $headers
         * @param array $data
         * @param array $options
         * @return \WpOrg\Requests\Response
         */
        /**
         * Send a POST request
         */
        public static function post($url, $headers = [], $data = [], $options = [])
        {
        }
        /**
         * Send a PUT request
         */
        public static function put($url, $headers = [], $data = [], $options = [])
        {
        }
        /**
         * Send an OPTIONS request
         */
        public static function options($url, $headers = [], $data = [], $options = [])
        {
        }
        /**
         * Send a PATCH request
         *
         * Note: Unlike {@see \WpOrg\Requests\Requests::post()} and {@see \WpOrg\Requests\Requests::put()},
         * `$headers` is required, as the specification recommends that should send an ETag
         *
         * @link https://tools.ietf.org/html/rfc5789
         */
        public static function patch($url, $headers, $data = [], $options = [])
        {
        }
        /**#@-*/
        /**
         * Main interface for HTTP requests
         *
         * This method initiates a request and sends it via a transport before
         * parsing.
         *
         * The `$options` parameter takes an associative array with the following
         * options:
         *
         * - `timeout`: How long should we wait for a response?
         *    Note: for cURL, a minimum of 1 second applies, as DNS resolution
         *    operates at second-resolution only.
         *    (float, seconds with a millisecond precision, default: 10, example: 0.01)
         * - `connect_timeout`: How long should we wait while trying to connect?
         *    (float, seconds with a millisecond precision, default: 10, example: 0.01)
         * - `useragent`: Useragent to send to the server
         *    (string, default: php-requests/$version)
         * - `follow_redirects`: Should we follow 3xx redirects?
         *    (boolean, default: true)
         * - `redirects`: How many times should we redirect before erroring?
         *    (integer, default: 10)
         * - `blocking`: Should we block processing on this request?
         *    (boolean, default: true)
         * - `filename`: File to stream the body to instead.
         *    (string|boolean, default: false)
         * - `auth`: Authentication handler or array of user/password details to use
         *    for Basic authentication
         *    (\WpOrg\Requests\Auth|array|boolean, default: false)
         * - `proxy`: Proxy details to use for proxy by-passing and authentication
         *    (\WpOrg\Requests\Proxy|array|string|boolean, default: false)
         * - `max_bytes`: Limit for the response body size.
         *    (integer|boolean, default: false)
         * - `idn`: Enable IDN parsing
         *    (boolean, default: true)
         * - `transport`: Custom transport. Either a class name, or a
         *    transport object. Defaults to the first working transport from
         *    {@see \WpOrg\Requests\Requests::getTransport()}
         *    (string|\WpOrg\Requests\Transport, default: {@see \WpOrg\Requests\Requests::getTransport()})
         * - `hooks`: Hooks handler.
         *    (\WpOrg\Requests\HookManager, default: new WpOrg\Requests\Hooks())
         * - `verify`: Should we verify SSL certificates? Allows passing in a custom
         *    certificate file as a string. (Using true uses the system-wide root
         *    certificate store instead, but this may have different behaviour
         *    across transports.)
         *    (string|boolean, default: certificates/cacert.pem)
         * - `verifyname`: Should we verify the common name in the SSL certificate?
         *    (boolean, default: true)
         * - `data_format`: How should we send the `$data` parameter?
         *    (string, one of 'query' or 'body', default: 'query' for
         *    HEAD/GET/DELETE, 'body' for POST/PUT/OPTIONS/PATCH)
         *
         * @param string|Stringable $url URL to request
         * @param array $headers Extra headers to send with the request
         * @param array|null $data Data to send either as a query string for GET/HEAD requests, or in the body for POST requests
         * @param string $type HTTP request type (use Requests constants)
         * @param array $options Options for the request (see description for more information)
         * @return \WpOrg\Requests\Response
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $url argument is not a string or Stringable.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $type argument is not a string.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $options argument is not an array.
         * @throws \WpOrg\Requests\Exception On invalid URLs (`nonhttp`)
         */
        public static function request($url, $headers = [], $data = [], $type = self::GET, $options = [])
        {
        }
        /**
         * Send multiple HTTP requests simultaneously
         *
         * The `$requests` parameter takes an associative or indexed array of
         * request fields. The key of each request can be used to match up the
         * request with the returned data, or with the request passed into your
         * `multiple.request.complete` callback.
         *
         * The request fields value is an associative array with the following keys:
         *
         * - `url`: Request URL Same as the `$url` parameter to
         *    {@see \WpOrg\Requests\Requests::request()}
         *    (string, required)
         * - `headers`: Associative array of header fields. Same as the `$headers`
         *    parameter to {@see \WpOrg\Requests\Requests::request()}
         *    (array, default: `array()`)
         * - `data`: Associative array of data fields or a string. Same as the
         *    `$data` parameter to {@see \WpOrg\Requests\Requests::request()}
         *    (array|string, default: `array()`)
         * - `type`: HTTP request type (use \WpOrg\Requests\Requests constants). Same as the `$type`
         *    parameter to {@see \WpOrg\Requests\Requests::request()}
         *    (string, default: `\WpOrg\Requests\Requests::GET`)
         * - `cookies`: Associative array of cookie name to value, or cookie jar.
         *    (array|\WpOrg\Requests\Cookie\Jar)
         *
         * If the `$options` parameter is specified, individual requests will
         * inherit options from it. This can be used to use a single hooking system,
         * or set all the types to `\WpOrg\Requests\Requests::POST`, for example.
         *
         * In addition, the `$options` parameter takes the following global options:
         *
         * - `complete`: A callback for when a request is complete. Takes two
         *    parameters, a \WpOrg\Requests\Response/\WpOrg\Requests\Exception reference, and the
         *    ID from the request array (Note: this can also be overridden on a
         *    per-request basis, although that's a little silly)
         *    (callback)
         *
         * @param array $requests Requests data (see description for more information)
         * @param array $options Global and default options (see {@see \WpOrg\Requests\Requests::request()})
         * @return array Responses (either \WpOrg\Requests\Response or a \WpOrg\Requests\Exception object)
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $requests argument is not an array or iterable object with array access.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $options argument is not an array.
         */
        public static function request_multiple($requests, $options = [])
        {
        }
        /**
         * Get the default options
         *
         * @see \WpOrg\Requests\Requests::request() for values returned by this method
         * @param boolean $multirequest Is this a multirequest?
         * @return array Default option values
         */
        protected static function get_default_options($multirequest = false)
        {
        }
        /**
         * Get default certificate path.
         *
         * @return string Default certificate path.
         */
        public static function get_certificate_path()
        {
        }
        /**
         * Set default certificate path.
         *
         * @param string|Stringable|bool $path Certificate path, pointing to a PEM file.
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $url argument is not a string, Stringable or boolean.
         */
        public static function set_certificate_path($path)
        {
        }
        /**
         * Set the default values
         *
         * The $options parameter is updated with the results.
         *
         * @param string $url URL to request
         * @param array $headers Extra headers to send with the request
         * @param array|null $data Data to send either as a query string for GET/HEAD requests, or in the body for POST requests
         * @param string $type HTTP request type
         * @param array $options Options for the request
         * @return void
         *
         * @throws \WpOrg\Requests\Exception When the $url is not an http(s) URL.
         */
        protected static function set_defaults(&$url, &$headers, &$data, &$type, &$options)
        {
        }
        /**
         * HTTP response parser
         *
         * @param string $headers Full response text including headers and body
         * @param string $url Original request URL
         * @param array $req_headers Original $headers array passed to {@link request()}, in case we need to follow redirects
         * @param array $req_data Original $data array passed to {@link request()}, in case we need to follow redirects
         * @param array $options Original $options array passed to {@link request()}, in case we need to follow redirects
         * @return \WpOrg\Requests\Response
         *
         * @throws \WpOrg\Requests\Exception On missing head/body separator (`requests.no_crlf_separator`)
         * @throws \WpOrg\Requests\Exception On missing head/body separator (`noversion`)
         * @throws \WpOrg\Requests\Exception On missing head/body separator (`toomanyredirects`)
         */
        protected static function parse_response($headers, $url, $req_headers, $req_data, $options)
        {
        }
        /**
         * Callback for `transport.internal.parse_response`
         *
         * Internal use only. Converts a raw HTTP response to a \WpOrg\Requests\Response
         * while still executing a multiple request.
         *
         * `$response` is either set to a \WpOrg\Requests\Response instance, or a \WpOrg\Requests\Exception object
         *
         * @param string $response Full response text including headers and body (will be overwritten with Response instance)
         * @param array $request Request data as passed into {@see \WpOrg\Requests\Requests::request_multiple()}
         * @return void
         */
        public static function parse_multiple(&$response, $request)
        {
        }
        /**
         * Decoded a chunked body as per RFC 2616
         *
         * @link https://tools.ietf.org/html/rfc2616#section-3.6.1
         * @param string $data Chunked body
         * @return string Decoded body
         */
        protected static function decode_chunked($data)
        {
        }
        /**
         * Convert a key => value array to a 'key: value' array for headers
         *
         * @param iterable $dictionary Dictionary of header values
         * @return array List of headers
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed argument is not iterable.
         */
        public static function flatten($dictionary)
        {
        }
        /**
         * Decompress an encoded body
         *
         * Implements gzip, compress and deflate. Guesses which it is by attempting
         * to decode.
         *
         * @param string $data Compressed data in one of the above formats
         * @return string Decompressed string
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed argument is not a string.
         */
        public static function decompress($data)
        {
        }
        /**
         * Decompression of deflated string while staying compatible with the majority of servers.
         *
         * Certain Servers will return deflated data with headers which PHP's gzinflate()
         * function cannot handle out of the box. The following function has been created from
         * various snippets on the gzinflate() PHP documentation.
         *
         * Warning: Magic numbers within. Due to the potential different formats that the compressed
         * data may be returned in, some "magic offsets" are needed to ensure proper decompression
         * takes place. For a simple progmatic way to determine the magic offset in use, see:
         * https://core.trac.wordpress.org/ticket/18273
         *
         * @since 1.6.0
         * @link https://core.trac.wordpress.org/ticket/18273
         * @link https://www.php.net/gzinflate#70875
         * @link https://www.php.net/gzinflate#77336
         *
         * @param string $gz_data String to decompress.
         * @return string|bool False on failure.
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed argument is not a string.
         */
        public static function compatible_gzinflate($gz_data)
        {
        }
    }
    /**
     * HTTP response class
     *
     * Contains a response from \WpOrg\Requests\Requests::request()
     *
     * @package Requests
     */
    class Response
    {
        /**
         * Response body
         *
         * @var string
         */
        public $body = '';
        /**
         * Raw HTTP data from the transport
         *
         * @var string
         */
        public $raw = '';
        /**
         * Headers, as an associative array
         *
         * @var \WpOrg\Requests\Response\Headers Array-like object representing headers
         */
        public $headers = [];
        /**
         * Status code, false if non-blocking
         *
         * @var integer|boolean
         */
        public $status_code = false;
        /**
         * Protocol version, false if non-blocking
         *
         * @var float|boolean
         */
        public $protocol_version = false;
        /**
         * Whether the request succeeded or not
         *
         * @var boolean
         */
        public $success = false;
        /**
         * Number of redirects the request used
         *
         * @var integer
         */
        public $redirects = 0;
        /**
         * URL requested
         *
         * @var string
         */
        public $url = '';
        /**
         * Previous requests (from redirects)
         *
         * @var array Array of \WpOrg\Requests\Response objects
         */
        public $history = [];
        /**
         * Cookies from the request
         *
         * @var \WpOrg\Requests\Cookie\Jar Array-like object representing a cookie jar
         */
        public $cookies = [];
        /**
         * Constructor
         */
        public function __construct()
        {
        }
        /**
         * Is the response a redirect?
         *
         * @return boolean True if redirect (3xx status), false if not.
         */
        public function is_redirect()
        {
        }
        /**
         * Throws an exception if the request was not successful
         *
         * @param boolean $allow_redirects Set to false to throw on a 3xx as well
         *
         * @throws \WpOrg\Requests\Exception If `$allow_redirects` is false, and code is 3xx (`response.no_redirects`)
         * @throws \WpOrg\Requests\Exception\Http On non-successful status code. Exception class corresponds to "Status" + code (e.g. {@see \WpOrg\Requests\Exception\Http\Status404})
         */
        public function throw_for_status($allow_redirects = true)
        {
        }
        /**
         * JSON decode the response body.
         *
         * The method parameters are the same as those for the PHP native `json_decode()` function.
         *
         * @link https://php.net/json-decode
         *
         * @param bool|null $associative Optional. When `true`, JSON objects will be returned as associative arrays;
         *                               When `false`, JSON objects will be returned as objects.
         *                               When `null`, JSON objects will be returned as associative arrays
         *                               or objects depending on whether `JSON_OBJECT_AS_ARRAY` is set in the flags.
         *                               Defaults to `true` (in contrast to the PHP native default of `null`).
         * @param int       $depth       Optional. Maximum nesting depth of the structure being decoded.
         *                               Defaults to `512`.
         * @param int       $options     Optional. Bitmask of JSON_BIGINT_AS_STRING, JSON_INVALID_UTF8_IGNORE,
         *                               JSON_INVALID_UTF8_SUBSTITUTE, JSON_OBJECT_AS_ARRAY, JSON_THROW_ON_ERROR.
         *                               Defaults to `0` (no options set).
         *
         * @return array
         *
         * @throws \WpOrg\Requests\Exception If `$this->body` is not valid json.
         */
        public function decode_body($associative = true, $depth = 512, $options = 0)
        {
        }
    }
}
namespace WpOrg\Requests\Utility {
    /**
     * Case-insensitive dictionary, suitable for HTTP headers
     *
     * @package Requests\Utilities
     */
    class CaseInsensitiveDictionary implements \ArrayAccess, \IteratorAggregate
    {
        /**
         * Actual item data
         *
         * @var array
         */
        protected $data = [];
        /**
         * Creates a case insensitive dictionary.
         *
         * @param array $data Dictionary/map to convert to case-insensitive
         */
        public function __construct(array $data = [])
        {
        }
        /**
         * Check if the given item exists
         *
         * @param string $offset Item key
         * @return boolean Does the item exist?
         */
        #[\ReturnTypeWillChange]
        public function offsetExists($offset)
        {
        }
        /**
         * Get the value for the item
         *
         * @param string $offset Item key
         * @return string|null Item value (null if the item key doesn't exist)
         */
        #[\ReturnTypeWillChange]
        public function offsetGet($offset)
        {
        }
        /**
         * Set the given item
         *
         * @param string $offset Item name
         * @param string $value Item value
         *
         * @throws \WpOrg\Requests\Exception On attempting to use dictionary as list (`invalidset`)
         */
        #[\ReturnTypeWillChange]
        public function offsetSet($offset, $value)
        {
        }
        /**
         * Unset the given header
         *
         * @param string $offset The key for the item to unset.
         */
        #[\ReturnTypeWillChange]
        public function offsetUnset($offset)
        {
        }
        /**
         * Get an iterator for the data
         *
         * @return \ArrayIterator
         */
        #[\ReturnTypeWillChange]
        public function getIterator()
        {
        }
        /**
         * Get the headers as an array
         *
         * @return array Header data
         */
        public function getAll()
        {
        }
    }
}
namespace WpOrg\Requests\Response {
    /**
     * Case-insensitive dictionary, suitable for HTTP headers
     *
     * @package Requests
     */
    class Headers extends \WpOrg\Requests\Utility\CaseInsensitiveDictionary
    {
        /**
         * Get the given header
         *
         * Unlike {@see \WpOrg\Requests\Response\Headers::getValues()}, this returns a string. If there are
         * multiple values, it concatenates them with a comma as per RFC2616.
         *
         * Avoid using this where commas may be used unquoted in values, such as
         * Set-Cookie headers.
         *
         * @param string $offset Name of the header to retrieve.
         * @return string|null Header value
         */
        public function offsetGet($offset)
        {
        }
        /**
         * Set the given item
         *
         * @param string $offset Item name
         * @param string $value Item value
         *
         * @throws \WpOrg\Requests\Exception On attempting to use dictionary as list (`invalidset`)
         */
        public function offsetSet($offset, $value)
        {
        }
        /**
         * Get all values for a given header
         *
         * @param string $offset Name of the header to retrieve.
         * @return array|null Header values
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed argument is not valid as an array key.
         */
        public function getValues($offset)
        {
        }
        /**
         * Flattens a value into a string
         *
         * Converts an array into a string by imploding values with a comma, as per
         * RFC2616's rules for folding headers.
         *
         * @param string|array $value Value to flatten
         * @return string Flattened value
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed argument is not a string or an array.
         */
        public function flatten($value)
        {
        }
        /**
         * Get an iterator for the data
         *
         * Converts the internally stored values to a comma-separated string if there is more
         * than one value for a key.
         *
         * @return \ArrayIterator
         */
        public function getIterator()
        {
        }
    }
}
namespace WpOrg\Requests {
    /**
     * Session handler for persistent requests and default parameters
     *
     * Allows various options to be set as default values, and merges both the
     * options and URL properties together. A base URL can be set for all requests,
     * with all subrequests resolved from this. Base options can be set (including
     * a shared cookie jar), then overridden for individual requests.
     *
     * @package Requests\SessionHandler
     */
    class Session
    {
        /**
         * Base URL for requests
         *
         * URLs will be made absolute using this as the base
         *
         * @var string|null
         */
        public $url = null;
        /**
         * Base headers for requests
         *
         * @var array
         */
        public $headers = [];
        /**
         * Base data for requests
         *
         * If both the base data and the per-request data are arrays, the data will
         * be merged before sending the request.
         *
         * @var array
         */
        public $data = [];
        /**
         * Base options for requests
         *
         * The base options are merged with the per-request data for each request.
         * The only default option is a shared cookie jar between requests.
         *
         * Values here can also be set directly via properties on the Session
         * object, e.g. `$session->useragent = 'X';`
         *
         * @var array
         */
        public $options = [];
        /**
         * Create a new session
         *
         * @param string|Stringable|null $url Base URL for requests
         * @param array $headers Default headers for requests
         * @param array $data Default data for requests
         * @param array $options Default options for requests
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $url argument is not a string, Stringable or null.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $headers argument is not an array.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $data argument is not an array.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $options argument is not an array.
         */
        public function __construct($url = null, $headers = [], $data = [], $options = [])
        {
        }
        /**
         * Get a property's value
         *
         * @param string $name Property name.
         * @return mixed|null Property value, null if none found
         */
        public function __get($name)
        {
        }
        /**
         * Set a property's value
         *
         * @param string $name Property name.
         * @param mixed $value Property value
         */
        public function __set($name, $value)
        {
        }
        /**
         * Remove a property's value
         *
         * @param string $name Property name.
         */
        public function __isset($name)
        {
        }
        /**
         * Remove a property's value
         *
         * @param string $name Property name.
         */
        public function __unset($name)
        {
        }
        /**#@+
         * @see \WpOrg\Requests\Session::request()
         * @param string $url
         * @param array $headers
         * @param array $options
         * @return \WpOrg\Requests\Response
         */
        /**
         * Send a GET request
         */
        public function get($url, $headers = [], $options = [])
        {
        }
        /**
         * Send a HEAD request
         */
        public function head($url, $headers = [], $options = [])
        {
        }
        /**
         * Send a DELETE request
         */
        public function delete($url, $headers = [], $options = [])
        {
        }
        /**#@-*/
        /**#@+
         * @see \WpOrg\Requests\Session::request()
         * @param string $url
         * @param array $headers
         * @param array $data
         * @param array $options
         * @return \WpOrg\Requests\Response
         */
        /**
         * Send a POST request
         */
        public function post($url, $headers = [], $data = [], $options = [])
        {
        }
        /**
         * Send a PUT request
         */
        public function put($url, $headers = [], $data = [], $options = [])
        {
        }
        /**
         * Send a PATCH request
         *
         * Note: Unlike {@see \WpOrg\Requests\Session::post()} and {@see \WpOrg\Requests\Session::put()},
         * `$headers` is required, as the specification recommends that should send an ETag
         *
         * @link https://tools.ietf.org/html/rfc5789
         */
        public function patch($url, $headers, $data = [], $options = [])
        {
        }
        /**#@-*/
        /**
         * Main interface for HTTP requests
         *
         * This method initiates a request and sends it via a transport before
         * parsing.
         *
         * @see \WpOrg\Requests\Requests::request()
         *
         * @param string $url URL to request
         * @param array $headers Extra headers to send with the request
         * @param array|null $data Data to send either as a query string for GET/HEAD requests, or in the body for POST requests
         * @param string $type HTTP request type (use \WpOrg\Requests\Requests constants)
         * @param array $options Options for the request (see {@see \WpOrg\Requests\Requests::request()})
         * @return \WpOrg\Requests\Response
         *
         * @throws \WpOrg\Requests\Exception On invalid URLs (`nonhttp`)
         */
        public function request($url, $headers = [], $data = [], $type = \WpOrg\Requests\Requests::GET, $options = [])
        {
        }
        /**
         * Send multiple HTTP requests simultaneously
         *
         * @see \WpOrg\Requests\Requests::request_multiple()
         *
         * @param array $requests Requests data (see {@see \WpOrg\Requests\Requests::request_multiple()})
         * @param array $options Global and default options (see {@see \WpOrg\Requests\Requests::request()})
         * @return array Responses (either \WpOrg\Requests\Response or a \WpOrg\Requests\Exception object)
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $requests argument is not an array or iterable object with array access.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $options argument is not an array.
         */
        public function request_multiple($requests, $options = [])
        {
        }
        public function __wakeup()
        {
        }
        /**
         * Merge a request's data with the default data
         *
         * @param array $request Request data (same form as {@see \WpOrg\Requests\Session::request_multiple()})
         * @param boolean $merge_options Should we merge options as well?
         * @return array Request data
         */
        protected function merge_request($request, $merge_options = true)
        {
        }
    }
    /**
     * SSL utilities for Requests
     *
     * Collection of utilities for working with and verifying SSL certificates.
     *
     * @package Requests\Utilities
     */
    final class Ssl
    {
        /**
         * Verify the certificate against common name and subject alternative names
         *
         * Unfortunately, PHP doesn't check the certificate against the alternative
         * names, leading things like 'https://www.github.com/' to be invalid.
         *
         * @link https://tools.ietf.org/html/rfc2818#section-3.1 RFC2818, Section 3.1
         *
         * @param string|Stringable $host Host name to verify against
         * @param array $cert Certificate data from openssl_x509_parse()
         * @return bool
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $host argument is not a string or a stringable object.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $cert argument is not an array or array accessible.
         */
        public static function verify_certificate($host, $cert)
        {
        }
        /**
         * Verify that a reference name is valid
         *
         * Verifies a dNSName for HTTPS usage, (almost) as per Firefox's rules:
         * - Wildcards can only occur in a name with more than 3 components
         * - Wildcards can only occur as the last character in the first
         *   component
         * - Wildcards may be preceded by additional characters
         *
         * We modify these rules to be a bit stricter and only allow the wildcard
         * character to be the full first component; that is, with the exclusion of
         * the third rule.
         *
         * @param string|Stringable $reference Reference dNSName
         * @return boolean Is the name valid?
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed argument is not a string or a stringable object.
         */
        public static function verify_reference_name($reference)
        {
        }
        /**
         * Match a hostname against a dNSName reference
         *
         * @param string|Stringable $host Requested host
         * @param string|Stringable $reference dNSName to match against
         * @return boolean Does the domain match?
         * @throws \WpOrg\Requests\Exception\InvalidArgument When either of the passed arguments is not a string or a stringable object.
         */
        public static function match_domain($host, $reference)
        {
        }
    }
    /**
     * Base HTTP transport
     *
     * @package Requests\Transport
     */
    interface Transport
    {
        /**
         * Perform a request
         *
         * @param string $url URL to request
         * @param array $headers Associative array of request headers
         * @param string|array $data Data to send either as the POST body, or as parameters in the URL for a GET/HEAD
         * @param array $options Request options, see {@see \WpOrg\Requests\Requests::response()} for documentation
         * @return string Raw HTTP result
         */
        public function request($url, $headers = [], $data = [], $options = []);
        /**
         * Send multiple requests simultaneously
         *
         * @param array $requests Request data (array of 'url', 'headers', 'data', 'options') as per {@see \WpOrg\Requests\Transport::request()}
         * @param array $options Global options, see {@see \WpOrg\Requests\Requests::response()} for documentation
         * @return array Array of \WpOrg\Requests\Response objects (may contain \WpOrg\Requests\Exception or string responses as well)
         */
        public function request_multiple($requests, $options);
        /**
         * Self-test whether the transport can be used.
         *
         * The available capabilities to test for can be found in {@see \WpOrg\Requests\Capability}.
         *
         * @param array<string, bool> $capabilities Optional. Associative array of capabilities to test against, i.e. `['<capability>' => true]`.
         * @return bool Whether the transport can be used.
         */
        public static function test($capabilities = []);
    }
}
namespace WpOrg\Requests\Transport {
    /**
     * cURL HTTP transport
     *
     * @package Requests\Transport
     */
    final class Curl implements \WpOrg\Requests\Transport
    {
        const CURL_7_10_5 = 0x70a05;
        const CURL_7_16_2 = 0x71002;
        /**
         * Raw HTTP data
         *
         * @var string
         */
        public $headers = '';
        /**
         * Raw body data
         *
         * @var string
         */
        public $response_data = '';
        /**
         * Information on the current request
         *
         * @var array cURL information array, see {@link https://www.php.net/curl_getinfo}
         */
        public $info;
        /**
         * cURL version number
         *
         * @var int
         */
        public $version;
        /**
         * Constructor
         */
        public function __construct()
        {
        }
        /**
         * Destructor
         */
        public function __destruct()
        {
        }
        /**
         * Perform a request
         *
         * @param string|Stringable $url URL to request
         * @param array $headers Associative array of request headers
         * @param string|array $data Data to send either as the POST body, or as parameters in the URL for a GET/HEAD
         * @param array $options Request options, see {@see \WpOrg\Requests\Requests::response()} for documentation
         * @return string Raw HTTP result
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $url argument is not a string or Stringable.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $headers argument is not an array.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $data parameter is not an array or string.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $options argument is not an array.
         * @throws \WpOrg\Requests\Exception       On a cURL error (`curlerror`)
         */
        public function request($url, $headers = [], $data = [], $options = [])
        {
        }
        /**
         * Send multiple requests simultaneously
         *
         * @param array $requests Request data
         * @param array $options Global options
         * @return array Array of \WpOrg\Requests\Response objects (may contain \WpOrg\Requests\Exception or string responses as well)
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $requests argument is not an array or iterable object with array access.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $options argument is not an array.
         */
        public function request_multiple($requests, $options)
        {
        }
        /**
         * Get the cURL handle for use in a multi-request
         *
         * @param string $url URL to request
         * @param array $headers Associative array of request headers
         * @param string|array $data Data to send either as the POST body, or as parameters in the URL for a GET/HEAD
         * @param array $options Request options, see {@see \WpOrg\Requests\Requests::response()} for documentation
         * @return resource|\CurlHandle Subrequest's cURL handle
         */
        public function &get_subrequest_handle($url, $headers, $data, $options)
        {
        }
        /**
         * Process a response
         *
         * @param string $response Response data from the body
         * @param array $options Request options
         * @return string|false HTTP response data including headers. False if non-blocking.
         * @throws \WpOrg\Requests\Exception If the request resulted in a cURL error.
         */
        public function process_response($response, $options)
        {
        }
        /**
         * Collect the headers as they are received
         *
         * @param resource|\CurlHandle $handle cURL handle
         * @param string $headers Header string
         * @return integer Length of provided header
         */
        public function stream_headers($handle, $headers)
        {
        }
        /**
         * Collect data as it's received
         *
         * @since 1.6.1
         *
         * @param resource|\CurlHandle $handle cURL handle
         * @param string $data Body data
         * @return integer Length of provided data
         */
        public function stream_body($handle, $data)
        {
        }
        /**
         * Self-test whether the transport can be used.
         *
         * The available capabilities to test for can be found in {@see \WpOrg\Requests\Capability}.
         *
         * @codeCoverageIgnore
         * @param array<string, bool> $capabilities Optional. Associative array of capabilities to test against, i.e. `['<capability>' => true]`.
         * @return bool Whether the transport can be used.
         */
        public static function test($capabilities = [])
        {
        }
    }
    /**
     * fsockopen HTTP transport
     *
     * @package Requests\Transport
     */
    final class Fsockopen implements \WpOrg\Requests\Transport
    {
        /**
         * Second to microsecond conversion
         *
         * @var integer
         */
        const SECOND_IN_MICROSECONDS = 1000000;
        /**
         * Raw HTTP data
         *
         * @var string
         */
        public $headers = '';
        /**
         * Stream metadata
         *
         * @var array Associative array of properties, see {@link https://www.php.net/stream_get_meta_data}
         */
        public $info;
        /**
         * Perform a request
         *
         * @param string|Stringable $url URL to request
         * @param array $headers Associative array of request headers
         * @param string|array $data Data to send either as the POST body, or as parameters in the URL for a GET/HEAD
         * @param array $options Request options, see {@see \WpOrg\Requests\Requests::response()} for documentation
         * @return string Raw HTTP result
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $url argument is not a string or Stringable.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $headers argument is not an array.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $data parameter is not an array or string.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $options argument is not an array.
         * @throws \WpOrg\Requests\Exception       On failure to connect to socket (`fsockopenerror`)
         * @throws \WpOrg\Requests\Exception       On socket timeout (`timeout`)
         */
        public function request($url, $headers = [], $data = [], $options = [])
        {
        }
        /**
         * Send multiple requests simultaneously
         *
         * @param array $requests Request data (array of 'url', 'headers', 'data', 'options') as per {@see \WpOrg\Requests\Transport::request()}
         * @param array $options Global options, see {@see \WpOrg\Requests\Requests::response()} for documentation
         * @return array Array of \WpOrg\Requests\Response objects (may contain \WpOrg\Requests\Exception or string responses as well)
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $requests argument is not an array or iterable object with array access.
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $options argument is not an array.
         */
        public function request_multiple($requests, $options)
        {
        }
        /**
         * Error handler for stream_socket_client()
         *
         * @param int $errno Error number (e.g. E_WARNING)
         * @param string $errstr Error message
         */
        public function connect_error_handler($errno, $errstr)
        {
        }
        /**
         * Verify the certificate against common name and subject alternative names
         *
         * Unfortunately, PHP doesn't check the certificate against the alternative
         * names, leading things like 'https://www.github.com/' to be invalid.
         * Instead
         *
         * @link https://tools.ietf.org/html/rfc2818#section-3.1 RFC2818, Section 3.1
         *
         * @param string $host Host name to verify against
         * @param resource $context Stream context
         * @return bool
         *
         * @throws \WpOrg\Requests\Exception On failure to connect via TLS (`fsockopen.ssl.connect_error`)
         * @throws \WpOrg\Requests\Exception On not obtaining a match for the host (`fsockopen.ssl.no_match`)
         */
        public function verify_certificate_from_context($host, $context)
        {
        }
        /**
         * Self-test whether the transport can be used.
         *
         * The available capabilities to test for can be found in {@see \WpOrg\Requests\Capability}.
         *
         * @codeCoverageIgnore
         * @param array<string, bool> $capabilities Optional. Associative array of capabilities to test against, i.e. `['<capability>' => true]`.
         * @return bool Whether the transport can be used.
         */
        public static function test($capabilities = [])
        {
        }
    }
}
namespace WpOrg\Requests\Utility {
    /**
     * Iterator for arrays requiring filtered values
     *
     * @package Requests\Utilities
     */
    final class FilteredIterator extends \ArrayIterator
    {
        /**
         * Create a new iterator
         *
         * @param array    $data     The array or object to be iterated on.
         * @param callable $callback Callback to be called on each value
         *
         * @throws \WpOrg\Requests\Exception\InvalidArgument When the passed $data argument is not iterable.
         */
        public function __construct($data, $callback)
        {
        }
        /**
         * Prevent unserialization of the object for security reasons.
         *
         * @phpcs:disable PHPCompatibility.FunctionNameRestrictions.NewMagicMethods.__unserializeFound
         *
         * @param array $data Restored array of data originally serialized.
         *
         * @return void
         */
        #[\ReturnTypeWillChange]
        public function __unserialize($data)
        {
        }
        /**
         * Perform reinitialization tasks.
         *
         * Prevents a callback from being injected during unserialization of an object.
         *
         * @return void
         */
        public function __wakeup()
        {
        }
        /**
         * Get the current item's value after filtering
         *
         * @return string
         */
        #[\ReturnTypeWillChange]
        public function current()
        {
        }
        /**
         * Prevent creating a PHP value from a stored representation of the object for security reasons.
         *
         * @param string $data The serialized string.
         *
         * @return void
         */
        #[\ReturnTypeWillChange]
        public function unserialize($data)
        {
        }
    }
    /**
     * Input validation utilities.
     *
     * @package Requests\Utilities
     */
    final class InputValidator
    {
        /**
         * Verify that a received input parameter is of type string or is "stringable".
         *
         * @param mixed $input Input parameter to verify.
         *
         * @return bool
         */
        public static function is_string_or_stringable($input)
        {
        }
        /**
         * Verify whether a received input parameter is usable as an integer array key.
         *
         * @param mixed $input Input parameter to verify.
         *
         * @return bool
         */
        public static function is_numeric_array_key($input)
        {
        }
        /**
         * Verify whether a received input parameter is "stringable".
         *
         * @param mixed $input Input parameter to verify.
         *
         * @return bool
         */
        public static function is_stringable_object($input)
        {
        }
        /**
         * Verify whether a received input parameter is _accessible as if it were an array_.
         *
         * @param mixed $input Input parameter to verify.
         *
         * @return bool
         */
        public static function has_array_access($input)
        {
        }
        /**
         * Verify whether a received input parameter is "iterable".
         *
         * @internal The PHP native `is_iterable()` function was only introduced in PHP 7.1
         * and this library still supports PHP 5.6.
         *
         * @param mixed $input Input parameter to verify.
         *
         * @return bool
         */
        public static function is_iterable($input)
        {
        }
        /**
         * Verify whether a received input parameter is a Curl handle.
         *
         * The PHP Curl extension worked with resources prior to PHP 8.0 and with
         * an instance of the `CurlHandle` class since PHP 8.0.
         * {@link https://www.php.net/manual/en/migration80.incompatible.php#migration80.incompatible.resource2object}
         *
         * @param mixed $input Input parameter to verify.
         *
         * @return bool
         */
        public static function is_curl_handle($input)
        {
        }
    }
}
namespace {
    /**
     * Autoloader class
     *
     * @package SimplePie
     * @subpackage API
     */
    class SimplePie_Autoloader
    {
        protected $path;
        /**
         * Constructor
         */
        public function __construct()
        {
        }
        /**
         * Autoloader
         *
         * @param string $class The name of the class to attempt to load.
         * @phpstan-return void
         */
        public function autoload($class)
        {
        }
    }
}
namespace SimplePie {
    /**
     * SimplePie
     *
     * @package SimplePie
     * @subpackage API
     */
    class SimplePie
    {
        /**
         * SimplePie Name
         */
        public const NAME = 'SimplePie';
        /**
         * SimplePie Version
         */
        public const VERSION = '1.8.0';
        /**
         * SimplePie Website URL
         */
        public const URL = 'http://simplepie.org';
        /**
         * SimplePie Linkback
         */
        public const LINKBACK = '<a href="' . self::URL . '" title="' . self::NAME . ' ' . self::VERSION . '">' . self::NAME . '</a>';
        /**
         * No Autodiscovery
         * @see SimplePie::set_autodiscovery_level()
         */
        public const LOCATOR_NONE = 0;
        /**
         * Feed Link Element Autodiscovery
         * @see SimplePie::set_autodiscovery_level()
         */
        public const LOCATOR_AUTODISCOVERY = 1;
        /**
         * Local Feed Extension Autodiscovery
         * @see SimplePie::set_autodiscovery_level()
         */
        public const LOCATOR_LOCAL_EXTENSION = 2;
        /**
         * Local Feed Body Autodiscovery
         * @see SimplePie::set_autodiscovery_level()
         */
        public const LOCATOR_LOCAL_BODY = 4;
        /**
         * Remote Feed Extension Autodiscovery
         * @see SimplePie::set_autodiscovery_level()
         */
        public const LOCATOR_REMOTE_EXTENSION = 8;
        /**
         * Remote Feed Body Autodiscovery
         * @see SimplePie::set_autodiscovery_level()
         */
        public const LOCATOR_REMOTE_BODY = 16;
        /**
         * All Feed Autodiscovery
         * @see SimplePie::set_autodiscovery_level()
         */
        public const LOCATOR_ALL = 31;
        /**
         * No known feed type
         */
        public const TYPE_NONE = 0;
        /**
         * RSS 0.90
         */
        public const TYPE_RSS_090 = 1;
        /**
         * RSS 0.91 (Netscape)
         */
        public const TYPE_RSS_091_NETSCAPE = 2;
        /**
         * RSS 0.91 (Userland)
         */
        public const TYPE_RSS_091_USERLAND = 4;
        /**
         * RSS 0.91 (both Netscape and Userland)
         */
        public const TYPE_RSS_091 = 6;
        /**
         * RSS 0.92
         */
        public const TYPE_RSS_092 = 8;
        /**
         * RSS 0.93
         */
        public const TYPE_RSS_093 = 16;
        /**
         * RSS 0.94
         */
        public const TYPE_RSS_094 = 32;
        /**
         * RSS 1.0
         */
        public const TYPE_RSS_10 = 64;
        /**
         * RSS 2.0
         */
        public const TYPE_RSS_20 = 128;
        /**
         * RDF-based RSS
         */
        public const TYPE_RSS_RDF = 65;
        /**
         * Non-RDF-based RSS (truly intended as syndication format)
         */
        public const TYPE_RSS_SYNDICATION = 190;
        /**
         * All RSS
         */
        public const TYPE_RSS_ALL = 255;
        /**
         * Atom 0.3
         */
        public const TYPE_ATOM_03 = 256;
        /**
         * Atom 1.0
         */
        public const TYPE_ATOM_10 = 512;
        /**
         * All Atom
         */
        public const TYPE_ATOM_ALL = 768;
        /**
         * All feed types
         */
        public const TYPE_ALL = 1023;
        /**
         * No construct
         */
        public const CONSTRUCT_NONE = 0;
        /**
         * Text construct
         */
        public const CONSTRUCT_TEXT = 1;
        /**
         * HTML construct
         */
        public const CONSTRUCT_HTML = 2;
        /**
         * XHTML construct
         */
        public const CONSTRUCT_XHTML = 4;
        /**
         * base64-encoded construct
         */
        public const CONSTRUCT_BASE64 = 8;
        /**
         * IRI construct
         */
        public const CONSTRUCT_IRI = 16;
        /**
         * A construct that might be HTML
         */
        public const CONSTRUCT_MAYBE_HTML = 32;
        /**
         * All constructs
         */
        public const CONSTRUCT_ALL = 63;
        /**
         * Don't change case
         */
        public const SAME_CASE = 1;
        /**
         * Change to lowercase
         */
        public const LOWERCASE = 2;
        /**
         * Change to uppercase
         */
        public const UPPERCASE = 4;
        /**
         * PCRE for HTML attributes
         */
        public const PCRE_HTML_ATTRIBUTE = '((?:[\\x09\\x0A\\x0B\\x0C\\x0D\\x20]+[^\\x09\\x0A\\x0B\\x0C\\x0D\\x20\\x2F\\x3E][^\\x09\\x0A\\x0B\\x0C\\x0D\\x20\\x2F\\x3D\\x3E]*(?:[\\x09\\x0A\\x0B\\x0C\\x0D\\x20]*=[\\x09\\x0A\\x0B\\x0C\\x0D\\x20]*(?:"(?:[^"]*)"|\'(?:[^\']*)\'|(?:[^\\x09\\x0A\\x0B\\x0C\\x0D\\x20\\x22\\x27\\x3E][^\\x09\\x0A\\x0B\\x0C\\x0D\\x20\\x3E]*)?))?)*)[\\x09\\x0A\\x0B\\x0C\\x0D\\x20]*';
        /**
         * PCRE for XML attributes
         */
        public const PCRE_XML_ATTRIBUTE = '((?:\\s+(?:(?:[^\\s:]+:)?[^\\s:]+)\\s*=\\s*(?:"(?:[^"]*)"|\'(?:[^\']*)\'))*)\\s*';
        /**
         * XML Namespace
         */
        public const NAMESPACE_XML = 'http://www.w3.org/XML/1998/namespace';
        /**
         * Atom 1.0 Namespace
         */
        public const NAMESPACE_ATOM_10 = 'http://www.w3.org/2005/Atom';
        /**
         * Atom 0.3 Namespace
         */
        public const NAMESPACE_ATOM_03 = 'http://purl.org/atom/ns#';
        /**
         * RDF Namespace
         */
        public const NAMESPACE_RDF = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#';
        /**
         * RSS 0.90 Namespace
         */
        public const NAMESPACE_RSS_090 = 'http://my.netscape.com/rdf/simple/0.9/';
        /**
         * RSS 1.0 Namespace
         */
        public const NAMESPACE_RSS_10 = 'http://purl.org/rss/1.0/';
        /**
         * RSS 1.0 Content Module Namespace
         */
        public const NAMESPACE_RSS_10_MODULES_CONTENT = 'http://purl.org/rss/1.0/modules/content/';
        /**
         * RSS 2.0 Namespace
         * (Stupid, I know, but I'm certain it will confuse people less with support.)
         */
        public const NAMESPACE_RSS_20 = '';
        /**
         * DC 1.0 Namespace
         */
        public const NAMESPACE_DC_10 = 'http://purl.org/dc/elements/1.0/';
        /**
         * DC 1.1 Namespace
         */
        public const NAMESPACE_DC_11 = 'http://purl.org/dc/elements/1.1/';
        /**
         * W3C Basic Geo (WGS84 lat/long) Vocabulary Namespace
         */
        public const NAMESPACE_W3C_BASIC_GEO = 'http://www.w3.org/2003/01/geo/wgs84_pos#';
        /**
         * GeoRSS Namespace
         */
        public const NAMESPACE_GEORSS = 'http://www.georss.org/georss';
        /**
         * Media RSS Namespace
         */
        public const NAMESPACE_MEDIARSS = 'http://search.yahoo.com/mrss/';
        /**
         * Wrong Media RSS Namespace. Caused by a long-standing typo in the spec.
         */
        public const NAMESPACE_MEDIARSS_WRONG = 'http://search.yahoo.com/mrss';
        /**
         * Wrong Media RSS Namespace #2. New namespace introduced in Media RSS 1.5.
         */
        public const NAMESPACE_MEDIARSS_WRONG2 = 'http://video.search.yahoo.com/mrss';
        /**
         * Wrong Media RSS Namespace #3. A possible typo of the Media RSS 1.5 namespace.
         */
        public const NAMESPACE_MEDIARSS_WRONG3 = 'http://video.search.yahoo.com/mrss/';
        /**
         * Wrong Media RSS Namespace #4. New spec location after the RSS Advisory Board takes it over, but not a valid namespace.
         */
        public const NAMESPACE_MEDIARSS_WRONG4 = 'http://www.rssboard.org/media-rss';
        /**
         * Wrong Media RSS Namespace #5. A possible typo of the RSS Advisory Board URL.
         */
        public const NAMESPACE_MEDIARSS_WRONG5 = 'http://www.rssboard.org/media-rss/';
        /**
         * iTunes RSS Namespace
         */
        public const NAMESPACE_ITUNES = 'http://www.itunes.com/dtds/podcast-1.0.dtd';
        /**
         * XHTML Namespace
         */
        public const NAMESPACE_XHTML = 'http://www.w3.org/1999/xhtml';
        /**
         * IANA Link Relations Registry
         */
        public const IANA_LINK_RELATIONS_REGISTRY = 'http://www.iana.org/assignments/relation/';
        /**
         * No file source
         */
        public const FILE_SOURCE_NONE = 0;
        /**
         * Remote file source
         */
        public const FILE_SOURCE_REMOTE = 1;
        /**
         * Local file source
         */
        public const FILE_SOURCE_LOCAL = 2;
        /**
         * fsockopen() file source
         */
        public const FILE_SOURCE_FSOCKOPEN = 4;
        /**
         * cURL file source
         */
        public const FILE_SOURCE_CURL = 8;
        /**
         * file_get_contents() file source
         */
        public const FILE_SOURCE_FILE_GET_CONTENTS = 16;
        /**
         * @var array Raw data
         * @access private
         */
        public $data = [];
        /**
         * @var mixed Error string
         * @access private
         */
        public $error;
        /**
         * @var int HTTP status code
         * @see SimplePie::status_code()
         * @access private
         */
        public $status_code = 0;
        /**
         * @var object Instance of \SimplePie\Sanitize (or other class)
         * @see SimplePie::set_sanitize_class()
         * @access private
         */
        public $sanitize;
        /**
         * @var string SimplePie Useragent
         * @see SimplePie::set_useragent()
         * @access private
         */
        public $useragent = '';
        /**
         * @var string Feed URL
         * @see SimplePie::set_feed_url()
         * @access private
         */
        public $feed_url;
        /**
         * @var string Original feed URL, or new feed URL iff HTTP 301 Moved Permanently
         * @see SimplePie::subscribe_url()
         * @access private
         */
        public $permanent_url = null;
        /**
         * @var object Instance of \SimplePie\File to use as a feed
         * @see SimplePie::set_file()
         * @access private
         */
        public $file;
        /**
         * @var string Raw feed data
         * @see SimplePie::set_raw_data()
         * @access private
         */
        public $raw_data;
        /**
         * @var int Timeout for fetching remote files
         * @see SimplePie::set_timeout()
         * @access private
         */
        public $timeout = 10;
        /**
         * @var array Custom curl options
         * @see SimplePie::set_curl_options()
         * @access private
         */
        public $curl_options = [];
        /**
         * @var bool Forces fsockopen() to be used for remote files instead
         * of cURL, even if a new enough version is installed
         * @see SimplePie::force_fsockopen()
         * @access private
         */
        public $force_fsockopen = false;
        /**
         * @var bool Force the given data/URL to be treated as a feed no matter what
         * it appears like
         * @see SimplePie::force_feed()
         * @access private
         */
        public $force_feed = false;
        /**
         * @var bool Force SimplePie to fallback to expired cache, if enabled,
         * when feed is unavailable.
         * @see SimplePie::force_cache_fallback()
         * @access private
         */
        public $force_cache_fallback = false;
        /**
         * @var int Cache duration (in seconds)
         * @see SimplePie::set_cache_duration()
         * @access private
         */
        public $cache_duration = 3600;
        /**
         * @var int Auto-discovery cache duration (in seconds)
         * @see SimplePie::set_autodiscovery_cache_duration()
         * @access private
         */
        public $autodiscovery_cache_duration = 604800;
        /**
         * @var string Cache location (relative to executing script)
         * @see SimplePie::set_cache_location()
         * @access private
         */
        public $cache_location = './cache';
        /**
         * @var string Function that creates the cache filename
         * @see SimplePie::set_cache_name_function()
         * @access private
         */
        public $cache_name_function = 'md5';
        /**
         * @var bool Reorder feed by date descending
         * @see SimplePie::enable_order_by_date()
         * @access private
         */
        public $order_by_date = true;
        /**
         * @var mixed Force input encoding to be set to the follow value
         * (false, or anything type-cast to false, disables this feature)
         * @see SimplePie::set_input_encoding()
         * @access private
         */
        public $input_encoding = false;
        /**
         * @var int Feed Autodiscovery Level
         * @see SimplePie::set_autodiscovery_level()
         * @access private
         */
        public $autodiscovery = self::LOCATOR_ALL;
        /**
         * Class registry object
         *
         * @var \SimplePie\Registry
         */
        public $registry;
        /**
         * @var int Maximum number of feeds to check with autodiscovery
         * @see SimplePie::set_max_checked_feeds()
         * @access private
         */
        public $max_checked_feeds = 10;
        /**
         * @var array All the feeds found during the autodiscovery process
         * @see SimplePie::get_all_discovered_feeds()
         * @access private
         */
        public $all_discovered_feeds = [];
        /**
         * @var string Web-accessible path to the handler_image.php file.
         * @see SimplePie::set_image_handler()
         * @access private
         */
        public $image_handler = '';
        /**
         * @var array Stores the URLs when multiple feeds are being initialized.
         * @see SimplePie::set_feed_url()
         * @access private
         */
        public $multifeed_url = [];
        /**
         * @var array Stores SimplePie objects when multiple feeds initialized.
         * @access private
         */
        public $multifeed_objects = [];
        /**
         * @var array Stores the get_object_vars() array for use with multifeeds.
         * @see SimplePie::set_feed_url()
         * @access private
         */
        public $config_settings = null;
        /**
         * @var integer Stores the number of items to return per-feed with multifeeds.
         * @see SimplePie::set_item_limit()
         * @access private
         */
        public $item_limit = 0;
        /**
         * @var bool Stores if last-modified and/or etag headers were sent with the
         * request when checking a feed.
         */
        public $check_modified = false;
        /**
         * @var array Stores the default attributes to be stripped by strip_attributes().
         * @see SimplePie::strip_attributes()
         * @access private
         */
        public $strip_attributes = ['bgsound', 'class', 'expr', 'id', 'style', 'onclick', 'onerror', 'onfinish', 'onmouseover', 'onmouseout', 'onfocus', 'onblur', 'lowsrc', 'dynsrc'];
        /**
         * @var array Stores the default attributes to add to different tags by add_attributes().
         * @see SimplePie::add_attributes()
         * @access private
         */
        public $add_attributes = ['audio' => ['preload' => 'none'], 'iframe' => ['sandbox' => 'allow-scripts allow-same-origin'], 'video' => ['preload' => 'none']];
        /**
         * @var array Stores the default tags to be stripped by strip_htmltags().
         * @see SimplePie::strip_htmltags()
         * @access private
         */
        public $strip_htmltags = ['base', 'blink', 'body', 'doctype', 'embed', 'font', 'form', 'frame', 'frameset', 'html', 'iframe', 'input', 'marquee', 'meta', 'noscript', 'object', 'param', 'script', 'style'];
        /**
         * @var array Stores the default attributes to be renamed by rename_attributes().
         * @see SimplePie::rename_attributes()
         * @access private
         */
        public $rename_attributes = [];
        /**
         * @var bool Should we throw exceptions, or use the old-style error property?
         * @access private
         */
        public $enable_exceptions = false;
        /**
         * The SimplePie class contains feed level data and options
         *
         * To use SimplePie, create the SimplePie object with no parameters. You can
         * then set configuration options using the provided methods. After setting
         * them, you must initialise the feed using $feed->init(). At that point the
         * object's methods and properties will be available to you.
         *
         * Previously, it was possible to pass in the feed URL along with cache
         * options directly into the constructor. This has been removed as of 1.3 as
         * it caused a lot of confusion.
         *
         * @since 1.0 Preview Release
         */
        public function __construct()
        {
        }
        /**
         * Used for converting object to a string
         */
        public function __toString()
        {
        }
        /**
         * Remove items that link back to this before destroying this object
         */
        public function __destruct()
        {
        }
        /**
         * Force the given data/URL to be treated as a feed
         *
         * This tells SimplePie to ignore the content-type provided by the server.
         * Be careful when using this option, as it will also disable autodiscovery.
         *
         * @since 1.1
         * @param bool $enable Force the given data/URL to be treated as a feed
         */
        public function force_feed($enable = false)
        {
        }
        /**
         * Set the URL of the feed you want to parse
         *
         * This allows you to enter the URL of the feed you want to parse, or the
         * website you want to try to use auto-discovery on. This takes priority
         * over any set raw data.
         *
         * You can set multiple feeds to mash together by passing an array instead
         * of a string for the $url. Remember that with each additional feed comes
         * additional processing and resources.
         *
         * @since 1.0 Preview Release
         * @see set_raw_data()
         * @param string|array $url This is the URL (or array of URLs) that you want to parse.
         */
        public function set_feed_url($url)
        {
        }
        /**
         * Set an instance of {@see \SimplePie\File} to use as a feed
         *
         * @param \SimplePie\File &$file
         * @return bool True on success, false on failure
         */
        public function set_file(&$file)
        {
        }
        /**
         * Set the raw XML data to parse
         *
         * Allows you to use a string of RSS/Atom data instead of a remote feed.
         *
         * If you have a feed available as a string in PHP, you can tell SimplePie
         * to parse that data string instead of a remote feed. Any set feed URL
         * takes precedence.
         *
         * @since 1.0 Beta 3
         * @param string $data RSS or Atom data as a string.
         * @see set_feed_url()
         */
        public function set_raw_data($data)
        {
        }
        /**
         * Set the default timeout for fetching remote feeds
         *
         * This allows you to change the maximum time the feed's server to respond
         * and send the feed back.
         *
         * @since 1.0 Beta 3
         * @param int $timeout The maximum number of seconds to spend waiting to retrieve a feed.
         */
        public function set_timeout($timeout = 10)
        {
        }
        /**
         * Set custom curl options
         *
         * This allows you to change default curl options
         *
         * @since 1.0 Beta 3
         * @param array $curl_options Curl options to add to default settings
         */
        public function set_curl_options(array $curl_options = [])
        {
        }
        /**
         * Force SimplePie to use fsockopen() instead of cURL
         *
         * @since 1.0 Beta 3
         * @param bool $enable Force fsockopen() to be used
         */
        public function force_fsockopen($enable = false)
        {
        }
        /**
         * Enable/disable caching in SimplePie.
         *
         * This option allows you to disable caching all-together in SimplePie.
         * However, disabling the cache can lead to longer load times.
         *
         * @since 1.0 Preview Release
         * @param bool $enable Enable caching
         */
        public function enable_cache($enable = true)
        {
        }
        /**
         * Set a PSR-16 implementation as cache
         *
         * @param CacheInterface $psr16cache The PSR-16 cache implementation
         *
         * @return void
         */
        public function set_cache(\Psr\SimpleCache\CacheInterface $cache)
        {
        }
        /**
         * SimplePie to continue to fall back to expired cache, if enabled, when
         * feed is unavailable.
         *
         * This tells SimplePie to ignore any file errors and fall back to cache
         * instead. This only works if caching is enabled and cached content
         * still exists.
         *
         * @deprecated since SimplePie 1.8.0, expired cache will not be used anymore.
         *
         * @param bool $enable Force use of cache on fail.
         */
        public function force_cache_fallback($enable = false)
        {
        }
        /**
         * Set the length of time (in seconds) that the contents of a feed will be
         * cached
         *
         * @param int $seconds The feed content cache duration
         */
        public function set_cache_duration($seconds = 3600)
        {
        }
        /**
         * Set the length of time (in seconds) that the autodiscovered feed URL will
         * be cached
         *
         * @param int $seconds The autodiscovered feed URL cache duration.
         */
        public function set_autodiscovery_cache_duration($seconds = 604800)
        {
        }
        /**
         * Set the file system location where the cached files should be stored
         *
         * @deprecated since SimplePie 1.8.0, use \SimplePie\SimplePie::set_cache() instead.
         *
         * @param string $location The file system location.
         */
        public function set_cache_location($location = './cache')
        {
        }
        /**
         * Return the filename (i.e. hash, without path and without extension) of the file to cache a given URL.
         *
         * @param string $url The URL of the feed to be cached.
         * @return string A filename (i.e. hash, without path and without extension).
         */
        public function get_cache_filename($url)
        {
        }
        /**
         * Set whether feed items should be sorted into reverse chronological order
         *
         * @param bool $enable Sort as reverse chronological order.
         */
        public function enable_order_by_date($enable = true)
        {
        }
        /**
         * Set the character encoding used to parse the feed
         *
         * This overrides the encoding reported by the feed, however it will fall
         * back to the normal encoding detection if the override fails
         *
         * @param string $encoding Character encoding
         */
        public function set_input_encoding($encoding = false)
        {
        }
        /**
         * Set how much feed autodiscovery to do
         *
         * @see \SimplePie\SimplePie::LOCATOR_NONE
         * @see \SimplePie\SimplePie::LOCATOR_AUTODISCOVERY
         * @see \SimplePie\SimplePie::LOCATOR_LOCAL_EXTENSION
         * @see \SimplePie\SimplePie::LOCATOR_LOCAL_BODY
         * @see \SimplePie\SimplePie::LOCATOR_REMOTE_EXTENSION
         * @see \SimplePie\SimplePie::LOCATOR_REMOTE_BODY
         * @see \SimplePie\SimplePie::LOCATOR_ALL
         * @param int $level Feed Autodiscovery Level (level can be a combination of the above constants, see bitwise OR operator)
         */
        public function set_autodiscovery_level($level = self::LOCATOR_ALL)
        {
        }
        /**
         * Get the class registry
         *
         * Use this to override SimplePie's default classes
         * @see \SimplePie\Registry
         *
         * @return Registry
         */
        public function &get_registry()
        {
        }
        /**
         * Set which class SimplePie uses for caching
         *
         * @deprecated since SimplePie 1.3, use {@see set_cache()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_cache_class($class = \SimplePie\Cache::class)
        {
        }
        /**
         * Set which class SimplePie uses for auto-discovery
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_locator_class($class = \SimplePie\Locator::class)
        {
        }
        /**
         * Set which class SimplePie uses for XML parsing
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_parser_class($class = \SimplePie\Parser::class)
        {
        }
        /**
         * Set which class SimplePie uses for remote file fetching
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_file_class($class = \SimplePie\File::class)
        {
        }
        /**
         * Set which class SimplePie uses for data sanitization
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_sanitize_class($class = \SimplePie\Sanitize::class)
        {
        }
        /**
         * Set which class SimplePie uses for handling feed items
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_item_class($class = \SimplePie\Item::class)
        {
        }
        /**
         * Set which class SimplePie uses for handling author data
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_author_class($class = \SimplePie\Author::class)
        {
        }
        /**
         * Set which class SimplePie uses for handling category data
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_category_class($class = \SimplePie\Category::class)
        {
        }
        /**
         * Set which class SimplePie uses for feed enclosures
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_enclosure_class($class = \SimplePie\Enclosure::class)
        {
        }
        /**
         * Set which class SimplePie uses for `<media:text>` captions
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_caption_class($class = \SimplePie\Caption::class)
        {
        }
        /**
         * Set which class SimplePie uses for `<media:copyright>`
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_copyright_class($class = \SimplePie\Copyright::class)
        {
        }
        /**
         * Set which class SimplePie uses for `<media:credit>`
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_credit_class($class = \SimplePie\Credit::class)
        {
        }
        /**
         * Set which class SimplePie uses for `<media:rating>`
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_rating_class($class = \SimplePie\Rating::class)
        {
        }
        /**
         * Set which class SimplePie uses for `<media:restriction>`
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_restriction_class($class = \SimplePie\Restriction::class)
        {
        }
        /**
         * Set which class SimplePie uses for content-type sniffing
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_content_type_sniffer_class($class = \SimplePie\Content\Type\Sniffer::class)
        {
        }
        /**
         * Set which class SimplePie uses item sources
         *
         * @deprecated since SimplePie 1.3, use {@see get_registry()} instead
         *
         * @param string $class Name of custom class
         *
         * @return boolean True on success, false otherwise
         */
        public function set_source_class($class = \SimplePie\Source::class)
        {
        }
        /**
         * Set the user agent string
         *
         * @param string $ua New user agent string.
         */
        public function set_useragent($ua = null)
        {
        }
        /**
         * Set a namefilter to modify the cache filename with
         *
         * @param NameFilter $filter
         *
         * @return void
         */
        public function set_cache_namefilter(\SimplePie\Cache\NameFilter $filter) : void
        {
        }
        /**
         * Set callback function to create cache filename with
         *
         * @deprecated since SimplePie 1.8.0, use {@see set_cache_namefilter()} instead
         *
         * @param mixed $function Callback function
         */
        public function set_cache_name_function($function = 'md5')
        {
        }
        /**
         * Set options to make SP as fast as possible
         *
         * Forgoes a substantial amount of data sanitization in favor of speed. This
         * turns SimplePie into a dumb parser of feeds.
         *
         * @param bool $set Whether to set them or not
         */
        public function set_stupidly_fast($set = false)
        {
        }
        /**
         * Set maximum number of feeds to check with autodiscovery
         *
         * @param int $max Maximum number of feeds to check
         */
        public function set_max_checked_feeds($max = 10)
        {
        }
        public function remove_div($enable = true)
        {
        }
        public function strip_htmltags($tags = '', $encode = null)
        {
        }
        public function encode_instead_of_strip($enable = true)
        {
        }
        public function rename_attributes($attribs = '')
        {
        }
        public function strip_attributes($attribs = '')
        {
        }
        public function add_attributes($attribs = '')
        {
        }
        /**
         * Set the output encoding
         *
         * Allows you to override SimplePie's output to match that of your webpage.
         * This is useful for times when your webpages are not being served as
         * UTF-8. This setting will be obeyed by {@see handle_content_type()}, and
         * is similar to {@see set_input_encoding()}.
         *
         * It should be noted, however, that not all character encodings can support
         * all characters. If your page is being served as ISO-8859-1 and you try
         * to display a Japanese feed, you'll likely see garbled characters.
         * Because of this, it is highly recommended to ensure that your webpages
         * are served as UTF-8.
         *
         * The number of supported character encodings depends on whether your web
         * host supports {@link http://php.net/mbstring mbstring},
         * {@link http://php.net/iconv iconv}, or both. See
         * {@link http://simplepie.org/wiki/faq/Supported_Character_Encodings} for
         * more information.
         *
         * @param string $encoding
         */
        public function set_output_encoding($encoding = 'UTF-8')
        {
        }
        public function strip_comments($strip = false)
        {
        }
        /**
         * Set element/attribute key/value pairs of HTML attributes
         * containing URLs that need to be resolved relative to the feed
         *
         * Defaults to |a|@href, |area|@href, |blockquote|@cite, |del|@cite,
         * |form|@action, |img|@longdesc, |img|@src, |input|@src, |ins|@cite,
         * |q|@cite
         *
         * @since 1.0
         * @param array|null $element_attribute Element/attribute key/value pairs, null for default
         */
        public function set_url_replacements($element_attribute = null)
        {
        }
        /**
         * Set the list of domains for which to force HTTPS.
         * @see \SimplePie\Sanitize::set_https_domains()
         * @param array List of HTTPS domains. Example array('biz', 'example.com', 'example.org', 'www.example.net').
         */
        public function set_https_domains($domains = [])
        {
        }
        /**
         * Set the handler to enable the display of cached images.
         *
         * @param string $page Web-accessible path to the handler_image.php file.
         * @param string $qs The query string that the value should be passed to.
         */
        public function set_image_handler($page = false, $qs = 'i')
        {
        }
        /**
         * Set the limit for items returned per-feed with multifeeds
         *
         * @param integer $limit The maximum number of items to return.
         */
        public function set_item_limit($limit = 0)
        {
        }
        /**
         * Enable throwing exceptions
         *
         * @param boolean $enable Should we throw exceptions, or use the old-style error property?
         */
        public function enable_exceptions($enable = true)
        {
        }
        /**
         * Initialize the feed object
         *
         * This is what makes everything happen. Period. This is where all of the
         * configuration options get processed, feeds are fetched, cached, and
         * parsed, and all of that other good stuff.
         *
         * @return boolean True if successful, false otherwise
         */
        public function init()
        {
        }
        /**
         * Fetch the data via \SimplePie\File
         *
         * If the data is already cached, attempt to fetch it from there instead
         * @param Base|DataCache|false $cache Cache handler, or false to not load from the cache
         * @return array|true Returns true if the data was loaded from the cache, or an array of HTTP headers and sniffed type
         */
        protected function fetch_data(&$cache)
        {
        }
        /**
         * Get the error message for the occurred error
         *
         * @return string|array Error message, or array of messages for multifeeds
         */
        public function error()
        {
        }
        /**
         * Get the last HTTP status code
         *
         * @return int Status code
         */
        public function status_code()
        {
        }
        /**
         * Get the raw XML
         *
         * This is the same as the old `$feed->enable_xml_dump(true)`, but returns
         * the data instead of printing it.
         *
         * @return string|boolean Raw XML data, false if the cache is used
         */
        public function get_raw_data()
        {
        }
        /**
         * Get the character encoding used for output
         *
         * @since Preview Release
         * @return string
         */
        public function get_encoding()
        {
        }
        /**
         * Send the content-type header with correct encoding
         *
         * This method ensures that the SimplePie-enabled page is being served with
         * the correct {@link http://www.iana.org/assignments/media-types/ mime-type}
         * and character encoding HTTP headers (character encoding determined by the
         * {@see set_output_encoding} config option).
         *
         * This won't work properly if any content or whitespace has already been
         * sent to the browser, because it relies on PHP's
         * {@link http://php.net/header header()} function, and these are the
         * circumstances under which the function works.
         *
         * Because it's setting these settings for the entire page (as is the nature
         * of HTTP headers), this should only be used once per page (again, at the
         * top).
         *
         * @param string $mime MIME type to serve the page as
         */
        public function handle_content_type($mime = 'text/html')
        {
        }
        /**
         * Get the type of the feed
         *
         * This returns a \SimplePie\SimplePie::TYPE_* constant, which can be tested against
         * using {@link http://php.net/language.operators.bitwise bitwise operators}
         *
         * @since 0.8 (usage changed to using constants in 1.0)
         * @see \SimplePie\SimplePie::TYPE_NONE Unknown.
         * @see \SimplePie\SimplePie::TYPE_RSS_090 RSS 0.90.
         * @see \SimplePie\SimplePie::TYPE_RSS_091_NETSCAPE RSS 0.91 (Netscape).
         * @see \SimplePie\SimplePie::TYPE_RSS_091_USERLAND RSS 0.91 (Userland).
         * @see \SimplePie\SimplePie::TYPE_RSS_091 RSS 0.91.
         * @see \SimplePie\SimplePie::TYPE_RSS_092 RSS 0.92.
         * @see \SimplePie\SimplePie::TYPE_RSS_093 RSS 0.93.
         * @see \SimplePie\SimplePie::TYPE_RSS_094 RSS 0.94.
         * @see \SimplePie\SimplePie::TYPE_RSS_10 RSS 1.0.
         * @see \SimplePie\SimplePie::TYPE_RSS_20 RSS 2.0.x.
         * @see \SimplePie\SimplePie::TYPE_RSS_RDF RDF-based RSS.
         * @see \SimplePie\SimplePie::TYPE_RSS_SYNDICATION Non-RDF-based RSS (truly intended as syndication format).
         * @see \SimplePie\SimplePie::TYPE_RSS_ALL Any version of RSS.
         * @see \SimplePie\SimplePie::TYPE_ATOM_03 Atom 0.3.
         * @see \SimplePie\SimplePie::TYPE_ATOM_10 Atom 1.0.
         * @see \SimplePie\SimplePie::TYPE_ATOM_ALL Any version of Atom.
         * @see \SimplePie\SimplePie::TYPE_ALL Any known/supported feed type.
         * @return int \SimplePie\SimplePie::TYPE_* constant
         */
        public function get_type()
        {
        }
        /**
         * Get the URL for the feed
         *
         * When the 'permanent' mode is enabled, returns the original feed URL,
         * except in the case of an `HTTP 301 Moved Permanently` status response,
         * in which case the location of the first redirection is returned.
         *
         * When the 'permanent' mode is disabled (default),
         * may or may not be different from the URL passed to {@see set_feed_url()},
         * depending on whether auto-discovery was used, and whether there were
         * any redirects along the way.
         *
         * @since Preview Release (previously called `get_feed_url()` since SimplePie 0.8.)
         * @todo Support <itunes:new-feed-url>
         * @todo Also, |atom:link|@rel=self
         * @param bool $permanent Permanent mode to return only the original URL or the first redirection
         * iff it is a 301 redirection
         * @return string|null
         */
        public function subscribe_url($permanent = false)
        {
        }
        /**
         * Get data for an feed-level element
         *
         * This method allows you to get access to ANY element/attribute that is a
         * sub-element of the opening feed tag.
         *
         * The return value is an indexed array of elements matching the given
         * namespace and tag name. Each element has `attribs`, `data` and `child`
         * subkeys. For `attribs` and `child`, these contain namespace subkeys.
         * `attribs` then has one level of associative name => value data (where
         * `value` is a string) after the namespace. `child` has tag-indexed keys
         * after the namespace, each member of which is an indexed array matching
         * this same format.
         *
         * For example:
         * <pre>
         * // This is probably a bad example because we already support
         * // <media:content> natively, but it shows you how to parse through
         * // the nodes.
         * $group = $item->get_item_tags(\SimplePie\SimplePie::NAMESPACE_MEDIARSS, 'group');
         * $content = $group[0]['child'][\SimplePie\SimplePie::NAMESPACE_MEDIARSS]['content'];
         * $file = $content[0]['attribs']['']['url'];
         * echo $file;
         * </pre>
         *
         * @since 1.0
         * @see http://simplepie.org/wiki/faq/supported_xml_namespaces
         * @param string $namespace The URL of the XML namespace of the elements you're trying to access
         * @param string $tag Tag name
         * @return array
         */
        public function get_feed_tags($namespace, $tag)
        {
        }
        /**
         * Get data for an channel-level element
         *
         * This method allows you to get access to ANY element/attribute in the
         * channel/header section of the feed.
         *
         * See {@see SimplePie::get_feed_tags()} for a description of the return value
         *
         * @since 1.0
         * @see http://simplepie.org/wiki/faq/supported_xml_namespaces
         * @param string $namespace The URL of the XML namespace of the elements you're trying to access
         * @param string $tag Tag name
         * @return array
         */
        public function get_channel_tags($namespace, $tag)
        {
        }
        /**
         * Get data for an channel-level element
         *
         * This method allows you to get access to ANY element/attribute in the
         * image/logo section of the feed.
         *
         * See {@see SimplePie::get_feed_tags()} for a description of the return value
         *
         * @since 1.0
         * @see http://simplepie.org/wiki/faq/supported_xml_namespaces
         * @param string $namespace The URL of the XML namespace of the elements you're trying to access
         * @param string $tag Tag name
         * @return array
         */
        public function get_image_tags($namespace, $tag)
        {
        }
        /**
         * Get the base URL value from the feed
         *
         * Uses `<xml:base>` if available, otherwise uses the first link in the
         * feed, or failing that, the URL of the feed itself.
         *
         * @see get_link
         * @see subscribe_url
         *
         * @param array $element
         * @return string
         */
        public function get_base($element = [])
        {
        }
        /**
         * Sanitize feed data
         *
         * @access private
         * @see \SimplePie\Sanitize::sanitize()
         * @param string $data Data to sanitize
         * @param int $type One of the \SimplePie\SimplePie::CONSTRUCT_* constants
         * @param string $base Base URL to resolve URLs against
         * @return string Sanitized data
         */
        public function sanitize($data, $type, $base = '')
        {
        }
        /**
         * Get the title of the feed
         *
         * Uses `<atom:title>`, `<title>` or `<dc:title>`
         *
         * @since 1.0 (previously called `get_feed_title` since 0.8)
         * @return string|null
         */
        public function get_title()
        {
        }
        /**
         * Get a category for the feed
         *
         * @since Unknown
         * @param int $key The category that you want to return. Remember that arrays begin with 0, not 1
         * @return \SimplePie\Category|null
         */
        public function get_category($key = 0)
        {
        }
        /**
         * Get all categories for the feed
         *
         * Uses `<atom:category>`, `<category>` or `<dc:subject>`
         *
         * @since Unknown
         * @return array|null List of {@see \SimplePie\Category} objects
         */
        public function get_categories()
        {
        }
        /**
         * Get an author for the feed
         *
         * @since 1.1
         * @param int $key The author that you want to return. Remember that arrays begin with 0, not 1
         * @return \SimplePie\Author|null
         */
        public function get_author($key = 0)
        {
        }
        /**
         * Get all authors for the feed
         *
         * Uses `<atom:author>`, `<author>`, `<dc:creator>` or `<itunes:author>`
         *
         * @since 1.1
         * @return array|null List of {@see \SimplePie\Author} objects
         */
        public function get_authors()
        {
        }
        /**
         * Get a contributor for the feed
         *
         * @since 1.1
         * @param int $key The contrbutor that you want to return. Remember that arrays begin with 0, not 1
         * @return \SimplePie\Author|null
         */
        public function get_contributor($key = 0)
        {
        }
        /**
         * Get all contributors for the feed
         *
         * Uses `<atom:contributor>`
         *
         * @since 1.1
         * @return array|null List of {@see \SimplePie\Author} objects
         */
        public function get_contributors()
        {
        }
        /**
         * Get a single link for the feed
         *
         * @since 1.0 (previously called `get_feed_link` since Preview Release, `get_feed_permalink()` since 0.8)
         * @param int $key The link that you want to return. Remember that arrays begin with 0, not 1
         * @param string $rel The relationship of the link to return
         * @return string|null Link URL
         */
        public function get_link($key = 0, $rel = 'alternate')
        {
        }
        /**
         * Get the permalink for the item
         *
         * Returns the first link available with a relationship of "alternate".
         * Identical to {@see get_link()} with key 0
         *
         * @see get_link
         * @since 1.0 (previously called `get_feed_link` since Preview Release, `get_feed_permalink()` since 0.8)
         * @internal Added for parity between the parent-level and the item/entry-level.
         * @return string|null Link URL
         */
        public function get_permalink()
        {
        }
        /**
         * Get all links for the feed
         *
         * Uses `<atom:link>` or `<link>`
         *
         * @since Beta 2
         * @param string $rel The relationship of links to return
         * @return array|null Links found for the feed (strings)
         */
        public function get_links($rel = 'alternate')
        {
        }
        public function get_all_discovered_feeds()
        {
        }
        /**
         * Get the content for the item
         *
         * Uses `<atom:subtitle>`, `<atom:tagline>`, `<description>`,
         * `<dc:description>`, `<itunes:summary>` or `<itunes:subtitle>`
         *
         * @since 1.0 (previously called `get_feed_description()` since 0.8)
         * @return string|null
         */
        public function get_description()
        {
        }
        /**
         * Get the copyright info for the feed
         *
         * Uses `<atom:rights>`, `<atom:copyright>` or `<dc:rights>`
         *
         * @since 1.0 (previously called `get_feed_copyright()` since 0.8)
         * @return string|null
         */
        public function get_copyright()
        {
        }
        /**
         * Get the language for the feed
         *
         * Uses `<language>`, `<dc:language>`, or @xml_lang
         *
         * @since 1.0 (previously called `get_feed_language()` since 0.8)
         * @return string|null
         */
        public function get_language()
        {
        }
        /**
         * Get the latitude coordinates for the item
         *
         * Compatible with the W3C WGS84 Basic Geo and GeoRSS specifications
         *
         * Uses `<geo:lat>` or `<georss:point>`
         *
         * @since 1.0
         * @link http://www.w3.org/2003/01/geo/ W3C WGS84 Basic Geo
         * @link http://www.georss.org/ GeoRSS
         * @return string|null
         */
        public function get_latitude()
        {
        }
        /**
         * Get the longitude coordinates for the feed
         *
         * Compatible with the W3C WGS84 Basic Geo and GeoRSS specifications
         *
         * Uses `<geo:long>`, `<geo:lon>` or `<georss:point>`
         *
         * @since 1.0
         * @link http://www.w3.org/2003/01/geo/ W3C WGS84 Basic Geo
         * @link http://www.georss.org/ GeoRSS
         * @return string|null
         */
        public function get_longitude()
        {
        }
        /**
         * Get the feed logo's title
         *
         * RSS 0.9.0, 1.0 and 2.0 feeds are allowed to have a "feed logo" title.
         *
         * Uses `<image><title>` or `<image><dc:title>`
         *
         * @return string|null
         */
        public function get_image_title()
        {
        }
        /**
         * Get the feed logo's URL
         *
         * RSS 0.9.0, 2.0, Atom 1.0, and feeds with iTunes RSS tags are allowed to
         * have a "feed logo" URL. This points directly to the image itself.
         *
         * Uses `<itunes:image>`, `<atom:logo>`, `<atom:icon>`,
         * `<image><title>` or `<image><dc:title>`
         *
         * @return string|null
         */
        public function get_image_url()
        {
        }
        /**
         * Get the feed logo's link
         *
         * RSS 0.9.0, 1.0 and 2.0 feeds are allowed to have a "feed logo" link. This
         * points to a human-readable page that the image should link to.
         *
         * Uses `<itunes:image>`, `<atom:logo>`, `<atom:icon>`,
         * `<image><title>` or `<image><dc:title>`
         *
         * @return string|null
         */
        public function get_image_link()
        {
        }
        /**
         * Get the feed logo's link
         *
         * RSS 2.0 feeds are allowed to have a "feed logo" width.
         *
         * Uses `<image><width>` or defaults to 88 if no width is specified and
         * the feed is an RSS 2.0 feed.
         *
         * @return int|null
         */
        public function get_image_width()
        {
        }
        /**
         * Get the feed logo's height
         *
         * RSS 2.0 feeds are allowed to have a "feed logo" height.
         *
         * Uses `<image><height>` or defaults to 31 if no height is specified and
         * the feed is an RSS 2.0 feed.
         *
         * @return int|null
         */
        public function get_image_height()
        {
        }
        /**
         * Get the number of items in the feed
         *
         * This is well-suited for {@link http://php.net/for for()} loops with
         * {@see get_item()}
         *
         * @param int $max Maximum value to return. 0 for no limit
         * @return int Number of items in the feed
         */
        public function get_item_quantity($max = 0)
        {
        }
        /**
         * Get a single item from the feed
         *
         * This is better suited for {@link http://php.net/for for()} loops, whereas
         * {@see get_items()} is better suited for
         * {@link http://php.net/foreach foreach()} loops.
         *
         * @see get_item_quantity()
         * @since Beta 2
         * @param int $key The item that you want to return. Remember that arrays begin with 0, not 1
         * @return \SimplePie\Item|null
         */
        public function get_item($key = 0)
        {
        }
        /**
         * Get all items from the feed
         *
         * This is better suited for {@link http://php.net/for for()} loops, whereas
         * {@see get_items()} is better suited for
         * {@link http://php.net/foreach foreach()} loops.
         *
         * @see get_item_quantity
         * @since Beta 2
         * @param int $start Index to start at
         * @param int $end Number of items to return. 0 for all items after `$start`
         * @return \SimplePie\Item[]|null List of {@see \SimplePie\Item} objects
         */
        public function get_items($start = 0, $end = 0)
        {
        }
        /**
         * Set the favicon handler
         *
         * @deprecated Use your own favicon handling instead
         */
        public function set_favicon_handler($page = false, $qs = 'i')
        {
        }
        /**
         * Get the favicon for the current feed
         *
         * @deprecated Use your own favicon handling instead
         */
        public function get_favicon()
        {
        }
        /**
         * Magic method handler
         *
         * @param string $method Method name
         * @param array $args Arguments to the method
         * @return mixed
         */
        public function __call($method, $args)
        {
        }
        /**
         * Sorting callback for items
         *
         * @access private
         * @param SimplePie $a
         * @param SimplePie $b
         * @return boolean
         */
        public static function sort_items($a, $b)
        {
        }
        /**
         * Merge items from several feeds into one
         *
         * If you're merging multiple feeds together, they need to all have dates
         * for the items or else SimplePie will refuse to sort them.
         *
         * @link http://simplepie.org/wiki/tutorial/sort_multiple_feeds_by_time_and_date#if_feeds_require_separate_per-feed_settings
         * @param array $urls List of SimplePie feed objects to merge
         * @param int $start Starting item
         * @param int $end Number of items to return
         * @param int $limit Maximum number of items per feed
         * @return array
         */
        public static function merge_items($urls, $start = 0, $end = 0, $limit = 0)
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\SimplePie" instead */
    class SimplePie extends \SimplePie\SimplePie
    {
    }
}
namespace SimplePie {
    /**
     * Manages all author-related data
     *
     * Used by {@see Item::get_author()} and {@see SimplePie::get_authors()}
     *
     * This class can be overloaded with {@see SimplePie::set_author_class()}
     *
     * @package SimplePie
     * @subpackage API
     */
    class Author
    {
        /**
         * Author's name
         *
         * @var string
         * @see get_name()
         */
        public $name;
        /**
         * Author's link
         *
         * @var string
         * @see get_link()
         */
        public $link;
        /**
         * Author's email address
         *
         * @var string
         * @see get_email()
         */
        public $email;
        /**
         * Constructor, used to input the data
         *
         * @param string $name
         * @param string $link
         * @param string $email
         */
        public function __construct($name = null, $link = null, $email = null)
        {
        }
        /**
         * String-ified version
         *
         * @return string
         */
        public function __toString()
        {
        }
        /**
         * Author's name
         *
         * @return string|null
         */
        public function get_name()
        {
        }
        /**
         * Author's link
         *
         * @return string|null
         */
        public function get_link()
        {
        }
        /**
         * Author's email address
         *
         * @return string|null
         */
        public function get_email()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Author" instead */
    class SimplePie_Author extends \SimplePie\Author
    {
    }
}
namespace SimplePie {
    /**
     * Used to create cache objects
     *
     * This class can be overloaded with {@see SimplePie::set_cache_class()},
     * although the preferred way is to create your own handler
     * via {@see register()}
     *
     * @package SimplePie
     * @subpackage Caching
     * @deprecated since SimplePie 1.8.0, use "SimplePie\SimplePie::set_cache()" instead
     */
    class Cache
    {
        /**
         * Cache handler classes
         *
         * These receive 3 parameters to their constructor, as documented in
         * {@see register()}
         * @var array
         */
        protected static $handlers = ['mysql' => 'SimplePie\\Cache\\MySQL', 'memcache' => 'SimplePie\\Cache\\Memcache', 'memcached' => 'SimplePie\\Cache\\Memcached', 'redis' => 'SimplePie\\Cache\\Redis'];
        /**
         * Create a new SimplePie\Cache object
         *
         * @param string $location URL location (scheme is used to determine handler)
         * @param string $filename Unique identifier for cache object
         * @param Base::TYPE_FEED|Base::TYPE_IMAGE $extension 'spi' or 'spc'
         * @return Base Type of object depends on scheme of `$location`
         */
        public static function get_handler($location, $filename, $extension)
        {
        }
        /**
         * Create a new SimplePie\Cache object
         *
         * @deprecated since SimplePie 1.3.1, use {@see get_handler()} instead
         */
        public function create($location, $filename, $extension)
        {
        }
        /**
         * Register a handler
         *
         * @param string $type DSN type to register for
         * @param class-string<Base> $class Name of handler class. Must implement Base
         */
        public static function register($type, $class)
        {
        }
        /**
         * Parse a URL into an array
         *
         * @param string $url
         * @return array
         */
        public static function parse_URL($url)
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Cache" instead */
    class SimplePie_Cache extends \SimplePie\Cache
    {
    }
}
namespace SimplePie\Cache {
    /**
     * Base for cache objects
     *
     * Classes to be used with {@see \SimplePie\Cache::register()} are expected
     * to implement this interface.
     *
     * @package SimplePie
     * @subpackage Caching
     * @deprecated since SimplePie 1.8.0, use "Psr\SimpleCache\CacheInterface" instead
     */
    interface Base
    {
        /**
         * Feed cache type
         *
         * @var string
         */
        public const TYPE_FEED = 'spc';
        /**
         * Image cache type
         *
         * @var string
         */
        public const TYPE_IMAGE = 'spi';
        /**
         * Create a new cache object
         *
         * @param string $location Location string (from SimplePie::$cache_location)
         * @param string $name Unique ID for the cache
         * @param Base::TYPE_FEED|Base::TYPE_IMAGE $type Either TYPE_FEED for SimplePie data, or TYPE_IMAGE for image data
         */
        public function __construct($location, $name, $type);
        /**
         * Save data to the cache
         *
         * @param array|\SimplePie\SimplePie $data Data to store in the cache. If passed a SimplePie object, only cache the $data property
         * @return bool Successfulness
         */
        public function save($data);
        /**
         * Retrieve the data saved to the cache
         *
         * @return array Data for SimplePie::$data
         */
        public function load();
        /**
         * Retrieve the last modified time for the cache
         *
         * @return int Timestamp
         */
        public function mtime();
        /**
         * Set the last modified time to the current time
         *
         * @return bool Success status
         */
        public function touch();
        /**
         * Remove the cache
         *
         * @return bool Success status
         */
        public function unlink();
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Cache\Base" instead */
    interface SimplePie_Cache_Base extends \SimplePie\Cache\Base
    {
    }
}
namespace SimplePie\Cache {
    /**
     * Base class for database-based caches
     *
     * @package SimplePie
     * @subpackage Caching
     * @deprecated since SimplePie 1.8.0, use implementation of "Psr\SimpleCache\CacheInterface" instead
     */
    abstract class DB implements \SimplePie\Cache\Base
    {
        /**
         * Helper for database conversion
         *
         * Converts a given {@see SimplePie} object into data to be stored
         *
         * @param \SimplePie\SimplePie $data
         * @return array First item is the serialized data for storage, second item is the unique ID for this item
         */
        protected static function prepare_simplepie_object_for_cache($data)
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Cache\DB" instead */
    abstract class SimplePie_Cache_DB extends \SimplePie\Cache\DB
    {
    }
}
namespace SimplePie\Cache {
    /**
     * Caches data to the filesystem
     *
     * @package SimplePie
     * @subpackage Caching
     * @deprecated since SimplePie 1.8.0, use implementation of "Psr\SimpleCache\CacheInterface" instead
     */
    class File implements \SimplePie\Cache\Base
    {
        /**
         * Location string
         *
         * @see SimplePie::$cache_location
         * @var string
         */
        protected $location;
        /**
         * Filename
         *
         * @var string
         */
        protected $filename;
        /**
         * File extension
         *
         * @var string
         */
        protected $extension;
        /**
         * File path
         *
         * @var string
         */
        protected $name;
        /**
         * Create a new cache object
         *
         * @param string $location Location string (from SimplePie::$cache_location)
         * @param string $name Unique ID for the cache
         * @param Base::TYPE_FEED|Base::TYPE_IMAGE $type Either TYPE_FEED for SimplePie data, or TYPE_IMAGE for image data
         */
        public function __construct($location, $name, $type)
        {
        }
        /**
         * Save data to the cache
         *
         * @param array|\SimplePie\SimplePie $data Data to store in the cache. If passed a SimplePie object, only cache the $data property
         * @return bool Successfulness
         */
        public function save($data)
        {
        }
        /**
         * Retrieve the data saved to the cache
         *
         * @return array Data for SimplePie::$data
         */
        public function load()
        {
        }
        /**
         * Retrieve the last modified time for the cache
         *
         * @return int Timestamp
         */
        public function mtime()
        {
        }
        /**
         * Set the last modified time to the current time
         *
         * @return bool Success status
         */
        public function touch()
        {
        }
        /**
         * Remove the cache
         *
         * @return bool Success status
         */
        public function unlink()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Cache\File" instead */
    class SimplePie_Cache_File extends \SimplePie\Cache\File
    {
    }
}
namespace SimplePie\Cache {
    /**
     * Caches data to memcache
     *
     * Registered for URLs with the "memcache" protocol
     *
     * For example, `memcache://localhost:11211/?timeout=3600&prefix=sp_` will
     * connect to memcache on `localhost` on port 11211. All tables will be
     * prefixed with `sp_` and data will expire after 3600 seconds
     *
     * @package SimplePie
     * @subpackage Caching
     * @uses Memcache
     * @deprecated since SimplePie 1.8.0, use implementation of "Psr\SimpleCache\CacheInterface" instead
     */
    class Memcache implements \SimplePie\Cache\Base
    {
        /**
         * Memcache instance
         *
         * @var Memcache
         */
        protected $cache;
        /**
         * Options
         *
         * @var array
         */
        protected $options;
        /**
         * Cache name
         *
         * @var string
         */
        protected $name;
        /**
         * Create a new cache object
         *
         * @param string $location Location string (from SimplePie::$cache_location)
         * @param string $name Unique ID for the cache
         * @param Base::TYPE_FEED|Base::TYPE_IMAGE $type Either TYPE_FEED for SimplePie data, or TYPE_IMAGE for image data
         */
        public function __construct($location, $name, $type)
        {
        }
        /**
         * Save data to the cache
         *
         * @param array|\SimplePie\SimplePie $data Data to store in the cache. If passed a SimplePie object, only cache the $data property
         * @return bool Successfulness
         */
        public function save($data)
        {
        }
        /**
         * Retrieve the data saved to the cache
         *
         * @return array Data for SimplePie::$data
         */
        public function load()
        {
        }
        /**
         * Retrieve the last modified time for the cache
         *
         * @return int Timestamp
         */
        public function mtime()
        {
        }
        /**
         * Set the last modified time to the current time
         *
         * @return bool Success status
         */
        public function touch()
        {
        }
        /**
         * Remove the cache
         *
         * @return bool Success status
         */
        public function unlink()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Cache\Memcache" instead */
    class SimplePie_Cache_Memcache extends \SimplePie\Cache\Memcache
    {
    }
}
namespace SimplePie\Cache {
    /**
     * Caches data to memcached
     *
     * Registered for URLs with the "memcached" protocol
     *
     * For example, `memcached://localhost:11211/?timeout=3600&prefix=sp_` will
     * connect to memcached on `localhost` on port 11211. All tables will be
     * prefixed with `sp_` and data will expire after 3600 seconds
     *
     * @package    SimplePie
     * @subpackage Caching
     * @author     Paul L. McNeely
     * @uses       Memcached
     * @deprecated since SimplePie 1.8.0, use implementation of "Psr\SimpleCache\CacheInterface" instead
     */
    class Memcached implements \SimplePie\Cache\Base
    {
        /**
         * NativeMemcached instance
         * @var NativeMemcached
         */
        protected $cache;
        /**
         * Options
         * @var array
         */
        protected $options;
        /**
         * Cache name
         * @var string
         */
        protected $name;
        /**
         * Create a new cache object
         * @param string $location Location string (from SimplePie::$cache_location)
         * @param string $name Unique ID for the cache
         * @param Base::TYPE_FEED|Base::TYPE_IMAGE $type Either TYPE_FEED for SimplePie data, or TYPE_IMAGE for image data
         */
        public function __construct($location, $name, $type)
        {
        }
        /**
         * Save data to the cache
         * @param array|\SimplePie\SimplePie $data Data to store in the cache. If passed a SimplePie object, only cache the $data property
         * @return bool Successfulness
         */
        public function save($data)
        {
        }
        /**
         * Retrieve the data saved to the cache
         * @return array Data for SimplePie::$data
         */
        public function load()
        {
        }
        /**
         * Retrieve the last modified time for the cache
         * @return int Timestamp
         */
        public function mtime()
        {
        }
        /**
         * Set the last modified time to the current time
         * @return bool Success status
         */
        public function touch()
        {
        }
        /**
         * Remove the cache
         * @return bool Success status
         */
        public function unlink()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Cache\Memcached" instead */
    class SimplePie_Cache_Memcached extends \SimplePie\Cache\Memcached
    {
    }
}
namespace SimplePie\Cache {
    /**
     * Caches data to a MySQL database
     *
     * Registered for URLs with the "mysql" protocol
     *
     * For example, `mysql://root:password@localhost:3306/mydb?prefix=sp_` will
     * connect to the `mydb` database on `localhost` on port 3306, with the user
     * `root` and the password `password`. All tables will be prefixed with `sp_`
     *
     * @package SimplePie
     * @subpackage Caching
     * @deprecated since SimplePie 1.8.0, use implementation of "Psr\SimpleCache\CacheInterface" instead
     */
    class MySQL extends \SimplePie\Cache\DB
    {
        /**
         * PDO instance
         *
         * @var \PDO
         */
        protected $mysql;
        /**
         * Options
         *
         * @var array
         */
        protected $options;
        /**
         * Cache ID
         *
         * @var string
         */
        protected $id;
        /**
         * Create a new cache object
         *
         * @param string $location Location string (from SimplePie::$cache_location)
         * @param string $name Unique ID for the cache
         * @param Base::TYPE_FEED|Base::TYPE_IMAGE $type Either TYPE_FEED for SimplePie data, or TYPE_IMAGE for image data
         * @phpstan-return void
         */
        public function __construct($location, $name, $type)
        {
        }
        /**
         * Save data to the cache
         *
         * @param array|\SimplePie\SimplePie $data Data to store in the cache. If passed a SimplePie object, only cache the $data property
         * @return bool Successfulness
         */
        public function save($data)
        {
        }
        /**
         * Retrieve the data saved to the cache
         *
         * @return array Data for SimplePie::$data
         */
        public function load()
        {
        }
        /**
         * Retrieve the last modified time for the cache
         *
         * @return int Timestamp
         */
        public function mtime()
        {
        }
        /**
         * Set the last modified time to the current time
         *
         * @return bool Success status
         */
        public function touch()
        {
        }
        /**
         * Remove the cache
         *
         * @return bool Success status
         */
        public function unlink()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Cache\MySQL" instead */
    class SimplePie_Cache_MySQL extends \SimplePie\Cache\MySQL
    {
    }
}
namespace SimplePie\Cache {
    /**
     * Caches data to redis
     *
     * Registered for URLs with the "redis" protocol
     *
     * For example, `redis://localhost:6379/?timeout=3600&prefix=sp_&dbIndex=0` will
     * connect to redis on `localhost` on port 6379. All tables will be
     * prefixed with `simple_primary-` and data will expire after 3600 seconds
     *
     * @package SimplePie
     * @subpackage Caching
     * @uses Redis
     * @deprecated since SimplePie 1.8.0, use implementation of "Psr\SimpleCache\CacheInterface" instead
     */
    class Redis implements \SimplePie\Cache\Base
    {
        /**
         * Redis instance
         *
         * @var NativeRedis
         */
        protected $cache;
        /**
         * Options
         *
         * @var array
         */
        protected $options;
        /**
         * Cache name
         *
         * @var string
         */
        protected $name;
        /**
         * Create a new cache object
         *
         * @param string $location Location string (from SimplePie::$cache_location)
         * @param string $name Unique ID for the cache
         * @param Base::TYPE_FEED|Base::TYPE_IMAGE $type Either TYPE_FEED for SimplePie data, or TYPE_IMAGE for image data
         */
        public function __construct($location, $name, $options = null)
        {
        }
        /**
         * @param NativeRedis $cache
         */
        public function setRedisClient(\Redis $cache)
        {
        }
        /**
         * Save data to the cache
         *
         * @param array|\SimplePie\SimplePie $data Data to store in the cache. If passed a SimplePie object, only cache the $data property
         * @return bool Successfulness
         */
        public function save($data)
        {
        }
        /**
         * Retrieve the data saved to the cache
         *
         * @return array Data for SimplePie::$data
         */
        public function load()
        {
        }
        /**
         * Retrieve the last modified time for the cache
         *
         * @return int Timestamp
         */
        public function mtime()
        {
        }
        /**
         * Set the last modified time to the current time
         *
         * @return bool Success status
         */
        public function touch()
        {
        }
        /**
         * Remove the cache
         *
         * @return bool Success status
         */
        public function unlink()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Cache\Redis" instead */
    class SimplePie_Cache_Redis extends \SimplePie\Cache\Redis
    {
    }
}
namespace SimplePie {
    /**
     * Handles `<media:text>` captions as defined in Media RSS.
     *
     * Used by {@see \SimplePie\Enclosure::get_caption()} and {@see \SimplePie\Enclosure::get_captions()}
     *
     * This class can be overloaded with {@see \SimplePie\SimplePie::set_caption_class()}
     *
     * @package SimplePie
     * @subpackage API
     */
    class Caption
    {
        /**
         * Content type
         *
         * @var string
         * @see get_type()
         */
        public $type;
        /**
         * Language
         *
         * @var string
         * @see get_language()
         */
        public $lang;
        /**
         * Start time
         *
         * @var string
         * @see get_starttime()
         */
        public $startTime;
        /**
         * End time
         *
         * @var string
         * @see get_endtime()
         */
        public $endTime;
        /**
         * Caption text
         *
         * @var string
         * @see get_text()
         */
        public $text;
        /**
         * Constructor, used to input the data
         *
         * For documentation on all the parameters, see the corresponding
         * properties and their accessors
         */
        public function __construct($type = null, $lang = null, $startTime = null, $endTime = null, $text = null)
        {
        }
        /**
         * String-ified version
         *
         * @return string
         */
        public function __toString()
        {
        }
        /**
         * Get the end time
         *
         * @return string|null Time in the format 'hh:mm:ss.SSS'
         */
        public function get_endtime()
        {
        }
        /**
         * Get the language
         *
         * @link http://tools.ietf.org/html/rfc3066
         * @return string|null Language code as per RFC 3066
         */
        public function get_language()
        {
        }
        /**
         * Get the start time
         *
         * @return string|null Time in the format 'hh:mm:ss.SSS'
         */
        public function get_starttime()
        {
        }
        /**
         * Get the text of the caption
         *
         * @return string|null
         */
        public function get_text()
        {
        }
        /**
         * Get the content type (not MIME type)
         *
         * @return string|null Either 'text' or 'html'
         */
        public function get_type()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Caption" instead */
    class SimplePie_Caption extends \SimplePie\Caption
    {
    }
}
namespace SimplePie {
    /**
     * Manages all category-related data
     *
     * Used by {@see \SimplePie\Item::get_category()} and {@see \SimplePie\Item::get_categories()}
     *
     * This class can be overloaded with {@see \SimplePie\SimplePie::set_category_class()}
     *
     * @package SimplePie
     * @subpackage API
     */
    class Category
    {
        /**
         * Category identifier
         *
         * @var string|null
         * @see get_term
         */
        public $term;
        /**
         * Categorization scheme identifier
         *
         * @var string|null
         * @see get_scheme()
         */
        public $scheme;
        /**
         * Human readable label
         *
         * @var string|null
         * @see get_label()
         */
        public $label;
        /**
         * Category type
         *
         * category for <category>
         * subject for <dc:subject>
         *
         * @var string|null
         * @see get_type()
         */
        public $type;
        /**
         * Constructor, used to input the data
         *
         * @param string|null $term
         * @param string|null $scheme
         * @param string|null $label
         * @param string|null $type
         */
        public function __construct($term = null, $scheme = null, $label = null, $type = null)
        {
        }
        /**
         * String-ified version
         *
         * @return string
         */
        public function __toString()
        {
        }
        /**
         * Get the category identifier
         *
         * @return string|null
         */
        public function get_term()
        {
        }
        /**
         * Get the categorization scheme identifier
         *
         * @return string|null
         */
        public function get_scheme()
        {
        }
        /**
         * Get the human readable label
         *
         * @param bool $strict
         * @return string|null
         */
        public function get_label($strict = false)
        {
        }
        /**
         * Get the category type
         *
         * @return string|null
         */
        public function get_type()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Category" instead */
    class SimplePie_Category extends \SimplePie\Category
    {
    }
}
namespace SimplePie\Content\Type {
    /**
     * Content-type sniffing
     *
     * Based on the rules in http://tools.ietf.org/html/draft-abarth-mime-sniff-06
     *
     * This is used since we can't always trust Content-Type headers, and is based
     * upon the HTML5 parsing rules.
     *
     *
     * This class can be overloaded with {@see \SimplePie\SimplePie::set_content_type_sniffer_class()}
     *
     * @package SimplePie
     * @subpackage HTTP
     */
    class Sniffer
    {
        /**
         * File object
         *
         * @var \SimplePie\File
         */
        public $file;
        /**
         * Create an instance of the class with the input file
         *
         * @param Sniffer $file Input file
         */
        public function __construct($file)
        {
        }
        /**
         * Get the Content-Type of the specified file
         *
         * @return string Actual Content-Type
         */
        public function get_type()
        {
        }
        /**
         * Sniff text or binary
         *
         * @return string Actual Content-Type
         */
        public function text_or_binary()
        {
        }
        /**
         * Sniff unknown
         *
         * @return string Actual Content-Type
         */
        public function unknown()
        {
        }
        /**
         * Sniff images
         *
         * @return string Actual Content-Type
         */
        public function image()
        {
        }
        /**
         * Sniff HTML
         *
         * @return string Actual Content-Type
         */
        public function feed_or_html()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Content\Type\Sniffer" instead */
    class SimplePie_Content_Type_Sniffer extends \SimplePie\Content\Type\Sniffer
    {
    }
}
namespace SimplePie {
    /**
     * Manages `<media:copyright>` copyright tags as defined in Media RSS
     *
     * Used by {@see \SimplePie\Enclosure::get_copyright()}
     *
     * This class can be overloaded with {@see \SimplePie\SimplePie::set_copyright_class()}
     *
     * @package SimplePie
     * @subpackage API
     */
    class Copyright
    {
        /**
         * Copyright URL
         *
         * @var string
         * @see get_url()
         */
        public $url;
        /**
         * Attribution
         *
         * @var string
         * @see get_attribution()
         */
        public $label;
        /**
         * Constructor, used to input the data
         *
         * For documentation on all the parameters, see the corresponding
         * properties and their accessors
         */
        public function __construct($url = null, $label = null)
        {
        }
        /**
         * String-ified version
         *
         * @return string
         */
        public function __toString()
        {
        }
        /**
         * Get the copyright URL
         *
         * @return string|null URL to copyright information
         */
        public function get_url()
        {
        }
        /**
         * Get the attribution text
         *
         * @return string|null
         */
        public function get_attribution()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Copyright" instead */
    class SimplePie_Copyright extends \SimplePie\Copyright
    {
    }
    /**
     * SimplePie class.
     *
     * Class for backward compatibility.
     *
     * @deprecated Use {@see SimplePie} directly
     * @package SimplePie
     * @subpackage API
     */
    class SimplePie_Core extends \SimplePie
    {
    }
}
namespace SimplePie {
    /**
     * Handles `<media:credit>` as defined in Media RSS
     *
     * Used by {@see \SimplePie\Enclosure::get_credit()} and {@see \SimplePie\Enclosure::get_credits()}
     *
     * This class can be overloaded with {@see \SimplePie\SimplePie::set_credit_class()}
     *
     * @package SimplePie
     * @subpackage API
     */
    class Credit
    {
        /**
         * Credited role
         *
         * @var string
         * @see get_role()
         */
        public $role;
        /**
         * Organizational scheme
         *
         * @var string
         * @see get_scheme()
         */
        public $scheme;
        /**
         * Credited name
         *
         * @var string
         * @see get_name()
         */
        public $name;
        /**
         * Constructor, used to input the data
         *
         * For documentation on all the parameters, see the corresponding
         * properties and their accessors
         */
        public function __construct($role = null, $scheme = null, $name = null)
        {
        }
        /**
         * String-ified version
         *
         * @return string
         */
        public function __toString()
        {
        }
        /**
         * Get the role of the person receiving credit
         *
         * @return string|null
         */
        public function get_role()
        {
        }
        /**
         * Get the organizational scheme
         *
         * @return string|null
         */
        public function get_scheme()
        {
        }
        /**
         * Get the credited person/entity's name
         *
         * @return string|null
         */
        public function get_name()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Credit" instead */
    class SimplePie_Credit extends \SimplePie\Credit
    {
    }
    /**
     * Decode HTML Entities
     *
     * This implements HTML5 as of revision 967 (2007-06-28)
     *
     * @deprecated Use DOMDocument instead!
     * @package SimplePie
     */
    class SimplePie_Decode_HTML_Entities
    {
        /**
         * Data to be parsed
         *
         * @access private
         * @var string
         */
        public $data = '';
        /**
         * Currently consumed bytes
         *
         * @access private
         * @var string
         */
        public $consumed = '';
        /**
         * Position of the current byte being parsed
         *
         * @access private
         * @var int
         */
        public $position = 0;
        /**
         * Create an instance of the class with the input data
         *
         * @access public
         * @param string $data Input data
         */
        public function __construct($data)
        {
        }
        /**
         * Parse the input data
         *
         * @access public
         * @return string Output data
         */
        public function parse()
        {
        }
        /**
         * Consume the next byte
         *
         * @access private
         * @return mixed The next byte, or false, if there is no more data
         */
        public function consume()
        {
        }
        /**
         * Consume a range of characters
         *
         * @access private
         * @param string $chars Characters to consume
         * @return mixed A series of characters that match the range, or false
         */
        public function consume_range($chars)
        {
        }
        /**
         * Unconsume one byte
         *
         * @access private
         */
        public function unconsume()
        {
        }
        /**
         * Decode an entity
         *
         * @access private
         */
        public function entity()
        {
        }
    }
}
namespace SimplePie {
    /**
     * Handles everything related to enclosures (including Media RSS and iTunes RSS)
     *
     * Used by {@see \SimplePie\Item::get_enclosure()} and {@see \SimplePie\Item::get_enclosures()}
     *
     * This class can be overloaded with {@see \SimplePie\SimplePie::set_enclosure_class()}
     *
     * @package SimplePie
     * @subpackage API
     */
    class Enclosure
    {
        /**
         * @var string
         * @see get_bitrate()
         */
        public $bitrate;
        /**
         * @var array
         * @see get_captions()
         */
        public $captions;
        /**
         * @var array
         * @see get_categories()
         */
        public $categories;
        /**
         * @var int
         * @see get_channels()
         */
        public $channels;
        /**
         * @var \SimplePie\Copyright
         * @see get_copyright()
         */
        public $copyright;
        /**
         * @var array
         * @see get_credits()
         */
        public $credits;
        /**
         * @var string
         * @see get_description()
         */
        public $description;
        /**
         * @var int
         * @see get_duration()
         */
        public $duration;
        /**
         * @var string
         * @see get_expression()
         */
        public $expression;
        /**
         * @var string
         * @see get_framerate()
         */
        public $framerate;
        /**
         * @var string
         * @see get_handler()
         */
        public $handler;
        /**
         * @var array
         * @see get_hashes()
         */
        public $hashes;
        /**
         * @var string
         * @see get_height()
         */
        public $height;
        /**
         * @deprecated
         * @var null
         */
        public $javascript;
        /**
         * @var array
         * @see get_keywords()
         */
        public $keywords;
        /**
         * @var string
         * @see get_language()
         */
        public $lang;
        /**
         * @var string
         * @see get_length()
         */
        public $length;
        /**
         * @var string
         * @see get_link()
         */
        public $link;
        /**
         * @var string
         * @see get_medium()
         */
        public $medium;
        /**
         * @var string
         * @see get_player()
         */
        public $player;
        /**
         * @var array
         * @see get_ratings()
         */
        public $ratings;
        /**
         * @var array
         * @see get_restrictions()
         */
        public $restrictions;
        /**
         * @var string
         * @see get_sampling_rate()
         */
        public $samplingrate;
        /**
         * @var array
         * @see get_thumbnails()
         */
        public $thumbnails;
        /**
         * @var string
         * @see get_title()
         */
        public $title;
        /**
         * @var string
         * @see get_type()
         */
        public $type;
        /**
         * @var string
         * @see get_width()
         */
        public $width;
        /**
         * Constructor, used to input the data
         *
         * For documentation on all the parameters, see the corresponding
         * properties and their accessors
         *
         * @uses idna_convert If available, this will convert an IDN
         */
        public function __construct($link = null, $type = null, $length = null, $javascript = null, $bitrate = null, $captions = null, $categories = null, $channels = null, $copyright = null, $credits = null, $description = null, $duration = null, $expression = null, $framerate = null, $hashes = null, $height = null, $keywords = null, $lang = null, $medium = null, $player = null, $ratings = null, $restrictions = null, $samplingrate = null, $thumbnails = null, $title = null, $width = null)
        {
        }
        /**
         * String-ified version
         *
         * @return string
         */
        public function __toString()
        {
        }
        /**
         * Get the bitrate
         *
         * @return string|null
         */
        public function get_bitrate()
        {
        }
        /**
         * Get a single caption
         *
         * @param int $key
         * @return \SimplePie\Caption|null
         */
        public function get_caption($key = 0)
        {
        }
        /**
         * Get all captions
         *
         * @return array|null Array of {@see \SimplePie\Caption} objects
         */
        public function get_captions()
        {
        }
        /**
         * Get a single category
         *
         * @param int $key
         * @return \SimplePie\Category|null
         */
        public function get_category($key = 0)
        {
        }
        /**
         * Get all categories
         *
         * @return array|null Array of {@see \SimplePie\Category} objects
         */
        public function get_categories()
        {
        }
        /**
         * Get the number of audio channels
         *
         * @return int|null
         */
        public function get_channels()
        {
        }
        /**
         * Get the copyright information
         *
         * @return \SimplePie\Copyright|null
         */
        public function get_copyright()
        {
        }
        /**
         * Get a single credit
         *
         * @param int $key
         * @return \SimplePie\Credit|null
         */
        public function get_credit($key = 0)
        {
        }
        /**
         * Get all credits
         *
         * @return array|null Array of {@see \SimplePie\Credit} objects
         */
        public function get_credits()
        {
        }
        /**
         * Get the description of the enclosure
         *
         * @return string|null
         */
        public function get_description()
        {
        }
        /**
         * Get the duration of the enclosure
         *
         * @param bool $convert Convert seconds into hh:mm:ss
         * @return string|int|null 'hh:mm:ss' string if `$convert` was specified, otherwise integer (or null if none found)
         */
        public function get_duration($convert = false)
        {
        }
        /**
         * Get the expression
         *
         * @return string Probably one of 'sample', 'full', 'nonstop', 'clip'. Defaults to 'full'
         */
        public function get_expression()
        {
        }
        /**
         * Get the file extension
         *
         * @return string|null
         */
        public function get_extension()
        {
        }
        /**
         * Get the framerate (in frames-per-second)
         *
         * @return string|null
         */
        public function get_framerate()
        {
        }
        /**
         * Get the preferred handler
         *
         * @return string|null One of 'flash', 'fmedia', 'quicktime', 'wmedia', 'mp3'
         */
        public function get_handler()
        {
        }
        /**
         * Get a single hash
         *
         * @link http://www.rssboard.org/media-rss#media-hash
         * @param int $key
         * @return string|null Hash as per `media:hash`, prefixed with "$algo:"
         */
        public function get_hash($key = 0)
        {
        }
        /**
         * Get all credits
         *
         * @return array|null Array of strings, see {@see get_hash()}
         */
        public function get_hashes()
        {
        }
        /**
         * Get the height
         *
         * @return string|null
         */
        public function get_height()
        {
        }
        /**
         * Get the language
         *
         * @link http://tools.ietf.org/html/rfc3066
         * @return string|null Language code as per RFC 3066
         */
        public function get_language()
        {
        }
        /**
         * Get a single keyword
         *
         * @param int $key
         * @return string|null
         */
        public function get_keyword($key = 0)
        {
        }
        /**
         * Get all keywords
         *
         * @return array|null Array of strings
         */
        public function get_keywords()
        {
        }
        /**
         * Get length
         *
         * @return float Length in bytes
         */
        public function get_length()
        {
        }
        /**
         * Get the URL
         *
         * @return string|null
         */
        public function get_link()
        {
        }
        /**
         * Get the medium
         *
         * @link http://www.rssboard.org/media-rss#media-content
         * @return string|null Should be one of 'image', 'audio', 'video', 'document', 'executable'
         */
        public function get_medium()
        {
        }
        /**
         * Get the player URL
         *
         * Typically the same as {@see get_permalink()}
         * @return string|null Player URL
         */
        public function get_player()
        {
        }
        /**
         * Get a single rating
         *
         * @param int $key
         * @return \SimplePie\Rating|null
         */
        public function get_rating($key = 0)
        {
        }
        /**
         * Get all ratings
         *
         * @return array|null Array of {@see \SimplePie\Rating} objects
         */
        public function get_ratings()
        {
        }
        /**
         * Get a single restriction
         *
         * @param int $key
         * @return \SimplePie\Restriction|null
         */
        public function get_restriction($key = 0)
        {
        }
        /**
         * Get all restrictions
         *
         * @return array|null Array of {@see \SimplePie\Restriction} objects
         */
        public function get_restrictions()
        {
        }
        /**
         * Get the sampling rate (in kHz)
         *
         * @return string|null
         */
        public function get_sampling_rate()
        {
        }
        /**
         * Get the file size (in MiB)
         *
         * @return float|null File size in mebibytes (1048 bytes)
         */
        public function get_size()
        {
        }
        /**
         * Get a single thumbnail
         *
         * @param int $key
         * @return string|null Thumbnail URL
         */
        public function get_thumbnail($key = 0)
        {
        }
        /**
         * Get all thumbnails
         *
         * @return array|null Array of thumbnail URLs
         */
        public function get_thumbnails()
        {
        }
        /**
         * Get the title
         *
         * @return string|null
         */
        public function get_title()
        {
        }
        /**
         * Get mimetype of the enclosure
         *
         * @see get_real_type()
         * @return string|null MIME type
         */
        public function get_type()
        {
        }
        /**
         * Get the width
         *
         * @return string|null
         */
        public function get_width()
        {
        }
        /**
         * Embed the enclosure using `<embed>`
         *
         * @deprecated Use the second parameter to {@see embed} instead
         *
         * @param array|string $options See first parameter to {@see embed}
         * @return string HTML string to output
         */
        public function native_embed($options = '')
        {
        }
        /**
         * Embed the enclosure using Javascript
         *
         * `$options` is an array or comma-separated key:value string, with the
         * following properties:
         *
         * - `alt` (string): Alternate content for when an end-user does not have
         *    the appropriate handler installed or when a file type is
         *    unsupported. Can be any text or HTML. Defaults to blank.
         * - `altclass` (string): If a file type is unsupported, the end-user will
         *    see the alt text (above) linked directly to the content. That link
         *    will have this value as its class name. Defaults to blank.
         * - `audio` (string): This is an image that should be used as a
         *    placeholder for audio files before they're loaded (QuickTime-only).
         *    Can be any relative or absolute URL. Defaults to blank.
         * - `bgcolor` (string): The background color for the media, if not
         *    already transparent. Defaults to `#ffffff`.
         * - `height` (integer): The height of the embedded media. Accepts any
         *    numeric pixel value (such as `360`) or `auto`. Defaults to `auto`,
         *    and it is recommended that you use this default.
         * - `loop` (boolean): Do you want the media to loop when it's done?
         *    Defaults to `false`.
         * - `mediaplayer` (string): The location of the included
         *    `mediaplayer.swf` file. This allows for the playback of Flash Video
         *    (`.flv`) files, and is the default handler for non-Odeo MP3's.
         *    Defaults to blank.
         * - `video` (string): This is an image that should be used as a
         *    placeholder for video files before they're loaded (QuickTime-only).
         *    Can be any relative or absolute URL. Defaults to blank.
         * - `width` (integer): The width of the embedded media. Accepts any
         *    numeric pixel value (such as `480`) or `auto`. Defaults to `auto`,
         *    and it is recommended that you use this default.
         * - `widescreen` (boolean): Is the enclosure widescreen or standard?
         *    This applies only to video enclosures, and will automatically resize
         *    the content appropriately.  Defaults to `false`, implying 4:3 mode.
         *
         * Note: Non-widescreen (4:3) mode with `width` and `height` set to `auto`
         * will default to 480x360 video resolution.  Widescreen (16:9) mode with
         * `width` and `height` set to `auto` will default to 480x270 video resolution.
         *
         * @todo If the dimensions for media:content are defined, use them when width/height are set to 'auto'.
         * @param array|string $options Comma-separated key:value list, or array
         * @param bool $native Use `<embed>`
         * @return string HTML string to output
         */
        public function embed($options = '', $native = false)
        {
        }
        /**
         * Get the real media type
         *
         * Often, feeds lie to us, necessitating a bit of deeper inspection. This
         * converts types to their canonical representations based on the file
         * extension
         *
         * @see get_type()
         * @param bool $find_handler Internal use only, use {@see get_handler()} instead
         * @return string MIME type
         */
        public function get_real_type($find_handler = false)
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Enclosure" instead */
    class SimplePie_Enclosure extends \SimplePie\Enclosure
    {
    }
}
namespace SimplePie {
    /**
     * General SimplePie exception class
     *
     * @package SimplePie
     */
    class Exception extends \Exception
    {
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Exception" instead */
    class SimplePie_Exception extends \SimplePie\Exception
    {
    }
}
namespace SimplePie {
    /**
     * Used for fetching remote files and reading local files
     *
     * Supports HTTP 1.0 via cURL or fsockopen, with spotty HTTP 1.1 support
     *
     * This class can be overloaded with {@see \SimplePie\SimplePie::set_file_class()}
     *
     * @package SimplePie
     * @subpackage HTTP
     * @todo Move to properly supporting RFC2616 (HTTP/1.1)
     */
    class File
    {
        public $url;
        public $useragent;
        public $success = true;
        public $headers = [];
        public $body;
        public $status_code = 0;
        public $redirects = 0;
        public $error;
        public $method = \SimplePie\SimplePie::FILE_SOURCE_NONE;
        public $permanent_url;
        public function __construct($url, $timeout = 10, $redirects = 5, $headers = null, $useragent = null, $force_fsockopen = false, $curl_options = [])
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\File" instead */
    class SimplePie_File extends \SimplePie\File
    {
    }
}
namespace SimplePie\HTTP {
    /**
     * HTTP Response Parser
     *
     * @package SimplePie
     * @subpackage HTTP
     */
    class Parser
    {
        /**
         * HTTP Version
         *
         * @var float
         */
        public $http_version = 0.0;
        /**
         * Status code
         *
         * @var int
         */
        public $status_code = 0;
        /**
         * Reason phrase
         *
         * @var string
         */
        public $reason = '';
        /**
         * Key/value pairs of the headers
         *
         * @var array
         */
        public $headers = [];
        /**
         * Body of the response
         *
         * @var string
         */
        public $body = '';
        /**
         * Current state of the state machine
         *
         * @var self::STATE_*
         */
        protected $state = self::STATE_HTTP_VERSION;
        /**
         * Input data
         *
         * @var string
         */
        protected $data = '';
        /**
         * Input data length (to avoid calling strlen() everytime this is needed)
         *
         * @var int
         */
        protected $data_length = 0;
        /**
         * Current position of the pointer
         *
         * @var int
         */
        protected $position = 0;
        /**
         * Name of the hedaer currently being parsed
         *
         * @var string
         */
        protected $name = '';
        /**
         * Value of the hedaer currently being parsed
         *
         * @var string
         */
        protected $value = '';
        /**
         * Create an instance of the class with the input data
         *
         * @param string $data Input data
         */
        public function __construct($data)
        {
        }
        /**
         * Parse the input data
         *
         * @return bool true on success, false on failure
         */
        public function parse()
        {
        }
        /**
         * Check whether there is data beyond the pointer
         *
         * @return bool true if there is further data, false if not
         */
        protected function has_data()
        {
        }
        /**
         * See if the next character is LWS
         *
         * @return bool true if the next character is LWS, false if not
         */
        protected function is_linear_whitespace()
        {
        }
        /**
         * Parse the HTTP version
         */
        protected function http_version()
        {
        }
        /**
         * Parse the status code
         */
        protected function status()
        {
        }
        /**
         * Parse the reason phrase
         */
        protected function reason()
        {
        }
        /**
         * Deal with a new line, shifting data around as needed
         */
        protected function new_line()
        {
        }
        /**
         * Parse a header name
         */
        protected function name()
        {
        }
        /**
         * Parse LWS, replacing consecutive LWS characters with a single space
         */
        protected function linear_whitespace()
        {
        }
        /**
         * See what state to move to while within non-quoted header values
         */
        protected function value()
        {
        }
        /**
         * Parse a header value while outside quotes
         */
        protected function value_char()
        {
        }
        /**
         * See what state to move to while within quoted header values
         */
        protected function quote()
        {
        }
        /**
         * Parse a header value while within quotes
         */
        protected function quote_char()
        {
        }
        /**
         * Parse an escaped character within quotes
         */
        protected function quote_escaped()
        {
        }
        /**
         * Parse the body
         */
        protected function body()
        {
        }
        /**
         * Parsed a "Transfer-Encoding: chunked" body
         * @phpstan-return void
         */
        protected function chunked()
        {
        }
        /**
         * Prepare headers (take care of proxies headers)
         *
         * @param string  $headers Raw headers
         * @param integer $count   Redirection count. Default to 1.
         *
         * @return string
         */
        public static function prepareHeaders($headers, $count = 1)
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\HTTP\Parser" instead */
    class SimplePie_HTTP_Parser extends \SimplePie\HTTP\Parser
    {
    }
}
namespace SimplePie {
    /**
     * IRI parser/serialiser/normaliser
     *
     * @package SimplePie
     * @subpackage HTTP
     * @author Sam Sneddon
     * @author Steve Minutillo
     * @author Ryan McCue
     * @copyright 2007-2012 Sam Sneddon, Steve Minutillo, Ryan McCue
     * @license http://www.opensource.org/licenses/bsd-license.php
     */
    class IRI
    {
        /**
         * Scheme
         *
         * @var string
         */
        protected $scheme = null;
        /**
         * User Information
         *
         * @var string
         */
        protected $iuserinfo = null;
        /**
         * ihost
         *
         * @var string
         */
        protected $ihost = null;
        /**
         * Port
         *
         * @var string
         */
        protected $port = null;
        /**
         * ipath
         *
         * @var string
         */
        protected $ipath = '';
        /**
         * iquery
         *
         * @var string
         */
        protected $iquery = null;
        /**
         * ifragment
         *
         * @var string
         */
        protected $ifragment = null;
        /**
         * Normalization database
         *
         * Each key is the scheme, each value is an array with each key as the IRI
         * part and value as the default value for that part.
         */
        protected $normalization = ['acap' => ['port' => 674], 'dict' => ['port' => 2628], 'file' => ['ihost' => 'localhost'], 'http' => ['port' => 80, 'ipath' => '/'], 'https' => ['port' => 443, 'ipath' => '/']];
        /**
         * Return the entire IRI when you try and read the object as a string
         *
         * @return string
         */
        public function __toString()
        {
        }
        /**
         * Overload __set() to provide access via properties
         *
         * @param string $name Property name
         * @param mixed $value Property value
         */
        public function __set($name, $value)
        {
        }
        /**
         * Overload __get() to provide access via properties
         *
         * @param string $name Property name
         * @return mixed
         */
        public function __get($name)
        {
        }
        /**
         * Overload __isset() to provide access via properties
         *
         * @param string $name Property name
         * @return bool
         */
        public function __isset($name)
        {
        }
        /**
         * Overload __unset() to provide access via properties
         *
         * @param string $name Property name
         */
        public function __unset($name)
        {
        }
        /**
         * Create a new IRI object, from a specified string
         *
         * @param string $iri
         */
        public function __construct($iri = null)
        {
        }
        /**
         * Clean up
         */
        public function __destruct()
        {
        }
        /**
         * Create a new IRI object by resolving a relative IRI
         *
         * Returns false if $base is not absolute, otherwise an IRI.
         *
         * @param IRI|string $base (Absolute) Base IRI
         * @param IRI|string $relative Relative IRI
         * @return IRI|false
         */
        public static function absolutize($base, $relative)
        {
        }
        /**
         * Parse an IRI into scheme/authority/path/query/fragment segments
         *
         * @param string $iri
         * @return array
         */
        protected function parse_iri($iri)
        {
        }
        /**
         * Remove dot segments from a path
         *
         * @param string $input
         * @return string
         */
        protected function remove_dot_segments($input)
        {
        }
        /**
         * Replace invalid character with percent encoding
         *
         * @param string $string Input string
         * @param string $extra_chars Valid characters not in iunreserved or
         *                            iprivate (this is ASCII-only)
         * @param bool $iprivate Allow iprivate
         * @return string
         */
        protected function replace_invalid_with_pct_encoding($string, $extra_chars, $iprivate = false)
        {
        }
        /**
         * Callback function for preg_replace_callback.
         *
         * Removes sequences of percent encoded bytes that represent UTF-8
         * encoded characters in iunreserved
         *
         * @param array $match PCRE match
         * @return string Replacement
         */
        protected function remove_iunreserved_percent_encoded($match)
        {
        }
        protected function scheme_normalization()
        {
        }
        /**
         * Check if the object represents a valid IRI. This needs to be done on each
         * call as some things change depending on another part of the IRI.
         *
         * @return bool
         */
        public function is_valid()
        {
        }
        /**
         * Set the entire IRI. Returns true on success, false on failure (if there
         * are any invalid characters).
         *
         * @param string $iri
         * @return bool
         */
        public function set_iri($iri, $clear_cache = false)
        {
        }
        /**
         * Set the scheme. Returns true on success, false on failure (if there are
         * any invalid characters).
         *
         * @param string $scheme
         * @return bool
         */
        public function set_scheme($scheme)
        {
        }
        /**
         * Set the authority. Returns true on success, false on failure (if there are
         * any invalid characters).
         *
         * @param string $authority
         * @return bool
         */
        public function set_authority($authority, $clear_cache = false)
        {
        }
        /**
         * Set the iuserinfo.
         *
         * @param string $iuserinfo
         * @return bool
         */
        public function set_userinfo($iuserinfo)
        {
        }
        /**
         * Set the ihost. Returns true on success, false on failure (if there are
         * any invalid characters).
         *
         * @param string $ihost
         * @return bool
         */
        public function set_host($ihost)
        {
        }
        /**
         * Set the port. Returns true on success, false on failure (if there are
         * any invalid characters).
         *
         * @param string $port
         * @return bool
         */
        public function set_port($port)
        {
        }
        /**
         * Set the ipath.
         *
         * @param string $ipath
         * @return bool
         */
        public function set_path($ipath, $clear_cache = false)
        {
        }
        /**
         * Set the iquery.
         *
         * @param string $iquery
         * @return bool
         */
        public function set_query($iquery)
        {
        }
        /**
         * Set the ifragment.
         *
         * @param string $ifragment
         * @return bool
         */
        public function set_fragment($ifragment)
        {
        }
        /**
         * Convert an IRI to a URI (or parts thereof)
         *
         * @return string
         */
        public function to_uri($string)
        {
        }
        /**
         * Get the complete IRI
         *
         * @return string
         */
        public function get_iri()
        {
        }
        /**
         * Get the complete URI
         *
         * @return string
         */
        public function get_uri()
        {
        }
        /**
         * Get the complete iauthority
         *
         * @return string
         */
        protected function get_iauthority()
        {
        }
        /**
         * Get the complete authority
         *
         * @return string
         */
        protected function get_authority()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\IRI" instead */
    class SimplePie_IRI extends \SimplePie\IRI
    {
    }
}
namespace SimplePie {
    /**
     * Handles the injection of Registry into other class
     *
     * {@see \SimplePie\SimplePie::get_registry()}
     *
     * @package SimplePie
     */
    interface RegistryAware
    {
        /**
         * Set the Registry into the class
         *
         * @param Registry $registry
         *
         * @return void
         */
        public function set_registry(\SimplePie\Registry $registry);
    }
    /**
     * Manages all item-related data
     *
     * Used by {@see \SimplePie\SimplePie::get_item()} and {@see \SimplePie\SimplePie::get_items()}
     *
     * This class can be overloaded with {@see \SimplePie\SimplePie::set_item_class()}
     *
     * @package \SimplePie\SimplePie
     * @subpackage API
     */
    class Item implements \SimplePie\RegistryAware
    {
        /**
         * Parent feed
         *
         * @access private
         * @var \SimplePie\SimplePie
         */
        public $feed;
        /**
         * Raw data
         *
         * @access private
         * @var array
         */
        public $data = [];
        /**
         * Registry object
         *
         * @see set_registry
         * @var \SimplePie\Registry
         */
        protected $registry;
        /**
         * Create a new item object
         *
         * This is usually used by {@see \SimplePie\SimplePie::get_items} and
         * {@see \SimplePie\SimplePie::get_item}. Avoid creating this manually.
         *
         * @param \SimplePie\SimplePie $feed Parent feed
         * @param array $data Raw data
         */
        public function __construct($feed, $data)
        {
        }
        /**
         * Set the registry handler
         *
         * This is usually used by {@see \SimplePie\Registry::create}
         *
         * @since 1.3
         * @param \SimplePie\Registry $registry
         */
        public function set_registry(\SimplePie\Registry $registry)
        {
        }
        /**
         * Get a string representation of the item
         *
         * @return string
         */
        public function __toString()
        {
        }
        /**
         * Remove items that link back to this before destroying this object
         */
        public function __destruct()
        {
        }
        /**
         * Get data for an item-level element
         *
         * This method allows you to get access to ANY element/attribute that is a
         * sub-element of the item/entry tag.
         *
         * See {@see \SimplePie\SimplePie::get_feed_tags()} for a description of the return value
         *
         * @since 1.0
         * @see http://simplepie.org/wiki/faq/supported_xml_namespaces
         * @param string $namespace The URL of the XML namespace of the elements you're trying to access
         * @param string $tag Tag name
         * @return array
         */
        public function get_item_tags($namespace, $tag)
        {
        }
        /**
         * Get the base URL value.
         * Uses `<xml:base>`, or item link, or feed base URL.
         *
         * @param array $element
         * @return string
         */
        public function get_base($element = [])
        {
        }
        /**
         * Sanitize feed data
         *
         * @access private
         * @see \SimplePie\SimplePie::sanitize()
         * @param string $data Data to sanitize
         * @param int $type One of the \SimplePie\SimplePie::CONSTRUCT_* constants
         * @param string $base Base URL to resolve URLs against
         * @return string Sanitized data
         */
        public function sanitize($data, $type, $base = '')
        {
        }
        /**
         * Get the parent feed
         *
         * Note: this may not work as you think for multifeeds!
         *
         * @link http://simplepie.org/faq/typical_multifeed_gotchas#missing_data_from_feed
         * @since 1.0
         * @return \SimplePie\SimplePie
         */
        public function get_feed()
        {
        }
        /**
         * Get the unique identifier for the item
         *
         * This is usually used when writing code to check for new items in a feed.
         *
         * Uses `<atom:id>`, `<guid>`, `<dc:identifier>` or the `about` attribute
         * for RDF. If none of these are supplied (or `$hash` is true), creates an
         * MD5 hash based on the permalink, title and content.
         *
         * @since Beta 2
         * @param boolean $hash Should we force using a hash instead of the supplied ID?
         * @param string|false $fn User-supplied function to generate an hash
         * @return string|null
         */
        public function get_id($hash = false, $fn = 'md5')
        {
        }
        /**
         * Get the title of the item
         *
         * Uses `<atom:title>`, `<title>` or `<dc:title>`
         *
         * @since Beta 2 (previously called `get_item_title` since 0.8)
         * @return string|null
         */
        public function get_title()
        {
        }
        /**
         * Get the content for the item
         *
         * Prefers summaries over full content , but will return full content if a
         * summary does not exist.
         *
         * To prefer full content instead, use {@see get_content}
         *
         * Uses `<atom:summary>`, `<description>`, `<dc:description>` or
         * `<itunes:subtitle>`
         *
         * @since 0.8
         * @param boolean $description_only Should we avoid falling back to the content?
         * @return string|null
         */
        public function get_description($description_only = false)
        {
        }
        /**
         * Get the content for the item
         *
         * Prefers full content over summaries, but will return a summary if full
         * content does not exist.
         *
         * To prefer summaries instead, use {@see get_description}
         *
         * Uses `<atom:content>` or `<content:encoded>` (RSS 1.0 Content Module)
         *
         * @since 1.0
         * @param boolean $content_only Should we avoid falling back to the description?
         * @return string|null
         */
        public function get_content($content_only = false)
        {
        }
        /**
         * Get the media:thumbnail of the item
         *
         * Uses `<media:thumbnail>`
         *
         *
         * @return array|null
         */
        public function get_thumbnail()
        {
        }
        /**
         * Get a category for the item
         *
         * @since Beta 3 (previously called `get_categories()` since Beta 2)
         * @param int $key The category that you want to return.  Remember that arrays begin with 0, not 1
         * @return \SimplePie\Category|null
         */
        public function get_category($key = 0)
        {
        }
        /**
         * Get all categories for the item
         *
         * Uses `<atom:category>`, `<category>` or `<dc:subject>`
         *
         * @since Beta 3
         * @return \SimplePie\Category[]|null List of {@see \SimplePie\Category} objects
         */
        public function get_categories()
        {
        }
        /**
         * Get an author for the item
         *
         * @since Beta 2
         * @param int $key The author that you want to return.  Remember that arrays begin with 0, not 1
         * @return \SimplePie\Author|null
         */
        public function get_author($key = 0)
        {
        }
        /**
         * Get a contributor for the item
         *
         * @since 1.1
         * @param int $key The contrbutor that you want to return.  Remember that arrays begin with 0, not 1
         * @return \SimplePie\Author|null
         */
        public function get_contributor($key = 0)
        {
        }
        /**
         * Get all contributors for the item
         *
         * Uses `<atom:contributor>`
         *
         * @since 1.1
         * @return \SimplePie\Author[]|null List of {@see \SimplePie\Author} objects
         */
        public function get_contributors()
        {
        }
        /**
         * Get all authors for the item
         *
         * Uses `<atom:author>`, `<author>`, `<dc:creator>` or `<itunes:author>`
         *
         * @since Beta 2
         * @return \SimplePie\Author[]|null List of {@see \SimplePie\Author} objects
         */
        public function get_authors()
        {
        }
        /**
         * Get the copyright info for the item
         *
         * Uses `<atom:rights>` or `<dc:rights>`
         *
         * @since 1.1
         * @return string
         */
        public function get_copyright()
        {
        }
        /**
         * Get the posting date/time for the item
         *
         * Uses `<atom:published>`, `<atom:updated>`, `<atom:issued>`,
         * `<atom:modified>`, `<pubDate>` or `<dc:date>`
         *
         * Note: obeys PHP's timezone setting. To get a UTC date/time, use
         * {@see get_gmdate}
         *
         * @since Beta 2 (previously called `get_item_date` since 0.8)
         *
         * @param string $date_format Supports any PHP date format from {@see http://php.net/date} (empty for the raw data)
         * @return int|string|null
         */
        public function get_date($date_format = 'j F Y, g:i a')
        {
        }
        /**
         * Get the update date/time for the item
         *
         * Uses `<atom:updated>`
         *
         * Note: obeys PHP's timezone setting. To get a UTC date/time, use
         * {@see get_gmdate}
         *
         * @param string $date_format Supports any PHP date format from {@see http://php.net/date} (empty for the raw data)
         * @return int|string|null
         */
        public function get_updated_date($date_format = 'j F Y, g:i a')
        {
        }
        /**
         * Get the localized posting date/time for the item
         *
         * Returns the date formatted in the localized language. To display in
         * languages other than the server's default, you need to change the locale
         * with {@link http://php.net/setlocale setlocale()}. The available
         * localizations depend on which ones are installed on your web server.
         *
         * @since 1.0
         *
         * @param string $date_format Supports any PHP date format from {@see http://php.net/strftime} (empty for the raw data)
         * @return int|string|null
         */
        public function get_local_date($date_format = '%c')
        {
        }
        /**
         * Get the posting date/time for the item (UTC time)
         *
         * @see get_date
         * @param string $date_format Supports any PHP date format from {@see http://php.net/date}
         * @return int|string|null
         */
        public function get_gmdate($date_format = 'j F Y, g:i a')
        {
        }
        /**
         * Get the update date/time for the item (UTC time)
         *
         * @see get_updated_date
         * @param string $date_format Supports any PHP date format from {@see http://php.net/date}
         * @return int|string|null
         */
        public function get_updated_gmdate($date_format = 'j F Y, g:i a')
        {
        }
        /**
         * Get the permalink for the item
         *
         * Returns the first link available with a relationship of "alternate".
         * Identical to {@see get_link()} with key 0
         *
         * @see get_link
         * @since 0.8
         * @return string|null Permalink URL
         */
        public function get_permalink()
        {
        }
        /**
         * Get a single link for the item
         *
         * @since Beta 3
         * @param int $key The link that you want to return.  Remember that arrays begin with 0, not 1
         * @param string $rel The relationship of the link to return
         * @return string|null Link URL
         */
        public function get_link($key = 0, $rel = 'alternate')
        {
        }
        /**
         * Get all links for the item
         *
         * Uses `<atom:link>`, `<link>` or `<guid>`
         *
         * @since Beta 2
         * @param string $rel The relationship of links to return
         * @return array|null Links found for the item (strings)
         */
        public function get_links($rel = 'alternate')
        {
        }
        /**
         * Get an enclosure from the item
         *
         * Supports the <enclosure> RSS tag, as well as Media RSS and iTunes RSS.
         *
         * @since Beta 2
         * @todo Add ability to prefer one type of content over another (in a media group).
         * @param int $key The enclosure that you want to return.  Remember that arrays begin with 0, not 1
         * @return \SimplePie\Enclosure|null
         */
        public function get_enclosure($key = 0, $prefer = null)
        {
        }
        /**
         * Get all available enclosures (podcasts, etc.)
         *
         * Supports the <enclosure> RSS tag, as well as Media RSS and iTunes RSS.
         *
         * At this point, we're pretty much assuming that all enclosures for an item
         * are the same content.  Anything else is too complicated to
         * properly support.
         *
         * @since Beta 2
         * @todo Add support for end-user defined sorting of enclosures by type/handler (so we can prefer the faster-loading FLV over MP4).
         * @todo If an element exists at a level, but its value is empty, we should fall back to the value from the parent (if it exists).
         * @return \SimplePie\Enclosure[]|null List of \SimplePie\Enclosure items
         */
        public function get_enclosures()
        {
        }
        /**
         * Get the latitude coordinates for the item
         *
         * Compatible with the W3C WGS84 Basic Geo and GeoRSS specifications
         *
         * Uses `<geo:lat>` or `<georss:point>`
         *
         * @since 1.0
         * @link http://www.w3.org/2003/01/geo/ W3C WGS84 Basic Geo
         * @link http://www.georss.org/ GeoRSS
         * @return string|null
         */
        public function get_latitude()
        {
        }
        /**
         * Get the longitude coordinates for the item
         *
         * Compatible with the W3C WGS84 Basic Geo and GeoRSS specifications
         *
         * Uses `<geo:long>`, `<geo:lon>` or `<georss:point>`
         *
         * @since 1.0
         * @link http://www.w3.org/2003/01/geo/ W3C WGS84 Basic Geo
         * @link http://www.georss.org/ GeoRSS
         * @return string|null
         */
        public function get_longitude()
        {
        }
        /**
         * Get the `<atom:source>` for the item
         *
         * @since 1.1
         * @return \SimplePie\Source|null
         */
        public function get_source()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Item" instead */
    class SimplePie_Item extends \SimplePie\Item
    {
    }
}
namespace SimplePie {
    /**
     * Used for feed auto-discovery
     *
     *
     * This class can be overloaded with {@see \SimplePie\SimplePie::set_locator_class()}
     *
     * @package SimplePie
     */
    class Locator implements \SimplePie\RegistryAware
    {
        public $useragent;
        public $timeout;
        public $file;
        public $local = [];
        public $elsewhere = [];
        public $cached_entities = [];
        public $http_base;
        public $base;
        public $base_location = 0;
        public $checked_feeds = 0;
        public $max_checked_feeds = 10;
        public $force_fsockopen = false;
        public $curl_options = [];
        public $dom;
        protected $registry;
        public function __construct(\SimplePie\File $file, $timeout = 10, $useragent = null, $max_checked_feeds = 10, $force_fsockopen = false, $curl_options = [])
        {
        }
        public function set_registry(\SimplePie\Registry $registry)
        {
        }
        public function find($type = \SimplePie\SimplePie::LOCATOR_ALL, &$working = null)
        {
        }
        public function is_feed($file, $check_html = false)
        {
        }
        public function get_base()
        {
        }
        public function autodiscovery()
        {
        }
        protected function search_elements_by_tag($name, &$done, $feeds)
        {
        }
        public function get_links()
        {
        }
        public function get_rel_link($rel)
        {
        }
        public function extension(&$array)
        {
        }
        public function body(&$array)
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Locator" instead */
    class SimplePie_Locator extends \SimplePie\Locator
    {
    }
}
namespace SimplePie {
    /**
     * Miscellaneous utilities
     *
     * @package SimplePie
     */
    class Misc
    {
        public static function time_hms($seconds)
        {
        }
        public static function absolutize_url($relative, $base)
        {
        }
        /**
         * Get a HTML/XML element from a HTML string
         *
         * @deprecated since SimplePie 1.3, use DOMDocument instead (parsing HTML with regex is bad!)
         * @param string $realname Element name (including namespace prefix if applicable)
         * @param string $string HTML document
         * @return array
         */
        public static function get_element($realname, $string)
        {
        }
        public static function element_implode($element)
        {
        }
        public static function error($message, $level, $file, $line)
        {
        }
        public static function fix_protocol($url, $http = 1)
        {
        }
        /**
         * @deprecated since SimplePie 1.8.0, use PHP native array_replace_recursive() instead.
         */
        public static function array_merge_recursive($array1, $array2)
        {
        }
        public static function parse_url($url)
        {
        }
        public static function compress_parse_url($scheme = '', $authority = '', $path = '', $query = '', $fragment = '')
        {
        }
        public static function normalize_url($url)
        {
        }
        public static function percent_encoding_normalization($match)
        {
        }
        /**
         * Converts a Windows-1252 encoded string to a UTF-8 encoded string
         *
         * @static
         * @param string $string Windows-1252 encoded string
         * @return string UTF-8 encoded string
         */
        public static function windows_1252_to_utf8($string)
        {
        }
        /**
         * Change a string from one encoding to another
         *
         * @param string $data Raw data in $input encoding
         * @param string $input Encoding of $data
         * @param string $output Encoding you want
         * @return string|boolean False if we can't convert it
         */
        public static function change_encoding($data, $input, $output)
        {
        }
        protected static function change_encoding_mbstring($data, $input, $output)
        {
        }
        protected static function change_encoding_iconv($data, $input, $output)
        {
        }
        /**
         * @param string $data
         * @param string $input
         * @param string $output
         * @return string|false
         */
        protected static function change_encoding_uconverter($data, $input, $output)
        {
        }
        /**
         * Normalize an encoding name
         *
         * This is automatically generated by create.php
         *
         * To generate it, run `php create.php` on the command line, and copy the
         * output to replace this function.
         *
         * @param string $charset Character set to standardise
         * @return string Standardised name
         */
        public static function encoding($charset)
        {
        }
        public static function get_curl_version()
        {
        }
        /**
         * Strip HTML comments
         *
         * @param string $data Data to strip comments from
         * @return string Comment stripped string
         */
        public static function strip_comments($data)
        {
        }
        public static function parse_date($dt)
        {
        }
        /**
         * Decode HTML entities
         *
         * @deprecated since SimplePie 1.3, use DOMDocument instead
         * @param string $data Input data
         * @return string Output data
         */
        public static function entities_decode($data)
        {
        }
        /**
         * Remove RFC822 comments
         *
         * @param string $data Data to strip comments from
         * @return string Comment stripped string
         */
        public static function uncomment_rfc822($string)
        {
        }
        public static function parse_mime($mime)
        {
        }
        public static function atom_03_construct_type($attribs)
        {
        }
        public static function atom_10_construct_type($attribs)
        {
        }
        public static function atom_10_content_construct_type($attribs)
        {
        }
        public static function is_isegment_nz_nc($string)
        {
        }
        public static function space_separated_tokens($string)
        {
        }
        /**
         * Converts a unicode codepoint to a UTF-8 character
         *
         * @static
         * @param int $codepoint Unicode codepoint
         * @return string UTF-8 character
         */
        public static function codepoint_to_utf8($codepoint)
        {
        }
        /**
         * Similar to parse_str()
         *
         * Returns an associative array of name/value pairs, where the value is an
         * array of values that have used the same name
         *
         * @static
         * @param string $str The input string.
         * @return array
         */
        public static function parse_str($str)
        {
        }
        /**
         * Detect XML encoding, as per XML 1.0 Appendix F.1
         *
         * @todo Add support for EBCDIC
         * @param string $data XML data
         * @param \SimplePie\Registry $registry Class registry
         * @return array Possible encodings
         */
        public static function xml_encoding($data, $registry)
        {
        }
        public static function output_javascript()
        {
        }
        /**
         * Get the SimplePie build timestamp
         *
         * Uses the git index if it exists, otherwise uses the modification time
         * of the newest file.
         */
        public static function get_build()
        {
        }
        /**
         * Get the default user agent string
         *
         * @return string
         */
        public static function get_default_useragent()
        {
        }
        /**
         * Format debugging information
         */
        public static function debug(&$sp)
        {
        }
        public static function silence_errors($num, $str)
        {
        }
        /**
         * Sanitize a URL by removing HTTP credentials.
         * @param string $url the URL to sanitize.
         * @return string the same URL without HTTP credentials.
         */
        public static function url_remove_credentials($url)
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Misc" instead */
    class SimplePie_Misc extends \SimplePie\Misc
    {
    }
}
namespace SimplePie\Net {
    /**
     * Class to validate and to work with IPv6 addresses.
     *
     * @package SimplePie
     * @subpackage HTTP
     * @copyright 2003-2005 The PHP Group
     * @license http://www.opensource.org/licenses/bsd-license.php
     * @link http://pear.php.net/package/Net_IPv6
     * @author Alexander Merz <alexander.merz@web.de>
     * @author elfrink at introweb dot nl
     * @author Josh Peck <jmp at joshpeck dot org>
     * @author Sam Sneddon <geoffers@gmail.com>
     */
    class IPv6
    {
        /**
         * Uncompresses an IPv6 address
         *
         * RFC 4291 allows you to compress concecutive zero pieces in an address to
         * '::'. This method expects a valid IPv6 address and expands the '::' to
         * the required number of zero pieces.
         *
         * Example:  FF01::101   ->  FF01:0:0:0:0:0:0:101
         *           ::1         ->  0:0:0:0:0:0:0:1
         *
         * @author Alexander Merz <alexander.merz@web.de>
         * @author elfrink at introweb dot nl
         * @author Josh Peck <jmp at joshpeck dot org>
         * @copyright 2003-2005 The PHP Group
         * @license http://www.opensource.org/licenses/bsd-license.php
         * @param string $ip An IPv6 address
         * @return string The uncompressed IPv6 address
         */
        public static function uncompress($ip)
        {
        }
        /**
         * Compresses an IPv6 address
         *
         * RFC 4291 allows you to compress concecutive zero pieces in an address to
         * '::'. This method expects a valid IPv6 address and compresses consecutive
         * zero pieces to '::'.
         *
         * Example:  FF01:0:0:0:0:0:0:101   ->  FF01::101
         *           0:0:0:0:0:0:0:1        ->  ::1
         *
         * @see uncompress()
         * @param string $ip An IPv6 address
         * @return string The compressed IPv6 address
         */
        public static function compress($ip)
        {
        }
        /**
         * Checks an IPv6 address
         *
         * Checks if the given IP is a valid IPv6 address
         *
         * @param string $ip An IPv6 address
         * @return bool true if $ip is a valid IPv6 address
         */
        public static function check_ipv6($ip)
        {
        }
        /**
         * Checks if the given IP is a valid IPv6 address
         *
         * @codeCoverageIgnore
         * @deprecated Use {@see IPv6::check_ipv6()} instead
         * @see check_ipv6
         * @param string $ip An IPv6 address
         * @return bool true if $ip is a valid IPv6 address
         */
        public static function checkIPv6($ip)
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Net\IPv6" instead */
    class SimplePie_Net_IPv6 extends \SimplePie\Net\IPv6
    {
    }
}
namespace SimplePie\Parse {
    /**
     * Date Parser
     *
     * @package SimplePie
     * @subpackage Parsing
     */
    class Date
    {
        /**
         * Input data
         *
         * @access protected
         * @var string
         */
        public $date;
        /**
         * List of days, calendar day name => ordinal day number in the week
         *
         * @access protected
         * @var array
         */
        public $day = [
            // English
            'mon' => 1,
            'monday' => 1,
            'tue' => 2,
            'tuesday' => 2,
            'wed' => 3,
            'wednesday' => 3,
            'thu' => 4,
            'thursday' => 4,
            'fri' => 5,
            'friday' => 5,
            'sat' => 6,
            'saturday' => 6,
            'sun' => 7,
            'sunday' => 7,
            // Dutch
            'maandag' => 1,
            'dinsdag' => 2,
            'woensdag' => 3,
            'donderdag' => 4,
            'vrijdag' => 5,
            'zaterdag' => 6,
            'zondag' => 7,
            // French
            'lundi' => 1,
            'mardi' => 2,
            'mercredi' => 3,
            'jeudi' => 4,
            'vendredi' => 5,
            'samedi' => 6,
            'dimanche' => 7,
            // German
            'montag' => 1,
            'mo' => 1,
            'dienstag' => 2,
            'di' => 2,
            'mittwoch' => 3,
            'mi' => 3,
            'donnerstag' => 4,
            'do' => 4,
            'freitag' => 5,
            'fr' => 5,
            'samstag' => 6,
            'sa' => 6,
            'sonnabend' => 6,
            // AFAIK no short form for sonnabend
            'so' => 7,
            'sonntag' => 7,
            // Italian
            'lunedì' => 1,
            'martedì' => 2,
            'mercoledì' => 3,
            'giovedì' => 4,
            'venerdì' => 5,
            'sabato' => 6,
            'domenica' => 7,
            // Spanish
            'lunes' => 1,
            'martes' => 2,
            'miércoles' => 3,
            'jueves' => 4,
            'viernes' => 5,
            'sábado' => 6,
            'domingo' => 7,
            // Finnish
            'maanantai' => 1,
            'tiistai' => 2,
            'keskiviikko' => 3,
            'torstai' => 4,
            'perjantai' => 5,
            'lauantai' => 6,
            'sunnuntai' => 7,
            // Hungarian
            'hétfő' => 1,
            'kedd' => 2,
            'szerda' => 3,
            'csütörtok' => 4,
            'péntek' => 5,
            'szombat' => 6,
            'vasárnap' => 7,
            // Greek
            'Δευ' => 1,
            'Τρι' => 2,
            'Τετ' => 3,
            'Πεμ' => 4,
            'Παρ' => 5,
            'Σαβ' => 6,
            'Κυρ' => 7,
            // Russian
            'Пн.' => 1,
            'Вт.' => 2,
            'Ср.' => 3,
            'Чт.' => 4,
            'Пт.' => 5,
            'Сб.' => 6,
            'Вс.' => 7,
        ];
        /**
         * List of months, calendar month name => calendar month number
         *
         * @access protected
         * @var array
         */
        public $month = [
            // English
            'jan' => 1,
            'january' => 1,
            'feb' => 2,
            'february' => 2,
            'mar' => 3,
            'march' => 3,
            'apr' => 4,
            'april' => 4,
            'may' => 5,
            // No long form of May
            'jun' => 6,
            'june' => 6,
            'jul' => 7,
            'july' => 7,
            'aug' => 8,
            'august' => 8,
            'sep' => 9,
            'september' => 9,
            'oct' => 10,
            'october' => 10,
            'nov' => 11,
            'november' => 11,
            'dec' => 12,
            'december' => 12,
            // Dutch
            'januari' => 1,
            'februari' => 2,
            'maart' => 3,
            'april' => 4,
            'mei' => 5,
            'juni' => 6,
            'juli' => 7,
            'augustus' => 8,
            'september' => 9,
            'oktober' => 10,
            'november' => 11,
            'december' => 12,
            // French
            'janvier' => 1,
            'février' => 2,
            'mars' => 3,
            'avril' => 4,
            'mai' => 5,
            'juin' => 6,
            'juillet' => 7,
            'août' => 8,
            'septembre' => 9,
            'octobre' => 10,
            'novembre' => 11,
            'décembre' => 12,
            // German
            'januar' => 1,
            'jan' => 1,
            'februar' => 2,
            'feb' => 2,
            'märz' => 3,
            'mär' => 3,
            'april' => 4,
            'apr' => 4,
            'mai' => 5,
            // no short form for may
            'juni' => 6,
            'jun' => 6,
            'juli' => 7,
            'jul' => 7,
            'august' => 8,
            'aug' => 8,
            'september' => 9,
            'sep' => 9,
            'oktober' => 10,
            'okt' => 10,
            'november' => 11,
            'nov' => 11,
            'dezember' => 12,
            'dez' => 12,
            // Italian
            'gennaio' => 1,
            'febbraio' => 2,
            'marzo' => 3,
            'aprile' => 4,
            'maggio' => 5,
            'giugno' => 6,
            'luglio' => 7,
            'agosto' => 8,
            'settembre' => 9,
            'ottobre' => 10,
            'novembre' => 11,
            'dicembre' => 12,
            // Spanish
            'enero' => 1,
            'febrero' => 2,
            'marzo' => 3,
            'abril' => 4,
            'mayo' => 5,
            'junio' => 6,
            'julio' => 7,
            'agosto' => 8,
            'septiembre' => 9,
            'setiembre' => 9,
            'octubre' => 10,
            'noviembre' => 11,
            'diciembre' => 12,
            // Finnish
            'tammikuu' => 1,
            'helmikuu' => 2,
            'maaliskuu' => 3,
            'huhtikuu' => 4,
            'toukokuu' => 5,
            'kesäkuu' => 6,
            'heinäkuu' => 7,
            'elokuu' => 8,
            'suuskuu' => 9,
            'lokakuu' => 10,
            'marras' => 11,
            'joulukuu' => 12,
            // Hungarian
            'január' => 1,
            'február' => 2,
            'március' => 3,
            'április' => 4,
            'május' => 5,
            'június' => 6,
            'július' => 7,
            'augusztus' => 8,
            'szeptember' => 9,
            'október' => 10,
            'november' => 11,
            'december' => 12,
            // Greek
            'Ιαν' => 1,
            'Φεβ' => 2,
            'Μάώ' => 3,
            'Μαώ' => 3,
            'Απρ' => 4,
            'Μάι' => 5,
            'Μαϊ' => 5,
            'Μαι' => 5,
            'Ιούν' => 6,
            'Ιον' => 6,
            'Ιούλ' => 7,
            'Ιολ' => 7,
            'Αύγ' => 8,
            'Αυγ' => 8,
            'Σεπ' => 9,
            'Οκτ' => 10,
            'Νοέ' => 11,
            'Δεκ' => 12,
            // Russian
            'Янв' => 1,
            'января' => 1,
            'Фев' => 2,
            'февраля' => 2,
            'Мар' => 3,
            'марта' => 3,
            'Апр' => 4,
            'апреля' => 4,
            'Май' => 5,
            'мая' => 5,
            'Июн' => 6,
            'июня' => 6,
            'Июл' => 7,
            'июля' => 7,
            'Авг' => 8,
            'августа' => 8,
            'Сен' => 9,
            'сентября' => 9,
            'Окт' => 10,
            'октября' => 10,
            'Ноя' => 11,
            'ноября' => 11,
            'Дек' => 12,
            'декабря' => 12,
        ];
        /**
         * List of timezones, abbreviation => offset from UTC
         *
         * @access protected
         * @var array
         */
        public $timezone = ['ACDT' => 37800, 'ACIT' => 28800, 'ACST' => 34200, 'ACT' => -18000, 'ACWDT' => 35100, 'ACWST' => 31500, 'AEDT' => 39600, 'AEST' => 36000, 'AFT' => 16200, 'AKDT' => -28800, 'AKST' => -32400, 'AMDT' => 18000, 'AMT' => -14400, 'ANAST' => 46800, 'ANAT' => 43200, 'ART' => -10800, 'AZOST' => -3600, 'AZST' => 18000, 'AZT' => 14400, 'BIOT' => 21600, 'BIT' => -43200, 'BOT' => -14400, 'BRST' => -7200, 'BRT' => -10800, 'BST' => 3600, 'BTT' => 21600, 'CAST' => 18000, 'CAT' => 7200, 'CCT' => 23400, 'CDT' => -18000, 'CEDT' => 7200, 'CEST' => 7200, 'CET' => 3600, 'CGST' => -7200, 'CGT' => -10800, 'CHADT' => 49500, 'CHAST' => 45900, 'CIST' => -28800, 'CKT' => -36000, 'CLDT' => -10800, 'CLST' => -14400, 'COT' => -18000, 'CST' => -21600, 'CVT' => -3600, 'CXT' => 25200, 'DAVT' => 25200, 'DTAT' => 36000, 'EADT' => -18000, 'EAST' => -21600, 'EAT' => 10800, 'ECT' => -18000, 'EDT' => -14400, 'EEST' => 10800, 'EET' => 7200, 'EGT' => -3600, 'EKST' => 21600, 'EST' => -18000, 'FJT' => 43200, 'FKDT' => -10800, 'FKST' => -14400, 'FNT' => -7200, 'GALT' => -21600, 'GEDT' => 14400, 'GEST' => 10800, 'GFT' => -10800, 'GILT' => 43200, 'GIT' => -32400, 'GST' => 14400, 'GST' => -7200, 'GYT' => -14400, 'HAA' => -10800, 'HAC' => -18000, 'HADT' => -32400, 'HAE' => -14400, 'HAP' => -25200, 'HAR' => -21600, 'HAST' => -36000, 'HAT' => -9000, 'HAY' => -28800, 'HKST' => 28800, 'HMT' => 18000, 'HNA' => -14400, 'HNC' => -21600, 'HNE' => -18000, 'HNP' => -28800, 'HNR' => -25200, 'HNT' => -12600, 'HNY' => -32400, 'IRDT' => 16200, 'IRKST' => 32400, 'IRKT' => 28800, 'IRST' => 12600, 'JFDT' => -10800, 'JFST' => -14400, 'JST' => 32400, 'KGST' => 21600, 'KGT' => 18000, 'KOST' => 39600, 'KOVST' => 28800, 'KOVT' => 25200, 'KRAST' => 28800, 'KRAT' => 25200, 'KST' => 32400, 'LHDT' => 39600, 'LHST' => 37800, 'LINT' => 50400, 'LKT' => 21600, 'MAGST' => 43200, 'MAGT' => 39600, 'MAWT' => 21600, 'MDT' => -21600, 'MESZ' => 7200, 'MEZ' => 3600, 'MHT' => 43200, 'MIT' => -34200, 'MNST' => 32400, 'MSDT' => 14400, 'MSST' => 10800, 'MST' => -25200, 'MUT' => 14400, 'MVT' => 18000, 'MYT' => 28800, 'NCT' => 39600, 'NDT' => -9000, 'NFT' => 41400, 'NMIT' => 36000, 'NOVST' => 25200, 'NOVT' => 21600, 'NPT' => 20700, 'NRT' => 43200, 'NST' => -12600, 'NUT' => -39600, 'NZDT' => 46800, 'NZST' => 43200, 'OMSST' => 25200, 'OMST' => 21600, 'PDT' => -25200, 'PET' => -18000, 'PETST' => 46800, 'PETT' => 43200, 'PGT' => 36000, 'PHOT' => 46800, 'PHT' => 28800, 'PKT' => 18000, 'PMDT' => -7200, 'PMST' => -10800, 'PONT' => 39600, 'PST' => -28800, 'PWT' => 32400, 'PYST' => -10800, 'PYT' => -14400, 'RET' => 14400, 'ROTT' => -10800, 'SAMST' => 18000, 'SAMT' => 14400, 'SAST' => 7200, 'SBT' => 39600, 'SCDT' => 46800, 'SCST' => 43200, 'SCT' => 14400, 'SEST' => 3600, 'SGT' => 28800, 'SIT' => 28800, 'SRT' => -10800, 'SST' => -39600, 'SYST' => 10800, 'SYT' => 7200, 'TFT' => 18000, 'THAT' => -36000, 'TJT' => 18000, 'TKT' => -36000, 'TMT' => 18000, 'TOT' => 46800, 'TPT' => 32400, 'TRUT' => 36000, 'TVT' => 43200, 'TWT' => 28800, 'UYST' => -7200, 'UYT' => -10800, 'UZT' => 18000, 'VET' => -14400, 'VLAST' => 39600, 'VLAT' => 36000, 'VOST' => 21600, 'VUT' => 39600, 'WAST' => 7200, 'WAT' => 3600, 'WDT' => 32400, 'WEST' => 3600, 'WFT' => 43200, 'WIB' => 25200, 'WIT' => 32400, 'WITA' => 28800, 'WKST' => 18000, 'WST' => 28800, 'YAKST' => 36000, 'YAKT' => 32400, 'YAPT' => 36000, 'YEKST' => 21600, 'YEKT' => 18000];
        /**
         * Cached PCRE for Date::$day
         *
         * @access protected
         * @var string
         */
        public $day_pcre;
        /**
         * Cached PCRE for Date::$month
         *
         * @access protected
         * @var string
         */
        public $month_pcre;
        /**
         * Array of user-added callback methods
         *
         * @access private
         * @var array
         */
        public $built_in = [];
        /**
         * Array of user-added callback methods
         *
         * @access private
         * @var array
         */
        public $user = [];
        /**
         * Create new Date object, and set self::day_pcre,
         * self::month_pcre, and self::built_in
         *
         * @access private
         */
        public function __construct()
        {
        }
        /**
         * Get the object
         *
         * @access public
         */
        public static function get()
        {
        }
        /**
         * Parse a date
         *
         * @final
         * @access public
         * @param string $date Date to parse
         * @return int Timestamp corresponding to date string, or false on failure
         */
        public function parse($date)
        {
        }
        /**
         * Add a callback method to parse a date
         *
         * @final
         * @access public
         * @param callable $callback
         */
        public function add_callback($callback)
        {
        }
        /**
         * Parse a superset of W3C-DTF (allows hyphens and colons to be omitted, as
         * well as allowing any of upper or lower case "T", horizontal tabs, or
         * spaces to be used as the time separator (including more than one))
         *
         * @access protected
         * @return int Timestamp
         */
        public function date_w3cdtf($date)
        {
        }
        /**
         * Remove RFC822 comments
         *
         * @access protected
         * @param string $data Data to strip comments from
         * @return string Comment stripped string
         */
        public function remove_rfc2822_comments($string)
        {
        }
        /**
         * Parse RFC2822's date format
         *
         * @access protected
         * @return int Timestamp
         */
        public function date_rfc2822($date)
        {
        }
        /**
         * Parse RFC850's date format
         *
         * @access protected
         * @return int Timestamp
         */
        public function date_rfc850($date)
        {
        }
        /**
         * Parse C99's asctime()'s date format
         *
         * @access protected
         * @return int Timestamp
         */
        public function date_asctime($date)
        {
        }
        /**
         * Parse dates using strtotime()
         *
         * @access protected
         * @return int Timestamp
         */
        public function date_strtotime($date)
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Parse\Date" instead */
    class SimplePie_Parse_Date extends \SimplePie\Parse\Date
    {
    }
}
namespace SimplePie {
    /**
     * Parses XML into something sane
     *
     *
     * This class can be overloaded with {@see \SimplePie\SimplePie::set_parser_class()}
     *
     * @package SimplePie
     * @subpackage Parsing
     */
    class Parser implements \SimplePie\RegistryAware
    {
        public $error_code;
        public $error_string;
        public $current_line;
        public $current_column;
        public $current_byte;
        public $separator = ' ';
        public $namespace = [''];
        public $element = [''];
        public $xml_base = [''];
        public $xml_base_explicit = [false];
        public $xml_lang = [''];
        public $data = [];
        public $datas = [[]];
        public $current_xhtml_construct = -1;
        public $encoding;
        protected $registry;
        public function set_registry(\SimplePie\Registry $registry)
        {
        }
        public function parse(&$data, $encoding, $url = '')
        {
        }
        public function get_error_code()
        {
        }
        public function get_error_string()
        {
        }
        public function get_current_line()
        {
        }
        public function get_current_column()
        {
        }
        public function get_current_byte()
        {
        }
        public function get_data()
        {
        }
        public function tag_open($parser, $tag, $attributes)
        {
        }
        public function cdata($parser, $cdata)
        {
        }
        public function tag_close($parser, $tag)
        {
        }
        public function split_ns($string)
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Parser" instead */
    class SimplePie_Parser extends \SimplePie\Parser
    {
    }
}
namespace SimplePie {
    /**
     * Handles `<media:rating>` or `<itunes:explicit>` tags as defined in Media RSS and iTunes RSS respectively
     *
     * Used by {@see \SimplePie\Enclosure::get_rating()} and {@see \SimplePie\Enclosure::get_ratings()}
     *
     * This class can be overloaded with {@see \SimplePie\SimplePie::set_rating_class()}
     *
     * @package SimplePie
     * @subpackage API
     */
    class Rating
    {
        /**
         * Rating scheme
         *
         * @var string
         * @see get_scheme()
         */
        public $scheme;
        /**
         * Rating value
         *
         * @var string
         * @see get_value()
         */
        public $value;
        /**
         * Constructor, used to input the data
         *
         * For documentation on all the parameters, see the corresponding
         * properties and their accessors
         */
        public function __construct($scheme = null, $value = null)
        {
        }
        /**
         * String-ified version
         *
         * @return string
         */
        public function __toString()
        {
        }
        /**
         * Get the organizational scheme for the rating
         *
         * @return string|null
         */
        public function get_scheme()
        {
        }
        /**
         * Get the value of the rating
         *
         * @return string|null
         */
        public function get_value()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Rating" instead */
    class SimplePie_Rating extends \SimplePie\Rating
    {
    }
}
namespace SimplePie {
    /**
     * Handles creating objects and calling methods
     *
     * Access this via {@see \SimplePie\SimplePie::get_registry()}
     *
     * @package SimplePie
     */
    class Registry
    {
        /**
         * Default class mapping
         *
         * Overriding classes *must* subclass these.
         *
         * @var array<class-string, class-string>
         */
        protected $default = [\SimplePie\Cache::class => \SimplePie\Cache::class, \SimplePie\Locator::class => \SimplePie\Locator::class, \SimplePie\Parser::class => \SimplePie\Parser::class, \SimplePie\File::class => \SimplePie\File::class, \SimplePie\Sanitize::class => \SimplePie\Sanitize::class, \SimplePie\Item::class => \SimplePie\Item::class, \SimplePie\Author::class => \SimplePie\Author::class, \SimplePie\Category::class => \SimplePie\Category::class, \SimplePie\Enclosure::class => \SimplePie\Enclosure::class, \SimplePie\Caption::class => \SimplePie\Caption::class, \SimplePie\Copyright::class => \SimplePie\Copyright::class, \SimplePie\Credit::class => \SimplePie\Credit::class, \SimplePie\Rating::class => \SimplePie\Rating::class, \SimplePie\Restriction::class => \SimplePie\Restriction::class, \SimplePie\Content\Type\Sniffer::class => \SimplePie\Content\Type\Sniffer::class, \SimplePie\Source::class => \SimplePie\Source::class, \SimplePie\Misc::class => \SimplePie\Misc::class, \SimplePie\XML\Declaration\Parser::class => \SimplePie\XML\Declaration\Parser::class, \SimplePie\Parse\Date::class => \SimplePie\Parse\Date::class];
        /**
         * Class mapping
         *
         * @see register()
         * @var array
         */
        protected $classes = [];
        /**
         * Legacy classes
         *
         * @see register()
         * @var array<class-string>
         */
        protected $legacy = [];
        /**
         * Constructor
         *
         * No-op
         */
        public function __construct()
        {
        }
        /**
         * Register a class
         *
         * @param string $type See {@see $default} for names
         * @param class-string $class Class name, must subclass the corresponding default
         * @param bool $legacy Whether to enable legacy support for this class
         * @return bool Successfulness
         */
        public function register($type, $class, $legacy = false)
        {
        }
        /**
         * Get the class registered for a type
         *
         * Where possible, use {@see create()} or {@see call()} instead
         *
         * @template T
         * @param class-string<T> $type
         * @return class-string<T>|null
         */
        public function get_class($type)
        {
        }
        /**
         * Create a new instance of a given type
         *
         * @template T class-string $type
         * @param class-string<T> $type
         * @param array $parameters Parameters to pass to the constructor
         * @return T Instance of class
         */
        public function &create($type, $parameters = [])
        {
        }
        /**
         * Call a static method for a type
         *
         * @param class-string $type
         * @param string $method
         * @param array $parameters
         * @return mixed
         */
        public function &call($type, $method, $parameters = [])
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Registry" instead */
    class SimplePie_Registry extends \SimplePie\Registry
    {
    }
}
namespace SimplePie {
    /**
     * Handles `<media:restriction>` as defined in Media RSS
     *
     * Used by {@see \SimplePie\Enclosure::get_restriction()} and {@see \SimplePie\Enclosure::get_restrictions()}
     *
     * This class can be overloaded with {@see \SimplePie\SimplePie::set_restriction_class()}
     *
     * @package SimplePie
     * @subpackage API
     */
    class Restriction
    {
        /**
         * Relationship ('allow'/'deny')
         *
         * @var string
         * @see get_relationship()
         */
        public $relationship;
        /**
         * Type of restriction
         *
         * @var string
         * @see get_type()
         */
        public $type;
        /**
         * Restricted values
         *
         * @var string
         * @see get_value()
         */
        public $value;
        /**
         * Constructor, used to input the data
         *
         * For documentation on all the parameters, see the corresponding
         * properties and their accessors
         */
        public function __construct($relationship = null, $type = null, $value = null)
        {
        }
        /**
         * String-ified version
         *
         * @return string
         */
        public function __toString()
        {
        }
        /**
         * Get the relationship
         *
         * @return string|null Either 'allow' or 'deny'
         */
        public function get_relationship()
        {
        }
        /**
         * Get the type
         *
         * @return string|null
         */
        public function get_type()
        {
        }
        /**
         * Get the list of restricted things
         *
         * @return string|null
         */
        public function get_value()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Restriction" instead */
    class SimplePie_Restriction extends \SimplePie\Restriction
    {
    }
}
namespace SimplePie {
    /**
     * Used for data cleanup and post-processing
     *
     *
     * This class can be overloaded with {@see \SimplePie\SimplePie::set_sanitize_class()}
     *
     * @package SimplePie
     * @todo Move to using an actual HTML parser (this will allow tags to be properly stripped, and to switch between HTML and XHTML), this will also make it easier to shorten a string while preserving HTML tags
     */
    class Sanitize implements \SimplePie\RegistryAware
    {
        public $base;
        public $remove_div = true;
        public $image_handler = '';
        public $strip_htmltags = ['base', 'blink', 'body', 'doctype', 'embed', 'font', 'form', 'frame', 'frameset', 'html', 'iframe', 'input', 'marquee', 'meta', 'noscript', 'object', 'param', 'script', 'style'];
        public $encode_instead_of_strip = false;
        public $strip_attributes = ['bgsound', 'expr', 'id', 'style', 'onclick', 'onerror', 'onfinish', 'onmouseover', 'onmouseout', 'onfocus', 'onblur', 'lowsrc', 'dynsrc'];
        public $rename_attributes = [];
        public $add_attributes = ['audio' => ['preload' => 'none'], 'iframe' => ['sandbox' => 'allow-scripts allow-same-origin'], 'video' => ['preload' => 'none']];
        public $strip_comments = false;
        public $output_encoding = 'UTF-8';
        public $enable_cache = true;
        public $cache_location = './cache';
        public $cache_name_function = 'md5';
        public $timeout = 10;
        public $useragent = '';
        public $force_fsockopen = false;
        public $replace_url_attributes = null;
        public $registry;
        /**
         * List of domains for which to force HTTPS.
         * @see \SimplePie\Sanitize::set_https_domains()
         * Array is a tree split at DNS levels. Example:
         * array('biz' => true, 'com' => array('example' => true), 'net' => array('example' => array('www' => true)))
         */
        public $https_domains = [];
        public function __construct()
        {
        }
        public function remove_div($enable = true)
        {
        }
        public function set_image_handler($page = false)
        {
        }
        public function set_registry(\SimplePie\Registry $registry)
        {
        }
        public function pass_cache_data($enable_cache = true, $cache_location = './cache', $cache_name_function = 'md5', $cache_class = 'SimplePie\\Cache', ?\SimplePie\Cache\DataCache $cache = null)
        {
        }
        public function pass_file_data($file_class = 'SimplePie\\File', $timeout = 10, $useragent = '', $force_fsockopen = false)
        {
        }
        public function strip_htmltags($tags = ['base', 'blink', 'body', 'doctype', 'embed', 'font', 'form', 'frame', 'frameset', 'html', 'iframe', 'input', 'marquee', 'meta', 'noscript', 'object', 'param', 'script', 'style'])
        {
        }
        public function encode_instead_of_strip($encode = false)
        {
        }
        public function rename_attributes($attribs = [])
        {
        }
        public function strip_attributes($attribs = ['bgsound', 'expr', 'id', 'style', 'onclick', 'onerror', 'onfinish', 'onmouseover', 'onmouseout', 'onfocus', 'onblur', 'lowsrc', 'dynsrc'])
        {
        }
        public function add_attributes($attribs = ['audio' => ['preload' => 'none'], 'iframe' => ['sandbox' => 'allow-scripts allow-same-origin'], 'video' => ['preload' => 'none']])
        {
        }
        public function strip_comments($strip = false)
        {
        }
        public function set_output_encoding($encoding = 'UTF-8')
        {
        }
        /**
         * Set element/attribute key/value pairs of HTML attributes
         * containing URLs that need to be resolved relative to the feed
         *
         * Defaults to |a|@href, |area|@href, |audio|@src, |blockquote|@cite,
         * |del|@cite, |form|@action, |img|@longdesc, |img|@src, |input|@src,
         * |ins|@cite, |q|@cite, |source|@src, |video|@src
         *
         * @since 1.0
         * @param array|null $element_attribute Element/attribute key/value pairs, null for default
         */
        public function set_url_replacements($element_attribute = null)
        {
        }
        /**
         * Set the list of domains for which to force HTTPS.
         * @see \SimplePie\Misc::https_url()
         * Example array('biz', 'example.com', 'example.org', 'www.example.net');
         */
        public function set_https_domains($domains)
        {
        }
        /**
         * Check if the domain is in the list of forced HTTPS.
         */
        protected function is_https_domain($domain)
        {
        }
        /**
         * Force HTTPS for selected Web sites.
         */
        public function https_url($url)
        {
        }
        public function sanitize($data, $type, $base = '')
        {
        }
        protected function preprocess($html, $type)
        {
        }
        public function replace_urls($document, $tag, $attributes)
        {
        }
        public function do_strip_htmltags($match)
        {
        }
        protected function strip_tag($tag, $document, $xpath, $type)
        {
        }
        protected function strip_attr($attrib, $xpath)
        {
        }
        protected function rename_attr($attrib, $xpath)
        {
        }
        protected function add_attr($tag, $valuePairs, $document)
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Sanitize" instead */
    class SimplePie_Sanitize extends \SimplePie\Sanitize
    {
    }
}
namespace SimplePie {
    /**
     * Handles `<atom:source>`
     *
     * Used by {@see \SimplePie\Item::get_source()}
     *
     * This class can be overloaded with {@see \SimplePie::set_source_class()}
     *
     * @package SimplePie
     * @subpackage API
     */
    class Source implements \SimplePie\RegistryAware
    {
        public $item;
        public $data = [];
        protected $registry;
        public function __construct($item, $data)
        {
        }
        public function set_registry(\SimplePie\Registry $registry)
        {
        }
        public function __toString()
        {
        }
        public function get_source_tags($namespace, $tag)
        {
        }
        public function get_base($element = [])
        {
        }
        public function sanitize($data, $type, $base = '')
        {
        }
        public function get_item()
        {
        }
        public function get_title()
        {
        }
        public function get_category($key = 0)
        {
        }
        public function get_categories()
        {
        }
        public function get_author($key = 0)
        {
        }
        public function get_authors()
        {
        }
        public function get_contributor($key = 0)
        {
        }
        public function get_contributors()
        {
        }
        public function get_link($key = 0, $rel = 'alternate')
        {
        }
        /**
         * Added for parity between the parent-level and the item/entry-level.
         */
        public function get_permalink()
        {
        }
        public function get_links($rel = 'alternate')
        {
        }
        public function get_description()
        {
        }
        public function get_copyright()
        {
        }
        public function get_language()
        {
        }
        public function get_latitude()
        {
        }
        public function get_longitude()
        {
        }
        public function get_image_url()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Source" instead */
    class SimplePie_Source extends \SimplePie\Source
    {
    }
}
namespace SimplePie\XML\Declaration {
    /**
     * Parses the XML Declaration
     *
     * @package SimplePie
     * @subpackage Parsing
     */
    class Parser
    {
        /**
         * XML Version
         *
         * @access public
         * @var string
         */
        public $version = '1.0';
        /**
         * Encoding
         *
         * @access public
         * @var string
         */
        public $encoding = 'UTF-8';
        /**
         * Standalone
         *
         * @access public
         * @var bool
         */
        public $standalone = false;
        /**
         * Current state of the state machine
         *
         * @access private
         * @var self::STATE_*
         */
        public $state = self::STATE_BEFORE_VERSION_NAME;
        /**
         * Input data
         *
         * @access private
         * @var string
         */
        public $data = '';
        /**
         * Input data length (to avoid calling strlen() everytime this is needed)
         *
         * @access private
         * @var int
         */
        public $data_length = 0;
        /**
         * Current position of the pointer
         *
         * @var int
         * @access private
         */
        public $position = 0;
        /**
         * Create an instance of the class with the input data
         *
         * @access public
         * @param string $data Input data
         */
        public function __construct($data)
        {
        }
        /**
         * Parse the input data
         *
         * @access public
         * @return bool true on success, false on failure
         */
        public function parse()
        {
        }
        /**
         * Check whether there is data beyond the pointer
         *
         * @access private
         * @return bool true if there is further data, false if not
         */
        public function has_data()
        {
        }
        /**
         * Advance past any whitespace
         *
         * @return int Number of whitespace characters passed
         */
        public function skip_whitespace()
        {
        }
        /**
         * Read value
         */
        public function get_value()
        {
        }
        public function before_version_name()
        {
        }
        public function version_name()
        {
        }
        public function version_equals()
        {
        }
        public function version_value()
        {
        }
        public function encoding_name()
        {
        }
        public function encoding_equals()
        {
        }
        public function encoding_value()
        {
        }
        public function standalone_name()
        {
        }
        public function standalone_equals()
        {
        }
        public function standalone_value()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\XML\Declaration\Parser" instead */
    class SimplePie_XML_Declaration_Parser extends \SimplePie\XML\Declaration\Parser
    {
    }
}
namespace SimplePie {
    /**
     * Decode 'gzip' encoded HTTP data
     *
     * @package SimplePie
     * @subpackage HTTP
     * @link http://www.gzip.org/format.txt
     */
    class Gzdecode
    {
        /**
         * Compressed data
         *
         * @access private
         * @var string
         * @see gzdecode::$data
         */
        public $compressed_data;
        /**
         * Size of compressed data
         *
         * @access private
         * @var int
         */
        public $compressed_size;
        /**
         * Minimum size of a valid gzip string
         *
         * @access private
         * @var int
         */
        public $min_compressed_size = 18;
        /**
         * Current position of pointer
         *
         * @access private
         * @var int
         */
        public $position = 0;
        /**
         * Flags (FLG)
         *
         * @access private
         * @var int
         */
        public $flags;
        /**
         * Uncompressed data
         *
         * @access public
         * @see gzdecode::$compressed_data
         * @var string
         */
        public $data;
        /**
         * Modified time
         *
         * @access public
         * @var int
         */
        public $MTIME;
        /**
         * Extra Flags
         *
         * @access public
         * @var int
         */
        public $XFL;
        /**
         * Operating System
         *
         * @access public
         * @var int
         */
        public $OS;
        /**
         * Subfield ID 1
         *
         * @access public
         * @see gzdecode::$extra_field
         * @see gzdecode::$SI2
         * @var string
         */
        public $SI1;
        /**
         * Subfield ID 2
         *
         * @access public
         * @see gzdecode::$extra_field
         * @see gzdecode::$SI1
         * @var string
         */
        public $SI2;
        /**
         * Extra field content
         *
         * @access public
         * @see gzdecode::$SI1
         * @see gzdecode::$SI2
         * @var string
         */
        public $extra_field;
        /**
         * Original filename
         *
         * @access public
         * @var string
         */
        public $filename;
        /**
         * Human readable comment
         *
         * @access public
         * @var string
         */
        public $comment;
        /**
         * Don't allow anything to be set
         *
         * @param string $name
         * @param mixed $value
         */
        public function __set($name, $value)
        {
        }
        /**
         * Set the compressed string and related properties
         *
         * @param string $data
         */
        public function __construct($data)
        {
        }
        /**
         * Decode the GZIP stream
         *
         * @return bool Successfulness
         */
        public function parse()
        {
        }
    }
}
namespace {
    /** @deprecated since SimplePie 1.7.0, use "SimplePie\Gzdecode" instead */
    class SimplePie_gzdecode extends \SimplePie\Gzdecode
    {
    }
}
namespace SimplePie\Cache {
    /**
     * Subset of PSR-16 Cache client for caching data arrays
     *
     * Only get(), set() and delete() methods are used,
     * but not has(), getMultiple(), setMultiple() or deleteMultiple().
     *
     * The methods names must be different, but should be compatible to the
     * methods of \Psr\SimpleCache\CacheInterface.
     *
     * @package SimplePie
     * @subpackage Caching
     * @internal
     */
    interface DataCache
    {
        /**
         * Fetches a value from the cache.
         *
         * Equivalent to \Psr\SimpleCache\CacheInterface::get()
         * <code>
         * public function get(string $key, mixed $default = null): mixed;
         * </code>
         *
         * @param string   $key     The unique key of this item in the cache.
         * @param mixed    $default Default value to return if the key does not exist.
         *
         * @return array|mixed The value of the item from the cache, or $default in case of cache miss.
         *
         * @throws InvalidArgumentException
         *   MUST be thrown if the $key string is not a legal value.
         */
        public function get_data(string $key, $default = null);
        /**
         * Persists data in the cache, uniquely referenced by a key with an optional expiration TTL time.
         *
         * Equivalent to \Psr\SimpleCache\CacheInterface::set()
         * <code>
         * public function set(string $key, mixed $value, null|int|\DateInterval $ttl = null): bool;
         * </code>
         *
         * @param string   $key   The key of the item to store.
         * @param array    $value The value of the item to store, must be serializable.
         * @param null|int $ttl   Optional. The TTL value of this item. If no value is sent and
         *                                      the driver supports TTL then the library may set a default value
         *                                      for it or let the driver take care of that.
         *
         * @return bool True on success and false on failure.
         *
         * @throws InvalidArgumentException
         *   MUST be thrown if the $key string is not a legal value.
         */
        public function set_data(string $key, array $value, ?int $ttl = null) : bool;
        /**
         * Delete an item from the cache by its unique key.
         *
         * Equivalent to \Psr\SimpleCache\CacheInterface::delete()
         * <code>
         * public function delete(string $key): bool;
         * </code>
         *
         * @param string $key The unique cache key of the item to delete.
         *
         * @return bool True if the item was successfully removed. False if there was an error.
         *
         * @throws InvalidArgumentException
         *   MUST be thrown if the $key string is not a legal value.
         */
        public function delete_data(string $key) : bool;
    }
    /**
     * Adapter for deprecated \SimplePie\Cache\Base implementations
     *
     * @package SimplePie
     * @subpackage Caching
     * @internal
     */
    final class BaseDataCache implements \SimplePie\Cache\DataCache
    {
        public function __construct(\SimplePie\Cache\Base $cache)
        {
        }
        /**
         * Fetches a value from the cache.
         *
         * Equivalent to \Psr\SimpleCache\CacheInterface::get()
         * <code>
         * public function get(string $key, mixed $default = null): mixed;
         * </code>
         *
         * @param string $key     The unique key of this item in the cache.
         * @param mixed  $default Default value to return if the key does not exist.
         *
         * @return array|mixed The value of the item from the cache, or $default in case of cache miss.
         *
         * @throws InvalidArgumentException
         *   MUST be thrown if the $key string is not a legal value.
         */
        public function get_data(string $key, $default = null)
        {
        }
        /**
         * Persists data in the cache, uniquely referenced by a key with an optional expiration TTL time.
         *
         * Equivalent to \Psr\SimpleCache\CacheInterface::set()
         * <code>
         * public function set(string $key, mixed $value, null|int|\DateInterval $ttl = null): bool;
         * </code>
         *
         * @param string   $key   The key of the item to store.
         * @param array    $value The value of the item to store, must be serializable.
         * @param null|int $ttl   Optional. The TTL value of this item. If no value is sent and
         *                                      the driver supports TTL then the library may set a default value
         *                                      for it or let the driver take care of that.
         *
         * @return bool True on success and false on failure.
         *
         * @throws InvalidArgumentException
         *   MUST be thrown if the $key string is not a legal value.
         */
        public function set_data(string $key, array $value, ?int $ttl = null) : bool
        {
        }
        /**
         * Delete an item from the cache by its unique key.
         *
         * Equivalent to \Psr\SimpleCache\CacheInterface::delete()
         * <code>
         * public function delete(string $key): bool;
         * </code>
         *
         * @param string $key The unique cache key of the item to delete.
         *
         * @return bool True if the item was successfully removed. False if there was an error.
         *
         * @throws InvalidArgumentException
         *   MUST be thrown if the $key string is not a legal value.
         */
        public function delete_data(string $key) : bool
        {
        }
    }
    /**
     * Interface for creating a cache filename
     *
     * @package SimplePie
     * @subpackage Caching
     */
    interface NameFilter
    {
        /**
         * Method to create cache filename with.
         *
         * The returning name MUST follow the rules for keys in PSR-16.
         *
         * @link https://www.php-fig.org/psr/psr-16/
         *
         * The returning name MUST be a string of at least one character
         * that uniquely identifies a cached item, MUST only contain the
         * characters A-Z, a-z, 0-9, _, and . in any order in UTF-8 encoding
         * and MUST not longer then 64 characters. The following characters
         * are reserved for future extensions and MUST NOT be used: {}()/\@:
         *
         * A provided implementing library MAY support additional characters
         * and encodings or longer lengths, but MUST support at least that
         * minimum.
         *
         * @param string $name The name for the cache will be most likly an url with query string
         *
         * @return string the new cache name
         */
        public function filter(string $name) : string;
    }
    /**
     * Creating a cache filename with callables
     *
     * @package SimplePie
     * @subpackage Caching
     */
    final class CallableNameFilter implements \SimplePie\Cache\NameFilter
    {
        public function __construct(callable $callable)
        {
        }
        /**
         * Method to create cache filename with.
         *
         * The returning name MUST follow the rules for keys in PSR-16.
         *
         * @link https://www.php-fig.org/psr/psr-16/
         *
         * The returning name MUST be a string of at least one character
         * that uniquely identifies a cached item, MUST only contain the
         * characters A-Z, a-z, 0-9, _, and . in any order in UTF-8 encoding
         * and MUST not longer then 64 characters. The following characters
         * are reserved for future extensions and MUST NOT be used: {}()/\@:
         *
         * A provided implementing library MAY support additional characters
         * and encodings or longer lengths, but MUST support at least that
         * minimum.
         *
         * @param string $name The name for the cache will be most likly an url with query string
         *
         * @return string the new cache name
         */
        public function filter(string $name) : string
        {
        }
    }
    /**
     * Caches data into a PSR-16 cache implementation
     *
     * @package SimplePie
     * @subpackage Caching
     * @internal
     */
    final class Psr16 implements \SimplePie\Cache\DataCache
    {
        /**
         * PSR-16 cache implementation
         *
         * @param CacheInterface $cache
         */
        public function __construct(\Psr\SimpleCache\CacheInterface $cache)
        {
        }
        /**
         * Fetches a value from the cache.
         *
         * Equivalent to \Psr\SimpleCache\CacheInterface::get()
         * <code>
         * public function get(string $key, mixed $default = null): mixed;
         * </code>
         *
         * @param string $key     The unique key of this item in the cache.
         * @param mixed  $default Default value to return if the key does not exist.
         *
         * @return array|mixed The value of the item from the cache, or $default in case of cache miss.
         *
         * @throws InvalidArgumentException
         *   MUST be thrown if the $key string is not a legal value.
         */
        public function get_data(string $key, $default = null)
        {
        }
        /**
         * Persists data in the cache, uniquely referenced by a key with an optional expiration TTL time.
         *
         * Equivalent to \Psr\SimpleCache\CacheInterface::set()
         * <code>
         * public function set(string $key, mixed $value, null|int|\DateInterval $ttl = null): bool;
         * </code>
         *
         * @param string   $key   The key of the item to store.
         * @param array    $value The value of the item to store, must be serializable.
         * @param null|int $ttl   Optional. The TTL value of this item. If no value is sent and
         *                                      the driver supports TTL then the library may set a default value
         *                                      for it or let the driver take care of that.
         *
         * @return bool True on success and false on failure.
         *
         * @throws InvalidArgumentException
         *   MUST be thrown if the $key string is not a legal value.
         */
        public function set_data(string $key, array $value, ?int $ttl = null) : bool
        {
        }
        /**
         * Delete an item from the cache by its unique key.
         *
         * Equivalent to \Psr\SimpleCache\CacheInterface::delete()
         * <code>
         * public function delete(string $key): bool;
         * </code>
         *
         * @param string $key The unique cache key of the item to delete.
         *
         * @return bool True if the item was successfully removed. False if there was an error.
         *
         * @throws InvalidArgumentException
         *   MUST be thrown if the $key string is not a legal value.
         */
        public function delete_data(string $key) : bool
        {
        }
    }
}
namespace {
    /**
     * General API for generating and formatting diffs - the differences between
     * two sequences of strings.
     *
     * The original PHP version of this code was written by Geoffrey T. Dairiki
     * <dairiki@dairiki.org>, and is used/adapted with his permission.
     *
     * Copyright 2004 Geoffrey T. Dairiki <dairiki@dairiki.org>
     * Copyright 2004-2010 The Horde Project (http://www.horde.org/)
     *
     * See the enclosed file COPYING for license information (LGPL). If you did
     * not receive this file, see https://opensource.org/license/lgpl-2-1/.
     *
     * @package Text_Diff
     * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
     */
    class Text_Diff
    {
        /**
         * Array of changes.
         *
         * @var array
         */
        var $_edits;
        /**
         * Computes diffs between sequences of strings.
         *
         * @param string $engine     Name of the diffing engine to use.  'auto'
         *                           will automatically select the best.
         * @param array $params      Parameters to pass to the diffing engine.
         *                           Normally an array of two arrays, each
         *                           containing the lines from a file.
         */
        function __construct($engine, $params)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function Text_Diff($engine, $params)
        {
        }
        /**
         * Returns the array of differences.
         */
        function getDiff()
        {
        }
        /**
         * returns the number of new (added) lines in a given diff.
         *
         * @since Text_Diff 1.1.0
         *
         * @return int The number of new lines
         */
        function countAddedLines()
        {
        }
        /**
         * Returns the number of deleted (removed) lines in a given diff.
         *
         * @since Text_Diff 1.1.0
         *
         * @return int The number of deleted lines
         */
        function countDeletedLines()
        {
        }
        /**
         * Computes a reversed diff.
         *
         * Example:
         * <code>
         * $diff = new Text_Diff($lines1, $lines2);
         * $rev = $diff->reverse();
         * </code>
         *
         * @return Text_Diff  A Diff object representing the inverse of the
         *                    original diff.  Note that we purposely don't return a
         *                    reference here, since this essentially is a clone()
         *                    method.
         */
        function reverse()
        {
        }
        /**
         * Checks for an empty diff.
         *
         * @return bool True if two sequences were identical.
         */
        function isEmpty()
        {
        }
        /**
         * Computes the length of the Longest Common Subsequence (LCS).
         *
         * This is mostly for diagnostic purposes.
         *
         * @return int The length of the LCS.
         */
        function lcs()
        {
        }
        /**
         * Gets the original set of lines.
         *
         * This reconstructs the $from_lines parameter passed to the constructor.
         *
         * @return array  The original sequence of strings.
         */
        function getOriginal()
        {
        }
        /**
         * Gets the final set of lines.
         *
         * This reconstructs the $to_lines parameter passed to the constructor.
         *
         * @return array  The sequence of strings.
         */
        function getFinal()
        {
        }
        /**
         * Removes trailing newlines from a line of text. This is meant to be used
         * with array_walk().
         *
         * @param string $line  The line to trim.
         * @param int    $key   The index of the line in the array. Not used.
         */
        static function trimNewlines(&$line, $key)
        {
        }
        /**
         * Determines the location of the system temporary directory.
         *
         * @access protected
         *
         * @return string  A directory name which can be used for temp files.
         *                 Returns false if one could not be found.
         */
        static function _getTempDir()
        {
        }
        /**
         * Checks a diff for validity.
         *
         * This is here only for debugging purposes.
         */
        function _check($from_lines, $to_lines)
        {
        }
    }
    /**
     * @package Text_Diff
     * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
     */
    class Text_MappedDiff extends \Text_Diff
    {
        /**
         * Computes a diff between sequences of strings.
         *
         * This can be used to compute things like case-insensitive diffs, or diffs
         * which ignore changes in white-space.
         *
         * @param array $from_lines         An array of strings.
         * @param array $to_lines           An array of strings.
         * @param array $mapped_from_lines  This array should have the same size
         *                                  number of elements as $from_lines.  The
         *                                  elements in $mapped_from_lines and
         *                                  $mapped_to_lines are what is actually
         *                                  compared when computing the diff.
         * @param array $mapped_to_lines    This array should have the same number
         *                                  of elements as $to_lines.
         */
        function __construct($from_lines, $to_lines, $mapped_from_lines, $mapped_to_lines)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function Text_MappedDiff($from_lines, $to_lines, $mapped_from_lines, $mapped_to_lines)
        {
        }
    }
    /**
     * @package Text_Diff
     * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
     *
     * @access private
     */
    abstract class Text_Diff_Op
    {
        var $orig;
        var $final;
        abstract function &reverse();
        function norig()
        {
        }
        function nfinal()
        {
        }
    }
    /**
     * @package Text_Diff
     * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
     *
     * @access private
     */
    class Text_Diff_Op_copy extends \Text_Diff_Op
    {
        /**
         * PHP5 constructor.
         */
        function __construct($orig, $final = \false)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function Text_Diff_Op_copy($orig, $final = \false)
        {
        }
        function &reverse()
        {
        }
    }
    /**
     * @package Text_Diff
     * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
     *
     * @access private
     */
    class Text_Diff_Op_delete extends \Text_Diff_Op
    {
        /**
         * PHP5 constructor.
         */
        function __construct($lines)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function Text_Diff_Op_delete($lines)
        {
        }
        function &reverse()
        {
        }
    }
    /**
     * @package Text_Diff
     * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
     *
     * @access private
     */
    class Text_Diff_Op_add extends \Text_Diff_Op
    {
        /**
         * PHP5 constructor.
         */
        function __construct($lines)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function Text_Diff_Op_add($lines)
        {
        }
        function &reverse()
        {
        }
    }
    /**
     * @package Text_Diff
     * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
     *
     * @access private
     */
    class Text_Diff_Op_change extends \Text_Diff_Op
    {
        /**
         * PHP5 constructor.
         */
        function __construct($orig, $final)
        {
        }
        /**
         * PHP4 constructor.
         */
        public function Text_Diff_Op_change($orig, $final)
        {
        }
        function &reverse()
        {
        }
    }
    /**
     * Class used internally by Text_Diff to actually compute the diffs.
     *
     * This class is implemented using native PHP code.
     *
     * The algorithm used here is mostly lifted from the perl module
     * Algorithm::Diff (version 1.06) by Ned Konz, which is available at:
     * https://cpan.metacpan.org/authors/id/N/NE/NEDKONZ/Algorithm-Diff-1.06.zip
     *
     * More ideas are taken from: http://www.ics.uci.edu/~eppstein/161/960229.html
     *
     * Some ideas (and a bit of code) are taken from analyze.c, of GNU
     * diffutils-2.7, which can be found at:
     * ftp://gnudist.gnu.org/pub/gnu/diffutils/diffutils-2.7.tar.gz
     *
     * Some ideas (subdivision by NCHUNKS > 2, and some optimizations) are from
     * Geoffrey T. Dairiki <dairiki@dairiki.org>. The original PHP version of this
     * code was written by him, and is used/adapted with his permission.
     *
     * Copyright 2004-2010 The Horde Project (http://www.horde.org/)
     *
     * See the enclosed file COPYING for license information (LGPL). If you did
     * not receive this file, see https://opensource.org/license/lgpl-2-1/.
     *
     * @author  Geoffrey T. Dairiki <dairiki@dairiki.org>
     * @package Text_Diff
     */
    class Text_Diff_Engine_native
    {
        public $xchanged;
        public $ychanged;
        public $xv;
        public $yv;
        public $xind;
        public $yind;
        public $seq;
        public $in_seq;
        public $lcs;
        function diff($from_lines, $to_lines)
        {
        }
        /**
         * Divides the Largest Common Subsequence (LCS) of the sequences (XOFF,
         * XLIM) and (YOFF, YLIM) into NCHUNKS approximately equally sized
         * segments.
         *
         * Returns (LCS, PTS).  LCS is the length of the LCS. PTS is an array of
         * NCHUNKS+1 (X, Y) indexes giving the diving points between sub
         * sequences.  The first sub-sequence is contained in (X0, X1), (Y0, Y1),
         * the second in (X1, X2), (Y1, Y2) and so on.  Note that (X0, Y0) ==
         * (XOFF, YOFF) and (X[NCHUNKS], Y[NCHUNKS]) == (XLIM, YLIM).
         *
         * This function assumes that the first lines of the specified portions of
         * the two files do not match, and likewise that the last lines do not
         * match.  The caller must trim matching lines from the beginning and end
         * of the portions it is going to specify.
         */
        function _diag($xoff, $xlim, $yoff, $ylim, $nchunks)
        {
        }
        function _lcsPos($ypos)
        {
        }
        /**
         * Finds LCS of two sequences.
         *
         * The results are recorded in the vectors $this->{x,y}changed[], by
         * storing a 1 in the element for each line that is an insertion or
         * deletion (ie. is not in the LCS).
         *
         * The subsequence of file 0 is (XOFF, XLIM) and likewise for file 1.
         *
         * Note that XLIM, YLIM are exclusive bounds.  All line numbers are
         * origin-0 and discarded lines are not counted.
         */
        function _compareseq($xoff, $xlim, $yoff, $ylim)
        {
        }
        /**
         * Adjusts inserts/deletes of identical lines to join changes as much as
         * possible.
         *
         * We do something when a run of changed lines include a line at one end
         * and has an excluded, identical line at the other.  We are free to
         * choose which identical line is included.  `compareseq' usually chooses
         * the one at the beginning, but usually it is cleaner to consider the
         * following identical line to be the "change".
         *
         * This is extracted verbatim from analyze.c (GNU diffutils-2.7).
         */
        function _shiftBoundaries($lines, &$changed, $other_changed)
        {
        }
    }
    /**
     * Class used internally by Diff to actually compute the diffs.
     *
     * This class uses the Unix `diff` program via shell_exec to compute the
     * differences between the two input arrays.
     *
     * Copyright 2007-2010 The Horde Project (http://www.horde.org/)
     *
     * See the enclosed file COPYING for license information (LGPL). If you did
     * not receive this file, see https://opensource.org/license/lgpl-2-1/.
     *
     * @author  Milian Wolff <mail@milianw.de>
     * @package Text_Diff
     * @since   0.3.0
     */
    class Text_Diff_Engine_shell
    {
        /**
         * Path to the diff executable
         *
         * @var string
         */
        var $_diffCommand = 'diff';
        /**
         * Returns the array of differences.
         *
         * @param array $from_lines lines of text from old file
         * @param array $to_lines   lines of text from new file
         *
         * @return array all changes made (array with Text_Diff_Op_* objects)
         */
        function diff($from_lines, $to_lines)
        {
        }
        /**
         * Get lines from either the old or new text
         *
         * @access private
         *
         * @param array $text_lines Either $from_lines or $to_lines (passed by reference).
         * @param int   $line_no    Current line number (passed by reference).
         * @param int   $end        Optional end line, when we want to chop more
         *                          than one line.
         *
         * @return array The chopped lines
         */
        function _getLines(&$text_lines, &$line_no, $end = \false)
        {
        }
    }
    /**
     * Parses unified or context diffs output from eg. the diff utility.
     *
     * Example:
     * <code>
     * $patch = file_get_contents('example.patch');
     * $diff = new Text_Diff('string', array($patch));
     * $renderer = new Text_Diff_Renderer_inline();
     * echo $renderer->render($diff);
     * </code>
     *
     * Copyright 2005 Örjan Persson <o@42mm.org>
     * Copyright 2005-2010 The Horde Project (http://www.horde.org/)
     *
     * See the enclosed file COPYING for license information (LGPL). If you did
     * not receive this file, see https://opensource.org/license/lgpl-2-1/.
     *
     * @author  Örjan Persson <o@42mm.org>
     * @package Text_Diff
     * @since   0.2.0
     */
    class Text_Diff_Engine_string
    {
        /**
         * Parses a unified or context diff.
         *
         * First param contains the whole diff and the second can be used to force
         * a specific diff type. If the second parameter is 'autodetect', the
         * diff will be examined to find out which type of diff this is.
         *
         * @param string $diff  The diff content.
         * @param string $mode  The diff mode of the content in $diff. One of
         *                      'context', 'unified', or 'autodetect'.
         *
         * @return array  List of all diff operations.
         * @phpstan-param 'context'|'unified'|'autodetect' $mode
         */
        function diff($diff, $mode = 'autodetect')
        {
        }
        /**
         * Parses an array containing the unified diff.
         *
         * @param array $diff  Array of lines.
         *
         * @return array  List of all diff operations.
         */
        function parseUnifiedDiff($diff)
        {
        }
        /**
         * Parses an array containing the context diff.
         *
         * @param array $diff  Array of lines.
         *
         * @return array  List of all diff operations.
         */
        function parseContextDiff(&$diff)
        {
        }
    }
    /**
     * Class used internally by Diff to actually compute the diffs.
     *
     * This class uses the xdiff PECL package (http://pecl.php.net/package/xdiff)
     * to compute the differences between the two input arrays.
     *
     * Copyright 2004-2010 The Horde Project (http://www.horde.org/)
     *
     * See the enclosed file COPYING for license information (LGPL). If you did
     * not receive this file, see https://opensource.org/license/lgpl-2-1/.
     *
     * @author  Jon Parise <jon@horde.org>
     * @package Text_Diff
     */
    class Text_Diff_Engine_xdiff
    {
        /**
         */
        function diff($from_lines, $to_lines)
        {
        }
    }
    /**
     * A class to render Diffs in different formats.
     *
     * This class renders the diff in classic diff format. It is intended that
     * this class be customized via inheritance, to obtain fancier outputs.
     *
     * Copyright 2004-2010 The Horde Project (http://www.horde.org/)
     *
     * See the enclosed file COPYING for license information (LGPL). If you did
     * not receive this file, see https://opensource.org/license/lgpl-2-1/.
     *
     * @package Text_Diff
     */
    class Text_Diff_Renderer
    {
        /**
         * Number of leading context "lines" to preserve.
         *
         * This should be left at zero for this class, but subclasses may want to
         * set this to other values.
         */
        var $_leading_context_lines = 0;
        /**
         * Number of trailing context "lines" to preserve.
         *
         * This should be left at zero for this class, but subclasses may want to
         * set this to other values.
         */
        var $_trailing_context_lines = 0;
        /**
         * Constructor.
         */
        function __construct($params = array())
        {
        }
        /**
         * PHP4 constructor.
         */
        public function Text_Diff_Renderer($params = array())
        {
        }
        /**
         * Get any renderer parameters.
         *
         * @return array  All parameters of this renderer object.
         */
        function getParams()
        {
        }
        /**
         * Renders a diff.
         *
         * @param Text_Diff $diff  A Text_Diff object.
         *
         * @return string  The formatted output.
         */
        function render($diff)
        {
        }
        function _block($xbeg, $xlen, $ybeg, $ylen, &$edits)
        {
        }
        function _startDiff()
        {
        }
        function _endDiff()
        {
        }
        function _blockHeader($xbeg, $xlen, $ybeg, $ylen)
        {
        }
        function _startBlock($header)
        {
        }
        function _endBlock()
        {
        }
        function _lines($lines, $prefix = ' ')
        {
        }
        function _context($lines)
        {
        }
        function _added($lines)
        {
        }
        function _deleted($lines)
        {
        }
        function _changed($orig, $final)
        {
        }
    }
    /**
     * "Inline" diff renderer.
     *
     * This class renders diffs in the Wiki-style "inline" format.
     *
     * @author  Ciprian Popovici
     * @package Text_Diff
     */
    class Text_Diff_Renderer_inline extends \Text_Diff_Renderer
    {
        /**
         * Number of leading context "lines" to preserve.
         *
         * @var integer
         */
        var $_leading_context_lines = 10000;
        /**
         * Number of trailing context "lines" to preserve.
         *
         * @var integer
         */
        var $_trailing_context_lines = 10000;
        /**
         * Prefix for inserted text.
         *
         * @var string
         */
        var $_ins_prefix = '<ins>';
        /**
         * Suffix for inserted text.
         *
         * @var string
         */
        var $_ins_suffix = '</ins>';
        /**
         * Prefix for deleted text.
         *
         * @var string
         */
        var $_del_prefix = '<del>';
        /**
         * Suffix for deleted text.
         *
         * @var string
         */
        var $_del_suffix = '</del>';
        /**
         * Header for each change block.
         *
         * @var string
         */
        var $_block_header = '';
        /**
         * Whether to split down to character-level.
         *
         * @var boolean
         */
        var $_split_characters = \false;
        /**
         * What are we currently splitting on? Used to recurse to show word-level
         * or character-level changes.
         *
         * @var string
         */
        var $_split_level = 'lines';
        function _blockHeader($xbeg, $xlen, $ybeg, $ylen)
        {
        }
        function _startBlock($header)
        {
        }
        function _lines($lines, $prefix = ' ', $encode = \true)
        {
        }
        function _added($lines)
        {
        }
        function _deleted($lines, $words = \false)
        {
        }
        function _changed($orig, $final)
        {
        }
        function _splitOnWords($string, $newlineEscape = "\n")
        {
        }
        function _encode(&$string)
        {
        }
    }
    /**
     * Exception for errors from the Text_Diff package.
     *
     * {@internal This is a WP native addition to the external Text_Diff package.}
     *
     * @package WordPress
     * @subpackage Text_Diff
     */
    class Text_Exception extends \Exception
    {
    }
    /**
     * Structure that store common Atom Feed Properties
     *
     * @package AtomLib
     */
    class AtomFeed
    {
        /**
         * Stores Links
         * @var array
         * @access public
         */
        var $links = array();
        /**
         * Stores Categories
         * @var array
         * @access public
         */
        var $categories = array();
        /**
         * Stores Entries
         *
         * @var array
         * @access public
         */
        var $entries = array();
    }
    /**
     * Structure that store Atom Entry Properties
     *
     * @package AtomLib
     */
    class AtomEntry
    {
        /**
         * Stores Links
         * @var array
         * @access public
         */
        var $links = array();
        /**
         * Stores Categories
         * @var array
         * @access public
         */
        var $categories = array();
    }
    /**
     * AtomLib Atom Parser API
     *
     * @package AtomLib
     */
    class AtomParser
    {
        var $NS = 'http://www.w3.org/2005/Atom';
        var $ATOM_CONTENT_ELEMENTS = array('content', 'summary', 'title', 'subtitle', 'rights');
        var $ATOM_SIMPLE_ELEMENTS = array('id', 'updated', 'published', 'draft');
        var $debug = \false;
        var $depth = 0;
        var $indent = 2;
        var $in_content;
        var $ns_contexts = array();
        var $ns_decls = array();
        var $content_ns_decls = array();
        var $content_ns_contexts = array();
        var $is_xhtml = \false;
        var $is_html = \false;
        var $is_text = \true;
        var $skipped_div = \false;
        var $FILE = "php://input";
        var $feed;
        var $current;
        var $map_attrs_func;
        var $map_xmlns_func;
        var $error;
        var $content;
        /**
         * PHP5 constructor.
         */
        function __construct()
        {
        }
        /**
         * PHP4 constructor.
         */
        public function AtomParser()
        {
        }
        /**
         * Map attributes to key="val"
         *
         * @param string $k Key
         * @param string $v Value
         * @return string
         */
        public static function map_attrs($k, $v)
        {
        }
        /**
         * Map XML namespace to string.
         *
         * @param indexish $p XML Namespace element index
         * @param array $n Two-element array pair. [ 0 => {namespace}, 1 => {url} ]
         * @return string 'xmlns="{url}"' or 'xmlns:{namespace}="{url}"'
         */
        public static function map_xmlns($p, $n)
        {
        }
        function _p($msg)
        {
        }
        function error_handler($log_level, $log_text, $error_file, $error_line)
        {
        }
        function parse()
        {
        }
        function start_element($parser, $name, $attrs)
        {
        }
        function end_element($parser, $name)
        {
        }
        function start_ns($parser, $prefix, $uri)
        {
        }
        function end_ns($parser, $prefix)
        {
        }
        function cdata($parser, $data)
        {
        }
        function _default($parser, $data)
        {
        }
        function ns_to_prefix($qname, $attr = \false)
        {
        }
        function is_declared_content_ns($new_mapping)
        {
        }
        function xml_escape($content)
        {
        }
    }
    /**
     * Helper functions used to render the navigation block.
     *
     * @since 6.5.0
     */
    class WP_Navigation_Block_Renderer
    {
        /**
         * Renders the navigation block.
         *
         * @since 6.5.0
         *
         * @param array    $attributes The block attributes.
         * @param string   $content    The saved content.
         * @param WP_Block $block      The parsed block.
         * @return string Returns the navigation block markup.
         */
        public static function render($attributes, $content, $block)
        {
        }
    }
}
namespace Avifinfo {
    class Tile
    {
        public $tile_item_id;
        public $parent_item_id;
    }
    class Prop
    {
        public $property_index;
        public $item_id;
    }
    class Dim_Prop
    {
        public $property_index;
        public $width;
        public $height;
    }
    class Chan_Prop
    {
        public $property_index;
        public $bit_depth;
        public $num_channels;
    }
    class Features
    {
        public $has_primary_item = false;
        public $has_alpha = false;
        public $primary_item_id;
        public $primary_item_features = array(
            // Deduced from the data below.
            'width' => UNDEFINED,
            // In number of pixels.
            'height' => UNDEFINED,
            // Ignores mirror and rotation.
            'bit_depth' => UNDEFINED,
            // Likely 8, 10 or 12 bits per channel per pixel.
            'num_channels' => UNDEFINED,
        );
        public $tiles = array();
        public $props = array();
        public $dim_props = array();
        public $chan_props = array();
        /**
         * Finds the width, height, bit depth and number of channels of the primary item.
         *
         * @return Status FOUND on success or NOT_FOUND on failure.
         */
        public function get_primary_item_features()
        {
        }
    }
    class Box
    {
        public $size;
        public $type;
        public $version;
        public $flags;
        public $content_size;
        /**
         * Reads the box header.
         *
         * @param stream  $handle              The resource the header will be parsed from.
         * @param int     $num_parsed_boxes    The total number of parsed boxes. Prevents timeouts.
         * @param int     $num_remaining_bytes The number of bytes that should be available from the resource.
         * @return Status                      FOUND on success or an error on failure.
         */
        public function parse($handle, &$num_parsed_boxes, $num_remaining_bytes = MAX_SIZE)
        {
        }
    }
    class Parser
    {
        public $features;
        function __construct($handle)
        {
        }
        /**
         * Parses a file stream.
         *
         * The file type is checked through the "ftyp" box.
         *
         * @return bool True if the input stream is an AVIF bitstream or false.
         */
        public function parse_ftyp()
        {
        }
        /**
         * Parses a file stream.
         *
         * Features are extracted from the "meta" box.
         *
         * @return bool True if the main features of the primary item were parsed or false.
         */
        public function parse_file()
        {
        }
    }
}
namespace {
    /**
     * Portable PHP password hashing framework.
     *
     * @package phpass
     * @version 0.5 / WordPress
     * @link https://www.openwall.com/phpass/
     * @since 2.5.0
     */
    class PasswordHash
    {
        var $itoa64;
        var $iteration_count_log2;
        var $portable_hashes;
        var $random_state;
        function __construct($iteration_count_log2, $portable_hashes)
        {
        }
        function PasswordHash($iteration_count_log2, $portable_hashes)
        {
        }
        function get_random_bytes($count)
        {
        }
        function encode64($input, $count)
        {
        }
        function gensalt_private($input)
        {
        }
        function crypt_private($password, $setting)
        {
        }
        function gensalt_blowfish($input)
        {
        }
        function HashPassword($password)
        {
        }
        function CheckPassword($password, $stored_hash)
        {
        }
    }
    /**
     * mail_fetch/setup.php
     *
     * Copyright (c) 1999-2011 CDI (cdi@thewebmasters.net) All Rights Reserved
     * Modified by Philippe Mingo 2001-2009 mingo@rotedic.com
     * An RFC 1939 compliant wrapper class for the POP3 protocol.
     *
     * Licensed under the GNU GPL. For full terms see the file COPYING.
     *
     * POP3 class
     *
     * @copyright 1999-2011 The SquirrelMail Project Team
     * @license https://opensource.org/licenses/gpl-license.php GNU Public License
     * @package plugins
     * @subpackage mail_fetch
     */
    class POP3
    {
        var $ERROR = '';
        var $TIMEOUT = 60;
        var $COUNT = -1;
        var $BUFFER = 512;
        var $FP = '';
        var $MAILSERVER = '';
        var $DEBUG = \FALSE;
        var $BANNER = '';
        var $ALLOWAPOP = \FALSE;
        /**
         * PHP5 constructor.
         */
        function __construct($server = '', $timeout = '')
        {
        }
        /**
         * PHP4 constructor.
         */
        public function POP3($server = '', $timeout = '')
        {
        }
        function update_timer()
        {
        }
        function connect($server, $port = 110)
        {
        }
        function user($user = "")
        {
        }
        function pass($pass = "")
        {
        }
        function apop($login, $pass)
        {
        }
        function login($login = "", $pass = "")
        {
        }
        function top($msgNum, $numLines = "0")
        {
        }
        function pop_list($msgNum = "")
        {
        }
        function get($msgNum)
        {
        }
        function last($type = "count")
        {
        }
        function reset()
        {
        }
        function send_cmd($cmd = "")
        {
        }
        function quit()
        {
        }
        function popstat()
        {
        }
        function uidl($msgNum = "")
        {
        }
        function delete($msgNum = "")
        {
        }
        function is_ok($cmd = "")
        {
        }
        function strip_clf($text = "")
        {
        }
        function parse_banner($server_text)
        {
        }
    }
    /**
     * Requests for PHP
     *
     * Inspired by Requests for Python.
     *
     * Based on concepts from SimplePie_File, RequestCore and WP_Http.
     *
     * @package Requests
     *
     * @deprecated 6.2.0 Use `WpOrg\Requests\Requests` instead for the actual functionality and
     *                   use `WpOrg\Requests\Autoload` for the autoloading.
     */
    class Requests extends \WpOrg\Requests\Requests
    {
        /**
         * Deprecated autoloader for Requests.
         *
         * @deprecated 6.2.0 Use the `WpOrg\Requests\Autoload::load()` method instead.
         *
         * @codeCoverageIgnore
         *
         * @param string $class Class name to load
         */
        public static function autoloader($class)
        {
        }
        /**
         * Register the built-in autoloader
         *
         * @deprecated 6.2.0 Include the `WpOrg\Requests\Autoload` class and
         *                   call `WpOrg\Requests\Autoload::register()` instead.
         *
         * @codeCoverageIgnore
         */
        public static function register_autoloader()
        {
        }
    }
    /**
     * Core class used to create an HTML dropdown list of Categories.
     *
     * @since 2.1.0
     *
     * @see Walker
     */
    class Walker_CategoryDropdown extends \Walker
    {
        /**
         * What the class handles.
         *
         * @since 2.1.0
         * @var string
         *
         * @see Walker::$tree_type
         */
        public $tree_type = 'category';
        /**
         * Database fields to use.
         *
         * @since 2.1.0
         * @todo Decouple this
         * @var string[]
         *
         * @see Walker::$db_fields
         */
        public $db_fields = array('parent' => 'parent', 'id' => 'term_id');
        /**
         * Starts the element output.
         *
         * @since 2.1.0
         * @since 5.9.0 Renamed `$category` to `$data_object` and `$id` to `$current_object_id`
         *              to match parent class for PHP 8 named parameter support.
         *
         * @see Walker::start_el()
         *
         * @param string  $output            Used to append additional content (passed by reference).
         * @param WP_Term $data_object       Category data object.
         * @param int     $depth             Depth of category. Used for padding.
         * @param array   $args              Uses 'selected', 'show_count', and 'value_field' keys, if they exist.
         *                                   See wp_dropdown_categories().
         * @param int     $current_object_id Optional. ID of the current category. Default 0.
         * @phpstan-param array{
         *   show_option_all?: string,
         *   show_option_none?: string,
         *   option_none_value?: string,
         *   orderby?: string,
         *   pad_counts?: bool,
         *   show_count?: bool|int,
         *   echo?: bool|int,
         *   hierarchical?: bool|int,
         *   depth?: int,
         *   tab_index?: int,
         *   name?: string,
         *   id?: string,
         *   class?: string,
         *   selected?: int|string,
         *   value_field?: string,
         *   taxonomy?: string|array,
         *   hide_if_empty?: bool,
         *   required?: bool,
         *   walker?: Walker,
         *   aria_describedby?: string,
         * } $args See wp_dropdown_categories()
         */
        public function start_el(&$output, $data_object, $depth = 0, $args = array(), $current_object_id = 0)
        {
        }
    }
    /**
     * Core class used to create an HTML list of categories.
     *
     * @since 2.1.0
     *
     * @see Walker
     */
    class Walker_Category extends \Walker
    {
        /**
         * What the class handles.
         *
         * @since 2.1.0
         * @var string
         *
         * @see Walker::$tree_type
         */
        public $tree_type = 'category';
        /**
         * Database fields to use.
         *
         * @since 2.1.0
         * @var string[]
         *
         * @see Walker::$db_fields
         * @todo Decouple this
         */
        public $db_fields = array('parent' => 'parent', 'id' => 'term_id');
        /**
         * Starts the list before the elements are added.
         *
         * @since 2.1.0
         *
         * @see Walker::start_lvl()
         *
         * @param string $output Used to append additional content. Passed by reference.
         * @param int    $depth  Optional. Depth of category. Used for tab indentation. Default 0.
         * @param array  $args   Optional. An array of arguments. Will only append content if style argument
         *                       value is 'list'. See wp_list_categories(). Default empty array.
         * @phpstan-param array{
         *   current_category?: int|int[],
         *   depth?: int,
         *   echo?: bool|int,
         *   exclude?: int[]|string,
         *   exclude_tree?: int[]|string,
         *   feed?: string,
         *   feed_image?: string,
         *   feed_type?: string,
         *   hide_title_if_empty?: bool,
         *   separator?: string,
         *   show_count?: bool|int,
         *   show_option_all?: string,
         *   show_option_none?: string,
         *   style?: string,
         *   taxonomy?: string,
         *   title_li?: string,
         *   use_desc_for_title?: bool|int,
         *   walker?: Walker,
         * } $args See wp_list_categories()
         * @phpstan-return void
         */
        public function start_lvl(&$output, $depth = 0, $args = array())
        {
        }
        /**
         * Ends the list of after the elements are added.
         *
         * @since 2.1.0
         *
         * @see Walker::end_lvl()
         *
         * @param string $output Used to append additional content. Passed by reference.
         * @param int    $depth  Optional. Depth of category. Used for tab indentation. Default 0.
         * @param array  $args   Optional. An array of arguments. Will only append content if style argument
         *                       value is 'list'. See wp_list_categories(). Default empty array.
         * @phpstan-param array{
         *   current_category?: int|int[],
         *   depth?: int,
         *   echo?: bool|int,
         *   exclude?: int[]|string,
         *   exclude_tree?: int[]|string,
         *   feed?: string,
         *   feed_image?: string,
         *   feed_type?: string,
         *   hide_title_if_empty?: bool,
         *   separator?: string,
         *   show_count?: bool|int,
         *   show_option_all?: string,
         *   show_option_none?: string,
         *   style?: string,
         *   taxonomy?: string,
         *   title_li?: string,
         *   use_desc_for_title?: bool|int,
         *   walker?: Walker,
         * } $args See wp_list_categories()
         * @phpstan-return void
         */
        public function end_lvl(&$output, $depth = 0, $args = array())
        {
        }
        /**
         * Starts the element output.
         *
         * @since 2.1.0
         * @since 5.9.0 Renamed `$category` to `$data_object` and `$id` to `$current_object_id`
         *              to match parent class for PHP 8 named parameter support.
         *
         * @see Walker::start_el()
         *
         * @param string  $output            Used to append additional content (passed by reference).
         * @param WP_Term $data_object       Category data object.
         * @param int     $depth             Optional. Depth of category in reference to parents. Default 0.
         * @param array   $args              Optional. An array of arguments. See wp_list_categories().
         *                                   Default empty array.
         * @param int     $current_object_id Optional. ID of the current category. Default 0.
         * @phpstan-param array{
         *   current_category?: int|int[],
         *   depth?: int,
         *   echo?: bool|int,
         *   exclude?: int[]|string,
         *   exclude_tree?: int[]|string,
         *   feed?: string,
         *   feed_image?: string,
         *   feed_type?: string,
         *   hide_title_if_empty?: bool,
         *   separator?: string,
         *   show_count?: bool|int,
         *   show_option_all?: string,
         *   show_option_none?: string,
         *   style?: string,
         *   taxonomy?: string,
         *   title_li?: string,
         *   use_desc_for_title?: bool|int,
         *   walker?: Walker,
         * } $args See wp_list_categories()
         * @phpstan-return void
         */
        public function start_el(&$output, $data_object, $depth = 0, $args = array(), $current_object_id = 0)
        {
        }
        /**
         * Ends the element output, if needed.
         *
         * @since 2.1.0
         * @since 5.9.0 Renamed `$page` to `$data_object` to match parent class for PHP 8 named parameter support.
         *
         * @see Walker::end_el()
         *
         * @param string $output      Used to append additional content (passed by reference).
         * @param object $data_object Category data object. Not used.
         * @param int    $depth       Optional. Depth of category. Not used.
         * @param array  $args        Optional. An array of arguments. Only uses 'list' for whether should
         *                            append to output. See wp_list_categories(). Default empty array.
         * @phpstan-param array{
         *   current_category?: int|int[],
         *   depth?: int,
         *   echo?: bool|int,
         *   exclude?: int[]|string,
         *   exclude_tree?: int[]|string,
         *   feed?: string,
         *   feed_image?: string,
         *   feed_type?: string,
         *   hide_title_if_empty?: bool,
         *   separator?: string,
         *   show_count?: bool|int,
         *   show_option_all?: string,
         *   show_option_none?: string,
         *   style?: string,
         *   taxonomy?: string,
         *   title_li?: string,
         *   use_desc_for_title?: bool|int,
         *   walker?: Walker,
         * } $args See wp_list_categories()
         * @phpstan-return void
         */
        public function end_el(&$output, $data_object, $depth = 0, $args = array())
        {
        }
    }
    /**
     * Core walker class used to create an HTML list of comments.
     *
     * @since 2.7.0
     *
     * @see Walker
     */
    class Walker_Comment extends \Walker
    {
        /**
         * What the class handles.
         *
         * @since 2.7.0
         * @var string
         *
         * @see Walker::$tree_type
         */
        public $tree_type = 'comment';
        /**
         * Database fields to use.
         *
         * @since 2.7.0
         * @var string[]
         *
         * @see Walker::$db_fields
         * @todo Decouple this
         */
        public $db_fields = array('parent' => 'comment_parent', 'id' => 'comment_ID');
        /**
         * Starts the list before the elements are added.
         *
         * @since 2.7.0
         *
         * @see Walker::start_lvl()
         * @global int $comment_depth
         *
         * @param string $output Used to append additional content (passed by reference).
         * @param int    $depth  Optional. Depth of the current comment. Default 0.
         * @param array  $args   Optional. Uses 'style' argument for type of HTML list. Default empty array.
         */
        public function start_lvl(&$output, $depth = 0, $args = array())
        {
        }
        /**
         * Ends the list of items after the elements are added.
         *
         * @since 2.7.0
         *
         * @see Walker::end_lvl()
         * @global int $comment_depth
         *
         * @param string $output Used to append additional content (passed by reference).
         * @param int    $depth  Optional. Depth of the current comment. Default 0.
         * @param array  $args   Optional. Will only append content if style argument value is 'ol' or 'ul'.
         *                       Default empty array.
         */
        public function end_lvl(&$output, $depth = 0, $args = array())
        {
        }
        /**
         * Traverses elements to create list from elements.
         *
         * This function is designed to enhance Walker::display_element() to
         * display children of higher nesting levels than selected inline on
         * the highest depth level displayed. This prevents them being orphaned
         * at the end of the comment list.
         *
         * Example: max_depth = 2, with 5 levels of nested content.
         *     1
         *      1.1
         *        1.1.1
         *        1.1.1.1
         *        1.1.1.1.1
         *        1.1.2
         *        1.1.2.1
         *     2
         *      2.2
         *
         * @since 2.7.0
         *
         * @see Walker::display_element()
         * @see wp_list_comments()
         *
         * @param WP_Comment $element           Comment data object.
         * @param array      $children_elements List of elements to continue traversing. Passed by reference.
         * @param int        $max_depth         Max depth to traverse.
         * @param int        $depth             Depth of the current element.
         * @param array      $args              An array of arguments.
         * @param string     $output            Used to append additional content. Passed by reference.
         * @phpstan-return void
         */
        public function display_element($element, &$children_elements, $max_depth, $depth, $args, &$output)
        {
        }
        /**
         * Starts the element output.
         *
         * @since 2.7.0
         * @since 5.9.0 Renamed `$comment` to `$data_object` and `$id` to `$current_object_id`
         *              to match parent class for PHP 8 named parameter support.
         *
         * @see Walker::start_el()
         * @see wp_list_comments()
         * @global int        $comment_depth
         * @global WP_Comment $comment       Global comment object.
         *
         * @param string     $output            Used to append additional content. Passed by reference.
         * @param WP_Comment $data_object       Comment data object.
         * @param int        $depth             Optional. Depth of the current comment in reference to parents. Default 0.
         * @param array      $args              Optional. An array of arguments. Default empty array.
         * @param int        $current_object_id Optional. ID of the current comment. Default 0.
         * @phpstan-return void
         */
        public function start_el(&$output, $data_object, $depth = 0, $args = array(), $current_object_id = 0)
        {
        }
        /**
         * Ends the element output, if needed.
         *
         * @since 2.7.0
         * @since 5.9.0 Renamed `$comment` to `$data_object` to match parent class for PHP 8 named parameter support.
         *
         * @see Walker::end_el()
         * @see wp_list_comments()
         *
         * @param string     $output      Used to append additional content. Passed by reference.
         * @param WP_Comment $data_object Comment data object.
         * @param int        $depth       Optional. Depth of the current comment. Default 0.
         * @param array      $args        Optional. An array of arguments. Default empty array.
         * @phpstan-return void
         */
        public function end_el(&$output, $data_object, $depth = 0, $args = array())
        {
        }
        /**
         * Outputs a pingback comment.
         *
         * @since 3.6.0
         *
         * @see wp_list_comments()
         *
         * @param WP_Comment $comment The comment object.
         * @param int        $depth   Depth of the current comment.
         * @param array      $args    An array of arguments.
         */
        protected function ping($comment, $depth, $args)
        {
        }
        /**
         * Filters the comment text.
         *
         * Removes links from the pending comment's text if the commenter did not consent
         * to the comment cookies.
         *
         * @since 5.4.2
         *
         * @param string          $comment_text Text of the current comment.
         * @param WP_Comment|null $comment      The comment object. Null if not found.
         * @return string Filtered text of the current comment.
         */
        public function filter_comment_text($comment_text, $comment)
        {
        }
        /**
         * Outputs a single comment.
         *
         * @since 3.6.0
         *
         * @see wp_list_comments()
         *
         * @param WP_Comment $comment Comment to display.
         * @param int        $depth   Depth of the current comment.
         * @param array      $args    An array of arguments.
         */
        protected function comment($comment, $depth, $args)
        {
        }
        /**
         * Outputs a comment in the HTML5 format.
         *
         * @since 3.6.0
         *
         * @see wp_list_comments()
         *
         * @param WP_Comment $comment Comment to display.
         * @param int        $depth   Depth of the current comment.
         * @param array      $args    An array of arguments.
         */
        protected function html5_comment($comment, $depth, $args)
        {
        }
    }
    /**
     * Core class used to create an HTML drop-down list of pages.
     *
     * @since 2.1.0
     *
     * @see Walker
     */
    class Walker_PageDropdown extends \Walker
    {
        /**
         * What the class handles.
         *
         * @since 2.1.0
         * @var string
         *
         * @see Walker::$tree_type
         */
        public $tree_type = 'page';
        /**
         * Database fields to use.
         *
         * @since 2.1.0
         * @var string[]
         *
         * @see Walker::$db_fields
         * @todo Decouple this
         */
        public $db_fields = array('parent' => 'post_parent', 'id' => 'ID');
        /**
         * Starts the element output.
         *
         * @since 2.1.0
         * @since 5.9.0 Renamed `$page` to `$data_object` and `$id` to `$current_object_id`
         *              to match parent class for PHP 8 named parameter support.
         *
         * @see Walker::start_el()
         *
         * @param string  $output            Used to append additional content. Passed by reference.
         * @param WP_Post $data_object       Page data object.
         * @param int     $depth             Optional. Depth of page in reference to parent pages.
         *                                   Used for padding. Default 0.
         * @param array   $args              Optional. Uses 'selected' argument for selected page to
         *                                   set selected HTML attribute for option element. Uses
         *                                   'value_field' argument to fill "value" attribute.
         *                                   See wp_dropdown_pages(). Default empty array.
         * @param int     $current_object_id Optional. ID of the current page. Default 0.
         * @phpstan-param array{
         *   depth?: int,
         *   child_of?: int,
         *   selected?: int|string,
         *   echo?: bool|int,
         *   name?: string,
         *   id?: string,
         *   class?: string,
         *   show_option_none?: string,
         *   show_option_no_change?: string,
         *   option_none_value?: string,
         *   value_field?: string,
         * } $args See wp_dropdown_pages()
         */
        public function start_el(&$output, $data_object, $depth = 0, $args = array(), $current_object_id = 0)
        {
        }
    }
    /**
     * Core walker class used to create an HTML list of pages.
     *
     * @since 2.1.0
     *
     * @see Walker
     */
    class Walker_Page extends \Walker
    {
        /**
         * What the class handles.
         *
         * @since 2.1.0
         * @var string
         *
         * @see Walker::$tree_type
         */
        public $tree_type = 'page';
        /**
         * Database fields to use.
         *
         * @since 2.1.0
         * @var string[]
         *
         * @see Walker::$db_fields
         * @todo Decouple this.
         */
        public $db_fields = array('parent' => 'post_parent', 'id' => 'ID');
        /**
         * Outputs the beginning of the current level in the tree before elements are output.
         *
         * @since 2.1.0
         *
         * @see Walker::start_lvl()
         *
         * @param string $output Used to append additional content (passed by reference).
         * @param int    $depth  Optional. Depth of page. Used for padding. Default 0.
         * @param array  $args   Optional. Arguments for outputting the next level.
         *                       Default empty array.
         */
        public function start_lvl(&$output, $depth = 0, $args = array())
        {
        }
        /**
         * Outputs the end of the current level in the tree after elements are output.
         *
         * @since 2.1.0
         *
         * @see Walker::end_lvl()
         *
         * @param string $output Used to append additional content (passed by reference).
         * @param int    $depth  Optional. Depth of page. Used for padding. Default 0.
         * @param array  $args   Optional. Arguments for outputting the end of the current level.
         *                       Default empty array.
         */
        public function end_lvl(&$output, $depth = 0, $args = array())
        {
        }
        /**
         * Outputs the beginning of the current element in the tree.
         *
         * @see Walker::start_el()
         * @since 2.1.0
         * @since 5.9.0 Renamed `$page` to `$data_object` and `$current_page` to `$current_object_id`
         *              to match parent class for PHP 8 named parameter support.
         *
         * @param string  $output            Used to append additional content. Passed by reference.
         * @param WP_Post $data_object       Page data object.
         * @param int     $depth             Optional. Depth of page. Used for padding. Default 0.
         * @param array   $args              Optional. Array of arguments. Default empty array.
         * @param int     $current_object_id Optional. ID of the current page. Default 0.
         */
        public function start_el(&$output, $data_object, $depth = 0, $args = array(), $current_object_id = 0)
        {
        }
        /**
         * Outputs the end of the current element in the tree.
         *
         * @since 2.1.0
         * @since 5.9.0 Renamed `$page` to `$data_object` to match parent class for PHP 8 named parameter support.
         *
         * @see Walker::end_el()
         *
         * @param string  $output      Used to append additional content. Passed by reference.
         * @param WP_Post $data_object Page data object. Not used.
         * @param int     $depth       Optional. Depth of page. Default 0 (unused).
         * @param array   $args        Optional. Array of arguments. Default empty array.
         */
        public function end_el(&$output, $data_object, $depth = 0, $args = array())
        {
        }
    }
    /**
     * Core class used to implement the Toolbar API.
     *
     * @since 3.1.0
     */
    #[\AllowDynamicProperties]
    class WP_Admin_Bar
    {
        public $user;
        /**
         * Deprecated menu property.
         *
         * @since 3.1.0
         * @deprecated 3.3.0 Modify admin bar nodes with WP_Admin_Bar::get_node(),
         *                   WP_Admin_Bar::add_node(), and WP_Admin_Bar::remove_node().
         * @var array
         */
        public $menu = array();
        /**
         * Initializes the admin bar.
         *
         * @since 3.1.0
         */
        public function initialize()
        {
        }
        /**
         * Adds a node (menu item) to the admin bar menu.
         *
         * @since 3.3.0
         *
         * @param array $node The attributes that define the node.
         */
        public function add_menu($node)
        {
        }
        /**
         * Removes a node from the admin bar.
         *
         * @since 3.1.0
         *
         * @param string $id The menu slug to remove.
         */
        public function remove_menu($id)
        {
        }
        /**
         * Adds a node to the menu.
         *
         * @since 3.1.0
         * @since 4.5.0 Added the ability to pass 'lang' and 'dir' meta data.
         * @since 6.5.0 Added the ability to pass 'menu_title' for an ARIA menu name.
         *
         * @param array $args {
         *     Arguments for adding a node.
         *
         *     @type string $id     ID of the item.
         *     @type string $title  Title of the node.
         *     @type string $parent Optional. ID of the parent node.
         *     @type string $href   Optional. Link for the item.
         *     @type bool   $group  Optional. Whether or not the node is a group. Default false.
         *     @type array  $meta   Meta data including the following keys: 'html', 'class', 'rel', 'lang', 'dir',
         *                          'onclick', 'target', 'title', 'tabindex', 'menu_title'. Default empty.
         * }
         * @phpstan-param array{
         *   id?: string,
         *   title?: string,
         *   parent?: string,
         *   href?: string,
         *   group?: bool,
         *   meta?: array,
         * } $args
         * @phpstan-return void
         */
        public function add_node($args)
        {
        }
        /**
         * @since 3.3.0
         *
         * @param array $args
         */
        protected final function _set_node($args)
        {
        }
        /**
         * Gets a node.
         *
         * @since 3.3.0
         *
         * @param string $id
         * @return object|void Node.
         */
        public final function get_node($id)
        {
        }
        /**
         * @since 3.3.0
         *
         * @param string $id
         * @return object|void
         */
        protected final function _get_node($id)
        {
        }
        /**
         * @since 3.3.0
         *
         * @return array|void
         */
        public final function get_nodes()
        {
        }
        /**
         * @since 3.3.0
         *
         * @return array|void
         */
        protected final function _get_nodes()
        {
        }
        /**
         * Adds a group to a toolbar menu node.
         *
         * Groups can be used to organize toolbar items into distinct sections of a toolbar menu.
         *
         * @since 3.3.0
         *
         * @param array $args {
         *     Array of arguments for adding a group.
         *
         *     @type string $id     ID of the item.
         *     @type string $parent Optional. ID of the parent node. Default 'root'.
         *     @type array  $meta   Meta data for the group including the following keys:
         *                         'class', 'onclick', 'target', and 'title'.
         * }
         * @phpstan-param array{
         *   id?: string,
         *   parent?: string,
         *   meta?: array,
         * } $args
         */
        public final function add_group($args)
        {
        }
        /**
         * Remove a node.
         *
         * @since 3.1.0
         *
         * @param string $id The ID of the item.
         */
        public function remove_node($id)
        {
        }
        /**
         * @since 3.3.0
         *
         * @param string $id
         */
        protected final function _unset_node($id)
        {
        }
        /**
         * @since 3.1.0
         */
        public function render()
        {
        }
        /**
         * @since 3.3.0
         *
         * @return object|void
         */
        protected final function _bind()
        {
        }
        /**
         * @since 3.3.0
         *
         * @param object $root
         */
        protected final function _render($root)
        {
        }
        /**
         * @since 3.3.0
         *
         * @param object $node
         * @phpstan-return void
         */
        protected final function _render_container($node)
        {
        }
        /**
         * @since 3.3.0
         * @since 6.5.0 Added `$menu_title` parameter to allow an ARIA menu name.
         *
         * @param object $node
         * @param string|bool $menu_title The accessible name of this ARIA menu or false if not provided.
         * @phpstan-return void
         */
        protected final function _render_group($node, $menu_title = \false)
        {
        }
        /**
         * @since 3.3.0
         *
         * @param object $node
         * @phpstan-return void
         */
        protected final function _render_item($node)
        {
        }
        /**
         * Renders toolbar items recursively.
         *
         * @since 3.1.0
         * @deprecated 3.3.0 Use WP_Admin_Bar::_render_item() or WP_Admin_bar::render() instead.
         * @see WP_Admin_Bar::_render_item()
         * @see WP_Admin_Bar::render()
         *
         * @param string $id    Unused.
         * @param object $node
         */
        public function recursive_render($id, $node)
        {
        }
        /**
         * Adds menus to the admin bar.
         *
         * @since 3.1.0
         */
        public function add_menus()
        {
        }
    }
    /**
     * Send XML response back to Ajax request.
     *
     * @package WordPress
     * @since 2.1.0
     */
    #[\AllowDynamicProperties]
    class WP_Ajax_Response
    {
        /**
         * Store XML responses to send.
         *
         * @since 2.1.0
         * @var array
         */
        public $responses = array();
        /**
         * Constructor - Passes args to WP_Ajax_Response::add().
         *
         * @since 2.1.0
         *
         * @see WP_Ajax_Response::add()
         *
         * @param string|array $args Optional. Will be passed to add() method.
         */
        public function __construct($args = '')
        {
        }
        /**
         * Appends data to an XML response based on given arguments.
         *
         * With `$args` defaults, extra data output would be:
         *
         *     <response action='{$action}_$id'>
         *      <$what id='$id' position='$position'>
         *          <response_data><![CDATA[$data]]></response_data>
         *      </$what>
         *     </response>
         *
         * @since 2.1.0
         *
         * @param string|array $args {
         *     Optional. An array or string of XML response arguments.
         *
         *     @type string          $what         XML-RPC response type. Used as a child element of `<response>`.
         *                                         Default 'object' (`<object>`).
         *     @type string|false    $action       Value to use for the `action` attribute in `<response>`. Will be
         *                                         appended with `_$id` on output. If false, `$action` will default to
         *                                         the value of `$_POST['action']`. Default false.
         *     @type int|WP_Error    $id           The response ID, used as the response type `id` attribute. Also
         *                                         accepts a `WP_Error` object if the ID does not exist. Default 0.
         *     @type int|false       $old_id       The previous response ID. Used as the value for the response type
         *                                         `old_id` attribute. False hides the attribute. Default false.
         *     @type string          $position     Value of the response type `position` attribute. Accepts 1 (bottom),
         *                                         -1 (top), HTML ID (after), or -HTML ID (before). Default 1 (bottom).
         *     @type string|WP_Error $data         The response content/message. Also accepts a WP_Error object if the
         *                                         ID does not exist. Default empty.
         *     @type array           $supplemental An array of extra strings that will be output within a `<supplemental>`
         *                                         element as CDATA. Default empty array.
         * }
         * @return string XML response.
         * @phpstan-param array{
         *   what?: string,
         *   action?: string|false,
         *   id?: int|WP_Error,
         *   old_id?: int|false,
         *   position?: string,
         *   data?: string|WP_Error,
         *   supplemental?: array,
         * } $args
         */
        public function add($args = '')
        {
        }
        /**
         * Display XML formatted responses.
         *
         * Sets the content type header to text/xml.
         *
         * @since 2.1.0
         */
        public function send()
        {
        }
    }
    /**
     * Class for displaying, modifying, and sanitizing application passwords.
     *
     * @package WordPress
     */
    #[\AllowDynamicProperties]
    class WP_Application_Passwords
    {
        /**
         * The application passwords user meta key.
         *
         * @since 5.6.0
         *
         * @var string
         */
        const USERMETA_KEY_APPLICATION_PASSWORDS = '_application_passwords';
        /**
         * The option name used to store whether application passwords are in use.
         *
         * @since 5.6.0
         *
         * @var string
         */
        const OPTION_KEY_IN_USE = 'using_application_passwords';
        /**
         * The generated application password length.
         *
         * @since 5.6.0
         *
         * @var int
         */
        const PW_LENGTH = 24;
        /**
         * Checks if application passwords are being used by the site.
         *
         * This returns true if at least one application password has ever been created.
         *
         * @since 5.6.0
         *
         * @return bool
         */
        public static function is_in_use()
        {
        }
        /**
         * Creates a new application password.
         *
         * @since 5.6.0
         * @since 5.7.0 Returns WP_Error if application name already exists.
         *
         * @param int   $user_id  User ID.
         * @param array $args     {
         *     Arguments used to create the application password.
         *
         *     @type string $name   The name of the application password.
         *     @type string $app_id A UUID provided by the application to uniquely identify it.
         * }
         * @return array|WP_Error {
         *     Application password details, or a WP_Error instance if an error occurs.
         *
         *     @type string $0 The generated application password in plain text.
         *     @type array  $1 {
         *         The details about the created password.
         *
         *         @type string $uuid      The unique identifier for the application password.
         *         @type string $app_id    A UUID provided by the application to uniquely identify it.
         *         @type string $name      The name of the application password.
         *         @type string $password  A one-way hash of the password.
         *         @type int    $created   Unix timestamp of when the password was created.
         *         @type null   $last_used Null.
         *         @type null   $last_ip   Null.
         *     }
         * }
         * @phpstan-param array{
         *   name?: string,
         *   app_id?: string,
         * } $args
         * @phpstan-return \WP_Error|array{
         *   0: string,
         *   1: array{
         *     uuid: string,
         *     app_id: string,
         *     name: string,
         *     password: string,
         *     created: int,
         *     last_used: null,
         *     last_ip: null,
         *   },
         * }
         */
        public static function create_new_application_password($user_id, $args = array())
        {
        }
        /**
         * Gets a user's application passwords.
         *
         * @since 5.6.0
         *
         * @param int $user_id User ID.
         * @return array {
         *     The list of application passwords.
         *
         *     @type array ...$0 {
         *         @type string      $uuid      The unique identifier for the application password.
         *         @type string      $app_id    A UUID provided by the application to uniquely identify it.
         *         @type string      $name      The name of the application password.
         *         @type string      $password  A one-way hash of the password.
         *         @type int         $created   Unix timestamp of when the password was created.
         *         @type int|null    $last_used The Unix timestamp of the GMT date the application password was last used.
         *         @type string|null $last_ip   The IP address the application password was last used by.
         *     }
         * }
         * @phpstan-return array<int|string, array{
         *   uuid: string,
         *   app_id: string,
         *   name: string,
         *   password: string,
         *   created: int,
         *   last_used: int|null,
         *   last_ip: string|null,
         * }>
         */
        public static function get_user_application_passwords($user_id)
        {
        }
        /**
         * Gets a user's application password with the given UUID.
         *
         * @since 5.6.0
         *
         * @param int    $user_id User ID.
         * @param string $uuid    The password's UUID.
         * @return array|null {
         *     The application password if found, null otherwise.
         *
         *     @type string      $uuid      The unique identifier for the application password.
         *     @type string      $app_id    A UUID provided by the application to uniquely identify it.
         *     @type string      $name      The name of the application password.
         *     @type string      $password  A one-way hash of the password.
         *     @type int         $created   Unix timestamp of when the password was created.
         *     @type int|null    $last_used The Unix timestamp of the GMT date the application password was last used.
         *     @type string|null $last_ip   The IP address the application password was last used by.
         * }
         * @phpstan-return null|array{
         *   uuid: string,
         *   app_id: string,
         *   name: string,
         *   password: string,
         *   created: int,
         *   last_used: int|null,
         *   last_ip: string|null,
         * }
         */
        public static function get_user_application_password($user_id, $uuid)
        {
        }
        /**
         * Checks if an application password with the given name exists for this user.
         *
         * @since 5.7.0
         *
         * @param int    $user_id User ID.
         * @param string $name    Application name.
         * @return bool Whether the provided application name exists.
         */
        public static function application_name_exists_for_user($user_id, $name)
        {
        }
        /**
         * Updates an application password.
         *
         * @since 5.6.0
         *
         * @param int    $user_id User ID.
         * @param string $uuid    The password's UUID.
         * @param array  $update  {
         *     Information about the application password to update.
         *
         *     @type string      $uuid      The unique identifier for the application password.
         *     @type string      $app_id    A UUID provided by the application to uniquely identify it.
         *     @type string      $name      The name of the application password.
         *     @type string      $password  A one-way hash of the password.
         *     @type int         $created   Unix timestamp of when the password was created.
         *     @type int|null    $last_used The Unix timestamp of the GMT date the application password was last used.
         *     @type string|null $last_ip   The IP address the application password was last used by.
         * }
         * @return true|WP_Error True if successful, otherwise a WP_Error instance is returned on error.
         * @phpstan-param array{
         *   uuid?: string,
         *   app_id?: string,
         *   name?: string,
         *   password?: string,
         *   created?: int,
         *   last_used?: int|null,
         *   last_ip?: string|null,
         * } $update
         */
        public static function update_application_password($user_id, $uuid, $update = array())
        {
        }
        /**
         * Records that an application password has been used.
         *
         * @since 5.6.0
         *
         * @param int    $user_id User ID.
         * @param string $uuid    The password's UUID.
         * @return true|WP_Error True if the usage was recorded, a WP_Error if an error occurs.
         */
        public static function record_application_password_usage($user_id, $uuid)
        {
        }
        /**
         * Deletes an application password.
         *
         * @since 5.6.0
         *
         * @param int    $user_id User ID.
         * @param string $uuid    The password's UUID.
         * @return true|WP_Error Whether the password was successfully found and deleted, a WP_Error otherwise.
         */
        public static function delete_application_password($user_id, $uuid)
        {
        }
        /**
         * Deletes all application passwords for the given user.
         *
         * @since 5.6.0
         *
         * @param int $user_id User ID.
         * @return int|WP_Error The number of passwords that were deleted or a WP_Error on failure.
         */
        public static function delete_all_application_passwords($user_id)
        {
        }
        /**
         * Sets a user's application passwords.
         *
         * @since 5.6.0
         *
         * @param int   $user_id   User ID.
         * @param array $passwords {
         *     The list of application passwords.
         *
         *     @type array ...$0 {
         *         @type string      $uuid      The unique identifier for the application password.
         *         @type string      $app_id    A UUID provided by the application to uniquely identify it.
         *         @type string      $name      The name of the application password.
         *         @type string      $password  A one-way hash of the password.
         *         @type int         $created   Unix timestamp of when the password was created.
         *         @type int|null    $last_used The Unix timestamp of the GMT date the application password was last used.
         *         @type string|null $last_ip   The IP address the application password was last used by.
         *     }
         * }
         * @return int|bool User meta ID if the key didn't exist (ie. this is the first time that an application password
         *                  has been saved for the user), true on successful update, false on failure or if the value passed
         *                  is the same as the one that is already in the database.
         * @phpstan-param array<int|string, array{
         *   uuid: string,
         *   app_id: string,
         *   name: string,
         *   password: string,
         *   created: int,
         *   last_used: int|null,
         *   last_ip: string|null,
         * }> $passwords
         */
        protected static function set_user_application_passwords($user_id, $passwords)
        {
        }
        /**
         * Sanitizes and then splits a password into smaller chunks.
         *
         * @since 5.6.0
         *
         * @param string $raw_password The raw application password.
         * @return string The chunked password.
         */
        public static function chunk_password($raw_password)
        {
        }
    }
    /**
     * Core class used for interacting with block bindings sources.
     *
     * @since 6.5.0
     */
    final class WP_Block_Bindings_Registry
    {
        /**
         * Registers a new block bindings source.
         *
         * This is a low-level method. For most use cases, it is recommended to use
         * the `register_block_bindings_source()` function instead.
         *
         * @see register_block_bindings_source()
         *
         * Sources are used to override block's original attributes with a value
         * coming from the source. Once a source is registered, it can be used by a
         * block by setting its `metadata.bindings` attribute to a value that refers
         * to the source.
         *
         * @since 6.5.0
         *
         * @param string $source_name       The name of the source. It must be a string containing a namespace prefix, i.e.
         *                                  `my-plugin/my-custom-source`. It must only contain lowercase alphanumeric
         *                                  characters, the forward slash `/` and dashes.
         * @param array  $source_properties {
         *     The array of arguments that are used to register a source.
         *
         *     @type string   $label              The label of the source.
         *     @type callable $get_value_callback A callback executed when the source is processed during block rendering.
         *                                        The callback should have the following signature:
         *
         *                                        `function( $source_args, $block_instance, $attribute_name ): mixed`
         *                                            - @param array    $source_args    Array containing source arguments
         *                                                                              used to look up the override value,
         *                                                                              i.e. {"key": "foo"}.
         *                                            - @param WP_Block $block_instance The block instance.
         *                                            - @param string   $attribute_name The name of the target attribute.
         *                                        The callback has a mixed return type; it may return a string to override
         *                                        the block's original value, null, false to remove an attribute, etc.
         *     @type string[] $uses_context       Optional. Array of values to add to block `uses_context` needed by the source.
         * }
         * @return WP_Block_Bindings_Source|false Source when the registration was successful, or `false` on failure.
         * @phpstan-param array{
         *   label?: string,
         *   get_value_callback?: callable,
         *   uses_context?: string[],
         * } $source_properties
         */
        public function register(string $source_name, array $source_properties)
        {
        }
        /**
         * Unregisters a block bindings source.
         *
         * @since 6.5.0
         *
         * @param string $source_name Block bindings source name including namespace.
         * @return WP_Block_Bindings_Source|false The unregistered block bindings source on success and `false` otherwise.
         */
        public function unregister(string $source_name)
        {
        }
        /**
         * Retrieves the list of all registered block bindings sources.
         *
         * @since 6.5.0
         *
         * @return WP_Block_Bindings_Source[] The array of registered sources.
         */
        public function get_all_registered()
        {
        }
        /**
         * Retrieves a registered block bindings source.
         *
         * @since 6.5.0
         *
         * @param string $source_name The name of the source.
         * @return WP_Block_Bindings_Source|null The registered block bindings source, or `null` if it is not registered.
         */
        public function get_registered(string $source_name)
        {
        }
        /**
         * Checks if a block bindings source is registered.
         *
         * @since 6.5.0
         *
         * @param string $source_name The name of the source.
         * @return bool `true` if the block bindings source is registered, `false` otherwise.
         */
        public function is_registered($source_name)
        {
        }
        /**
         * Wakeup magic method.
         *
         * @since 6.5.0
         * @phpstan-return void
         */
        public function __wakeup()
        {
        }
        /**
         * Utility method to retrieve the main instance of the class.
         *
         * The instance will be created if it does not exist yet.
         *
         * @since 6.5.0
         *
         * @return WP_Block_Bindings_Registry The main instance.
         */
        public static function get_instance()
        {
        }
    }
    /**
     * Class representing block bindings source.
     *
     * This class is designed for internal use by the Block Bindings registry.
     *
     * @since 6.5.0
     * @access private
     *
     * @see WP_Block_Bindings_Registry
     */
    final class WP_Block_Bindings_Source
    {
        /**
         * The name of the source.
         *
         * @since 6.5.0
         * @var string
         */
        public $name;
        /**
         * The label of the source.
         *
         * @since 6.5.0
         * @var string
         */
        public $label;
        /**
         * The context added to the blocks needed by the source.
         *
         * @since 6.5.0
         * @var string[]|null
         */
        public $uses_context = \null;
        /**
         * Constructor.
         *
         * Do not use this constructor directly. Instead, use the
         * `WP_Block_Bindings_Registry::register` method or the `register_block_bindings_source` function.
         *
         * @since 6.5.0
         *
         * @param string $name              The name of the source.
         * @param array  $source_properties The properties of the source.
         */
        public function __construct(string $name, array $source_properties)
        {
        }
        /**
         * Calls the callback function specified in the `$get_value_callback` property
         * with the given arguments and returns the result. It can be modified with
         * `block_bindings_source_value` filter.
         *
         * @since 6.5.0
         * @since 6.7.0 `block_bindings_source_value` filter was added.
         *
         * @param array    $source_args    Array containing source arguments used to look up the override value, i.e. {"key": "foo"}.
         * @param WP_Block $block_instance The block instance.
         * @param string   $attribute_name The name of the target attribute.
         * @return mixed The value of the source.
         */
        public function get_value(array $source_args, $block_instance, string $attribute_name)
        {
        }
        /**
         * Wakeup magic method.
         *
         * @since 6.5.0
         */
        public function __wakeup()
        {
        }
    }
    /**
     * Contains information about a block editor being rendered.
     *
     * @since 5.8.0
     */
    #[\AllowDynamicProperties]
    final class WP_Block_Editor_Context
    {
        /**
         * String that identifies the block editor being rendered. Can be one of:
         *
         * - `'core/edit-post'`         - The post editor at `/wp-admin/edit.php`.
         * - `'core/edit-widgets'`      - The widgets editor at `/wp-admin/widgets.php`.
         * - `'core/customize-widgets'` - The widgets editor at `/wp-admin/customize.php`.
         * - `'core/edit-site'`         - The site editor at `/wp-admin/site-editor.php`.
         *
         * Defaults to 'core/edit-post'.
         *
         * @since 6.0.0
         *
         * @var string
         */
        public $name = 'core/edit-post';
        /**
         * The post being edited by the block editor. Optional.
         *
         * @since 5.8.0
         *
         * @var WP_Post|null
         */
        public $post = \null;
        /**
         * Constructor.
         *
         * Populates optional properties for a given block editor context.
         *
         * @since 5.8.0
         *
         * @param array $settings The list of optional settings to expose in a given context.
         */
        public function __construct(array $settings = array())
        {
        }
    }
    /**
     * Class representing a list of block instances.
     *
     * @since 5.5.0
     * @phpstan-implements ArrayAccess<int, WP_Block>
     */
    #[\AllowDynamicProperties]
    class WP_Block_List implements \Iterator, \ArrayAccess, \Countable
    {
        /**
         * Original array of parsed block data, or block instances.
         *
         * @since 5.5.0
         * @var array[]|WP_Block[]
         * @access protected
         */
        protected $blocks;
        /**
         * All available context of the current hierarchy.
         *
         * @since 5.5.0
         * @var array
         * @access protected
         */
        protected $available_context;
        /**
         * Block type registry to use in constructing block instances.
         *
         * @since 5.5.0
         * @var WP_Block_Type_Registry
         * @access protected
         */
        protected $registry;
        /**
         * Constructor.
         *
         * Populates object properties from the provided block instance argument.
         *
         * @since 5.5.0
         *
         * @param array[]|WP_Block[]     $blocks            Array of parsed block data, or block instances.
         * @param array                  $available_context Optional array of ancestry context values.
         * @param WP_Block_Type_Registry $registry          Optional block type registry.
         */
        public function __construct($blocks, $available_context = array(), $registry = \null)
        {
        }
        /**
         * Returns true if a block exists by the specified block offset, or false
         * otherwise.
         *
         * @since 5.5.0
         *
         * @link https://www.php.net/manual/en/arrayaccess.offsetexists.php
         *
         * @param string $offset Offset of block to check for.
         * @return bool Whether block exists.
         * @phpstan-param int $offset
         */
        #[\ReturnTypeWillChange]
        public function offsetExists($offset)
        {
        }
        /**
         * Returns the value by the specified block offset.
         *
         * @since 5.5.0
         *
         * @link https://www.php.net/manual/en/arrayaccess.offsetget.php
         *
         * @param string $offset Offset of block value to retrieve.
         * @return mixed|null Block value if exists, or null.
         * @phpstan-param int $offset
         * @phpstan-return WP_Block|null
         */
        #[\ReturnTypeWillChange]
        public function offsetGet($offset)
        {
        }
        /**
         * Assign a block value by the specified block offset.
         *
         * @since 5.5.0
         *
         * @link https://www.php.net/manual/en/arrayaccess.offsetset.php
         *
         * @param string $offset Offset of block value to set.
         * @param mixed  $value Block value.
         * @phpstan-param int|null $offset
         * @phpstan-return void
         */
        #[\ReturnTypeWillChange]
        public function offsetSet($offset, $value)
        {
        }
        /**
         * Unset a block.
         *
         * @since 5.5.0
         *
         * @link https://www.php.net/manual/en/arrayaccess.offsetunset.php
         *
         * @param string $offset Offset of block value to unset.
         * @phpstan-param int $offset
         * @phpstan-return void
         */
        #[\ReturnTypeWillChange]
        public function offsetUnset($offset)
        {
        }
        /**
         * Rewinds back to the first element of the Iterator.
         *
         * @since 5.5.0
         *
         * @link https://www.php.net/manual/en/iterator.rewind.php
         */
        #[\ReturnTypeWillChange]
        public function rewind()
        {
        }
        /**
         * Returns the current element of the block list.
         *
         * @since 5.5.0
         *
         * @link https://www.php.net/manual/en/iterator.current.php
         *
         * @return mixed Current element.
         */
        #[\ReturnTypeWillChange]
        public function current()
        {
        }
        /**
         * Returns the key of the current element of the block list.
         *
         * @since 5.5.0
         *
         * @link https://www.php.net/manual/en/iterator.key.php
         *
         * @return mixed Key of the current element.
         */
        #[\ReturnTypeWillChange]
        public function key()
        {
        }
        /**
         * Moves the current position of the block list to the next element.
         *
         * @since 5.5.0
         *
         * @link https://www.php.net/manual/en/iterator.next.php
         */
        #[\ReturnTypeWillChange]
        public function next()
        {
        }
        /**
         * Checks if current position is valid.
         *
         * @since 5.5.0
         *
         * @link https://www.php.net/manual/en/iterator.valid.php
         */
        #[\ReturnTypeWillChange]
        public function valid()
        {
        }
        /**
         * Returns the count of blocks in the list.
         *
         * @since 5.5.0
         *
         * @link https://www.php.net/manual/en/countable.count.php
         *
         * @return int Block count.
         */
        #[\ReturnTypeWillChange]
        public function count()
        {
        }
    }
    /**
     * Class used for managing block metadata collections.
     *
     * The WP_Block_Metadata_Registry allows plugins to register metadata for large
     * collections of blocks (e.g., 50-100+) using a single PHP file. This approach
     * reduces the need to read and decode multiple `block.json` files, enhancing
     * performance through opcode caching.
     *
     * @since 6.7.0
     */
    class WP_Block_Metadata_Registry
    {
        /**
         * Registers a block metadata collection.
         *
         * This method allows registering a collection of block metadata from a single
         * manifest file, improving performance for large sets of blocks.
         *
         * The manifest file should be a PHP file that returns an associative array, where
         * the keys are the block identifiers (without their namespace) and the values are
         * the corresponding block metadata arrays. The block identifiers must match the
         * parent directory name for the respective `block.json` file.
         *
         * Example manifest file structure:
         * ```
         * return array(
         *     'example-block' => array(
         *         'title' => 'Example Block',
         *         'category' => 'widgets',
         *         'icon' => 'smiley',
         *         // ... other block metadata
         *     ),
         *     'another-block' => array(
         *         'title' => 'Another Block',
         *         'category' => 'formatting',
         *         'icon' => 'star-filled',
         *         // ... other block metadata
         *     ),
         *     // ... more block metadata entries
         * );
         * ```
         *
         * @since 6.7.0
         *
         * @param string $path     The absolute base path for the collection ( e.g., WP_PLUGIN_DIR . '/my-plugin/blocks/' ).
         * @param string $manifest The absolute path to the manifest file containing the metadata collection.
         * @return bool True if the collection was registered successfully, false otherwise.
         */
        public static function register_collection($path, $manifest)
        {
        }
        /**
         * Retrieves block metadata for a given block within a specific collection.
         *
         * This method uses the registered collections to efficiently lookup
         * block metadata without reading individual `block.json` files.
         *
         * @since 6.7.0
         *
         * @param string $file_or_folder The path to the file or folder containing the block.
         * @return array|null The block metadata for the block, or null if not found.
         */
        public static function get_metadata($file_or_folder)
        {
        }
        /**
         * Checks if metadata exists for a given block name in a specific collection.
         *
         * @since 6.7.0
         *
         * @param string $file_or_folder The path to the file or folder containing the block metadata.
         * @return bool True if metadata exists for the block, false otherwise.
         */
        public static function has_metadata($file_or_folder)
        {
        }
    }
    /**
     * Class WP_Block_Parser_Block
     *
     * Holds the block structure in memory
     *
     * @since 5.0.0
     */
    class WP_Block_Parser_Block
    {
        /**
         * Name of block
         *
         * @example "core/paragraph"
         *
         * @since 5.0.0
         * @var string
         */
        public $blockName;
        /**
         * Optional set of attributes from block comment delimiters
         *
         * @example null
         * @example array( 'columns' => 3 )
         *
         * @since 5.0.0
         * @var array|null
         */
        public $attrs;
        /**
         * List of inner blocks (of this same class)
         *
         * @since 5.0.0
         * @var WP_Block_Parser_Block[]
         */
        public $innerBlocks;
        /**
         * Resultant HTML from inside block comment delimiters
         * after removing inner blocks
         *
         * @example "...Just <!-- wp:test /--> testing..." -> "Just testing..."
         *
         * @since 5.0.0
         * @var string
         */
        public $innerHTML;
        /**
         * List of string fragments and null markers where inner blocks were found
         *
         * @example array(
         *   'innerHTML'    => 'BeforeInnerAfter',
         *   'innerBlocks'  => array( block, block ),
         *   'innerContent' => array( 'Before', null, 'Inner', null, 'After' ),
         * )
         *
         * @since 4.2.0
         * @var array
         */
        public $innerContent;
        /**
         * Constructor.
         *
         * Will populate object properties from the provided arguments.
         *
         * @since 5.0.0
         *
         * @param string $name          Name of block.
         * @param array  $attrs         Optional set of attributes from block comment delimiters.
         * @param array  $inner_blocks  List of inner blocks (of this same class).
         * @param string $inner_html    Resultant HTML from inside block comment delimiters after removing inner blocks.
         * @param array  $inner_content List of string fragments and null markers where inner blocks were found.
         */
        public function __construct($name, $attrs, $inner_blocks, $inner_html, $inner_content)
        {
        }
    }
    /**
     * Class WP_Block_Parser_Frame
     *
     * Holds partial blocks in memory while parsing
     *
     * @internal
     * @since 5.0.0
     */
    class WP_Block_Parser_Frame
    {
        /**
         * Full or partial block
         *
         * @since 5.0.0
         * @var WP_Block_Parser_Block
         */
        public $block;
        /**
         * Byte offset into document for start of parse token
         *
         * @since 5.0.0
         * @var int
         */
        public $token_start;
        /**
         * Byte length of entire parse token string
         *
         * @since 5.0.0
         * @var int
         */
        public $token_length;
        /**
         * Byte offset into document for after parse token ends
         * (used during reconstruction of stack into parse production)
         *
         * @since 5.0.0
         * @var int
         */
        public $prev_offset;
        /**
         * Byte offset into document where leading HTML before token starts
         *
         * @since 5.0.0
         * @var int
         */
        public $leading_html_start;
        /**
         * Constructor
         *
         * Will populate object properties from the provided arguments.
         *
         * @since 5.0.0
         *
         * @param WP_Block_Parser_Block $block              Full or partial block.
         * @param int                   $token_start        Byte offset into document for start of parse token.
         * @param int                   $token_length       Byte length of entire parse token string.
         * @param int|null              $prev_offset        Optional. Byte offset into document for after parse token ends. Default null.
         * @param int|null              $leading_html_start Optional. Byte offset into document where leading HTML before token starts.
         *                                                  Default null.
         */
        public function __construct($block, $token_start, $token_length, $prev_offset = \null, $leading_html_start = \null)
        {
        }
    }
    /**
     * Class WP_Block_Parser
     *
     * Parses a document and constructs a list of parsed block objects
     *
     * @since 5.0.0
     * @since 4.0.0 returns arrays not objects, all attributes are arrays
     */
    class WP_Block_Parser
    {
        /**
         * Input document being parsed
         *
         * @example "Pre-text\n<!-- wp:paragraph -->This is inside a block!<!-- /wp:paragraph -->"
         *
         * @since 5.0.0
         * @var string
         */
        public $document;
        /**
         * Tracks parsing progress through document
         *
         * @since 5.0.0
         * @var int
         */
        public $offset;
        /**
         * List of parsed blocks
         *
         * @since 5.0.0
         * @var WP_Block_Parser_Block[]
         */
        public $output;
        /**
         * Stack of partially-parsed structures in memory during parse
         *
         * @since 5.0.0
         * @var WP_Block_Parser_Frame[]
         */
        public $stack;
        /**
         * Parses a document and returns a list of block structures
         *
         * When encountering an invalid parse will return a best-effort
         * parse. In contrast to the specification parser this does not
         * return an error on invalid inputs.
         *
         * @since 5.0.0
         *
         * @param string $document Input document being parsed.
         * @return array[]
         */
        public function parse($document)
        {
        }
        /**
         * Processes the next token from the input document
         * and returns whether to proceed eating more tokens
         *
         * This is the "next step" function that essentially
         * takes a token as its input and decides what to do
         * with that token before descending deeper into a
         * nested block tree or continuing along the document
         * or breaking out of a level of nesting.
         *
         * @internal
         * @since 5.0.0
         * @return bool
         */
        public function proceed()
        {
        }
        /**
         * Scans the document from where we last left off
         * and finds the next valid token to parse if it exists
         *
         * Returns the type of the find: kind of find, block information, attributes
         *
         * @internal
         * @since 5.0.0
         * @since 4.6.1 fixed a bug in attribute parsing which caused catastrophic backtracking on invalid block comments
         * @return array
         */
        public function next_token()
        {
        }
        /**
         * Returns a new block object for freeform HTML
         *
         * @internal
         * @since 3.9.0
         *
         * @param string $inner_html HTML content of block.
         * @return WP_Block_Parser_Block freeform block object.
         */
        public function freeform($inner_html)
        {
        }
        /**
         * Pushes a length of text from the input document
         * to the output list as a freeform block.
         *
         * @internal
         * @since 5.0.0
         * @param null $length how many bytes of document text to output.
         * @phpstan-return void
         */
        public function add_freeform($length = \null)
        {
        }
        /**
         * Given a block structure from memory pushes
         * a new block to the output list.
         *
         * @internal
         * @since 5.0.0
         * @param WP_Block_Parser_Block $block        The block to add to the output.
         * @param int                   $token_start  Byte offset into the document where the first token for the block starts.
         * @param int                   $token_length Byte length of entire block from start of opening token to end of closing token.
         * @param int|null              $last_offset  Last byte offset into document if continuing form earlier output.
         */
        public function add_inner_block(\WP_Block_Parser_Block $block, $token_start, $token_length, $last_offset = \null)
        {
        }
        /**
         * Pushes the top block from the parsing stack to the output list.
         *
         * @internal
         * @since 5.0.0
         * @param int|null $end_offset byte offset into document for where we should stop sending text output as HTML.
         */
        public function add_block_from_stack($end_offset = \null)
        {
        }
    }
    /**
     * Class used for interacting with block pattern categories.
     */
    #[\AllowDynamicProperties]
    final class WP_Block_Pattern_Categories_Registry
    {
        /**
         * Registers a pattern category.
         *
         * @since 5.5.0
         *
         * @param string $category_name       Pattern category name including namespace.
         * @param array  $category_properties {
         *     List of properties for the block pattern category.
         *
         *     @type string $label Required. A human-readable label for the pattern category.
         * }
         * @return bool True if the pattern was registered with success and false otherwise.
         * @phpstan-param array{
         *   label?: string,
         * } $category_properties
         */
        public function register($category_name, $category_properties)
        {
        }
        /**
         * Unregisters a pattern category.
         *
         * @since 5.5.0
         *
         * @param string $category_name Pattern category name including namespace.
         * @return bool True if the pattern was unregistered with success and false otherwise.
         */
        public function unregister($category_name)
        {
        }
        /**
         * Retrieves an array containing the properties of a registered pattern category.
         *
         * @since 5.5.0
         *
         * @param string $category_name Pattern category name including namespace.
         * @return array Registered pattern properties.
         */
        public function get_registered($category_name)
        {
        }
        /**
         * Retrieves all registered pattern categories.
         *
         * @since 5.5.0
         *
         * @param bool $outside_init_only Return only categories registered outside the `init` action.
         * @return array[] Array of arrays containing the registered pattern categories properties.
         */
        public function get_all_registered($outside_init_only = \false)
        {
        }
        /**
         * Checks if a pattern category is registered.
         *
         * @since 5.5.0
         *
         * @param string $category_name Pattern category name including namespace.
         * @return bool True if the pattern category is registered, false otherwise.
         */
        public function is_registered($category_name)
        {
        }
        /**
         * Utility method to retrieve the main instance of the class.
         *
         * The instance will be created if it does not exist yet.
         *
         * @since 5.5.0
         *
         * @return WP_Block_Pattern_Categories_Registry The main instance.
         */
        public static function get_instance()
        {
        }
    }
    /**
     * Class used for interacting with block patterns.
     *
     * @since 5.5.0
     */
    #[\AllowDynamicProperties]
    final class WP_Block_Patterns_Registry
    {
        /**
         * Registers a block pattern.
         *
         * @since 5.5.0
         * @since 5.8.0 Added support for the `blockTypes` property.
         * @since 6.1.0 Added support for the `postTypes` property.
         * @since 6.2.0 Added support for the `templateTypes` property.
         * @since 6.5.0 Added support for the `filePath` property.
         *
         * @param string $pattern_name       Block pattern name including namespace.
         * @param array  $pattern_properties {
         *     List of properties for the block pattern.
         *
         *     @type string   $title         Required. A human-readable title for the pattern.
         *     @type string   $content       Optional. Block HTML markup for the pattern.
         *                                   If not provided, the content will be retrieved from the `filePath` if set.
         *                                   If both `content` and `filePath` are not set, the pattern will not be registered.
         *     @type string   $description   Optional. Visually hidden text used to describe the pattern
         *                                   in the inserter. A description is optional, but is strongly
         *                                   encouraged when the title does not fully describe what the
         *                                   pattern does. The description will help users discover the
         *                                   pattern while searching.
         *     @type int      $viewportWidth Optional. The intended width of the pattern to allow for a scaled
         *                                   preview within the pattern inserter.
         *     @type bool     $inserter      Optional. Determines whether the pattern is visible in inserter.
         *                                   To hide a pattern so that it can only be inserted programmatically,
         *                                   set this to false. Default true.
         *     @type string[] $categories    Optional. A list of registered pattern categories used to group
         *                                   block patterns. Block patterns can be shown on multiple categories.
         *                                   A category must be registered separately in order to be used here.
         *     @type string[] $keywords      Optional. A list of aliases or keywords that help users discover
         *                                   the pattern while searching.
         *     @type string[] $blockTypes    Optional. A list of block names including namespace that could use
         *                                   the block pattern in certain contexts (placeholder, transforms).
         *                                   The block pattern is available in the block editor inserter
         *                                   regardless of this list of block names.
         *                                   Certain blocks support further specificity besides the block name
         *                                   (e.g. for `core/template-part` you can specify areas
         *                                   like `core/template-part/header` or `core/template-part/footer`).
         *     @type string[] $postTypes     Optional. An array of post types that the pattern is restricted
         *                                   to be used with. The pattern will only be available when editing one
         *                                   of the post types passed on the array. For all the other post types
         *                                   not part of the array the pattern is not available at all.
         *     @type string[] $templateTypes Optional. An array of template types where the pattern fits.
         *     @type string   $filePath      Optional. The full path to the file containing the block pattern content.
         * }
         * @return bool True if the pattern was registered with success and false otherwise.
         * @phpstan-param array{
         *   title?: string,
         *   content?: string,
         *   description?: string,
         *   viewportWidth?: int,
         *   inserter?: bool,
         *   categories?: string[],
         *   keywords?: string[],
         *   blockTypes?: string[],
         *   postTypes?: string[],
         *   templateTypes?: string[],
         *   filePath?: string,
         * } $pattern_properties
         */
        public function register($pattern_name, $pattern_properties)
        {
        }
        /**
         * Unregisters a block pattern.
         *
         * @since 5.5.0
         *
         * @param string $pattern_name Block pattern name including namespace.
         * @return bool True if the pattern was unregistered with success and false otherwise.
         */
        public function unregister($pattern_name)
        {
        }
        /**
         * Retrieves an array containing the properties of a registered block pattern.
         *
         * @since 5.5.0
         *
         * @param string $pattern_name Block pattern name including namespace.
         * @return array Registered pattern properties.
         */
        public function get_registered($pattern_name)
        {
        }
        /**
         * Retrieves all registered block patterns.
         *
         * @since 5.5.0
         *
         * @param bool $outside_init_only Return only patterns registered outside the `init` action.
         * @return array[] Array of arrays containing the registered block patterns properties,
         *                 and per style.
         */
        public function get_all_registered($outside_init_only = \false)
        {
        }
        /**
         * Checks if a block pattern is registered.
         *
         * @since 5.5.0
         *
         * @param string $pattern_name Block pattern name including namespace.
         * @return bool True if the pattern is registered, false otherwise.
         */
        public function is_registered($pattern_name)
        {
        }
        public function __wakeup()
        {
        }
        /**
         * Utility method to retrieve the main instance of the class.
         *
         * The instance will be created if it does not exist yet.
         *
         * @since 5.5.0
         *
         * @return WP_Block_Patterns_Registry The main instance.
         */
        public static function get_instance()
        {
        }
    }
    /**
     * Class used for interacting with block styles.
     *
     * @since 5.3.0
     */
    #[\AllowDynamicProperties]
    final class WP_Block_Styles_Registry
    {
        /**
         * Registers a block style for the given block type.
         *
         * If the block styles are present in a standalone stylesheet, register it and pass
         * its handle as the `style_handle` argument. If the block styles should be inline,
         * use the `inline_style` argument. Usually, one of them would be used to pass CSS
         * styles. However, you could also skip them and provide CSS styles in any stylesheet
         * or with an inline tag.
         *
         * @since 5.3.0
         * @since 6.6.0 Added ability to register style across multiple block types along with theme.json-like style data.
         *
         * @link https://developer.wordpress.org/block-editor/reference-guides/block-api/block-styles/
         *
         * @param string|string[] $block_name       Block type name including namespace or array of namespaced block type names.
         * @param array           $style_properties {
         *     Array containing the properties of the style.
         *
         *     @type string $name         The identifier of the style used to compute a CSS class.
         *     @type string $label        A human-readable label for the style.
         *     @type string $inline_style Inline CSS code that registers the CSS class required
         *                                for the style.
         *     @type string $style_handle The handle to an already registered style that should be
         *                                enqueued in places where block styles are needed.
         *     @type bool   $is_default   Whether this is the default style for the block type.
         *     @type array  $style_data   Theme.json-like object to generate CSS from.
         * }
         * @return bool True if the block style was registered with success and false otherwise.
         * @phpstan-param array{
         *   name?: string,
         *   label?: string,
         *   inline_style?: string,
         *   style_handle?: string,
         *   is_default?: bool,
         *   style_data?: array,
         * } $style_properties
         */
        public function register($block_name, $style_properties)
        {
        }
        /**
         * Unregisters a block style of the given block type.
         *
         * @since 5.3.0
         *
         * @param string $block_name       Block type name including namespace.
         * @param string $block_style_name Block style name.
         * @return bool True if the block style was unregistered with success and false otherwise.
         */
        public function unregister($block_name, $block_style_name)
        {
        }
        /**
         * Retrieves the properties of a registered block style for the given block type.
         *
         * @since 5.3.0
         *
         * @param string $block_name       Block type name including namespace.
         * @param string $block_style_name Block style name.
         * @return array Registered block style properties.
         */
        public function get_registered($block_name, $block_style_name)
        {
        }
        /**
         * Retrieves all registered block styles.
         *
         * @since 5.3.0
         *
         * @return array[] Array of arrays containing the registered block styles properties grouped by block type.
         */
        public function get_all_registered()
        {
        }
        /**
         * Retrieves registered block styles for a specific block type.
         *
         * @since 5.3.0
         *
         * @param string $block_name Block type name including namespace.
         * @return array[] Array whose keys are block style names and whose values are block style properties.
         */
        public function get_registered_styles_for_block($block_name)
        {
        }
        /**
         * Checks if a block style is registered for the given block type.
         *
         * @since 5.3.0
         *
         * @param string $block_name       Block type name including namespace.
         * @param string $block_style_name Block style name.
         * @return bool True if the block style is registered, false otherwise.
         */
        public function is_registered($block_name, $block_style_name)
        {
        }
        /**
         * Utility method to retrieve the main instance of the class.
         *
         * The instance will be created if it does not exist yet.
         *
         * @since 5.3.0
         *
         * @return WP_Block_Styles_Registry The main instance.
         */
        public static function get_instance()
        {
        }
    }
    /**
     * Class encapsulating and implementing Block Supports.
     *
     * @since 5.6.0
     *
     * @access private
     */
    #[\AllowDynamicProperties]
    class WP_Block_Supports
    {
        /**
         * Tracks the current block to be rendered.
         *
         * @since 5.6.0
         * @var array
         */
        public static $block_to_render = \null;
        /**
         * Utility method to retrieve the main instance of the class.
         *
         * The instance will be created if it does not exist yet.
         *
         * @since 5.6.0
         *
         * @return WP_Block_Supports The main instance.
         */
        public static function get_instance()
        {
        }
        /**
         * Initializes the block supports. It registers the block supports block attributes.
         *
         * @since 5.6.0
         */
        public static function init()
        {
        }
        /**
         * Registers a block support.
         *
         * @since 5.6.0
         *
         * @link https://developer.wordpress.org/block-editor/reference-guides/block-api/block-supports/
         *
         * @param string $block_support_name   Block support name.
         * @param array  $block_support_config Array containing the properties of the block support.
         */
        public function register($block_support_name, $block_support_config)
        {
        }
        /**
         * Generates an array of HTML attributes, such as classes, by applying to
         * the given block all of the features that the block supports.
         *
         * @since 5.6.0
         *
         * @return string[] Array of HTML attribute values keyed by their name.
         */
        public function apply_block_supports()
        {
        }
    }
    /**
     * Class representing a block template.
     *
     * @since 5.8.0
     */
    #[\AllowDynamicProperties]
    class WP_Block_Template
    {
        /**
         * Type: wp_template.
         *
         * @since 5.8.0
         * @var string
         */
        public $type;
        /**
         * Theme.
         *
         * @since 5.8.0
         * @var string
         */
        public $theme;
        /**
         * Template slug.
         *
         * @since 5.8.0
         * @var string
         */
        public $slug;
        /**
         * ID.
         *
         * @since 5.8.0
         * @var string
         */
        public $id;
        /**
         * Title.
         *
         * @since 5.8.0
         * @var string
         */
        public $title = '';
        /**
         * Content.
         *
         * @since 5.8.0
         * @var string
         */
        public $content = '';
        /**
         * Description.
         *
         * @since 5.8.0
         * @var string
         */
        public $description = '';
        /**
         * Source of the content. `theme` and `custom` is used for now.
         *
         * @since 5.8.0
         * @var string
         */
        public $source = 'theme';
        /**
         * Origin of the content when the content has been customized.
         * When customized, origin takes on the value of source and source becomes
         * 'custom'.
         *
         * @since 5.9.0
         * @var string|null
         */
        public $origin;
        /**
         * Post ID.
         *
         * @since 5.8.0
         * @var int|null
         */
        public $wp_id;
        /**
         * Template Status.
         *
         * @since 5.8.0
         * @var string
         */
        public $status;
        /**
         * Whether a template is, or is based upon, an existing template file.
         *
         * @since 5.8.0
         * @var bool
         */
        public $has_theme_file;
        /**
         * Whether a template is a custom template.
         *
         * @since 5.9.0
         *
         * @var bool
         */
        public $is_custom = \true;
        /**
         * Author.
         *
         * A value of 0 means no author.
         *
         * @since 5.9.0
         * @var int|null
         */
        public $author;
        /**
         * Plugin.
         *
         * @since 6.7.0
         * @var string|null
         */
        public $plugin;
        /**
         * Post types.
         *
         * @since 5.9.0
         * @var string[]|null
         */
        public $post_types;
        /**
         * Area.
         *
         * @since 5.9.0
         * @var string|null
         */
        public $area;
        /**
         * Modified.
         *
         * @since 6.3.0
         * @var string|null
         */
        public $modified;
    }
    /**
     * Core class used for interacting with templates.
     *
     * @since 6.7.0
     */
    final class WP_Block_Templates_Registry
    {
        /**
         * Registers a template.
         *
         * @since 6.7.0
         *
         * @param string $template_name Template name including namespace.
         * @param array  $args          Optional. Array of template arguments.
         * @return WP_Block_Template|WP_Error The registered template on success, or WP_Error on failure.
         */
        public function register($template_name, $args = array())
        {
        }
        /**
         * Retrieves all registered templates.
         *
         * @since 6.7.0
         *
         * @return WP_Block_Template[] Associative array of `$template_name => $template` pairs.
         */
        public function get_all_registered()
        {
        }
        /**
         * Retrieves a registered template by its name.
         *
         * @since 6.7.0
         *
         * @param string $template_name Template name including namespace.
         * @return WP_Block_Template|null The registered template, or null if it is not registered.
         */
        public function get_registered($template_name)
        {
        }
        /**
         * Retrieves a registered template by its slug.
         *
         * @since 6.7.0
         *
         * @param string $template_slug Slug of the template.
         * @return WP_Block_Template|null The registered template, or null if it is not registered.
         */
        public function get_by_slug($template_slug)
        {
        }
        /**
         * Retrieves registered templates matching a query.
         *
         * @since 6.7.0
         *
         * @param array  $query {
         *     Arguments to retrieve templates. Optional, empty by default.
         *
         *     @type string[] $slug__in     List of slugs to include.
         *     @type string[] $slug__not_in List of slugs to skip.
         *     @type string   $post_type    Post type to get the templates for.
         * }
         * @return WP_Block_Template[] Associative array of `$template_name => $template` pairs.
         * @phpstan-param array{
         *   slug__in?: string[],
         *   slug__not_in?: string[],
         *   post_type?: string,
         * } $query
         */
        public function get_by_query($query = array())
        {
        }
        /**
         * Checks if a template is registered.
         *
         * @since 6.7.0
         *
         * @param string $template_name Template name.
         * @return bool True if the template is registered, false otherwise.
         */
        public function is_registered($template_name)
        {
        }
        /**
         * Unregisters a template.
         *
         * @since 6.7.0
         *
         * @param string $template_name Template name including namespace.
         * @return WP_Block_Template|WP_Error The unregistered template on success, or WP_Error on failure.
         */
        public function unregister($template_name)
        {
        }
        /**
         * Utility method to retrieve the main instance of the class.
         *
         * The instance will be created if it does not exist yet.
         *
         * @since 6.7.0
         *
         * @return WP_Block_Templates_Registry The main instance.
         */
        public static function get_instance()
        {
        }
    }
    /**
     * Core class used for interacting with block types.
     *
     * @since 5.0.0
     */
    #[\AllowDynamicProperties]
    final class WP_Block_Type_Registry
    {
        /**
         * Registers a block type.
         *
         * @since 5.0.0
         *
         * @see WP_Block_Type::__construct()
         *
         * @param string|WP_Block_Type $name Block type name including namespace, or alternatively
         *                                   a complete WP_Block_Type instance. In case a WP_Block_Type
         *                                   is provided, the $args parameter will be ignored.
         * @param array                $args Optional. Array of block type arguments. Accepts any public property
         *                                   of `WP_Block_Type`. See WP_Block_Type::__construct() for information
         *                                   on accepted arguments. Default empty array.
         * @return WP_Block_Type|false The registered block type on success, or false on failure.
         * @phpstan-param array{
         *   api_version?: string,
         *   title?: string,
         *   category?: string|null,
         *   parent?: string[]|null,
         *   ancestor?: string[]|null,
         *   allowed_blocks?: string[]|null,
         *   icon?: string|null,
         *   description?: string,
         *   keywords?: string[],
         *   textdomain?: string|null,
         *   styles?: array[],
         *   variations?: array[],
         *   selectors?: array,
         *   supports?: array|null,
         *   example?: array|null,
         *   render_callback?: callable|null,
         *   variation_callback?: callable|null,
         *   attributes?: array|null,
         *   uses_context?: string[],
         *   provides_context?: string[]|null,
         *   block_hooks?: string[],
         *   editor_script_handles?: string[],
         *   script_handles?: string[],
         *   view_script_handles?: string[],
         *   editor_style_handles?: string[],
         *   style_handles?: string[],
         *   view_style_handles?: string[],
         * } $args See WP_Block_Type::__construct()
         */
        public function register($name, $args = array())
        {
        }
        /**
         * Unregisters a block type.
         *
         * @since 5.0.0
         *
         * @param string|WP_Block_Type $name Block type name including namespace, or alternatively
         *                                   a complete WP_Block_Type instance.
         * @return WP_Block_Type|false The unregistered block type on success, or false on failure.
         */
        public function unregister($name)
        {
        }
        /**
         * Retrieves a registered block type.
         *
         * @since 5.0.0
         *
         * @param string $name Block type name including namespace.
         * @return WP_Block_Type|null The registered block type, or null if it is not registered.
         */
        public function get_registered($name)
        {
        }
        /**
         * Retrieves all registered block types.
         *
         * @since 5.0.0
         *
         * @return WP_Block_Type[] Associative array of `$block_type_name => $block_type` pairs.
         */
        public function get_all_registered()
        {
        }
        /**
         * Checks if a block type is registered.
         *
         * @since 5.0.0
         *
         * @param string $name Block type name including namespace.
         * @return bool True if the block type is registered, false otherwise.
         */
        public function is_registered($name)
        {
        }
        public function __wakeup()
        {
        }
        /**
         * Utility method to retrieve the main instance of the class.
         *
         * The instance will be created if it does not exist yet.
         *
         * @since 5.0.0
         *
         * @return WP_Block_Type_Registry The main instance.
         */
        public static function get_instance()
        {
        }
    }
    /**
     * Core class representing a block type.
     *
     * @since 5.0.0
     *
     * @see register_block_type()
     */
    #[\AllowDynamicProperties]
    class WP_Block_Type
    {
        /**
         * Block API version.
         *
         * @since 5.6.0
         * @var int
         */
        public $api_version = 1;
        /**
         * Block type key.
         *
         * @since 5.0.0
         * @var string
         */
        public $name;
        /**
         * Human-readable block type label.
         *
         * @since 5.5.0
         * @var string
         */
        public $title = '';
        /**
         * Block type category classification, used in search interfaces
         * to arrange block types by category.
         *
         * @since 5.5.0
         * @var string|null
         */
        public $category = \null;
        /**
         * Setting parent lets a block require that it is only available
         * when nested within the specified blocks.
         *
         * @since 5.5.0
         * @var string[]|null
         */
        public $parent = \null;
        /**
         * Setting ancestor makes a block available only inside the specified
         * block types at any position of the ancestor's block subtree.
         *
         * @since 6.0.0
         * @var string[]|null
         */
        public $ancestor = \null;
        /**
         * Limits which block types can be inserted as children of this block type.
         *
         * @since 6.5.0
         * @var string[]|null
         */
        public $allowed_blocks = \null;
        /**
         * Block type icon.
         *
         * @since 5.5.0
         * @var string|null
         */
        public $icon = \null;
        /**
         * A detailed block type description.
         *
         * @since 5.5.0
         * @var string
         */
        public $description = '';
        /**
         * Additional keywords to produce block type as result
         * in search interfaces.
         *
         * @since 5.5.0
         * @var string[]
         */
        public $keywords = array();
        /**
         * The translation textdomain.
         *
         * @since 5.5.0
         * @var string|null
         */
        public $textdomain = \null;
        /**
         * Alternative block styles.
         *
         * @since 5.5.0
         * @var array
         */
        public $styles = array();
        /**
         * Block variations callback.
         *
         * @since 6.5.0
         * @var callable|null
         */
        public $variation_callback = \null;
        /**
         * Custom CSS selectors for theme.json style generation.
         *
         * @since 6.3.0
         * @var array
         */
        public $selectors = array();
        /**
         * Supported features.
         *
         * @since 5.5.0
         * @var array|null
         */
        public $supports = \null;
        /**
         * Structured data for the block preview.
         *
         * @since 5.5.0
         * @var array|null
         */
        public $example = \null;
        /**
         * Block type render callback.
         *
         * @since 5.0.0
         * @var callable
         */
        public $render_callback = \null;
        /**
         * Block type attributes property schemas.
         *
         * @since 5.0.0
         * @var array|null
         */
        public $attributes = \null;
        /**
         * Context provided by blocks of this type.
         *
         * @since 5.5.0
         * @var string[]|null
         */
        public $provides_context = \null;
        /**
         * Block hooks for this block type.
         *
         * A block hook is specified by a block type and a relative position.
         * The hooked block will be automatically inserted in the given position
         * next to the "anchor" block whenever the latter is encountered.
         *
         * @since 6.4.0
         * @var string[]
         */
        public $block_hooks = array();
        /**
         * Block type editor only script handles.
         *
         * @since 6.1.0
         * @var string[]
         */
        public $editor_script_handles = array();
        /**
         * Block type front end and editor script handles.
         *
         * @since 6.1.0
         * @var string[]
         */
        public $script_handles = array();
        /**
         * Block type front end only script handles.
         *
         * @since 6.1.0
         * @var string[]
         */
        public $view_script_handles = array();
        /**
         * Block type front end only script module IDs.
         *
         * @since 6.5.0
         * @var string[]
         */
        public $view_script_module_ids = array();
        /**
         * Block type editor only style handles.
         *
         * @since 6.1.0
         * @var string[]
         */
        public $editor_style_handles = array();
        /**
         * Block type front end and editor style handles.
         *
         * @since 6.1.0
         * @var string[]
         */
        public $style_handles = array();
        /**
         * Block type front end only style handles.
         *
         * @since 6.5.0
         * @var string[]
         */
        public $view_style_handles = array();
        /**
         * Attributes supported by every block.
         *
         * @since 6.0.0 Added `lock`.
         * @since 6.5.0 Added `metadata`.
         * @var array
         */
        const GLOBAL_ATTRIBUTES = array('lock' => array('type' => 'object'), 'metadata' => array('type' => 'object'));
        /**
         * Constructor.
         *
         * Will populate object properties from the provided arguments.
         *
         * @since 5.0.0
         * @since 5.5.0 Added the `title`, `category`, `parent`, `icon`, `description`,
         *              `keywords`, `textdomain`, `styles`, `supports`, `example`,
         *              `uses_context`, and `provides_context` properties.
         * @since 5.6.0 Added the `api_version` property.
         * @since 5.8.0 Added the `variations` property.
         * @since 5.9.0 Added the `view_script` property.
         * @since 6.0.0 Added the `ancestor` property.
         * @since 6.1.0 Added the `editor_script_handles`, `script_handles`, `view_script_handles`,
         *              `editor_style_handles`, and `style_handles` properties.
         *              Deprecated the `editor_script`, `script`, `view_script`, `editor_style`, and `style` properties.
         * @since 6.3.0 Added the `selectors` property.
         * @since 6.4.0 Added the `block_hooks` property.
         * @since 6.5.0 Added the `allowed_blocks`, `variation_callback`, and `view_style_handles` properties.
         *
         * @see register_block_type()
         *
         * @param string       $block_type Block type name including namespace.
         * @param array|string $args       {
         *     Optional. Array or string of arguments for registering a block type. Any arguments may be defined,
         *     however the ones described below are supported by default. Default empty array.
         *
         *     @type string        $api_version              Block API version.
         *     @type string        $title                    Human-readable block type label.
         *     @type string|null   $category                 Block type category classification, used in
         *                                                   search interfaces to arrange block types by category.
         *     @type string[]|null $parent                   Setting parent lets a block require that it is only
         *                                                   available when nested within the specified blocks.
         *     @type string[]|null $ancestor                 Setting ancestor makes a block available only inside the specified
         *                                                   block types at any position of the ancestor's block subtree.
         *     @type string[]|null $allowed_blocks           Limits which block types can be inserted as children of this block type.
         *     @type string|null   $icon                     Block type icon.
         *     @type string        $description              A detailed block type description.
         *     @type string[]      $keywords                 Additional keywords to produce block type as
         *                                                   result in search interfaces.
         *     @type string|null   $textdomain               The translation textdomain.
         *     @type array[]       $styles                   Alternative block styles.
         *     @type array[]       $variations               Block variations.
         *     @type array         $selectors                Custom CSS selectors for theme.json style generation.
         *     @type array|null    $supports                 Supported features.
         *     @type array|null    $example                  Structured data for the block preview.
         *     @type callable|null $render_callback          Block type render callback.
         *     @type callable|null $variation_callback       Block type variations callback.
         *     @type array|null    $attributes               Block type attributes property schemas.
         *     @type string[]      $uses_context             Context values inherited by blocks of this type.
         *     @type string[]|null $provides_context         Context provided by blocks of this type.
         *     @type string[]      $block_hooks              Block hooks.
         *     @type string[]      $editor_script_handles    Block type editor only script handles.
         *     @type string[]      $script_handles           Block type front end and editor script handles.
         *     @type string[]      $view_script_handles      Block type front end only script handles.
         *     @type string[]      $editor_style_handles     Block type editor only style handles.
         *     @type string[]      $style_handles            Block type front end and editor style handles.
         *     @type string[]      $view_style_handles       Block type front end only style handles.
         * }
         * @phpstan-param array{
         *   api_version?: string,
         *   title?: string,
         *   category?: string|null,
         *   parent?: string[]|null,
         *   ancestor?: string[]|null,
         *   allowed_blocks?: string[]|null,
         *   icon?: string|null,
         *   description?: string,
         *   keywords?: string[],
         *   textdomain?: string|null,
         *   styles?: array[],
         *   variations?: array[],
         *   selectors?: array,
         *   supports?: array|null,
         *   example?: array|null,
         *   render_callback?: callable|null,
         *   variation_callback?: callable|null,
         *   attributes?: array|null,
         *   uses_context?: string[],
         *   provides_context?: string[]|null,
         *   block_hooks?: string[],
         *   editor_script_handles?: string[],
         *   script_handles?: string[],
         *   view_script_handles?: string[],
         *   editor_style_handles?: string[],
         *   style_handles?: string[],
         *   view_style_handles?: string[],
         * } $args
         */
        public function __construct($block_type, $args = array())
        {
        }
        /**
         * Proxies getting values for deprecated properties for script and style handles for backward compatibility.
         * Gets the value for the corresponding new property if the first item in the array provided.
         *
         * @since 6.1.0
         *
         * @param string $name Deprecated property name.
         *
         * @return string|string[]|null|void The value read from the new property if the first item in the array provided,
         *                                   null when value not found, or void when unknown property name provided.
         */
        public function __get($name)
        {
        }
        /**
         * Proxies checking for deprecated properties for script and style handles for backward compatibility.
         * Checks whether the corresponding new property has the first item in the array provided.
         *
         * @since 6.1.0
         *
         * @param string $name Deprecated property name.
         *
         * @return bool Returns true when for the new property the first item in the array exists,
         *              or false otherwise.
         */
        public function __isset($name)
        {
        }
        /**
         * Proxies setting values for deprecated properties for script and style handles for backward compatibility.
         * Sets the value for the corresponding new property as the first item in the array.
         * It also allows setting custom properties for backward compatibility.
         *
         * @since 6.1.0
         *
         * @param string $name  Property name.
         * @param mixed  $value Property value.
         * @phpstan-return void
         */
        public function __set($name, $value)
        {
        }
        /**
         * Renders the block type output for given attributes.
         *
         * @since 5.0.0
         *
         * @param array  $attributes Optional. Block attributes. Default empty array.
         * @param string $content    Optional. Block content. Default empty string.
         * @return string Rendered block type output.
         */
        public function render($attributes = array(), $content = '')
        {
        }
        /**
         * Returns true if the block type is dynamic, or false otherwise. A dynamic
         * block is one which defers its rendering to occur on-demand at runtime.
         *
         * @since 5.0.0
         *
         * @return bool Whether block type is dynamic.
         */
        public function is_dynamic()
        {
        }
        /**
         * Validates attributes against the current block schema, populating
         * defaulted and missing values.
         *
         * @since 5.0.0
         *
         * @param array $attributes Original block attributes.
         * @return array Prepared block attributes.
         */
        public function prepare_attributes_for_render($attributes)
        {
        }
        /**
         * Sets block type properties.
         *
         * @since 5.0.0
         *
         * @param array|string $args Array or string of arguments for registering a block type.
         *                           See WP_Block_Type::__construct() for information on accepted arguments.
         * @phpstan-param array{
         *   api_version?: string,
         *   title?: string,
         *   category?: string|null,
         *   parent?: string[]|null,
         *   ancestor?: string[]|null,
         *   allowed_blocks?: string[]|null,
         *   icon?: string|null,
         *   description?: string,
         *   keywords?: string[],
         *   textdomain?: string|null,
         *   styles?: array[],
         *   variations?: array[],
         *   selectors?: array,
         *   supports?: array|null,
         *   example?: array|null,
         *   render_callback?: callable|null,
         *   variation_callback?: callable|null,
         *   attributes?: array|null,
         *   uses_context?: string[],
         *   provides_context?: string[]|null,
         *   block_hooks?: string[],
         *   editor_script_handles?: string[],
         *   script_handles?: string[],
         *   view_script_handles?: string[],
         *   editor_style_handles?: string[],
         *   style_handles?: string[],
         *   view_style_handles?: string[],
         * } $args See WP_Block_Type::__construct()
         */
        public function set_props($args)
        {
        }
        /**
         * Get all available block attributes including possible layout attribute from Columns block.
         *
         * @since 5.0.0
         *
         * @return array Array of attributes.
         */
        public function get_attributes()
        {
        }
        /**
         * Get block variations.
         *
         * @since 6.5.0
         *
         * @return array[]
         */
        public function get_variations()
        {
        }
        /**
         * Get block uses context.
         *
         * @since 6.5.0
         *
         * @return string[]
         */
        public function get_uses_context()
        {
        }
    }
    /**
     * Class representing a parsed instance of a block.
     *
     * @since 5.5.0
     * @property array $attributes
     */
    #[\AllowDynamicProperties]
    class WP_Block
    {
        /**
         * Original parsed array representation of block.
         *
         * @since 5.5.0
         * @var array
         */
        public $parsed_block;
        /**
         * Name of block.
         *
         * @example "core/paragraph"
         *
         * @since 5.5.0
         * @var string
         */
        public $name;
        /**
         * Block type associated with the instance.
         *
         * @since 5.5.0
         * @var WP_Block_Type
         */
        public $block_type;
        /**
         * Block context values.
         *
         * @since 5.5.0
         * @var array
         */
        public $context = array();
        /**
         * All available context of the current hierarchy.
         *
         * @since 5.5.0
         * @var array
         * @access protected
         */
        protected $available_context;
        /**
         * Block type registry.
         *
         * @since 5.9.0
         * @var WP_Block_Type_Registry
         * @access protected
         */
        protected $registry;
        /**
         * List of inner blocks (of this same class)
         *
         * @since 5.5.0
         * @var WP_Block_List
         */
        public $inner_blocks = array();
        /**
         * Resultant HTML from inside block comment delimiters after removing inner
         * blocks.
         *
         * @example "...Just <!-- wp:test /--> testing..." -> "Just testing..."
         *
         * @since 5.5.0
         * @var string
         */
        public $inner_html = '';
        /**
         * List of string fragments and null markers where inner blocks were found
         *
         * @example array(
         *   'inner_html'    => 'BeforeInnerAfter',
         *   'inner_blocks'  => array( block, block ),
         *   'inner_content' => array( 'Before', null, 'Inner', null, 'After' ),
         * )
         *
         * @since 5.5.0
         * @var array
         */
        public $inner_content = array();
        /**
         * Constructor.
         *
         * Populates object properties from the provided block instance argument.
         *
         * The given array of context values will not necessarily be available on
         * the instance itself, but is treated as the full set of values provided by
         * the block's ancestry. This is assigned to the private `available_context`
         * property. Only values which are configured to consumed by the block via
         * its registered type will be assigned to the block's `context` property.
         *
         * @since 5.5.0
         *
         * @param array                  $block             {
         *     An associative array of a single parsed block object. See WP_Block_Parser_Block.
         *
         *     @type string   $blockName    Name of block.
         *     @type array    $attrs        Attributes from block comment delimiters.
         *     @type array    $innerBlocks  List of inner blocks. An array of arrays that
         *                                  have the same structure as this one.
         *     @type string   $innerHTML    HTML from inside block comment delimiters.
         *     @type array    $innerContent List of string fragments and null markers where inner blocks were found.
         * }
         * @param array                  $available_context Optional array of ancestry context values.
         * @param WP_Block_Type_Registry $registry          Optional block type registry.
         * @phpstan-param array{
         *   blockName?: string,
         *   attrs?: array,
         *   innerBlocks?: array,
         *   innerHTML?: string,
         *   innerContent?: array,
         * } $block
         */
        public function __construct($block, $available_context = array(), $registry = \null)
        {
        }
        /**
         * Returns a value from an inaccessible property.
         *
         * This is used to lazily initialize the `attributes` property of a block,
         * such that it is only prepared with default attributes at the time that
         * the property is accessed. For all other inaccessible properties, a `null`
         * value is returned.
         *
         * @since 5.5.0
         *
         * @param string $name Property name.
         * @return array|null Prepared attributes, or null.
         */
        public function __get($name)
        {
        }
        /**
         * Generates the render output for the block.
         *
         * @since 5.5.0
         * @since 6.5.0 Added block bindings processing.
         *
         * @global WP_Post $post Global post object.
         *
         * @param array $options {
         *     Optional options object.
         *
         *     @type bool $dynamic Defaults to 'true'. Optionally set to false to avoid using the block's render_callback.
         * }
         * @return string Rendered block output.
         * @phpstan-param array{
         *   dynamic?: bool,
         * } $options
         */
        public function render($options = array())
        {
        }
    }
    /**
     * Converts a Classic Menu to Block Menu blocks.
     *
     * @since 6.3.0
     * @access public
     */
    class WP_Classic_To_Block_Menu_Converter
    {
        /**
         * Converts a Classic Menu to blocks.
         *
         * @since 6.3.0
         *
         * @param WP_Term $menu The Menu term object of the menu to convert.
         * @return string|WP_Error The serialized and normalized parsed blocks on success,
         *                         an empty string when there are no menus to convert,
         *                         or WP_Error on invalid menu.
         */
        public static function convert($menu)
        {
        }
    }
    /**
     * Core class used for querying comments.
     *
     * @since 3.1.0
     *
     * @see WP_Comment_Query::__construct() for accepted arguments.
     */
    #[\AllowDynamicProperties]
    class WP_Comment_Query
    {
        /**
         * SQL for database query.
         *
         * @since 4.0.1
         * @var string
         */
        public $request;
        /**
         * Metadata query container
         *
         * @since 3.5.0
         * @var WP_Meta_Query A meta query instance.
         */
        public $meta_query = \false;
        /**
         * Metadata query clauses.
         *
         * @since 4.4.0
         * @var array
         */
        protected $meta_query_clauses;
        /**
         * SQL query clauses.
         *
         * @since 4.4.0
         * @var array
         */
        protected $sql_clauses = array('select' => '', 'from' => '', 'where' => array(), 'groupby' => '', 'orderby' => '', 'limits' => '');
        /**
         * SQL WHERE clause.
         *
         * Stored after the {@see 'comments_clauses'} filter is run on the compiled WHERE sub-clauses.
         *
         * @since 4.4.2
         * @var string
         */
        protected $filtered_where_clause;
        /**
         * Date query container
         *
         * @since 3.7.0
         * @var WP_Date_Query A date query instance.
         */
        public $date_query = \false;
        /**
         * Query vars set by the user.
         *
         * @since 3.1.0
         * @var array
         */
        public $query_vars;
        /**
         * Default values for query vars.
         *
         * @since 4.2.0
         * @var array
         */
        public $query_var_defaults;
        /**
         * List of comments located by the query.
         *
         * @since 4.0.0
         * @var int[]|WP_Comment[]
         */
        public $comments;
        /**
         * The amount of found comments for the current query.
         *
         * @since 4.4.0
         * @var int
         */
        public $found_comments = 0;
        /**
         * The number of pages.
         *
         * @since 4.4.0
         * @var int
         */
        public $max_num_pages = 0;
        /**
         * Make private/protected methods readable for backward compatibility.
         *
         * @since 4.0.0
         *
         * @param string $name      Method to call.
         * @param array  $arguments Arguments to pass when calling.
         * @return mixed|false Return value of the callback, false otherwise.
         */
        public function __call($name, $arguments)
        {
        }
        /**
         * Constructor.
         *
         * Sets up the comment query, based on the query vars passed.
         *
         * @since 4.2.0
         * @since 4.4.0 `$parent__in` and `$parent__not_in` were added.
         * @since 4.4.0 Order by `comment__in` was added. `$update_comment_meta_cache`, `$no_found_rows`,
         *              `$hierarchical`, and `$update_comment_post_cache` were added.
         * @since 4.5.0 Introduced the `$author_url` argument.
         * @since 4.6.0 Introduced the `$cache_domain` argument.
         * @since 4.9.0 Introduced the `$paged` argument.
         * @since 5.1.0 Introduced the `$meta_compare_key` argument.
         * @since 5.3.0 Introduced the `$meta_type_key` argument.
         *
         * @param string|array $query {
         *     Optional. Array or query string of comment query parameters. Default empty.
         *
         *     @type string          $author_email              Comment author email address. Default empty.
         *     @type string          $author_url                Comment author URL. Default empty.
         *     @type int[]           $author__in                Array of author IDs to include comments for. Default empty.
         *     @type int[]           $author__not_in            Array of author IDs to exclude comments for. Default empty.
         *     @type int[]           $comment__in               Array of comment IDs to include. Default empty.
         *     @type int[]           $comment__not_in           Array of comment IDs to exclude. Default empty.
         *     @type bool            $count                     Whether to return a comment count (true) or array of
         *                                                      comment objects (false). Default false.
         *     @type array           $date_query                Date query clauses to limit comments by. See WP_Date_Query.
         *                                                      Default null.
         *     @type string          $fields                    Comment fields to return. Accepts 'ids' for comment IDs
         *                                                      only or empty for all fields. Default empty.
         *     @type array           $include_unapproved        Array of IDs or email addresses of users whose unapproved
         *                                                      comments will be returned by the query regardless of
         *                                                      `$status`. Default empty.
         *     @type int             $karma                     Karma score to retrieve matching comments for.
         *                                                      Default empty.
         *     @type string|string[] $meta_key                  Meta key or keys to filter by.
         *     @type string|string[] $meta_value                Meta value or values to filter by.
         *     @type string          $meta_compare              MySQL operator used for comparing the meta value.
         *                                                      See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_compare_key          MySQL operator used for comparing the meta key.
         *                                                      See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_type                 MySQL data type that the meta_value column will be CAST to for comparisons.
         *                                                      See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_type_key             MySQL data type that the meta_key column will be CAST to for comparisons.
         *                                                      See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type array           $meta_query                An associative array of WP_Meta_Query arguments.
         *                                                      See WP_Meta_Query::__construct() for accepted values.
         *     @type int             $number                    Maximum number of comments to retrieve.
         *                                                      Default empty (no limit).
         *     @type int             $paged                     When used with `$number`, defines the page of results to return.
         *                                                      When used with `$offset`, `$offset` takes precedence. Default 1.
         *     @type int             $offset                    Number of comments to offset the query. Used to build
         *                                                      LIMIT clause. Default 0.
         *     @type bool            $no_found_rows             Whether to disable the `SQL_CALC_FOUND_ROWS` query.
         *                                                      Default: true.
         *     @type string|array    $orderby                   Comment status or array of statuses. To use 'meta_value'
         *                                                      or 'meta_value_num', `$meta_key` must also be defined.
         *                                                      To sort by a specific `$meta_query` clause, use that
         *                                                      clause's array key. Accepts:
         *                                                      - 'comment_agent'
         *                                                      - 'comment_approved'
         *                                                      - 'comment_author'
         *                                                      - 'comment_author_email'
         *                                                      - 'comment_author_IP'
         *                                                      - 'comment_author_url'
         *                                                      - 'comment_content'
         *                                                      - 'comment_date'
         *                                                      - 'comment_date_gmt'
         *                                                      - 'comment_ID'
         *                                                      - 'comment_karma'
         *                                                      - 'comment_parent'
         *                                                      - 'comment_post_ID'
         *                                                      - 'comment_type'
         *                                                      - 'user_id'
         *                                                      - 'comment__in'
         *                                                      - 'meta_value'
         *                                                      - 'meta_value_num'
         *                                                      - The value of `$meta_key`
         *                                                      - The array keys of `$meta_query`
         *                                                      - false, an empty array, or 'none' to disable `ORDER BY` clause.
         *                                                      Default: 'comment_date_gmt'.
         *     @type string          $order                     How to order retrieved comments. Accepts 'ASC', 'DESC'.
         *                                                      Default: 'DESC'.
         *     @type int             $parent                    Parent ID of comment to retrieve children of.
         *                                                      Default empty.
         *     @type int[]           $parent__in                Array of parent IDs of comments to retrieve children for.
         *                                                      Default empty.
         *     @type int[]           $parent__not_in            Array of parent IDs of comments *not* to retrieve
         *                                                      children for. Default empty.
         *     @type int[]           $post_author__in           Array of author IDs to retrieve comments for.
         *                                                      Default empty.
         *     @type int[]           $post_author__not_in       Array of author IDs *not* to retrieve comments for.
         *                                                      Default empty.
         *     @type int             $post_id                   Limit results to those affiliated with a given post ID.
         *                                                      Default 0.
         *     @type int[]           $post__in                  Array of post IDs to include affiliated comments for.
         *                                                      Default empty.
         *     @type int[]           $post__not_in              Array of post IDs to exclude affiliated comments for.
         *                                                      Default empty.
         *     @type int             $post_author               Post author ID to limit results by. Default empty.
         *     @type string|string[] $post_status               Post status or array of post statuses to retrieve
         *                                                      affiliated comments for. Pass 'any' to match any value.
         *                                                      Default empty.
         *     @type string|string[] $post_type                 Post type or array of post types to retrieve affiliated
         *                                                      comments for. Pass 'any' to match any value. Default empty.
         *     @type string          $post_name                 Post name to retrieve affiliated comments for.
         *                                                      Default empty.
         *     @type int             $post_parent               Post parent ID to retrieve affiliated comments for.
         *                                                      Default empty.
         *     @type string          $search                    Search term(s) to retrieve matching comments for.
         *                                                      Default empty.
         *     @type string|array    $status                    Comment statuses to limit results by. Accepts an array
         *                                                      or space/comma-separated list of 'hold' (`comment_status=0`),
         *                                                      'approve' (`comment_status=1`), 'all', or a custom
         *                                                      comment status. Default 'all'.
         *     @type string|string[] $type                      Include comments of a given type, or array of types.
         *                                                      Accepts 'comment', 'pings' (includes 'pingback' and
         *                                                      'trackback'), or any custom type string. Default empty.
         *     @type string[]        $type__in                  Include comments from a given array of comment types.
         *                                                      Default empty.
         *     @type string[]        $type__not_in              Exclude comments from a given array of comment types.
         *                                                      Default empty.
         *     @type int             $user_id                   Include comments for a specific user ID. Default empty.
         *     @type bool|string     $hierarchical              Whether to include comment descendants in the results.
         *                                                      - 'threaded' returns a tree, with each comment's children
         *                                                        stored in a `children` property on the `WP_Comment` object.
         *                                                      - 'flat' returns a flat array of found comments plus
         *                                                        their children.
         *                                                      - Boolean `false` leaves out descendants.
         *                                                      The parameter is ignored (forced to `false`) when
         *                                                      `$fields` is 'ids' or 'counts'. Accepts 'threaded',
         *                                                      'flat', or false. Default: false.
         *     @type string          $cache_domain              Unique cache key to be produced when this query is stored in
         *                                                      an object cache. Default is 'core'.
         *     @type bool            $update_comment_meta_cache Whether to prime the metadata cache for found comments.
         *                                                      Default true.
         *     @type bool            $update_comment_post_cache Whether to prime the cache for comment posts.
         *                                                      Default false.
         * }
         * @phpstan-param array{
         *   author_email?: string,
         *   author_url?: string,
         *   author__in?: int[],
         *   author__not_in?: int[],
         *   comment__in?: int[],
         *   comment__not_in?: int[],
         *   count?: bool,
         *   date_query?: array,
         *   fields?: string,
         *   include_unapproved?: array,
         *   karma?: int,
         *   meta_key?: string|string[],
         *   meta_value?: string|string[],
         *   meta_compare?: string,
         *   meta_compare_key?: string,
         *   meta_type?: string,
         *   meta_type_key?: string,
         *   meta_query?: array,
         *   number?: int,
         *   paged?: int,
         *   offset?: int,
         *   no_found_rows?: bool,
         *   orderby?: string|array,
         *   order?: string,
         *   parent?: int,
         *   parent__in?: int[],
         *   parent__not_in?: int[],
         *   post_author__in?: int[],
         *   post_author__not_in?: int[],
         *   post_id?: int,
         *   post__in?: int[],
         *   post__not_in?: int[],
         *   post_author?: int,
         *   post_status?: string|string[],
         *   post_type?: string|string[],
         *   post_name?: string,
         *   post_parent?: int,
         *   search?: string,
         *   status?: string|array,
         *   type?: string|string[],
         *   type__in?: string[],
         *   type__not_in?: string[],
         *   user_id?: int,
         *   hierarchical?: bool|string,
         *   cache_domain?: string,
         *   update_comment_meta_cache?: bool,
         *   update_comment_post_cache?: bool,
         * } $query
         */
        public function __construct($query = '')
        {
        }
        /**
         * Parse arguments passed to the comment query with default query parameters.
         *
         * @since 4.2.0 Extracted from WP_Comment_Query::query().
         *
         * @param string|array $query WP_Comment_Query arguments. See WP_Comment_Query::__construct() for accepted arguments.
         * @phpstan-param array{
         *   author_email?: string,
         *   author_url?: string,
         *   author__in?: int[],
         *   author__not_in?: int[],
         *   comment__in?: int[],
         *   comment__not_in?: int[],
         *   count?: bool,
         *   date_query?: array,
         *   fields?: string,
         *   include_unapproved?: array,
         *   karma?: int,
         *   meta_key?: string|string[],
         *   meta_value?: string|string[],
         *   meta_compare?: string,
         *   meta_compare_key?: string,
         *   meta_type?: string,
         *   meta_type_key?: string,
         *   meta_query?: array,
         *   number?: int,
         *   paged?: int,
         *   offset?: int,
         *   no_found_rows?: bool,
         *   orderby?: string|array,
         *   order?: string,
         *   parent?: int,
         *   parent__in?: int[],
         *   parent__not_in?: int[],
         *   post_author__in?: int[],
         *   post_author__not_in?: int[],
         *   post_id?: int,
         *   post__in?: int[],
         *   post__not_in?: int[],
         *   post_author?: int,
         *   post_status?: string|string[],
         *   post_type?: string|string[],
         *   post_name?: string,
         *   post_parent?: int,
         *   search?: string,
         *   status?: string|array,
         *   type?: string|string[],
         *   type__in?: string[],
         *   type__not_in?: string[],
         *   user_id?: int,
         *   hierarchical?: bool|string,
         *   cache_domain?: string,
         *   update_comment_meta_cache?: bool,
         *   update_comment_post_cache?: bool,
         * } $query See WP_Comment_Query::__construct()
         */
        public function parse_query($query = '')
        {
        }
        /**
         * Sets up the WordPress query for retrieving comments.
         *
         * @since 3.1.0
         * @since 4.1.0 Introduced 'comment__in', 'comment__not_in', 'post_author__in',
         *              'post_author__not_in', 'author__in', 'author__not_in', 'post__in',
         *              'post__not_in', 'include_unapproved', 'type__in', and 'type__not_in'
         *              arguments to $query_vars.
         * @since 4.2.0 Moved parsing to WP_Comment_Query::parse_query().
         *
         * @param string|array $query Array or URL query string of parameters.
         * @return array|int List of comments, or number of comments when 'count' is passed as a query var.
         */
        public function query($query)
        {
        }
        /**
         * Get a list of comments matching the query vars.
         *
         * @since 4.2.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @return int|int[]|WP_Comment[] List of comments or number of found comments if `$count` argument is true.
         */
        public function get_comments()
        {
        }
        /**
         * Used internally to get a list of comment IDs matching the query vars.
         *
         * @since 4.4.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @return int|array A single count of comment IDs if a count query. An array of comment IDs if a full query.
         */
        protected function get_comment_ids()
        {
        }
        /**
         * Fetch descendants for located comments.
         *
         * Instead of calling `get_children()` separately on each child comment, we do a single set of queries to fetch
         * the descendant trees for all matched top-level comments.
         *
         * @since 4.4.0
         *
         * @param WP_Comment[] $comments Array of top-level comments whose descendants should be filled in.
         * @return array
         */
        protected function fill_descendants($comments)
        {
        }
        /**
         * Used internally to generate an SQL string for searching across multiple columns.
         *
         * @since 3.1.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string   $search  Search string.
         * @param string[] $columns Array of columns to search.
         * @return string Search SQL.
         */
        protected function get_search_sql($search, $columns)
        {
        }
        /**
         * Parse and sanitize 'orderby' keys passed to the comment query.
         *
         * @since 4.2.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $orderby Alias for the field to order by.
         * @return string|false Value to used in the ORDER clause. False otherwise.
         */
        protected function parse_orderby($orderby)
        {
        }
        /**
         * Parse an 'order' query variable and cast it to ASC or DESC as necessary.
         *
         * @since 4.2.0
         *
         * @param string $order The 'order' query variable.
         * @return string The sanitized 'order' query variable.
         */
        protected function parse_order($order)
        {
        }
    }
    /**
     * Core class used to organize comments as instantiated objects with defined members.
     *
     * @since 4.4.0
     */
    #[\AllowDynamicProperties]
    final class WP_Comment
    {
        /**
         * Comment ID.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 4.4.0
         * @var string
         */
        public $comment_ID;
        /**
         * ID of the post the comment is associated with.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 4.4.0
         * @var string
         */
        public $comment_post_ID = 0;
        /**
         * Comment author name.
         *
         * @since 4.4.0
         * @var string
         */
        public $comment_author = '';
        /**
         * Comment author email address.
         *
         * @since 4.4.0
         * @var string
         */
        public $comment_author_email = '';
        /**
         * Comment author URL.
         *
         * @since 4.4.0
         * @var string
         */
        public $comment_author_url = '';
        /**
         * Comment author IP address (IPv4 format).
         *
         * @since 4.4.0
         * @var string
         */
        public $comment_author_IP = '';
        /**
         * Comment date in YYYY-MM-DD HH:MM:SS format.
         *
         * @since 4.4.0
         * @var string
         */
        public $comment_date = '0000-00-00 00:00:00';
        /**
         * Comment GMT date in YYYY-MM-DD HH::MM:SS format.
         *
         * @since 4.4.0
         * @var string
         */
        public $comment_date_gmt = '0000-00-00 00:00:00';
        /**
         * Comment content.
         *
         * @since 4.4.0
         * @var string
         */
        public $comment_content;
        /**
         * Comment karma count.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 4.4.0
         * @var string
         */
        public $comment_karma = 0;
        /**
         * Comment approval status.
         *
         * @since 4.4.0
         * @var string
         */
        public $comment_approved = '1';
        /**
         * Comment author HTTP user agent.
         *
         * @since 4.4.0
         * @var string
         */
        public $comment_agent = '';
        /**
         * Comment type.
         *
         * @since 4.4.0
         * @since 5.5.0 Default value changed to `comment`.
         * @var string
         */
        public $comment_type = 'comment';
        /**
         * Parent comment ID.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 4.4.0
         * @var string
         */
        public $comment_parent = 0;
        /**
         * Comment author ID.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 4.4.0
         * @var string
         */
        public $user_id = 0;
        /**
         * Retrieves a WP_Comment instance.
         *
         * @since 4.4.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param int $id Comment ID.
         * @return WP_Comment|false Comment object, otherwise false.
         */
        public static function get_instance($id)
        {
        }
        /**
         * Constructor.
         *
         * Populates properties with object vars.
         *
         * @since 4.4.0
         *
         * @param WP_Comment $comment Comment object.
         */
        public function __construct($comment)
        {
        }
        /**
         * Converts object to array.
         *
         * @since 4.4.0
         *
         * @return array Object as array.
         */
        public function to_array()
        {
        }
        /**
         * Gets the children of a comment.
         *
         * @since 4.4.0
         *
         * @param array $args {
         *     Array of arguments used to pass to get_comments() and determine format.
         *
         *     @type string $format        Return value format. 'tree' for a hierarchical tree, 'flat' for a flattened array.
         *                                 Default 'tree'.
         *     @type string $status        Comment status to limit results by. Accepts 'hold' (`comment_status=0`),
         *                                 'approve' (`comment_status=1`), 'all', or a custom comment status.
         *                                 Default 'all'.
         *     @type string $hierarchical  Whether to include comment descendants in the results.
         *                                 'threaded' returns a tree, with each comment's children
         *                                 stored in a `children` property on the `WP_Comment` object.
         *                                 'flat' returns a flat array of found comments plus their children.
         *                                 Pass `false` to leave out descendants.
         *                                 The parameter is ignored (forced to `false`) when `$fields` is 'ids' or 'counts'.
         *                                 Accepts 'threaded', 'flat', or false. Default: 'threaded'.
         *     @type string|array $orderby Comment status or array of statuses. To use 'meta_value'
         *                                 or 'meta_value_num', `$meta_key` must also be defined.
         *                                 To sort by a specific `$meta_query` clause, use that
         *                                 clause's array key. Accepts 'comment_agent',
         *                                 'comment_approved', 'comment_author',
         *                                 'comment_author_email', 'comment_author_IP',
         *                                 'comment_author_url', 'comment_content', 'comment_date',
         *                                 'comment_date_gmt', 'comment_ID', 'comment_karma',
         *                                 'comment_parent', 'comment_post_ID', 'comment_type',
         *                                 'user_id', 'comment__in', 'meta_value', 'meta_value_num',
         *                                 the value of $meta_key, and the array keys of
         *                                 `$meta_query`. Also accepts false, an empty array, or
         *                                 'none' to disable `ORDER BY` clause.
         * }
         * @return WP_Comment[] Array of `WP_Comment` objects.
         * @phpstan-param array{
         *   format?: string,
         *   status?: string,
         *   hierarchical?: string,
         *   orderby?: string|array,
         * } $args
         */
        public function get_children($args = array())
        {
        }
        /**
         * Adds a child to the comment.
         *
         * Used by `WP_Comment_Query` when bulk-filling descendants.
         *
         * @since 4.4.0
         *
         * @param WP_Comment $child Child comment.
         */
        public function add_child(\WP_Comment $child)
        {
        }
        /**
         * Gets a child comment by ID.
         *
         * @since 4.4.0
         *
         * @param int $child_id ID of the child.
         * @return WP_Comment|false Returns the comment object if found, otherwise false.
         */
        public function get_child($child_id)
        {
        }
        /**
         * Sets the 'populated_children' flag.
         *
         * This flag is important for ensuring that calling `get_children()` on a childless comment will not trigger
         * unneeded database queries.
         *
         * @since 4.4.0
         *
         * @param bool $set Whether the comment's children have already been populated.
         */
        public function populated_children($set)
        {
        }
        /**
         * Determines whether a non-public property is set.
         *
         * If `$name` matches a post field, the comment post will be loaded and the post's value checked.
         *
         * @since 4.4.0
         *
         * @param string $name Property name.
         * @return bool
         */
        public function __isset($name)
        {
        }
        /**
         * Magic getter.
         *
         * If `$name` matches a post field, the comment post will be loaded and the post's value returned.
         *
         * @since 4.4.0
         *
         * @param string $name Property name.
         * @return mixed
         */
        public function __get($name)
        {
        }
    }
    /**
     * Customize Control class.
     *
     * @since 3.4.0
     */
    #[\AllowDynamicProperties]
    class WP_Customize_Control
    {
        /**
         * Incremented with each new class instantiation, then stored in $instance_number.
         *
         * Used when sorting two instances whose priorities are equal.
         *
         * @since 4.1.0
         * @var int
         */
        protected static $instance_count = 0;
        /**
         * Order in which this instance was created in relation to other instances.
         *
         * @since 4.1.0
         * @var int
         */
        public $instance_number;
        /**
         * Customizer manager.
         *
         * @since 3.4.0
         * @var WP_Customize_Manager
         */
        public $manager;
        /**
         * Control ID.
         *
         * @since 3.4.0
         * @var string
         */
        public $id;
        /**
         * All settings tied to the control.
         *
         * @since 3.4.0
         * @var array
         */
        public $settings;
        /**
         * The primary setting for the control (if there is one).
         *
         * @since 3.4.0
         * @var string|WP_Customize_Setting|null
         */
        public $setting = 'default';
        /**
         * Capability required to use this control.
         *
         * Normally this is empty and the capability is derived from the capabilities
         * of the associated `$settings`.
         *
         * @since 4.5.0
         * @var string
         */
        public $capability;
        /**
         * Order priority to load the control in Customizer.
         *
         * @since 3.4.0
         * @var int
         */
        public $priority = 10;
        /**
         * Section the control belongs to.
         *
         * @since 3.4.0
         * @var string
         */
        public $section = '';
        /**
         * Label for the control.
         *
         * @since 3.4.0
         * @var string
         */
        public $label = '';
        /**
         * Description for the control.
         *
         * @since 4.0.0
         * @var string
         */
        public $description = '';
        /**
         * List of choices for 'radio' or 'select' type controls, where values are the keys, and labels are the values.
         *
         * @since 3.4.0
         * @var array
         */
        public $choices = array();
        /**
         * List of custom input attributes for control output, where attribute names are the keys and values are the values.
         *
         * Not used for 'checkbox', 'radio', 'select', 'textarea', or 'dropdown-pages' control types.
         *
         * @since 4.0.0
         * @var array
         */
        public $input_attrs = array();
        /**
         * Show UI for adding new content, currently only used for the dropdown-pages control.
         *
         * @since 4.7.0
         * @var bool
         */
        public $allow_addition = \false;
        /**
         * @deprecated It is better to just call the json() method
         * @since 3.4.0
         * @var array
         */
        public $json = array();
        /**
         * Control's Type.
         *
         * @since 3.4.0
         * @var string
         */
        public $type = 'text';
        /**
         * Callback.
         *
         * @since 4.0.0
         *
         * @see WP_Customize_Control::active()
         *
         * @var callable Callback is called with one argument, the instance of
         *               WP_Customize_Control, and returns bool to indicate whether
         *               the control is active (such as it relates to the URL
         *               currently being previewed).
         */
        public $active_callback = '';
        /**
         * Constructor.
         *
         * Supplied `$args` override class property defaults.
         *
         * If `$args['settings']` is not defined, use the `$id` as the setting ID.
         *
         * @since 3.4.0
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      Control ID.
         * @param array                $args    {
         *     Optional. Array of properties for the new Control object. Default empty array.
         *
         *     @type int                  $instance_number Order in which this instance was created in relation
         *                                                 to other instances.
         *     @type WP_Customize_Manager $manager         Customizer bootstrap instance.
         *     @type string               $id              Control ID.
         *     @type array                $settings        All settings tied to the control. If undefined, `$id` will
         *                                                 be used.
         *     @type string               $setting         The primary setting for the control (if there is one).
         *                                                 Default 'default'.
         *     @type string               $capability      Capability required to use this control. Normally this is empty
         *                                                 and the capability is derived from `$settings`.
         *     @type int                  $priority        Order priority to load the control. Default 10.
         *     @type string               $section         Section the control belongs to. Default empty.
         *     @type string               $label           Label for the control. Default empty.
         *     @type string               $description     Description for the control. Default empty.
         *     @type array                $choices         List of choices for 'radio' or 'select' type controls, where
         *                                                 values are the keys, and labels are the values.
         *                                                 Default empty array.
         *     @type array                $input_attrs     List of custom input attributes for control output, where
         *                                                 attribute names are the keys and values are the values. Not
         *                                                 used for 'checkbox', 'radio', 'select', 'textarea', or
         *                                                 'dropdown-pages' control types. Default empty array.
         *     @type bool                 $allow_addition  Show UI for adding new content, currently only used for the
         *                                                 dropdown-pages control. Default false.
         *     @type array                $json            Deprecated. Use WP_Customize_Control::json() instead.
         *     @type string               $type            Control type. Core controls include 'text', 'checkbox',
         *                                                 'textarea', 'radio', 'select', and 'dropdown-pages'. Additional
         *                                                 input types such as 'email', 'url', 'number', 'hidden', and
         *                                                 'date' are supported implicitly. Default 'text'.
         *     @type callable             $active_callback Active callback.
         * }
         * @phpstan-param array{
         *   instance_number?: int,
         *   manager?: WP_Customize_Manager,
         *   id?: string,
         *   settings?: array,
         *   setting?: string,
         *   capability?: string,
         *   priority?: int,
         *   section?: string,
         *   label?: string,
         *   description?: string,
         *   choices?: array,
         *   input_attrs?: array,
         *   allow_addition?: bool,
         *   json?: array,
         *   type?: string,
         *   active_callback?: callable,
         * } $args
         */
        public function __construct($manager, $id, $args = array())
        {
        }
        /**
         * Enqueue control related scripts/styles.
         *
         * @since 3.4.0
         */
        public function enqueue()
        {
        }
        /**
         * Check whether control is active to current Customizer preview.
         *
         * @since 4.0.0
         *
         * @return bool Whether the control is active to the current preview.
         */
        public final function active()
        {
        }
        /**
         * Default callback used when invoking WP_Customize_Control::active().
         *
         * Subclasses can override this with their specific logic, or they may
         * provide an 'active_callback' argument to the constructor.
         *
         * @since 4.0.0
         *
         * @return true Always true.
         */
        public function active_callback()
        {
        }
        /**
         * Fetch a setting's value.
         * Grabs the main setting by default.
         *
         * @since 3.4.0
         *
         * @param string $setting_key
         * @return mixed The requested setting's value, if the setting exists.
         */
        public final function value($setting_key = 'default')
        {
        }
        /**
         * Refresh the parameters passed to the JavaScript via JSON.
         *
         * @since 3.4.0
         */
        public function to_json()
        {
        }
        /**
         * Get the data to export to the client via JSON.
         *
         * @since 4.1.0
         *
         * @return array Array of parameters passed to the JavaScript.
         */
        public function json()
        {
        }
        /**
         * Checks if the user can use this control.
         *
         * Returns false if the user cannot manipulate one of the associated settings,
         * or if one of the associated settings does not exist. Also returns false if
         * the associated section does not exist or if its capability check returns
         * false.
         *
         * @since 3.4.0
         *
         * @return bool False if theme doesn't support the control or user doesn't have the required permissions, otherwise true.
         */
        public final function check_capabilities()
        {
        }
        /**
         * Get the control's content for insertion into the Customizer pane.
         *
         * @since 4.1.0
         *
         * @return string Contents of the control.
         */
        public final function get_content()
        {
        }
        /**
         * Check capabilities and render the control.
         *
         * @since 3.4.0
         * @uses WP_Customize_Control::render()
         * @phpstan-return void
         */
        public final function maybe_render()
        {
        }
        /**
         * Renders the control wrapper and calls $this->render_content() for the internals.
         *
         * @since 3.4.0
         */
        protected function render()
        {
        }
        /**
         * Get the data link attribute for a setting.
         *
         * @since 3.4.0
         * @since 4.9.0 Return a `data-customize-setting-key-link` attribute if a setting is not registered for the supplied setting key.
         *
         * @param string $setting_key
         * @return string Data link parameter, a `data-customize-setting-link` attribute if the `$setting_key` refers to a pre-registered setting,
         *                and a `data-customize-setting-key-link` attribute if the setting is not yet registered.
         */
        public function get_link($setting_key = 'default')
        {
        }
        /**
         * Render the data link attribute for the control's input element.
         *
         * @since 3.4.0
         * @uses WP_Customize_Control::get_link()
         *
         * @param string $setting_key
         */
        public function link($setting_key = 'default')
        {
        }
        /**
         * Render the custom attributes for the control's input element.
         *
         * @since 4.0.0
         */
        public function input_attrs()
        {
        }
        /**
         * Render the control's content.
         *
         * Allows the content to be overridden without having to rewrite the wrapper in `$this::render()`.
         *
         * Supports basic input types `text`, `checkbox`, `textarea`, `radio`, `select` and `dropdown-pages`.
         * Additional input types such as `email`, `url`, `number`, `hidden` and `date` are supported implicitly.
         *
         * Control content can alternately be rendered in JS. See WP_Customize_Control::print_template().
         *
         * @since 3.4.0
         * @phpstan-return void
         */
        protected function render_content()
        {
        }
        /**
         * Render the control's JS template.
         *
         * This function is only run for control types that have been registered with
         * WP_Customize_Manager::register_control_type().
         *
         * In the future, this will also print the template for the control's container
         * element and be override-able.
         *
         * @since 4.1.0
         */
        public final function print_template()
        {
        }
        /**
         * An Underscore (JS) template for this control's content (but not its container).
         *
         * Class variables for this control class are available in the `data` JS object;
         * export custom variables by overriding WP_Customize_Control::to_json().
         *
         * @see WP_Customize_Control::print_template()
         *
         * @since 4.1.0
         */
        protected function content_template()
        {
        }
    }
    /**
     * Customize Manager class.
     *
     * Bootstraps the Customize experience on the server-side.
     *
     * Sets up the theme-switching process if a theme other than the active one is
     * being previewed and customized.
     *
     * Serves as a factory for Customize Controls and Settings, and
     * instantiates default Customize Controls and Settings.
     *
     * @since 3.4.0
     */
    #[\AllowDynamicProperties]
    final class WP_Customize_Manager
    {
        /**
         * Methods and properties dealing with managing widgets in the Customizer.
         *
         * @since 3.9.0
         * @var WP_Customize_Widgets
         */
        public $widgets;
        /**
         * Methods and properties dealing with managing nav menus in the Customizer.
         *
         * @since 4.3.0
         * @var WP_Customize_Nav_Menus
         */
        public $nav_menus;
        /**
         * Methods and properties dealing with selective refresh in the Customizer preview.
         *
         * @since 4.5.0
         * @var WP_Customize_Selective_Refresh
         */
        public $selective_refresh;
        /**
         * Constructor.
         *
         * @since 3.4.0
         * @since 4.7.0 Added `$args` parameter.
         *
         * @param array $args {
         *     Args.
         *
         *     @type null|string|false $changeset_uuid     Changeset UUID, the `post_name` for the customize_changeset post containing the customized state.
         *                                                 Defaults to `null` resulting in a UUID to be immediately generated. If `false` is provided, then
         *                                                 then the changeset UUID will be determined during `after_setup_theme`: when the
         *                                                 `customize_changeset_branching` filter returns false, then the default UUID will be that
         *                                                 of the most recent `customize_changeset` post that has a status other than 'auto-draft',
         *                                                 'publish', or 'trash'. Otherwise, if changeset branching is enabled, then a random UUID will be used.
         *     @type string            $theme              Theme to be previewed (for theme switch). Defaults to customize_theme or theme query params.
         *     @type string            $messenger_channel  Messenger channel. Defaults to customize_messenger_channel query param.
         *     @type bool              $settings_previewed If settings should be previewed. Defaults to true.
         *     @type bool              $branching          If changeset branching is allowed; otherwise, changesets are linear. Defaults to true.
         *     @type bool              $autosaved          If data from a changeset's autosaved revision should be loaded if it exists. Defaults to false.
         * }
         * @phpstan-param array{
         *   changeset_uuid?: null|string|false,
         *   theme?: string,
         *   messenger_channel?: string,
         *   settings_previewed?: bool,
         *   branching?: bool,
         *   autosaved?: bool,
         * } $args
         */
        public function __construct($args = array())
        {
        }
        /**
         * Returns true if it's an Ajax request.
         *
         * @since 3.4.0
         * @since 4.2.0 Added `$action` param.
         *
         * @param string|null $action Whether the supplied Ajax action is being run.
         * @return bool True if it's an Ajax request, false otherwise.
         */
        public function doing_ajax($action = \null)
        {
        }
        /**
         * Returns the Ajax wp_die() handler if it's a customized request.
         *
         * @since 3.4.0
         * @deprecated 4.7.0
         *
         * @return callable Die handler.
         */
        public function wp_die_handler()
        {
        }
        /**
         * Starts preview and customize theme.
         *
         * Check if customize query variable exist. Init filters to filter the active theme.
         *
         * @since 3.4.0
         *
         * @global string $pagenow The filename of the current screen.
         * @phpstan-return void
         */
        public function setup_theme()
        {
        }
        /**
         * Establishes the loaded changeset.
         *
         * This method runs right at after_setup_theme and applies the 'customize_changeset_branching' filter to determine
         * whether concurrent changesets are allowed. Then if the Customizer is not initialized with a `changeset_uuid` param,
         * this method will determine which UUID should be used. If changeset branching is disabled, then the most saved
         * changeset will be loaded by default. Otherwise, if there are no existing saved changesets or if changeset branching is
         * enabled, then a new UUID will be generated.
         *
         * @since 4.9.0
         *
         * @global string $pagenow The filename of the current screen.
         */
        public function establish_loaded_changeset()
        {
        }
        /**
         * Callback to validate a theme once it is loaded
         *
         * @since 3.4.0
         */
        public function after_setup_theme()
        {
        }
        /**
         * If the theme to be previewed isn't the active theme, add filter callbacks
         * to swap it out at runtime.
         *
         * @since 3.4.0
         * @phpstan-return void
         */
        public function start_previewing_theme()
        {
        }
        /**
         * Stops previewing the selected theme.
         *
         * Removes filters to change the active theme.
         *
         * @since 3.4.0
         * @phpstan-return void
         */
        public function stop_previewing_theme()
        {
        }
        /**
         * Gets whether settings are or will be previewed.
         *
         * @since 4.9.0
         *
         * @see WP_Customize_Setting::preview()
         *
         * @return bool
         */
        public function settings_previewed()
        {
        }
        /**
         * Gets whether data from a changeset's autosaved revision should be loaded if it exists.
         *
         * @since 4.9.0
         *
         * @see WP_Customize_Manager::changeset_data()
         *
         * @return bool Is using autosaved changeset revision.
         */
        public function autosaved()
        {
        }
        /**
         * Whether the changeset branching is allowed.
         *
         * @since 4.9.0
         *
         * @see WP_Customize_Manager::establish_loaded_changeset()
         *
         * @return bool Is changeset branching.
         */
        public function branching()
        {
        }
        /**
         * Gets the changeset UUID.
         *
         * @since 4.7.0
         *
         * @see WP_Customize_Manager::establish_loaded_changeset()
         *
         * @return string UUID.
         */
        public function changeset_uuid()
        {
        }
        /**
         * Gets the theme being customized.
         *
         * @since 3.4.0
         *
         * @return WP_Theme
         */
        public function theme()
        {
        }
        /**
         * Gets the registered settings.
         *
         * @since 3.4.0
         *
         * @return array
         */
        public function settings()
        {
        }
        /**
         * Gets the registered controls.
         *
         * @since 3.4.0
         *
         * @return array
         */
        public function controls()
        {
        }
        /**
         * Gets the registered containers.
         *
         * @since 4.0.0
         *
         * @return array
         */
        public function containers()
        {
        }
        /**
         * Gets the registered sections.
         *
         * @since 3.4.0
         *
         * @return array
         */
        public function sections()
        {
        }
        /**
         * Gets the registered panels.
         *
         * @since 4.0.0
         *
         * @return array Panels.
         */
        public function panels()
        {
        }
        /**
         * Checks if the current theme is active.
         *
         * @since 3.4.0
         *
         * @return bool
         */
        public function is_theme_active()
        {
        }
        /**
         * Registers styles/scripts and initialize the preview of each setting
         *
         * @since 3.4.0
         */
        public function wp_loaded()
        {
        }
        /**
         * Prevents Ajax requests from following redirects when previewing a theme
         * by issuing a 200 response instead of a 30x.
         *
         * Instead, the JS will sniff out the location header.
         *
         * @since 3.4.0
         * @deprecated 4.7.0
         *
         * @param int $status Status.
         * @return int
         */
        public function wp_redirect_status($status)
        {
        }
        /**
         * Finds the changeset post ID for a given changeset UUID.
         *
         * @since 4.7.0
         *
         * @param string $uuid Changeset UUID.
         * @return int|null Returns post ID on success and null on failure.
         */
        public function find_changeset_post_id($uuid)
        {
        }
        /**
         * Gets the changeset post ID for the loaded changeset.
         *
         * @since 4.7.0
         *
         * @return int|null Post ID on success or null if there is no post yet saved.
         */
        public function changeset_post_id()
        {
        }
        /**
         * Gets changeset data.
         *
         * @since 4.7.0
         * @since 4.9.0 This will return the changeset's data with a user's autosave revision merged on top, if one exists and $autosaved is true.
         *
         * @return array Changeset data.
         */
        public function changeset_data()
        {
        }
        /**
         * Imports theme starter content into the customized state.
         *
         * @since 4.7.0
         *
         * @param array $starter_content Starter content. Defaults to `get_theme_starter_content()`.
         * @phpstan-return void
         */
        public function import_theme_starter_content($starter_content = array())
        {
        }
        /**
         * Saves starter content changeset.
         *
         * @since 4.7.0
         * @phpstan-return void
         */
        public function _save_starter_content_changeset()
        {
        }
        /**
         * Gets dirty pre-sanitized setting values in the current customized state.
         *
         * The returned array consists of a merge of three sources:
         * 1. If the theme is not currently active, then the base array is any stashed
         *    theme mods that were modified previously but never published.
         * 2. The values from the current changeset, if it exists.
         * 3. If the user can customize, the values parsed from the incoming
         *    `$_POST['customized']` JSON data.
         * 4. Any programmatically-set post values via `WP_Customize_Manager::set_post_value()`.
         *
         * The name "unsanitized_post_values" is a carry-over from when the customized
         * state was exclusively sourced from `$_POST['customized']`. Nevertheless,
         * the value returned will come from the current changeset post and from the
         * incoming post data.
         *
         * @since 4.1.1
         * @since 4.7.0 Added `$args` parameter and merging with changeset values and stashed theme mods.
         *
         * @param array $args {
         *     Args.
         *
         *     @type bool $exclude_changeset Whether the changeset values should also be excluded. Defaults to false.
         *     @type bool $exclude_post_data Whether the post input values should also be excluded. Defaults to false when lacking the customize capability.
         * }
         * @return array
         * @phpstan-param array{
         *   exclude_changeset?: bool,
         *   exclude_post_data?: bool,
         * } $args
         */
        public function unsanitized_post_values($args = array())
        {
        }
        /**
         * Returns the sanitized value for a given setting from the current customized state.
         *
         * The name "post_value" is a carry-over from when the customized state was exclusively
         * sourced from `$_POST['customized']`. Nevertheless, the value returned will come
         * from the current changeset post and from the incoming post data.
         *
         * @since 3.4.0
         * @since 4.1.1 Introduced the `$default_value` parameter.
         * @since 4.6.0 `$default_value` is now returned early when the setting post value is invalid.
         *
         * @see WP_REST_Server::dispatch()
         * @see WP_REST_Request::sanitize_params()
         * @see WP_REST_Request::has_valid_params()
         *
         * @param WP_Customize_Setting $setting       A WP_Customize_Setting derived object.
         * @param mixed                $default_value Value returned if `$setting` has no post value (added in 4.2.0)
         *                                            or the post value is invalid (added in 4.6.0).
         * @return string|mixed Sanitized value or the `$default_value` provided.
         */
        public function post_value($setting, $default_value = \null)
        {
        }
        /**
         * Overrides a setting's value in the current customized state.
         *
         * The name "post_value" is a carry-over from when the customized state was
         * exclusively sourced from `$_POST['customized']`.
         *
         * @since 4.2.0
         *
         * @param string $setting_id ID for the WP_Customize_Setting instance.
         * @param mixed  $value      Post value.
         */
        public function set_post_value($setting_id, $value)
        {
        }
        /**
         * Prints JavaScript settings.
         *
         * @since 3.4.0
         * @phpstan-return void
         */
        public function customize_preview_init()
        {
        }
        /**
         * Filters the X-Frame-Options and Content-Security-Policy headers to ensure frontend can load in customizer.
         *
         * @since 4.7.0
         *
         * @param array $headers Headers.
         * @return array Headers.
         */
        public function filter_iframe_security_headers($headers)
        {
        }
        /**
         * Adds customize state query params to a given URL if preview is allowed.
         *
         * @since 4.7.0
         *
         * @see wp_redirect()
         * @see WP_Customize_Manager::get_allowed_url()
         *
         * @param string $url URL.
         * @return string URL.
         */
        public function add_state_query_params($url)
        {
        }
        /**
         * Prevents sending a 404 status when returning the response for the customize
         * preview, since it causes the jQuery Ajax to fail. Send 200 instead.
         *
         * @since 4.0.0
         * @deprecated 4.7.0
         */
        public function customize_preview_override_404_status()
        {
        }
        /**
         * Prints base element for preview frame.
         *
         * @since 3.4.0
         * @deprecated 4.7.0
         */
        public function customize_preview_base()
        {
        }
        /**
         * Prints a workaround to handle HTML5 tags in IE < 9.
         *
         * @since 3.4.0
         * @deprecated 4.7.0 Customizer no longer supports IE8, so all supported browsers recognize HTML5.
         */
        public function customize_preview_html5()
        {
        }
        /**
         * Prints CSS for loading indicators for the Customizer preview.
         *
         * @since 4.2.0
         */
        public function customize_preview_loading_style()
        {
        }
        /**
         * Removes customize_messenger_channel query parameter from the preview window when it is not in an iframe.
         *
         * This ensures that the admin bar will be shown. It also ensures that link navigation will
         * work as expected since the parent frame is not being sent the URL to navigate to.
         *
         * @since 4.7.0
         * @phpstan-return void
         */
        public function remove_frameless_preview_messenger_channel()
        {
        }
        /**
         * Prints JavaScript settings for preview frame.
         *
         * @since 3.4.0
         */
        public function customize_preview_settings()
        {
        }
        /**
         * Prints a signature so we can ensure the Customizer was properly executed.
         *
         * @since 3.4.0
         * @deprecated 4.7.0
         */
        public function customize_preview_signature()
        {
        }
        /**
         * Removes the signature in case we experience a case where the Customizer was not properly executed.
         *
         * @since 3.4.0
         * @deprecated 4.7.0
         *
         * @param callable|null $callback Optional. Value passed through for {@see 'wp_die_handler'} filter.
         *                                Default null.
         * @return callable|null Value passed through for {@see 'wp_die_handler'} filter.
         */
        public function remove_preview_signature($callback = \null)
        {
        }
        /**
         * Determines whether it is a theme preview or not.
         *
         * @since 3.4.0
         *
         * @return bool True if it's a preview, false if not.
         */
        public function is_preview()
        {
        }
        /**
         * Retrieves the template name of the previewed theme.
         *
         * @since 3.4.0
         *
         * @return string Template name.
         */
        public function get_template()
        {
        }
        /**
         * Retrieves the stylesheet name of the previewed theme.
         *
         * @since 3.4.0
         *
         * @return string Stylesheet name.
         */
        public function get_stylesheet()
        {
        }
        /**
         * Retrieves the template root of the previewed theme.
         *
         * @since 3.4.0
         *
         * @return string Theme root.
         */
        public function get_template_root()
        {
        }
        /**
         * Retrieves the stylesheet root of the previewed theme.
         *
         * @since 3.4.0
         *
         * @return string Theme root.
         */
        public function get_stylesheet_root()
        {
        }
        /**
         * Filters the active theme and return the name of the previewed theme.
         *
         * @since 3.4.0
         *
         * @param mixed $current_theme {@internal Parameter is not used}
         * @return string Theme name.
         */
        public function current_theme($current_theme)
        {
        }
        /**
         * Validates setting values.
         *
         * Validation is skipped for unregistered settings or for values that are
         * already null since they will be skipped anyway. Sanitization is applied
         * to values that pass validation, and values that become null or `WP_Error`
         * after sanitizing are marked invalid.
         *
         * @since 4.6.0
         *
         * @see WP_REST_Request::has_valid_params()
         * @see WP_Customize_Setting::validate()
         *
         * @param array $setting_values Mapping of setting IDs to values to validate and sanitize.
         * @param array $options {
         *     Options.
         *
         *     @type bool $validate_existence  Whether a setting's existence will be checked.
         *     @type bool $validate_capability Whether the setting capability will be checked.
         * }
         * @return array Mapping of setting IDs to return value of validate method calls, either `true` or `WP_Error`.
         * @phpstan-param array{
         *   validate_existence?: bool,
         *   validate_capability?: bool,
         * } $options
         */
        public function validate_setting_values($setting_values, $options = array())
        {
        }
        /**
         * Prepares setting validity for exporting to the client (JS).
         *
         * Converts `WP_Error` instance into array suitable for passing into the
         * `wp.customize.Notification` JS model.
         *
         * @since 4.6.0
         *
         * @param true|WP_Error $validity Setting validity.
         * @return true|array If `$validity` was a WP_Error, the error codes will be array-mapped
         *                    to their respective `message` and `data` to pass into the
         *                    `wp.customize.Notification` JS model.
         */
        public function prepare_setting_validity_for_js($validity)
        {
        }
        /**
         * Handles customize_save WP Ajax request to save/update a changeset.
         *
         * @since 3.4.0
         * @since 4.7.0 The semantics of this method have changed to update a changeset, optionally to also change the status and other attributes.
         */
        public function save()
        {
        }
        /**
         * Saves the post for the loaded changeset.
         *
         * @since 4.7.0
         *
         * @param array $args {
         *     Args for changeset post.
         *
         *     @type array  $data            Optional additional changeset data. Values will be merged on top of any existing post values.
         *     @type string $status          Post status. Optional. If supplied, the save will be transactional and a post revision will be allowed.
         *     @type string $title           Post title. Optional.
         *     @type string $date_gmt        Date in GMT. Optional.
         *     @type int    $user_id         ID for user who is saving the changeset. Optional, defaults to the current user ID.
         *     @type bool   $starter_content Whether the data is starter content. If false (default), then $starter_content will be cleared for any $data being saved.
         *     @type bool   $autosave        Whether this is a request to create an autosave revision.
         * }
         *
         * @return array|WP_Error Returns array on success and WP_Error with array data on error.
         * @phpstan-param array{
         *   data?: array,
         *   status?: string,
         *   title?: string,
         *   date_gmt?: string,
         *   user_id?: int,
         *   starter_content?: bool,
         *   autosave?: bool,
         * } $args
         */
        public function save_changeset_post($args = array())
        {
        }
        /**
         * Preserves the initial JSON post_content passed to save into the post.
         *
         * This is needed to prevent KSES and other {@see 'content_save_pre'} filters
         * from corrupting JSON data.
         *
         * Note that WP_Customize_Manager::validate_setting_values() have already
         * run on the setting values being serialized as JSON into the post content
         * so it is pre-sanitized.
         *
         * Also, the sanitization logic is re-run through the respective
         * WP_Customize_Setting::sanitize() method when being read out of the
         * changeset, via WP_Customize_Manager::post_value(), and this sanitized
         * value will also be sent into WP_Customize_Setting::update() for
         * persisting to the DB.
         *
         * Multiple users can collaborate on a single changeset, where one user may
         * have the unfiltered_html capability but another may not. A user with
         * unfiltered_html may add a script tag to some field which needs to be kept
         * intact even when another user updates the changeset to modify another field
         * when they do not have unfiltered_html.
         *
         * @since 5.4.1
         *
         * @param array $data                An array of slashed and processed post data.
         * @param array $postarr             An array of sanitized (and slashed) but otherwise unmodified post data.
         * @param array $unsanitized_postarr An array of slashed yet *unsanitized* and unprocessed post data as originally passed to wp_insert_post().
         * @return array Filtered post data.
         */
        public function preserve_insert_changeset_post_content($data, $postarr, $unsanitized_postarr)
        {
        }
        /**
         * Trashes or deletes a changeset post.
         *
         * The following re-formulates the logic from `wp_trash_post()` as done in
         * `wp_publish_post()`. The reason for bypassing `wp_trash_post()` is that it
         * will mutate the the `post_content` and the `post_name` when they should be
         * untouched.
         *
         * @since 4.9.0
         *
         * @see wp_trash_post()
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param int|WP_Post $post The changeset post.
         * @return mixed A WP_Post object for the trashed post or an empty value on failure.
         */
        public function trash_changeset_post($post)
        {
        }
        /**
         * Handles request to trash a changeset.
         *
         * @since 4.9.0
         * @phpstan-return void
         */
        public function handle_changeset_trash_request()
        {
        }
        /**
         * Re-maps 'edit_post' meta cap for a customize_changeset post to be the same as 'customize' maps.
         *
         * There is essentially a "meta meta" cap in play here, where 'edit_post' meta cap maps to
         * the 'customize' meta cap which then maps to 'edit_theme_options'. This is currently
         * required in core for `wp_create_post_autosave()` because it will call
         * `_wp_translate_postdata()` which in turn will check if a user can 'edit_post', but the
         * the caps for the customize_changeset post type are all mapping to the meta capability.
         * This should be able to be removed once #40922 is addressed in core.
         *
         * @since 4.9.0
         *
         * @link https://core.trac.wordpress.org/ticket/40922
         * @see WP_Customize_Manager::save_changeset_post()
         * @see _wp_translate_postdata()
         *
         * @param string[] $caps    Array of the user's capabilities.
         * @param string   $cap     Capability name.
         * @param int      $user_id The user ID.
         * @param array    $args    Adds the context to the cap. Typically the object ID.
         * @return array Capabilities.
         */
        public function grant_edit_post_capability_for_changeset($caps, $cap, $user_id, $args)
        {
        }
        /**
         * Marks the changeset post as being currently edited by the current user.
         *
         * @since 4.9.0
         *
         * @param int  $changeset_post_id Changeset post ID.
         * @param bool $take_over Whether to take over the changeset. Default false.
         */
        public function set_changeset_lock($changeset_post_id, $take_over = \false)
        {
        }
        /**
         * Refreshes changeset lock with the current time if current user edited the changeset before.
         *
         * @since 4.9.0
         *
         * @param int $changeset_post_id Changeset post ID.
         * @phpstan-return void
         */
        public function refresh_changeset_lock($changeset_post_id)
        {
        }
        /**
         * Filters heartbeat settings for the Customizer.
         *
         * @since 4.9.0
         *
         * @global string $pagenow The filename of the current screen.
         *
         * @param array $settings Current settings to filter.
         * @return array Heartbeat settings.
         */
        public function add_customize_screen_to_heartbeat_settings($settings)
        {
        }
        /**
         * Checks locked changeset with heartbeat API.
         *
         * @since 4.9.0
         *
         * @param array  $response  The Heartbeat response.
         * @param array  $data      The $_POST data sent.
         * @param string $screen_id The screen id.
         * @return array The Heartbeat response.
         */
        public function check_changeset_lock_with_heartbeat($response, $data, $screen_id)
        {
        }
        /**
         * Removes changeset lock when take over request is sent via Ajax.
         *
         * @since 4.9.0
         * @phpstan-return never
         */
        public function handle_override_changeset_lock_request()
        {
        }
        /**
         * Filters whether a changeset has changed to create a new revision.
         *
         * Note that this will not be called while a changeset post remains in auto-draft status.
         *
         * @since 4.7.0
         *
         * @param bool    $post_has_changed Whether the post has changed.
         * @param WP_Post $latest_revision  The latest revision post object.
         * @param WP_Post $post             The post object.
         * @return bool Whether a revision should be made.
         */
        public function _filter_revision_post_has_changed($post_has_changed, $latest_revision, $post)
        {
        }
        /**
         * Publishes the values of a changeset.
         *
         * This will publish the values contained in a changeset, even changesets that do not
         * correspond to current manager instance. This is called by
         * `_wp_customize_publish_changeset()` when a customize_changeset post is
         * transitioned to the `publish` status. As such, this method should not be
         * called directly and instead `wp_publish_post()` should be used.
         *
         * Please note that if the settings in the changeset are for a non-activated
         * theme, the theme must first be switched to (via `switch_theme()`) before
         * invoking this method.
         *
         * @since 4.7.0
         *
         * @see _wp_customize_publish_changeset()
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param int $changeset_post_id ID for customize_changeset post. Defaults to the changeset for the current manager instance.
         * @return true|WP_Error True or error info.
         */
        public function _publish_changeset_values($changeset_post_id)
        {
        }
        /**
         * Refreshes nonces for the current preview.
         *
         * @since 4.2.0
         * @phpstan-return never
         */
        public function refresh_nonces()
        {
        }
        /**
         * Deletes a given auto-draft changeset or the autosave revision for a given changeset or delete changeset lock.
         *
         * @since 4.9.0
         * @phpstan-return never
         */
        public function handle_dismiss_autosave_or_lock_request()
        {
        }
        /**
         * Adds a customize setting.
         *
         * @since 3.4.0
         * @since 4.5.0 Return added WP_Customize_Setting instance.
         *
         * @see WP_Customize_Setting::__construct()
         * @link https://developer.wordpress.org/themes/customize-api
         *
         * @param WP_Customize_Setting|string $id   Customize Setting object, or ID.
         * @param array                       $args Optional. Array of properties for the new Setting object.
         *                                          See WP_Customize_Setting::__construct() for information
         *                                          on accepted arguments. Default empty array.
         * @return WP_Customize_Setting The instance of the setting that was added.
         * @phpstan-param array{
         *   type?: string,
         *   capability?: string,
         *   theme_supports?: string|string[],
         *   default?: string,
         *   transport?: string,
         *   validate_callback?: callable,
         *   sanitize_callback?: callable,
         *   sanitize_js_callback?: callable,
         *   dirty?: bool,
         * } $args See WP_Customize_Setting::__construct()
         */
        public function add_setting($id, $args = array())
        {
        }
        /**
         * Registers any dynamically-created settings, such as those from $_POST['customized']
         * that have no corresponding setting created.
         *
         * This is a mechanism to "wake up" settings that have been dynamically created
         * on the front end and have been sent to WordPress in `$_POST['customized']`. When WP
         * loads, the dynamically-created settings then will get created and previewed
         * even though they are not directly created statically with code.
         *
         * @since 4.2.0
         *
         * @param array $setting_ids The setting IDs to add.
         * @return array The WP_Customize_Setting objects added.
         */
        public function add_dynamic_settings($setting_ids)
        {
        }
        /**
         * Retrieves a customize setting.
         *
         * @since 3.4.0
         *
         * @param string $id Customize Setting ID.
         * @return WP_Customize_Setting|void The setting, if set.
         */
        public function get_setting($id)
        {
        }
        /**
         * Removes a customize setting.
         *
         * Note that removing the setting doesn't destroy the WP_Customize_Setting instance or remove its filters.
         *
         * @since 3.4.0
         *
         * @param string $id Customize Setting ID.
         */
        public function remove_setting($id)
        {
        }
        /**
         * Adds a customize panel.
         *
         * @since 4.0.0
         * @since 4.5.0 Return added WP_Customize_Panel instance.
         *
         * @see WP_Customize_Panel::__construct()
         *
         * @param WP_Customize_Panel|string $id   Customize Panel object, or ID.
         * @param array                     $args Optional. Array of properties for the new Panel object.
         *                                        See WP_Customize_Panel::__construct() for information
         *                                        on accepted arguments. Default empty array.
         * @return WP_Customize_Panel The instance of the panel that was added.
         * @phpstan-param array{
         *   priority?: int,
         *   capability?: string,
         *   theme_supports?: mixed[],
         *   title?: string,
         *   description?: string,
         *   type?: string,
         *   active_callback?: callable,
         * } $args See WP_Customize_Panel::__construct()
         */
        public function add_panel($id, $args = array())
        {
        }
        /**
         * Retrieves a customize panel.
         *
         * @since 4.0.0
         *
         * @param string $id Panel ID to get.
         * @return WP_Customize_Panel|void Requested panel instance, if set.
         */
        public function get_panel($id)
        {
        }
        /**
         * Removes a customize panel.
         *
         * Note that removing the panel doesn't destroy the WP_Customize_Panel instance or remove its filters.
         *
         * @since 4.0.0
         *
         * @param string $id Panel ID to remove.
         */
        public function remove_panel($id)
        {
        }
        /**
         * Registers a customize panel type.
         *
         * Registered types are eligible to be rendered via JS and created dynamically.
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Panel
         *
         * @param string $panel Name of a custom panel which is a subclass of WP_Customize_Panel.
         */
        public function register_panel_type($panel)
        {
        }
        /**
         * Renders JS templates for all registered panel types.
         *
         * @since 4.3.0
         */
        public function render_panel_templates()
        {
        }
        /**
         * Adds a customize section.
         *
         * @since 3.4.0
         * @since 4.5.0 Return added WP_Customize_Section instance.
         *
         * @see WP_Customize_Section::__construct()
         *
         * @param WP_Customize_Section|string $id   Customize Section object, or ID.
         * @param array                       $args Optional. Array of properties for the new Section object.
         *                                          See WP_Customize_Section::__construct() for information
         *                                          on accepted arguments. Default empty array.
         * @return WP_Customize_Section The instance of the section that was added.
         * @phpstan-param array{
         *   priority?: int,
         *   panel?: string,
         *   capability?: string,
         *   theme_supports?: string|string[],
         *   title?: string,
         *   description?: string,
         *   type?: string,
         *   active_callback?: callable,
         *   description_hidden?: bool,
         * } $args See WP_Customize_Section::__construct()
         */
        public function add_section($id, $args = array())
        {
        }
        /**
         * Retrieves a customize section.
         *
         * @since 3.4.0
         *
         * @param string $id Section ID.
         * @return WP_Customize_Section|void The section, if set.
         */
        public function get_section($id)
        {
        }
        /**
         * Removes a customize section.
         *
         * Note that removing the section doesn't destroy the WP_Customize_Section instance or remove its filters.
         *
         * @since 3.4.0
         *
         * @param string $id Section ID.
         */
        public function remove_section($id)
        {
        }
        /**
         * Registers a customize section type.
         *
         * Registered types are eligible to be rendered via JS and created dynamically.
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Section
         *
         * @param string $section Name of a custom section which is a subclass of WP_Customize_Section.
         */
        public function register_section_type($section)
        {
        }
        /**
         * Renders JS templates for all registered section types.
         *
         * @since 4.3.0
         */
        public function render_section_templates()
        {
        }
        /**
         * Adds a customize control.
         *
         * @since 3.4.0
         * @since 4.5.0 Return added WP_Customize_Control instance.
         *
         * @see WP_Customize_Control::__construct()
         *
         * @param WP_Customize_Control|string $id   Customize Control object, or ID.
         * @param array                       $args Optional. Array of properties for the new Control object.
         *                                          See WP_Customize_Control::__construct() for information
         *                                          on accepted arguments. Default empty array.
         * @return WP_Customize_Control The instance of the control that was added.
         * @phpstan-param array{
         *   instance_number?: int,
         *   manager?: WP_Customize_Manager,
         *   id?: string,
         *   settings?: array,
         *   setting?: string,
         *   capability?: string,
         *   priority?: int,
         *   section?: string,
         *   label?: string,
         *   description?: string,
         *   choices?: array,
         *   input_attrs?: array,
         *   allow_addition?: bool,
         *   json?: array,
         *   type?: string,
         *   active_callback?: callable,
         * } $args See WP_Customize_Control::__construct()
         */
        public function add_control($id, $args = array())
        {
        }
        /**
         * Retrieves a customize control.
         *
         * @since 3.4.0
         *
         * @param string $id ID of the control.
         * @return WP_Customize_Control|void The control object, if set.
         */
        public function get_control($id)
        {
        }
        /**
         * Removes a customize control.
         *
         * Note that removing the control doesn't destroy the WP_Customize_Control instance or remove its filters.
         *
         * @since 3.4.0
         *
         * @param string $id ID of the control.
         */
        public function remove_control($id)
        {
        }
        /**
         * Registers a customize control type.
         *
         * Registered types are eligible to be rendered via JS and created dynamically.
         *
         * @since 4.1.0
         *
         * @param string $control Name of a custom control which is a subclass of
         *                        WP_Customize_Control.
         */
        public function register_control_type($control)
        {
        }
        /**
         * Renders JS templates for all registered control types.
         *
         * @since 4.1.0
         */
        public function render_control_templates()
        {
        }
        /**
         * Prepares panels, sections, and controls.
         *
         * For each, check if required related components exist,
         * whether the user has the necessary capabilities,
         * and sort by priority.
         *
         * @since 3.4.0
         */
        public function prepare_controls()
        {
        }
        /**
         * Enqueues scripts for customize controls.
         *
         * @since 3.4.0
         */
        public function enqueue_control_scripts()
        {
        }
        /**
         * Determines whether the user agent is iOS.
         *
         * @since 4.4.0
         *
         * @return bool Whether the user agent is iOS.
         */
        public function is_ios()
        {
        }
        /**
         * Gets the template string for the Customizer pane document title.
         *
         * @since 4.4.0
         *
         * @return string The template string for the document title.
         */
        public function get_document_title_template()
        {
        }
        /**
         * Sets the initial URL to be previewed.
         *
         * URL is validated.
         *
         * @since 4.4.0
         *
         * @param string $preview_url URL to be previewed.
         */
        public function set_preview_url($preview_url)
        {
        }
        /**
         * Gets the initial URL to be previewed.
         *
         * @since 4.4.0
         *
         * @return string URL being previewed.
         */
        public function get_preview_url()
        {
        }
        /**
         * Determines whether the admin and the frontend are on different domains.
         *
         * @since 4.7.0
         *
         * @return bool Whether cross-domain.
         */
        public function is_cross_domain()
        {
        }
        /**
         * Gets URLs allowed to be previewed.
         *
         * If the front end and the admin are served from the same domain, load the
         * preview over ssl if the Customizer is being loaded over ssl. This avoids
         * insecure content warnings. This is not attempted if the admin and front end
         * are on different domains to avoid the case where the front end doesn't have
         * ssl certs. Domain mapping plugins can allow other urls in these conditions
         * using the customize_allowed_urls filter.
         *
         * @since 4.7.0
         *
         * @return array Allowed URLs.
         */
        public function get_allowed_urls()
        {
        }
        /**
         * Gets messenger channel.
         *
         * @since 4.7.0
         *
         * @return string Messenger channel.
         */
        public function get_messenger_channel()
        {
        }
        /**
         * Sets URL to link the user to when closing the Customizer.
         *
         * URL is validated.
         *
         * @since 4.4.0
         *
         * @param string $return_url URL for return link.
         */
        public function set_return_url($return_url)
        {
        }
        /**
         * Gets URL to link the user to when closing the Customizer.
         *
         * @since 4.4.0
         *
         * @global array $_registered_pages
         *
         * @return string URL for link to close Customizer.
         */
        public function get_return_url()
        {
        }
        /**
         * Sets the autofocused constructs.
         *
         * @since 4.4.0
         *
         * @param array $autofocus {
         *     Mapping of 'panel', 'section', 'control' to the ID which should be autofocused.
         *
         *     @type string $control ID for control to be autofocused.
         *     @type string $section ID for section to be autofocused.
         *     @type string $panel   ID for panel to be autofocused.
         * }
         * @phpstan-param array{
         *   control?: string,
         *   section?: string,
         *   panel?: string,
         * } $autofocus
         */
        public function set_autofocus($autofocus)
        {
        }
        /**
         * Gets the autofocused constructs.
         *
         * @since 4.4.0
         *
         * @return string[] {
         *     Mapping of 'panel', 'section', 'control' to the ID which should be autofocused.
         *
         *     @type string $control ID for control to be autofocused.
         *     @type string $section ID for section to be autofocused.
         *     @type string $panel   ID for panel to be autofocused.
         * }
         * @phpstan-return array{
         *   control: string,
         *   section: string,
         *   panel: string,
         * }
         */
        public function get_autofocus()
        {
        }
        /**
         * Gets nonces for the Customizer.
         *
         * @since 4.5.0
         *
         * @return array Nonces.
         */
        public function get_nonces()
        {
        }
        /**
         * Prints JavaScript settings for parent window.
         *
         * @since 4.4.0
         */
        public function customize_pane_settings()
        {
        }
        /**
         * Returns a list of devices to allow previewing.
         *
         * @since 4.5.0
         *
         * @return array List of devices with labels and default setting.
         */
        public function get_previewable_devices()
        {
        }
        /**
         * Registers some default controls.
         *
         * @since 3.4.0
         */
        public function register_controls()
        {
        }
        /**
         * Returns whether there are published pages.
         *
         * Used as active callback for static front page section and controls.
         *
         * @since 4.7.0
         *
         * @return bool Whether there are published (or to be published) pages.
         */
        public function has_published_pages()
        {
        }
        /**
         * Adds settings from the POST data that were not added with code, e.g. dynamically-created settings for Widgets
         *
         * @since 4.2.0
         *
         * @see add_dynamic_settings()
         */
        public function register_dynamic_settings()
        {
        }
        /**
         * Loads themes into the theme browsing/installation UI.
         *
         * @since 4.9.0
         * @phpstan-return never
         */
        public function handle_load_themes_request()
        {
        }
        /**
         * Callback for validating the header_textcolor value.
         *
         * Accepts 'blank', and otherwise uses sanitize_hex_color_no_hash().
         * Returns default text color if hex color is empty.
         *
         * @since 3.4.0
         *
         * @param string $color
         * @return mixed
         */
        public function _sanitize_header_textcolor($color)
        {
        }
        /**
         * Callback for validating a background setting value.
         *
         * @since 4.7.0
         *
         * @param string               $value   Repeat value.
         * @param WP_Customize_Setting $setting Setting.
         * @return string|WP_Error Background value or validation error.
         */
        public function _sanitize_background_setting($value, $setting)
        {
        }
        /**
         * Exports header video settings to facilitate selective refresh.
         *
         * @since 4.7.0
         *
         * @param array                          $response          Response.
         * @param WP_Customize_Selective_Refresh $selective_refresh Selective refresh component.
         * @param array                          $partials          Array of partials.
         * @return array
         */
        public function export_header_video_settings($response, $selective_refresh, $partials)
        {
        }
        /**
         * Callback for validating the header_video value.
         *
         * Ensures that the selected video is less than 8MB and provides an error message.
         *
         * @since 4.7.0
         *
         * @param WP_Error $validity
         * @param mixed    $value
         * @return mixed
         */
        public function _validate_header_video($validity, $value)
        {
        }
        /**
         * Callback for validating the external_header_video value.
         *
         * Ensures that the provided URL is supported.
         *
         * @since 4.7.0
         *
         * @param WP_Error $validity
         * @param mixed    $value
         * @return mixed
         */
        public function _validate_external_header_video($validity, $value)
        {
        }
        /**
         * Callback for sanitizing the external_header_video value.
         *
         * @since 4.7.1
         *
         * @param string $value URL.
         * @return string Sanitized URL.
         */
        public function _sanitize_external_header_video($value)
        {
        }
        /**
         * Callback for rendering the custom logo, used in the custom_logo partial.
         *
         * This method exists because the partial object and context data are passed
         * into a partial's render_callback so we cannot use get_custom_logo() as
         * the render_callback directly since it expects a blog ID as the first
         * argument.
         *
         * @see WP_Customize_Manager::register_controls()
         *
         * @since 4.5.0
         *
         * @return string Custom logo.
         */
        public function _render_custom_logo_partial()
        {
        }
    }
    /**
     * Customize Nav Menus class.
     *
     * Implements menu management in the Customizer.
     *
     * @since 4.3.0
     *
     * @see WP_Customize_Manager
     */
    #[\AllowDynamicProperties]
    final class WP_Customize_Nav_Menus
    {
        /**
         * WP_Customize_Manager instance.
         *
         * @since 4.3.0
         * @var WP_Customize_Manager
         */
        public $manager;
        /**
         * Constructor.
         *
         * @since 4.3.0
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @phpstan-return void
         */
        public function __construct($manager)
        {
        }
        /**
         * Adds a nonce for customizing menus.
         *
         * @since 4.5.0
         *
         * @param string[] $nonces Array of nonces.
         * @return string[] Modified array of nonces.
         */
        public function filter_nonces($nonces)
        {
        }
        /**
         * Ajax handler for loading available menu items.
         *
         * @since 4.3.0
         * @phpstan-return never
         */
        public function ajax_load_available_items()
        {
        }
        /**
         * Performs the post_type and taxonomy queries for loading available menu items.
         *
         * @since 4.3.0
         *
         * @param string $object_type Optional. Accepts any custom object type and has built-in support for
         *                            'post_type' and 'taxonomy'. Default is 'post_type'.
         * @param string $object_name Optional. Accepts any registered taxonomy or post type name. Default is 'page'.
         * @param int    $page        Optional. The page number used to generate the query offset. Default is '0'.
         * @return array|WP_Error An array of menu items on success, a WP_Error object on failure.
         */
        public function load_available_items_query($object_type = 'post_type', $object_name = 'page', $page = 0)
        {
        }
        /**
         * Ajax handler for searching available menu items.
         *
         * @since 4.3.0
         */
        public function ajax_search_available_items()
        {
        }
        /**
         * Performs post queries for available-item searching.
         *
         * Based on WP_Editor::wp_link_query().
         *
         * @since 4.3.0
         *
         * @param array $args Optional. Accepts 'pagenum' and 's' (search) arguments.
         * @return array Menu items.
         */
        public function search_available_items_query($args = array())
        {
        }
        /**
         * Enqueues scripts and styles for Customizer pane.
         *
         * @since 4.3.0
         */
        public function enqueue_scripts()
        {
        }
        /**
         * Filters a dynamic setting's constructor args.
         *
         * For a dynamic setting to be registered, this filter must be employed
         * to override the default false value with an array of args to pass to
         * the WP_Customize_Setting constructor.
         *
         * @since 4.3.0
         *
         * @param false|array $setting_args The arguments to the WP_Customize_Setting constructor.
         * @param string      $setting_id   ID for dynamic setting, usually coming from `$_POST['customized']`.
         * @return array|false
         */
        public function filter_dynamic_setting_args($setting_args, $setting_id)
        {
        }
        /**
         * Allows non-statically created settings to be constructed with custom WP_Customize_Setting subclass.
         *
         * @since 4.3.0
         *
         * @param string $setting_class WP_Customize_Setting or a subclass.
         * @param string $setting_id    ID for dynamic setting, usually coming from `$_POST['customized']`.
         * @param array  $setting_args  WP_Customize_Setting or a subclass.
         * @return string
         */
        public function filter_dynamic_setting_class($setting_class, $setting_id, $setting_args)
        {
        }
        /**
         * Adds the customizer settings and controls.
         *
         * @since 4.3.0
         */
        public function customize_register()
        {
        }
        /**
         * Gets the base10 intval.
         *
         * This is used as a setting's sanitize_callback; we can't use just plain
         * intval because the second argument is not what intval() expects.
         *
         * @since 4.3.0
         *
         * @param mixed $value Number to convert.
         * @return int Integer.
         */
        public function intval_base10($value)
        {
        }
        /**
         * Returns an array of all the available item types.
         *
         * @since 4.3.0
         * @since 4.7.0  Each array item now includes a `$type_label` in addition to `$title`, `$type`, and `$object`.
         *
         * @return array The available menu item types.
         */
        public function available_item_types()
        {
        }
        /**
         * Adds a new `auto-draft` post.
         *
         * @since 4.7.0
         *
         * @param array $postarr {
         *     Post array. Note that post_status is overridden to be `auto-draft`.
         *
         *     @type string $post_title   Post title. Required.
         *     @type string $post_type    Post type. Required.
         *     @type string $post_name    Post name.
         *     @type string $post_content Post content.
         * }
         * @return WP_Post|WP_Error Inserted auto-draft post object or error.
         * @phpstan-param array{
         *   post_title?: string,
         *   post_type?: string,
         *   post_name?: string,
         *   post_content?: string,
         * } $postarr
         */
        public function insert_auto_draft_post($postarr)
        {
        }
        /**
         * Ajax handler for adding a new auto-draft post.
         *
         * @since 4.7.0
         */
        public function ajax_insert_auto_draft_post()
        {
        }
        /**
         * Prints the JavaScript templates used to render Menu Customizer components.
         *
         * Templates are imported into the JS use wp.template.
         *
         * @since 4.3.0
         */
        public function print_templates()
        {
        }
        /**
         * Prints the HTML template used to render the add-menu-item frame.
         *
         * @since 4.3.0
         */
        public function available_items_template()
        {
        }
        /**
         * Nav menu args used for each instance, keyed by the args HMAC.
         *
         * @since 4.3.0
         * @var array
         */
        public $preview_nav_menu_instance_args = array();
        /**
         * Filters arguments for dynamic nav_menu selective refresh partials.
         *
         * @since 4.5.0
         *
         * @param array|false $partial_args Partial args.
         * @param string      $partial_id   Partial ID.
         * @return array Partial args.
         */
        public function customize_dynamic_partial_args($partial_args, $partial_id)
        {
        }
        /**
         * Adds hooks for the Customizer preview.
         *
         * @since 4.3.0
         */
        public function customize_preview_init()
        {
        }
        /**
         * Makes the auto-draft status protected so that it can be queried.
         *
         * @since 4.7.0
         *
         * @global stdClass[] $wp_post_statuses List of post statuses.
         */
        public function make_auto_draft_status_previewable()
        {
        }
        /**
         * Sanitizes post IDs for posts created for nav menu items to be published.
         *
         * @since 4.7.0
         *
         * @param array $value Post IDs.
         * @return array Post IDs.
         */
        public function sanitize_nav_menus_created_posts($value)
        {
        }
        /**
         * Publishes the auto-draft posts that were created for nav menu items.
         *
         * The post IDs will have been sanitized by already by
         * `WP_Customize_Nav_Menu_Items::sanitize_nav_menus_created_posts()` to
         * remove any post IDs for which the user cannot publish or for which the
         * post is not an auto-draft.
         *
         * @since 4.7.0
         *
         * @param WP_Customize_Setting $setting Customizer setting object.
         */
        public function save_nav_menus_created_posts($setting)
        {
        }
        /**
         * Keeps track of the arguments that are being passed to wp_nav_menu().
         *
         * @since 4.3.0
         *
         * @see wp_nav_menu()
         * @see WP_Customize_Widgets::filter_dynamic_sidebar_params()
         *
         * @param array $args An array containing wp_nav_menu() arguments.
         * @return array Arguments.
         */
        public function filter_wp_nav_menu_args($args)
        {
        }
        /**
         * Prepares wp_nav_menu() calls for partial refresh.
         *
         * Injects attributes into container element.
         *
         * @since 4.3.0
         *
         * @see wp_nav_menu()
         *
         * @param string $nav_menu_content The HTML content for the navigation menu.
         * @param object $args             An object containing wp_nav_menu() arguments.
         * @return string Nav menu HTML with selective refresh attributes added if partial can be refreshed.
         */
        public function filter_wp_nav_menu($nav_menu_content, $args)
        {
        }
        /**
         * Hashes (hmac) the nav menu arguments to ensure they are not tampered with when
         * submitted in the Ajax request.
         *
         * Note that the array is expected to be pre-sorted.
         *
         * @since 4.3.0
         *
         * @param array $args The arguments to hash.
         * @return string Hashed nav menu arguments.
         */
        public function hash_nav_menu_args($args)
        {
        }
        /**
         * Enqueues scripts for the Customizer preview.
         *
         * @since 4.3.0
         */
        public function customize_preview_enqueue_deps()
        {
        }
        /**
         * Exports data from PHP to JS.
         *
         * @since 4.3.0
         */
        public function export_preview_data()
        {
        }
        /**
         * Exports any wp_nav_menu() calls during the rendering of any partials.
         *
         * @since 4.5.0
         *
         * @param array $response Response.
         * @return array Response.
         */
        public function export_partial_rendered_nav_menu_instances($response)
        {
        }
        /**
         * Renders a specific menu via wp_nav_menu() using the supplied arguments.
         *
         * @since 4.3.0
         *
         * @see wp_nav_menu()
         *
         * @param WP_Customize_Partial $partial       Partial.
         * @param array                $nav_menu_args Nav menu args supplied as container context.
         * @return string|false
         */
        public function render_nav_menu_partial($partial, $nav_menu_args)
        {
        }
    }
    /**
     * Customize Panel class.
     *
     * A UI container for sections, managed by the WP_Customize_Manager.
     *
     * @since 4.0.0
     *
     * @see WP_Customize_Manager
     */
    #[\AllowDynamicProperties]
    class WP_Customize_Panel
    {
        /**
         * Incremented with each new class instantiation, then stored in $instance_number.
         *
         * Used when sorting two instances whose priorities are equal.
         *
         * @since 4.1.0
         * @var int
         */
        protected static $instance_count = 0;
        /**
         * Order in which this instance was created in relation to other instances.
         *
         * @since 4.1.0
         * @var int
         */
        public $instance_number;
        /**
         * WP_Customize_Manager instance.
         *
         * @since 4.0.0
         * @var WP_Customize_Manager
         */
        public $manager;
        /**
         * Unique identifier.
         *
         * @since 4.0.0
         * @var string
         */
        public $id;
        /**
         * Priority of the panel, defining the display order of panels and sections.
         *
         * @since 4.0.0
         * @var int
         */
        public $priority = 160;
        /**
         * Capability required for the panel.
         *
         * @since 4.0.0
         * @var string
         */
        public $capability = 'edit_theme_options';
        /**
         * Theme features required to support the panel.
         *
         * @since 4.0.0
         * @var mixed[]
         */
        public $theme_supports = '';
        /**
         * Title of the panel to show in UI.
         *
         * @since 4.0.0
         * @var string
         */
        public $title = '';
        /**
         * Description to show in the UI.
         *
         * @since 4.0.0
         * @var string
         */
        public $description = '';
        /**
         * Auto-expand a section in a panel when the panel is expanded when the panel only has the one section.
         *
         * @since 4.7.4
         * @var bool
         */
        public $auto_expand_sole_section = \false;
        /**
         * Customizer sections for this panel.
         *
         * @since 4.0.0
         * @var array
         */
        public $sections;
        /**
         * Type of this panel.
         *
         * @since 4.1.0
         * @var string
         */
        public $type = 'default';
        /**
         * Active callback.
         *
         * @since 4.1.0
         *
         * @see WP_Customize_Section::active()
         *
         * @var callable Callback is called with one argument, the instance of
         *               WP_Customize_Section, and returns bool to indicate whether
         *               the section is active (such as it relates to the URL currently
         *               being previewed).
         */
        public $active_callback = '';
        /**
         * Constructor.
         *
         * Any supplied $args override class property defaults.
         *
         * @since 4.0.0
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      A specific ID for the panel.
         * @param array                $args    {
         *     Optional. Array of properties for the new Panel object. Default empty array.
         *
         *     @type int             $priority        Priority of the panel, defining the display order
         *                                            of panels and sections. Default 160.
         *     @type string          $capability      Capability required for the panel.
         *                                            Default `edit_theme_options`.
         *     @type mixed[]         $theme_supports  Theme features required to support the panel.
         *     @type string          $title           Title of the panel to show in UI.
         *     @type string          $description     Description to show in the UI.
         *     @type string          $type            Type of the panel.
         *     @type callable        $active_callback Active callback.
         * }
         * @phpstan-param array{
         *   priority?: int,
         *   capability?: string,
         *   theme_supports?: mixed[],
         *   title?: string,
         *   description?: string,
         *   type?: string,
         *   active_callback?: callable,
         * } $args
         */
        public function __construct($manager, $id, $args = array())
        {
        }
        /**
         * Check whether panel is active to current Customizer preview.
         *
         * @since 4.1.0
         *
         * @return bool Whether the panel is active to the current preview.
         */
        public final function active()
        {
        }
        /**
         * Default callback used when invoking WP_Customize_Panel::active().
         *
         * Subclasses can override this with their specific logic, or they may
         * provide an 'active_callback' argument to the constructor.
         *
         * @since 4.1.0
         *
         * @return bool Always true.
         */
        public function active_callback()
        {
        }
        /**
         * Gather the parameters passed to client JavaScript via JSON.
         *
         * @since 4.1.0
         *
         * @return array The array to be exported to the client as JSON.
         */
        public function json()
        {
        }
        /**
         * Checks required user capabilities and whether the theme has the
         * feature support required by the panel.
         *
         * @since 4.0.0
         * @since 5.9.0 Method was marked non-final.
         *
         * @return bool False if theme doesn't support the panel or the user doesn't have the capability.
         */
        public function check_capabilities()
        {
        }
        /**
         * Get the panel's content template for insertion into the Customizer pane.
         *
         * @since 4.1.0
         *
         * @return string Content for the panel.
         */
        public final function get_content()
        {
        }
        /**
         * Check capabilities and render the panel.
         *
         * @since 4.0.0
         * @phpstan-return void
         */
        public final function maybe_render()
        {
        }
        /**
         * Render the panel container, and then its contents (via `this->render_content()`) in a subclass.
         *
         * Panel containers are now rendered in JS by default, see WP_Customize_Panel::print_template().
         *
         * @since 4.0.0
         */
        protected function render()
        {
        }
        /**
         * Render the panel UI in a subclass.
         *
         * Panel contents are now rendered in JS by default, see WP_Customize_Panel::print_template().
         *
         * @since 4.1.0
         */
        protected function render_content()
        {
        }
        /**
         * Render the panel's JS templates.
         *
         * This function is only run for panel types that have been registered with
         * WP_Customize_Manager::register_panel_type().
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Manager::register_panel_type()
         */
        public function print_template()
        {
        }
        /**
         * An Underscore (JS) template for rendering this panel's container.
         *
         * Class variables for this panel class are available in the `data` JS object;
         * export custom variables by overriding WP_Customize_Panel::json().
         *
         * @see WP_Customize_Panel::print_template()
         *
         * @since 4.3.0
         */
        protected function render_template()
        {
        }
        /**
         * An Underscore (JS) template for this panel's content (but not its container).
         *
         * Class variables for this panel class are available in the `data` JS object;
         * export custom variables by overriding WP_Customize_Panel::json().
         *
         * @see WP_Customize_Panel::print_template()
         *
         * @since 4.3.0
         */
        protected function content_template()
        {
        }
    }
    /**
     * Customize Section class.
     *
     * A UI container for controls, managed by the WP_Customize_Manager class.
     *
     * @since 3.4.0
     *
     * @see WP_Customize_Manager
     */
    #[\AllowDynamicProperties]
    class WP_Customize_Section
    {
        /**
         * Incremented with each new class instantiation, then stored in $instance_number.
         *
         * Used when sorting two instances whose priorities are equal.
         *
         * @since 4.1.0
         * @var int
         */
        protected static $instance_count = 0;
        /**
         * Order in which this instance was created in relation to other instances.
         *
         * @since 4.1.0
         * @var int
         */
        public $instance_number;
        /**
         * WP_Customize_Manager instance.
         *
         * @since 3.4.0
         * @var WP_Customize_Manager
         */
        public $manager;
        /**
         * Unique identifier.
         *
         * @since 3.4.0
         * @var string
         */
        public $id;
        /**
         * Priority of the section which informs load order of sections.
         *
         * @since 3.4.0
         * @var int
         */
        public $priority = 160;
        /**
         * Panel in which to show the section, making it a sub-section.
         *
         * @since 4.0.0
         * @var string
         */
        public $panel = '';
        /**
         * Capability required for the section.
         *
         * @since 3.4.0
         * @var string
         */
        public $capability = 'edit_theme_options';
        /**
         * Theme features required to support the section.
         *
         * @since 3.4.0
         * @var string|string[]
         */
        public $theme_supports = '';
        /**
         * Title of the section to show in UI.
         *
         * @since 3.4.0
         * @var string
         */
        public $title = '';
        /**
         * Description to show in the UI.
         *
         * @since 3.4.0
         * @var string
         */
        public $description = '';
        /**
         * Customizer controls for this section.
         *
         * @since 3.4.0
         * @var array
         */
        public $controls;
        /**
         * Type of this section.
         *
         * @since 4.1.0
         * @var string
         */
        public $type = 'default';
        /**
         * Active callback.
         *
         * @since 4.1.0
         *
         * @see WP_Customize_Section::active()
         *
         * @var callable Callback is called with one argument, the instance of
         *               WP_Customize_Section, and returns bool to indicate whether
         *               the section is active (such as it relates to the URL currently
         *               being previewed).
         */
        public $active_callback = '';
        /**
         * Show the description or hide it behind the help icon.
         *
         * @since 4.7.0
         *
         * @var bool Indicates whether the Section's description should be
         *           hidden behind a help icon ("?") in the Section header,
         *           similar to how help icons are displayed on Panels.
         */
        public $description_hidden = \false;
        /**
         * Constructor.
         *
         * Any supplied $args override class property defaults.
         *
         * @since 3.4.0
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      A specific ID of the section.
         * @param array                $args    {
         *     Optional. Array of properties for the new Section object. Default empty array.
         *
         *     @type int             $priority           Priority of the section, defining the display order
         *                                               of panels and sections. Default 160.
         *     @type string          $panel              The panel this section belongs to (if any).
         *                                               Default empty.
         *     @type string          $capability         Capability required for the section.
         *                                               Default 'edit_theme_options'
         *     @type string|string[] $theme_supports     Theme features required to support the section.
         *     @type string          $title              Title of the section to show in UI.
         *     @type string          $description        Description to show in the UI.
         *     @type string          $type               Type of the section.
         *     @type callable        $active_callback    Active callback.
         *     @type bool            $description_hidden Hide the description behind a help icon,
         *                                               instead of inline above the first control.
         *                                               Default false.
         * }
         * @phpstan-param array{
         *   priority?: int,
         *   panel?: string,
         *   capability?: string,
         *   theme_supports?: string|string[],
         *   title?: string,
         *   description?: string,
         *   type?: string,
         *   active_callback?: callable,
         *   description_hidden?: bool,
         * } $args
         */
        public function __construct($manager, $id, $args = array())
        {
        }
        /**
         * Check whether section is active to current Customizer preview.
         *
         * @since 4.1.0
         *
         * @return bool Whether the section is active to the current preview.
         */
        public final function active()
        {
        }
        /**
         * Default callback used when invoking WP_Customize_Section::active().
         *
         * Subclasses can override this with their specific logic, or they may provide
         * an 'active_callback' argument to the constructor.
         *
         * @since 4.1.0
         *
         * @return true Always true.
         */
        public function active_callback()
        {
        }
        /**
         * Gather the parameters passed to client JavaScript via JSON.
         *
         * @since 4.1.0
         *
         * @return array The array to be exported to the client as JSON.
         */
        public function json()
        {
        }
        /**
         * Checks required user capabilities and whether the theme has the
         * feature support required by the section.
         *
         * @since 3.4.0
         *
         * @return bool False if theme doesn't support the section or user doesn't have the capability.
         */
        public final function check_capabilities()
        {
        }
        /**
         * Get the section's content for insertion into the Customizer pane.
         *
         * @since 4.1.0
         *
         * @return string Contents of the section.
         */
        public final function get_content()
        {
        }
        /**
         * Check capabilities and render the section.
         *
         * @since 3.4.0
         * @phpstan-return void
         */
        public final function maybe_render()
        {
        }
        /**
         * Render the section UI in a subclass.
         *
         * Sections are now rendered in JS by default, see WP_Customize_Section::print_template().
         *
         * @since 3.4.0
         */
        protected function render()
        {
        }
        /**
         * Render the section's JS template.
         *
         * This function is only run for section types that have been registered with
         * WP_Customize_Manager::register_section_type().
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Manager::render_template()
         */
        public function print_template()
        {
        }
        /**
         * An Underscore (JS) template for rendering this section.
         *
         * Class variables for this section class are available in the `data` JS object;
         * export custom variables by overriding WP_Customize_Section::json().
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Section::print_template()
         */
        protected function render_template()
        {
        }
    }
    /**
     * Customize Setting class.
     *
     * Handles saving and sanitizing of settings.
     *
     * @since 3.4.0
     *
     * @see WP_Customize_Manager
     * @link https://developer.wordpress.org/themes/customize-api
     */
    #[\AllowDynamicProperties]
    class WP_Customize_Setting
    {
        /**
         * Customizer bootstrap instance.
         *
         * @since 3.4.0
         * @var WP_Customize_Manager
         */
        public $manager;
        /**
         * Unique string identifier for the setting.
         *
         * @since 3.4.0
         * @var string
         */
        public $id;
        /**
         * Type of customize settings.
         *
         * @since 3.4.0
         * @var string
         */
        public $type = 'theme_mod';
        /**
         * Capability required to edit this setting.
         *
         * @since 3.4.0
         * @var string|array
         */
        public $capability = 'edit_theme_options';
        /**
         * Theme features required to support the setting.
         *
         * @since 3.4.0
         * @var string|string[]
         */
        public $theme_supports = '';
        /**
         * The default value for the setting.
         *
         * @since 3.4.0
         * @var string
         */
        public $default = '';
        /**
         * Options for rendering the live preview of changes in Customizer.
         *
         * Set this value to 'postMessage' to enable a custom JavaScript handler to render changes to this setting
         * as opposed to reloading the whole page.
         *
         * @since 3.4.0
         * @var string
         */
        public $transport = 'refresh';
        /**
         * Server-side validation callback for the setting's value.
         *
         * @since 4.6.0
         * @var callable
         */
        public $validate_callback = '';
        /**
         * Callback to filter a Customize setting value in un-slashed form.
         *
         * @since 3.4.0
         * @var callable
         */
        public $sanitize_callback = '';
        /**
         * Callback to convert a Customize PHP setting value to a value that is JSON serializable.
         *
         * @since 3.4.0
         * @var callable
         */
        public $sanitize_js_callback = '';
        /**
         * Whether or not the setting is initially dirty when created.
         *
         * This is used to ensure that a setting will be sent from the pane to the
         * preview when loading the Customizer. Normally a setting only is synced to
         * the preview if it has been changed. This allows the setting to be sent
         * from the start.
         *
         * @since 4.2.0
         * @var bool
         */
        public $dirty = \false;
        /**
         * ID Data.
         *
         * @since 3.4.0
         * @var array
         */
        protected $id_data = array();
        /**
         * Whether or not preview() was called.
         *
         * @since 4.4.0
         * @var bool
         */
        protected $is_previewed = \false;
        /**
         * Cache of multidimensional values to improve performance.
         *
         * @since 4.4.0
         * @var array
         */
        protected static $aggregated_multidimensionals = array();
        /**
         * Whether the multidimensional setting is aggregated.
         *
         * @since 4.4.0
         * @var bool
         */
        protected $is_multidimensional_aggregated = \false;
        /**
         * Constructor.
         *
         * Any supplied $args override class property defaults.
         *
         * @since 3.4.0
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      A specific ID of the setting.
         *                                      Can be a theme mod or option name.
         * @param array                $args    {
         *     Optional. Array of properties for the new Setting object. Default empty array.
         *
         *     @type string          $type                 Type of the setting. Default 'theme_mod'.
         *     @type string          $capability           Capability required for the setting. Default 'edit_theme_options'
         *     @type string|string[] $theme_supports       Theme features required to support the panel. Default is none.
         *     @type string          $default              Default value for the setting. Default is empty string.
         *     @type string          $transport            Options for rendering the live preview of changes in Customizer.
         *                                                 Using 'refresh' makes the change visible by reloading the whole preview.
         *                                                 Using 'postMessage' allows a custom JavaScript to handle live changes.
         *                                                 Default is 'refresh'.
         *     @type callable        $validate_callback    Server-side validation callback for the setting's value.
         *     @type callable        $sanitize_callback    Callback to filter a Customize setting value in un-slashed form.
         *     @type callable        $sanitize_js_callback Callback to convert a Customize PHP setting value to a value that is
         *                                                 JSON serializable.
         *     @type bool            $dirty                Whether or not the setting is initially dirty when created.
         * }
         * @phpstan-param array{
         *   type?: string,
         *   capability?: string,
         *   theme_supports?: string|string[],
         *   default?: string,
         *   transport?: string,
         *   validate_callback?: callable,
         *   sanitize_callback?: callable,
         *   sanitize_js_callback?: callable,
         *   dirty?: bool,
         * } $args
         */
        public function __construct($manager, $id, $args = array())
        {
        }
        /**
         * Get parsed ID data for multidimensional setting.
         *
         * @since 4.4.0
         *
         * @return array {
         *     ID data for multidimensional setting.
         *
         *     @type string $base ID base
         *     @type array  $keys Keys for multidimensional array.
         * }
         * @phpstan-return array{
         *   base: string,
         *   keys: array,
         * }
         */
        public final function id_data()
        {
        }
        /**
         * Set up the setting for aggregated multidimensional values.
         *
         * When a multidimensional setting gets aggregated, all of its preview and update
         * calls get combined into one call, greatly improving performance.
         *
         * @since 4.4.0
         */
        protected function aggregate_multidimensional()
        {
        }
        /**
         * Reset `$aggregated_multidimensionals` static variable.
         *
         * This is intended only for use by unit tests.
         *
         * @since 4.5.0
         * @ignore
         */
        public static function reset_aggregated_multidimensionals()
        {
        }
        /**
         * The ID for the current site when the preview() method was called.
         *
         * @since 4.2.0
         * @var int
         */
        protected $_previewed_blog_id;
        /**
         * Return true if the current site is not the same as the previewed site.
         *
         * @since 4.2.0
         *
         * @return bool If preview() has been called.
         */
        public function is_current_blog_previewed()
        {
        }
        /**
         * Original non-previewed value stored by the preview method.
         *
         * @see WP_Customize_Setting::preview()
         * @since 4.1.1
         * @var mixed
         */
        protected $_original_value;
        /**
         * Add filters to supply the setting's value when accessed.
         *
         * If the setting already has a pre-existing value and there is no incoming
         * post value for the setting, then this method will short-circuit since
         * there is no change to preview.
         *
         * @since 3.4.0
         * @since 4.4.0 Added boolean return value.
         *
         * @return bool False when preview short-circuits due no change needing to be previewed.
         */
        public function preview()
        {
        }
        /**
         * Clear out the previewed-applied flag for a multidimensional-aggregated value whenever its post value is updated.
         *
         * This ensures that the new value will get sanitized and used the next time
         * that `WP_Customize_Setting::_multidimensional_preview_filter()`
         * is called for this setting.
         *
         * @since 4.4.0
         *
         * @see WP_Customize_Manager::set_post_value()
         * @see WP_Customize_Setting::_multidimensional_preview_filter()
         */
        public final function _clear_aggregated_multidimensional_preview_applied_flag()
        {
        }
        /**
         * Callback function to filter non-multidimensional theme mods and options.
         *
         * If switch_to_blog() was called after the preview() method, and the current
         * site is now not the same site, then this method does a no-op and returns
         * the original value.
         *
         * @since 3.4.0
         *
         * @param mixed $original Old value.
         * @return mixed New or old value.
         */
        public function _preview_filter($original)
        {
        }
        /**
         * Callback function to filter multidimensional theme mods and options.
         *
         * For all multidimensional settings of a given type, the preview filter for
         * the first setting previewed will be used to apply the values for the others.
         *
         * @since 4.4.0
         *
         * @see WP_Customize_Setting::$aggregated_multidimensionals
         * @param mixed $original Original root value.
         * @return mixed New or old value.
         */
        public final function _multidimensional_preview_filter($original)
        {
        }
        /**
         * Checks user capabilities and theme supports, and then saves
         * the value of the setting.
         *
         * @since 3.4.0
         *
         * @return void|false Void on success, false if cap check fails
         *                    or value isn't set or is invalid.
         */
        public final function save()
        {
        }
        /**
         * Fetch and sanitize the $_POST value for the setting.
         *
         * During a save request prior to save, post_value() provides the new value while value() does not.
         *
         * @since 3.4.0
         *
         * @param mixed $default_value A default value which is used as a fallback. Default null.
         * @return mixed The default value on failure, otherwise the sanitized and validated value.
         */
        public final function post_value($default_value = \null)
        {
        }
        /**
         * Sanitize an input.
         *
         * @since 3.4.0
         *
         * @param string|array $value The value to sanitize.
         * @return string|array|null|WP_Error Sanitized value, or `null`/`WP_Error` if invalid.
         */
        public function sanitize($value)
        {
        }
        /**
         * Validates an input.
         *
         * @since 4.6.0
         *
         * @see WP_REST_Request::has_valid_params()
         *
         * @param mixed $value Value to validate.
         * @return true|WP_Error True if the input was validated, otherwise WP_Error.
         */
        public function validate($value)
        {
        }
        /**
         * Get the root value for a setting, especially for multidimensional ones.
         *
         * @since 4.4.0
         *
         * @param mixed $default_value Value to return if root does not exist.
         * @return mixed
         */
        protected function get_root_value($default_value = \null)
        {
        }
        /**
         * Set the root value for a setting, especially for multidimensional ones.
         *
         * @since 4.4.0
         *
         * @param mixed $value Value to set as root of multidimensional setting.
         * @return bool Whether the multidimensional root was updated successfully.
         */
        protected function set_root_value($value)
        {
        }
        /**
         * Save the value of the setting, using the related API.
         *
         * @since 3.4.0
         *
         * @param mixed $value The value to update.
         * @return bool The result of saving the value.
         */
        protected function update($value)
        {
        }
        /**
         * Deprecated method.
         *
         * @since 3.4.0
         * @deprecated 4.4.0 Deprecated in favor of update() method.
         */
        protected function _update_theme_mod()
        {
        }
        /**
         * Deprecated method.
         *
         * @since 3.4.0
         * @deprecated 4.4.0 Deprecated in favor of update() method.
         */
        protected function _update_option()
        {
        }
        /**
         * Fetch the value of the setting.
         *
         * @since 3.4.0
         *
         * @return mixed The value.
         */
        public function value()
        {
        }
        /**
         * Sanitize the setting's value for use in JavaScript.
         *
         * @since 3.4.0
         *
         * @return mixed The requested escaped value.
         */
        public function js_value()
        {
        }
        /**
         * Retrieves the data to export to the client via JSON.
         *
         * @since 4.6.0
         *
         * @return array Array of parameters passed to JavaScript.
         */
        public function json()
        {
        }
        /**
         * Validate user capabilities whether the theme supports the setting.
         *
         * @since 3.4.0
         *
         * @return bool False if theme doesn't support the setting or user can't change setting, otherwise true.
         */
        public final function check_capabilities()
        {
        }
        /**
         * Multidimensional helper function.
         *
         * @since 3.4.0
         *
         * @param array $root
         * @param array $keys
         * @param bool  $create Default false.
         * @return array|void Keys are 'root', 'node', and 'key'.
         */
        protected final function multidimensional(&$root, $keys, $create = \false)
        {
        }
        /**
         * Will attempt to replace a specific value in a multidimensional array.
         *
         * @since 3.4.0
         *
         * @param array $root
         * @param array $keys
         * @param mixed $value The value to update.
         * @return mixed
         */
        protected final function multidimensional_replace($root, $keys, $value)
        {
        }
        /**
         * Will attempt to fetch a specific value from a multidimensional array.
         *
         * @since 3.4.0
         *
         * @param array $root
         * @param array $keys
         * @param mixed $default_value A default value which is used as a fallback. Default null.
         * @return mixed The requested value or the default value.
         */
        protected final function multidimensional_get($root, $keys, $default_value = \null)
        {
        }
        /**
         * Will attempt to check if a specific value in a multidimensional array is set.
         *
         * @since 3.4.0
         *
         * @param array $root
         * @param array $keys
         * @return bool True if value is set, false if not.
         */
        protected final function multidimensional_isset($root, $keys)
        {
        }
    }
    /**
     * Customize Widgets class.
     *
     * Implements widget management in the Customizer.
     *
     * @since 3.9.0
     *
     * @see WP_Customize_Manager
     */
    #[\AllowDynamicProperties]
    final class WP_Customize_Widgets
    {
        /**
         * WP_Customize_Manager instance.
         *
         * @since 3.9.0
         * @var WP_Customize_Manager
         */
        public $manager;
        /**
         * Initial loader.
         *
         * @since 3.9.0
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @phpstan-return void
         */
        public function __construct($manager)
        {
        }
        /**
         * List whether each registered widget can be use selective refresh.
         *
         * If the theme does not support the customize-selective-refresh-widgets feature,
         * then this will always return an empty array.
         *
         * @since 4.5.0
         *
         * @global WP_Widget_Factory $wp_widget_factory
         *
         * @return array Mapping of id_base to support. If theme doesn't support
         *               selective refresh, an empty array is returned.
         */
        public function get_selective_refreshable_widgets()
        {
        }
        /**
         * Determines if a widget supports selective refresh.
         *
         * @since 4.5.0
         *
         * @param string $id_base Widget ID Base.
         * @return bool Whether the widget can be selective refreshed.
         */
        public function is_widget_selective_refreshable($id_base)
        {
        }
        /**
         * Inspects the incoming customized data for any widget settings, and dynamically adds
         * them up-front so widgets will be initialized properly.
         *
         * @since 4.2.0
         */
        public function register_settings()
        {
        }
        /**
         * Determines the arguments for a dynamically-created setting.
         *
         * @since 4.2.0
         *
         * @param false|array $args       The arguments to the WP_Customize_Setting constructor.
         * @param string      $setting_id ID for dynamic setting, usually coming from `$_POST['customized']`.
         * @return array|false Setting arguments, false otherwise.
         */
        public function filter_customize_dynamic_setting_args($args, $setting_id)
        {
        }
        /**
         * Override sidebars_widgets for theme switch.
         *
         * When switching a theme via the Customizer, supply any previously-configured
         * sidebars_widgets from the target theme as the initial sidebars_widgets
         * setting. Also store the old theme's existing settings so that they can
         * be passed along for storing in the sidebars_widgets theme_mod when the
         * theme gets switched.
         *
         * @since 3.9.0
         *
         * @global array $sidebars_widgets
         * @global array $_wp_sidebars_widgets
         * @phpstan-return void
         */
        public function override_sidebars_widgets_for_theme_switch()
        {
        }
        /**
         * Filters old_sidebars_widgets_data Customizer setting.
         *
         * When switching themes, filter the Customizer setting old_sidebars_widgets_data
         * to supply initial $sidebars_widgets before they were overridden by retrieve_widgets().
         * The value for old_sidebars_widgets_data gets set in the old theme's sidebars_widgets
         * theme_mod.
         *
         * @since 3.9.0
         *
         * @see WP_Customize_Widgets::handle_theme_switch()
         *
         * @param array $old_sidebars_widgets
         * @return array
         */
        public function filter_customize_value_old_sidebars_widgets_data($old_sidebars_widgets)
        {
        }
        /**
         * Filters sidebars_widgets option for theme switch.
         *
         * When switching themes, the retrieve_widgets() function is run when the Customizer initializes,
         * and then the new sidebars_widgets here get supplied as the default value for the sidebars_widgets
         * option.
         *
         * @since 3.9.0
         *
         * @see WP_Customize_Widgets::handle_theme_switch()
         * @global array $sidebars_widgets
         *
         * @param array $sidebars_widgets
         * @return array
         */
        public function filter_option_sidebars_widgets_for_theme_switch($sidebars_widgets)
        {
        }
        /**
         * Ensures all widgets get loaded into the Customizer.
         *
         * Note: these actions are also fired in wp_ajax_update_widget().
         *
         * @since 3.9.0
         */
        public function customize_controls_init()
        {
        }
        /**
         * Ensures widgets are available for all types of previews.
         *
         * When in preview, hook to {@see 'customize_register'} for settings after WordPress is loaded
         * so that all filters have been initialized (e.g. Widget Visibility).
         *
         * @since 3.9.0
         */
        public function schedule_customize_register()
        {
        }
        /**
         * Registers Customizer settings and controls for all sidebars and widgets.
         *
         * @since 3.9.0
         *
         * @global array $wp_registered_widgets
         * @global array $wp_registered_widget_controls
         * @global array $wp_registered_sidebars
         */
        public function customize_register()
        {
        }
        /**
         * Determines whether the widgets panel is active, based on whether there are sidebars registered.
         *
         * @since 4.4.0
         *
         * @see WP_Customize_Panel::$active_callback
         *
         * @global array $wp_registered_sidebars
         * @return bool Active.
         */
        public function is_panel_active()
        {
        }
        /**
         * Converts a widget_id into its corresponding Customizer setting ID (option name).
         *
         * @since 3.9.0
         *
         * @param string $widget_id Widget ID.
         * @return string Maybe-parsed widget ID.
         */
        public function get_setting_id($widget_id)
        {
        }
        /**
         * Determines whether the widget is considered "wide".
         *
         * Core widgets which may have controls wider than 250, but can still be shown
         * in the narrow Customizer panel. The RSS and Text widgets in Core, for example,
         * have widths of 400 and yet they still render fine in the Customizer panel.
         *
         * This method will return all Core widgets as being not wide, but this can be
         * overridden with the {@see 'is_wide_widget_in_customizer'} filter.
         *
         * @since 3.9.0
         *
         * @global array $wp_registered_widget_controls
         *
         * @param string $widget_id Widget ID.
         * @return bool Whether or not the widget is a "wide" widget.
         */
        public function is_wide_widget($widget_id)
        {
        }
        /**
         * Converts a widget ID into its id_base and number components.
         *
         * @since 3.9.0
         *
         * @param string $widget_id Widget ID.
         * @return array Array containing a widget's id_base and number components.
         */
        public function parse_widget_id($widget_id)
        {
        }
        /**
         * Converts a widget setting ID (option path) to its id_base and number components.
         *
         * @since 3.9.0
         *
         * @param string $setting_id Widget setting ID.
         * @return array|WP_Error Array containing a widget's id_base and number components,
         *                        or a WP_Error object.
         */
        public function parse_widget_setting_id($setting_id)
        {
        }
        /**
         * Calls admin_print_styles-widgets.php and admin_print_styles hooks to
         * allow custom styles from plugins.
         *
         * @since 3.9.0
         */
        public function print_styles()
        {
        }
        /**
         * Calls admin_print_scripts-widgets.php and admin_print_scripts hooks to
         * allow custom scripts from plugins.
         *
         * @since 3.9.0
         */
        public function print_scripts()
        {
        }
        /**
         * Enqueues scripts and styles for Customizer panel and export data to JavaScript.
         *
         * @since 3.9.0
         *
         * @global WP_Scripts $wp_scripts
         * @global array $wp_registered_sidebars
         * @global array $wp_registered_widgets
         */
        public function enqueue_scripts()
        {
        }
        /**
         * Renders the widget form control templates into the DOM.
         *
         * @since 3.9.0
         */
        public function output_widget_control_templates()
        {
        }
        /**
         * Calls admin_print_footer_scripts and admin_print_scripts hooks to
         * allow custom scripts from plugins.
         *
         * @since 3.9.0
         */
        public function print_footer_scripts()
        {
        }
        /**
         * Retrieves common arguments to supply when constructing a Customizer setting.
         *
         * @since 3.9.0
         *
         * @param string $id        Widget setting ID.
         * @param array  $overrides Array of setting overrides.
         * @return array Possibly modified setting arguments.
         */
        public function get_setting_args($id, $overrides = array())
        {
        }
        /**
         * Ensures sidebar widget arrays only ever contain widget IDS.
         *
         * Used as the 'sanitize_callback' for each $sidebars_widgets setting.
         *
         * @since 3.9.0
         *
         * @param string[] $widget_ids Array of widget IDs.
         * @return string[] Array of sanitized widget IDs.
         */
        public function sanitize_sidebar_widgets($widget_ids)
        {
        }
        /**
         * Builds up an index of all available widgets for use in Backbone models.
         *
         * @since 3.9.0
         *
         * @global array $wp_registered_widgets
         * @global array $wp_registered_widget_controls
         *
         * @see wp_list_widgets()
         *
         * @return array List of available widgets.
         */
        public function get_available_widgets()
        {
        }
        /**
         * Retrieves the widget control markup.
         *
         * @since 3.9.0
         *
         * @param array $args Widget control arguments.
         * @return string Widget control form HTML markup.
         */
        public function get_widget_control($args)
        {
        }
        /**
         * Retrieves the widget control markup parts.
         *
         * @since 4.4.0
         *
         * @param array $args Widget control arguments.
         * @return array {
         *     @type string $control Markup for widget control wrapping form.
         *     @type string $content The contents of the widget form itself.
         * }
         * @phpstan-return array{
         *   control: string,
         *   content: string,
         * }
         */
        public function get_widget_control_parts($args)
        {
        }
        /**
         * Adds hooks for the Customizer preview.
         *
         * @since 3.9.0
         */
        public function customize_preview_init()
        {
        }
        /**
         * Refreshes the nonce for widget updates.
         *
         * @since 4.2.0
         *
         * @param array $nonces Array of nonces.
         * @return array Array of nonces.
         */
        public function refresh_nonces($nonces)
        {
        }
        /**
         * Tells the script loader to load the scripts and styles of custom blocks
         * if the widgets block editor is enabled.
         *
         * @since 5.8.0
         *
         * @param bool $is_block_editor_screen Current decision about loading block assets.
         * @return bool Filtered decision about loading block assets.
         */
        public function should_load_block_editor_scripts_and_styles($is_block_editor_screen)
        {
        }
        /**
         * When previewing, ensures the proper previewing widgets are used.
         *
         * Because wp_get_sidebars_widgets() gets called early at {@see 'init' } (via
         * wp_convert_widget_settings()) and can set global variable `$_wp_sidebars_widgets`
         * to the value of `get_option( 'sidebars_widgets' )` before the Customizer preview
         * filter is added, it has to be reset after the filter has been added.
         *
         * @since 3.9.0
         *
         * @param array $sidebars_widgets List of widgets for the current sidebar.
         * @return array
         */
        public function preview_sidebars_widgets($sidebars_widgets)
        {
        }
        /**
         * Enqueues scripts for the Customizer preview.
         *
         * @since 3.9.0
         */
        public function customize_preview_enqueue()
        {
        }
        /**
         * Inserts default style for highlighted widget at early point so theme
         * stylesheet can override.
         *
         * @since 3.9.0
         */
        public function print_preview_css()
        {
        }
        /**
         * Communicates the sidebars that appeared on the page at the very end of the page,
         * and at the very end of the wp_footer,
         *
         * @since 3.9.0
         *
         * @global array $wp_registered_sidebars
         * @global array $wp_registered_widgets
         */
        public function export_preview_data()
        {
        }
        /**
         * Tracks the widgets that were rendered.
         *
         * @since 3.9.0
         *
         * @param array $widget Rendered widget to tally.
         */
        public function tally_rendered_widgets($widget)
        {
        }
        /**
         * Determine if a widget is rendered on the page.
         *
         * @since 4.0.0
         *
         * @param string $widget_id Widget ID to check.
         * @return bool Whether the widget is rendered.
         */
        public function is_widget_rendered($widget_id)
        {
        }
        /**
         * Determines if a sidebar is rendered on the page.
         *
         * @since 4.0.0
         *
         * @param string $sidebar_id Sidebar ID to check.
         * @return bool Whether the sidebar is rendered.
         */
        public function is_sidebar_rendered($sidebar_id)
        {
        }
        /**
         * Tallies the sidebars rendered via is_active_sidebar().
         *
         * Keep track of the times that is_active_sidebar() is called in the template,
         * and assume that this means that the sidebar would be rendered on the template
         * if there were widgets populating it.
         *
         * @since 3.9.0
         *
         * @param bool   $is_active  Whether the sidebar is active.
         * @param string $sidebar_id Sidebar ID.
         * @return bool Whether the sidebar is active.
         */
        public function tally_sidebars_via_is_active_sidebar_calls($is_active, $sidebar_id)
        {
        }
        /**
         * Tallies the sidebars rendered via dynamic_sidebar().
         *
         * Keep track of the times that dynamic_sidebar() is called in the template,
         * and assume this means the sidebar would be rendered on the template if
         * there were widgets populating it.
         *
         * @since 3.9.0
         *
         * @param bool   $has_widgets Whether the current sidebar has widgets.
         * @param string $sidebar_id  Sidebar ID.
         * @return bool Whether the current sidebar has widgets.
         */
        public function tally_sidebars_via_dynamic_sidebar_calls($has_widgets, $sidebar_id)
        {
        }
        /**
         * Sanitizes a widget instance.
         *
         * Unserialize the JS-instance for storing in the options. It's important that this filter
         * only get applied to an instance *once*.
         *
         * @since 3.9.0
         * @since 5.8.0 Added the `$id_base` parameter.
         *
         * @global WP_Widget_Factory $wp_widget_factory
         *
         * @param array  $value   Widget instance to sanitize.
         * @param string $id_base Optional. Base of the ID of the widget being sanitized. Default null.
         * @return array|void Sanitized widget instance.
         */
        public function sanitize_widget_instance($value, $id_base = \null)
        {
        }
        /**
         * Converts a widget instance into JSON-representable format.
         *
         * @since 3.9.0
         * @since 5.8.0 Added the `$id_base` parameter.
         *
         * @global WP_Widget_Factory $wp_widget_factory
         *
         * @param array  $value   Widget instance to convert to JSON.
         * @param string $id_base Optional. Base of the ID of the widget being sanitized. Default null.
         * @return array JSON-converted widget instance.
         */
        public function sanitize_widget_js_instance($value, $id_base = \null)
        {
        }
        /**
         * Strips out widget IDs for widgets which are no longer registered.
         *
         * One example where this might happen is when a plugin orphans a widget
         * in a sidebar upon deactivation.
         *
         * @since 3.9.0
         *
         * @global array $wp_registered_widgets
         *
         * @param array $widget_ids List of widget IDs.
         * @return array Parsed list of widget IDs.
         */
        public function sanitize_sidebar_widgets_js_instance($widget_ids)
        {
        }
        /**
         * Finds and invokes the widget update and control callbacks.
         *
         * Requires that `$_POST` be populated with the instance data.
         *
         * @since 3.9.0
         *
         * @global array $wp_registered_widget_updates
         * @global array $wp_registered_widget_controls
         *
         * @param string $widget_id Widget ID.
         * @return array|WP_Error Array containing the updated widget information.
         *                        A WP_Error object, otherwise.
         */
        public function call_widget_update($widget_id)
        {
        }
        /**
         * Updates widget settings asynchronously.
         *
         * Allows the Customizer to update a widget using its form, but return the new
         * instance info via Ajax instead of saving it to the options table.
         *
         * Most code here copied from wp_ajax_save_widget().
         *
         * @since 3.9.0
         *
         * @see wp_ajax_save_widget()
         * @phpstan-return never
         */
        public function wp_ajax_update_widget()
        {
        }
        /**
         * Filters arguments for dynamic widget partials.
         *
         * @since 4.5.0
         *
         * @param array|false $partial_args Partial arguments.
         * @param string      $partial_id   Partial ID.
         * @return array (Maybe) modified partial arguments.
         */
        public function customize_dynamic_partial_args($partial_args, $partial_id)
        {
        }
        /**
         * Adds hooks for selective refresh.
         *
         * @since 4.5.0
         * @phpstan-return void
         */
        public function selective_refresh_init()
        {
        }
        /**
         * Inject selective refresh data attributes into widget container elements.
         *
         * @since 4.5.0
         *
         * @param array $params {
         *     Dynamic sidebar params.
         *
         *     @type array $args        Sidebar args.
         *     @type array $widget_args Widget args.
         * }
         * @see WP_Customize_Nav_Menus::filter_wp_nav_menu_args()
         *
         * @return array Params.
         * @phpstan-param array{
         *   args?: array,
         *   widget_args?: array,
         * } $params
         */
        public function filter_dynamic_sidebar_params($params)
        {
        }
        /**
         * Ensures the HTML data-* attributes for selective refresh are allowed by kses.
         *
         * This is needed in case the `$before_widget` is run through wp_kses() when printed.
         *
         * @since 4.5.0
         *
         * @param array $allowed_html Allowed HTML.
         * @return array (Maybe) modified allowed HTML.
         */
        public function filter_wp_kses_allowed_data_attributes($allowed_html)
        {
        }
        /**
         * Begins keeping track of the current sidebar being rendered.
         *
         * Insert marker before widgets are rendered in a dynamic sidebar.
         *
         * @since 4.5.0
         *
         * @param int|string $index Index, name, or ID of the dynamic sidebar.
         */
        public function start_dynamic_sidebar($index)
        {
        }
        /**
         * Finishes keeping track of the current sidebar being rendered.
         *
         * Inserts a marker after widgets are rendered in a dynamic sidebar.
         *
         * @since 4.5.0
         *
         * @param int|string $index Index, name, or ID of the dynamic sidebar.
         */
        public function end_dynamic_sidebar($index)
        {
        }
        /**
         * Filters sidebars_widgets to ensure the currently-rendered widget is the only widget in the current sidebar.
         *
         * @since 4.5.0
         *
         * @param array $sidebars_widgets Sidebars widgets.
         * @return array Filtered sidebars widgets.
         */
        public function filter_sidebars_widgets_for_rendering_widget($sidebars_widgets)
        {
        }
        /**
         * Renders a specific widget using the supplied sidebar arguments.
         *
         * @since 4.5.0
         *
         * @see dynamic_sidebar()
         *
         * @param WP_Customize_Partial $partial Partial.
         * @param array                $context {
         *     Sidebar args supplied as container context.
         *
         *     @type string $sidebar_id              ID for sidebar for widget to render into.
         *     @type int    $sidebar_instance_number Disambiguating instance number.
         * }
         * @return string|false
         * @phpstan-param array{
         *   sidebar_id?: string,
         *   sidebar_instance_number?: int,
         * } $context
         */
        public function render_widget_partial($partial, $context)
        {
        }
        /**
         * Pre-filters captured option values before updating.
         *
         * @since 3.9.0
         *
         * @param mixed  $new_value   The new option value.
         * @param string $option_name Name of the option.
         * @param mixed  $old_value   The old option value.
         * @return mixed Filtered option value.
         */
        public function capture_filter_pre_update_option($new_value, $option_name, $old_value)
        {
        }
        /**
         * Pre-filters captured option values before retrieving.
         *
         * @since 3.9.0
         *
         * @param mixed $value Value to return instead of the option value.
         * @return mixed Filtered option value.
         */
        public function capture_filter_pre_get_option($value)
        {
        }
        /**
         * {@internal Missing Summary}
         *
         * See the {@see 'customize_dynamic_setting_args'} filter.
         *
         * @since 3.9.0
         * @deprecated 4.2.0 Deprecated in favor of the {@see 'customize_dynamic_setting_args'} filter.
         */
        public function setup_widget_addition_previews()
        {
        }
        /**
         * {@internal Missing Summary}
         *
         * See the {@see 'customize_dynamic_setting_args'} filter.
         *
         * @since 3.9.0
         * @deprecated 4.2.0 Deprecated in favor of the {@see 'customize_dynamic_setting_args'} filter.
         */
        public function prepreview_added_sidebars_widgets()
        {
        }
        /**
         * {@internal Missing Summary}
         *
         * See the {@see 'customize_dynamic_setting_args'} filter.
         *
         * @since 3.9.0
         * @deprecated 4.2.0 Deprecated in favor of the {@see 'customize_dynamic_setting_args'} filter.
         */
        public function prepreview_added_widget_instance()
        {
        }
        /**
         * {@internal Missing Summary}
         *
         * See the {@see 'customize_dynamic_setting_args'} filter.
         *
         * @since 3.9.0
         * @deprecated 4.2.0 Deprecated in favor of the {@see 'customize_dynamic_setting_args'} filter.
         */
        public function remove_prepreview_filters()
        {
        }
    }
    /**
     * Class for generating SQL clauses that filter a primary query according to date.
     *
     * WP_Date_Query is a helper that allows primary query classes, such as WP_Query, to filter
     * their results by date columns, by generating `WHERE` subclauses to be attached to the
     * primary SQL query string.
     *
     * Attempting to filter by an invalid date value (eg month=13) will generate SQL that will
     * return no results. In these cases, a _doing_it_wrong() error notice is also thrown.
     * See WP_Date_Query::validate_date_values().
     *
     * @link https://developer.wordpress.org/reference/classes/wp_query/
     *
     * @since 3.7.0
     */
    #[\AllowDynamicProperties]
    class WP_Date_Query
    {
        /**
         * Array of date queries.
         *
         * See WP_Date_Query::__construct() for information on date query arguments.
         *
         * @since 3.7.0
         * @var array
         */
        public $queries = array();
        /**
         * The default relation between top-level queries. Can be either 'AND' or 'OR'.
         *
         * @since 3.7.0
         * @var string
         */
        public $relation = 'AND';
        /**
         * The column to query against. Can be changed via the query arguments.
         *
         * @since 3.7.0
         * @var string
         */
        public $column = 'post_date';
        /**
         * The value comparison operator. Can be changed via the query arguments.
         *
         * @since 3.7.0
         * @var string
         */
        public $compare = '=';
        /**
         * Supported time-related parameter keys.
         *
         * @since 4.1.0
         * @var string[]
         */
        public $time_keys = array('after', 'before', 'year', 'month', 'monthnum', 'week', 'w', 'dayofyear', 'day', 'dayofweek', 'dayofweek_iso', 'hour', 'minute', 'second');
        /**
         * Constructor.
         *
         * Time-related parameters that normally require integer values ('year', 'month', 'week', 'dayofyear', 'day',
         * 'dayofweek', 'dayofweek_iso', 'hour', 'minute', 'second') accept arrays of integers for some values of
         * 'compare'. When 'compare' is 'IN' or 'NOT IN', arrays are accepted; when 'compare' is 'BETWEEN' or 'NOT
         * BETWEEN', arrays of two valid values are required. See individual argument descriptions for accepted values.
         *
         * @since 3.7.0
         * @since 4.0.0 The $inclusive logic was updated to include all times within the date range.
         * @since 4.1.0 Introduced 'dayofweek_iso' time type parameter.
         *
         * @param array  $date_query {
         *     Array of date query clauses.
         *
         *     @type array ...$0 {
         *         @type string $column   Optional. The column to query against. If undefined, inherits the value of
         *                                the `$default_column` parameter. See WP_Date_Query::validate_column() and
         *                                the {@see 'date_query_valid_columns'} filter for the list of accepted values.
         *                                Default 'post_date'.
         *         @type string $compare  Optional. The comparison operator. Accepts '=', '!=', '>', '>=', '<', '<=',
         *                                'IN', 'NOT IN', 'BETWEEN', 'NOT BETWEEN'. Default '='.
         *         @type string $relation Optional. The boolean relationship between the date queries. Accepts 'OR' or 'AND'.
         *                                Default 'OR'.
         *         @type array  ...$0 {
         *             Optional. An array of first-order clause parameters, or another fully-formed date query.
         *
         *             @type string|array $before {
         *                 Optional. Date to retrieve posts before. Accepts `strtotime()`-compatible string,
         *                 or array of 'year', 'month', 'day' values.
         *
         *                 @type string $year  The four-digit year. Default empty. Accepts any four-digit year.
         *                 @type string $month Optional when passing array.The month of the year.
         *                                     Default (string:empty)|(array:1). Accepts numbers 1-12.
         *                 @type string $day   Optional when passing array.The day of the month.
         *                                     Default (string:empty)|(array:1). Accepts numbers 1-31.
         *             }
         *             @type string|array $after {
         *                 Optional. Date to retrieve posts after. Accepts `strtotime()`-compatible string,
         *                 or array of 'year', 'month', 'day' values.
         *
         *                 @type string $year  The four-digit year. Accepts any four-digit year. Default empty.
         *                 @type string $month Optional when passing array. The month of the year. Accepts numbers 1-12.
         *                                     Default (string:empty)|(array:12).
         *                 @type string $day   Optional when passing array.The day of the month. Accepts numbers 1-31.
         *                                     Default (string:empty)|(array:last day of month).
         *             }
         *             @type string       $column        Optional. Used to add a clause comparing a column other than
         *                                               the column specified in the top-level `$column` parameter.
         *                                               See WP_Date_Query::validate_column() and
         *                                               the {@see 'date_query_valid_columns'} filter for the list
         *                                               of accepted values. Default is the value of top-level `$column`.
         *             @type string       $compare       Optional. The comparison operator. Accepts '=', '!=', '>', '>=',
         *                                               '<', '<=', 'IN', 'NOT IN', 'BETWEEN', 'NOT BETWEEN'. 'IN',
         *                                               'NOT IN', 'BETWEEN', and 'NOT BETWEEN'. Comparisons support
         *                                               arrays in some time-related parameters. Default '='.
         *             @type bool         $inclusive     Optional. Include results from dates specified in 'before' or
         *                                               'after'. Default false.
         *             @type int|int[]    $year          Optional. The four-digit year number. Accepts any four-digit year
         *                                               or an array of years if `$compare` supports it. Default empty.
         *             @type int|int[]    $month         Optional. The two-digit month number. Accepts numbers 1-12 or an
         *                                               array of valid numbers if `$compare` supports it. Default empty.
         *             @type int|int[]    $week          Optional. The week number of the year. Accepts numbers 0-53 or an
         *                                               array of valid numbers if `$compare` supports it. Default empty.
         *             @type int|int[]    $dayofyear     Optional. The day number of the year. Accepts numbers 1-366 or an
         *                                               array of valid numbers if `$compare` supports it.
         *             @type int|int[]    $day           Optional. The day of the month. Accepts numbers 1-31 or an array
         *                                               of valid numbers if `$compare` supports it. Default empty.
         *             @type int|int[]    $dayofweek     Optional. The day number of the week. Accepts numbers 1-7 (1 is
         *                                               Sunday) or an array of valid numbers if `$compare` supports it.
         *                                               Default empty.
         *             @type int|int[]    $dayofweek_iso Optional. The day number of the week (ISO). Accepts numbers 1-7
         *                                               (1 is Monday) or an array of valid numbers if `$compare` supports it.
         *                                               Default empty.
         *             @type int|int[]    $hour          Optional. The hour of the day. Accepts numbers 0-23 or an array
         *                                               of valid numbers if `$compare` supports it. Default empty.
         *             @type int|int[]    $minute        Optional. The minute of the hour. Accepts numbers 0-59 or an array
         *                                               of valid numbers if `$compare` supports it. Default empty.
         *             @type int|int[]    $second        Optional. The second of the minute. Accepts numbers 0-59 or an
         *                                               array of valid numbers if `$compare` supports it. Default empty.
         *         }
         *     }
         * }
         * @param string $default_column Optional. Default column to query against. See WP_Date_Query::validate_column()
         *                               and the {@see 'date_query_valid_columns'} filter for the list of accepted values.
         *                               Default 'post_date'.
         * @phpstan-return void
         */
        public function __construct($date_query, $default_column = 'post_date')
        {
        }
        /**
         * Recursive-friendly query sanitizer.
         *
         * Ensures that each query-level clause has a 'relation' key, and that
         * each first-order clause contains all the necessary keys from `$defaults`.
         *
         * @since 4.1.0
         *
         * @param array $queries
         * @param array $parent_query
         * @return array Sanitized queries.
         */
        public function sanitize_query($queries, $parent_query = \null)
        {
        }
        /**
         * Determines whether this is a first-order clause.
         *
         * Checks to see if the current clause has any time-related keys.
         * If so, it's first-order.
         *
         * @since 4.1.0
         *
         * @param array $query Query clause.
         * @return bool True if this is a first-order clause.
         */
        protected function is_first_order_clause($query)
        {
        }
        /**
         * Determines and validates what comparison operator to use.
         *
         * @since 3.7.0
         *
         * @param array $query A date query or a date subquery.
         * @return string The comparison operator.
         */
        public function get_compare($query)
        {
        }
        /**
         * Validates the given date_query values and triggers errors if something is not valid.
         *
         * Note that date queries with invalid date ranges are allowed to
         * continue (though of course no items will be found for impossible dates).
         * This method only generates debug notices for these cases.
         *
         * @since 4.1.0
         *
         * @param array $date_query The date_query array.
         * @return bool True if all values in the query are valid, false if one or more fail.
         */
        public function validate_date_values($date_query = array())
        {
        }
        /**
         * Validates a column name parameter.
         *
         * Column names without a table prefix (like 'post_date') are checked against a list of
         * allowed and known tables, and then, if found, have a table prefix (such as 'wp_posts.')
         * prepended. Prefixed column names (such as 'wp_posts.post_date') bypass this allowed
         * check, and are only sanitized to remove illegal characters.
         *
         * @since 3.7.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $column The user-supplied column name.
         * @return string A validated column name value.
         */
        public function validate_column($column)
        {
        }
        /**
         * Generates WHERE clause to be appended to a main query.
         *
         * @since 3.7.0
         *
         * @return string MySQL WHERE clause.
         */
        public function get_sql()
        {
        }
        /**
         * Generates SQL clauses to be appended to a main query.
         *
         * Called by the public WP_Date_Query::get_sql(), this method is abstracted
         * out to maintain parity with the other Query classes.
         *
         * @since 4.1.0
         *
         * @return string[] {
         *     Array containing JOIN and WHERE SQL clauses to append to the main query.
         *
         *     @type string $join  SQL fragment to append to the main JOIN clause.
         *     @type string $where SQL fragment to append to the main WHERE clause.
         * }
         * @phpstan-return array{
         *   join: string,
         *   where: string,
         * }
         */
        protected function get_sql_clauses()
        {
        }
        /**
         * Generates SQL clauses for a single query array.
         *
         * If nested subqueries are found, this method recurses the tree to
         * produce the properly nested SQL.
         *
         * @since 4.1.0
         *
         * @param array $query Query to parse.
         * @param int   $depth Optional. Number of tree levels deep we currently are.
         *                     Used to calculate indentation. Default 0.
         * @return array {
         *     Array containing JOIN and WHERE SQL clauses to append to a single query array.
         *
         *     @type string $join  SQL fragment to append to the main JOIN clause.
         *     @type string $where SQL fragment to append to the main WHERE clause.
         * }
         * @phpstan-return array{
         *   join: string,
         *   where: string,
         * }
         */
        protected function get_sql_for_query($query, $depth = 0)
        {
        }
        /**
         * Turns a single date clause into pieces for a WHERE clause.
         *
         * A wrapper for get_sql_for_clause(), included here for backward
         * compatibility while retaining the naming convention across Query classes.
         *
         * @since 3.7.0
         *
         * @param array $query Date query arguments.
         * @return array {
         *     Array containing JOIN and WHERE SQL clauses to append to the main query.
         *
         *     @type string[] $join  Array of SQL fragments to append to the main JOIN clause.
         *     @type string[] $where Array of SQL fragments to append to the main WHERE clause.
         * }
         * @phpstan-return array{
         *   join: string[],
         *   where: string[],
         * }
         */
        protected function get_sql_for_subquery($query)
        {
        }
        /**
         * Turns a first-order date query into SQL for a WHERE clause.
         *
         * @since 4.1.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param array $query        Date query clause.
         * @param array $parent_query Parent query of the current date query.
         * @return array {
         *     Array containing JOIN and WHERE SQL clauses to append to the main query.
         *
         *     @type string[] $join  Array of SQL fragments to append to the main JOIN clause.
         *     @type string[] $where Array of SQL fragments to append to the main WHERE clause.
         * }
         * @phpstan-return array{
         *   join: string[],
         *   where: string[],
         * }
         */
        protected function get_sql_for_clause($query, $parent_query)
        {
        }
        /**
         * Builds and validates a value string based on the comparison operator.
         *
         * @since 3.7.0
         *
         * @param string       $compare The compare operator to use.
         * @param string|array $value   The value.
         * @return string|false|int The value to be used in SQL or false on error.
         */
        public function build_value($compare, $value)
        {
        }
        /**
         * Builds a MySQL format date/time based on some query parameters.
         *
         * You can pass an array of values (year, month, etc.) with missing parameter values being defaulted to
         * either the maximum or minimum values (controlled by the $default_to parameter). Alternatively you can
         * pass a string that will be passed to date_create().
         *
         * @since 3.7.0
         *
         * @param string|array $datetime       An array of parameters or a strtotime() string.
         * @param bool         $default_to_max Whether to round up incomplete dates. Supported by values
         *                                     of $datetime that are arrays, or string values that are a
         *                                     subset of MySQL date format ('Y', 'Y-m', 'Y-m-d', 'Y-m-d H:i').
         *                                     Default: false.
         * @return string|false A MySQL format date/time or false on failure.
         */
        public function build_mysql_datetime($datetime, $default_to_max = \false)
        {
        }
        /**
         * Builds a query string for comparing time values (hour, minute, second).
         *
         * If just hour, minute, or second is set than a normal comparison will be done.
         * However if multiple values are passed, a pseudo-decimal time will be created
         * in order to be able to accurately compare against.
         *
         * @since 3.7.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string   $column  The column to query against. Needs to be pre-validated!
         * @param string   $compare The comparison operator. Needs to be pre-validated!
         * @param int|null $hour    Optional. An hour value (0-23).
         * @param int|null $minute  Optional. A minute value (0-59).
         * @param int|null $second  Optional. A second value (0-59).
         * @return string|false A query part or false on failure.
         */
        public function build_time_query($column, $compare, $hour = \null, $minute = \null, $second = \null)
        {
        }
        /**
         * Sanitizes a 'relation' operator.
         *
         * @since 6.0.3
         *
         * @param string $relation Raw relation key from the query argument.
         * @return string Sanitized relation. Either 'AND' or 'OR'.
         * @phpstan-return 'AND'|'OR'
         */
        public function sanitize_relation($relation)
        {
        }
    }
    /**
     * Core base class extended to register items.
     *
     * @since 2.6.0
     *
     * @see _WP_Dependency
     */
    #[\AllowDynamicProperties]
    class WP_Dependencies
    {
        /**
         * An array of all registered dependencies keyed by handle.
         *
         * @since 2.6.8
         *
         * @var _WP_Dependency[]
         */
        public $registered = array();
        /**
         * An array of handles of queued dependencies.
         *
         * @since 2.6.8
         *
         * @var string[]
         */
        public $queue = array();
        /**
         * An array of handles of dependencies to queue.
         *
         * @since 2.6.0
         *
         * @var string[]
         */
        public $to_do = array();
        /**
         * An array of handles of dependencies already queued.
         *
         * @since 2.6.0
         *
         * @var string[]
         */
        public $done = array();
        /**
         * An array of additional arguments passed when a handle is registered.
         *
         * Arguments are appended to the item query string.
         *
         * @since 2.6.0
         *
         * @var array
         */
        public $args = array();
        /**
         * An array of dependency groups to enqueue.
         *
         * Each entry is keyed by handle and represents the integer group level or boolean
         * false if the handle has no group.
         *
         * @since 2.8.0
         *
         * @var (int|false)[]
         */
        public $groups = array();
        /**
         * A handle group to enqueue.
         *
         * @since 2.8.0
         *
         * @deprecated 4.5.0
         * @var int
         */
        public $group = 0;
        /**
         * Processes the items and dependencies.
         *
         * Processes the items passed to it or the queue, and their dependencies.
         *
         * @since 2.6.0
         * @since 2.8.0 Added the `$group` parameter.
         *
         * @param string|string[]|false $handles Optional. Items to be processed: queue (false),
         *                                       single item (string), or multiple items (array of strings).
         *                                       Default false.
         * @param int|false             $group   Optional. Group level: level (int), no group (false).
         * @return string[] Array of handles of items that have been processed.
         */
        public function do_items($handles = \false, $group = \false)
        {
        }
        /**
         * Processes a dependency.
         *
         * @since 2.6.0
         * @since 5.5.0 Added the `$group` parameter.
         *
         * @param string    $handle Name of the item. Should be unique.
         * @param int|false $group  Optional. Group level: level (int), no group (false).
         *                          Default false.
         * @return bool True on success, false if not set.
         */
        public function do_item($handle, $group = \false)
        {
        }
        /**
         * Determines dependencies.
         *
         * Recursively builds an array of items to process taking
         * dependencies into account. Does NOT catch infinite loops.
         *
         * @since 2.1.0
         * @since 2.6.0 Moved from `WP_Scripts`.
         * @since 2.8.0 Added the `$group` parameter.
         *
         * @param string|string[] $handles   Item handle (string) or item handles (array of strings).
         * @param bool            $recursion Optional. Internal flag that function is calling itself.
         *                                   Default false.
         * @param int|false       $group     Optional. Group level: level (int), no group (false).
         *                                   Default false.
         * @return bool True on success, false on failure.
         */
        public function all_deps($handles, $recursion = \false, $group = \false)
        {
        }
        /**
         * Register an item.
         *
         * Registers the item if no item of that name already exists.
         *
         * @since 2.1.0
         * @since 2.6.0 Moved from `WP_Scripts`.
         *
         * @param string           $handle Name of the item. Should be unique.
         * @param string|false     $src    Full URL of the item, or path of the item relative
         *                                 to the WordPress root directory. If source is set to false,
         *                                 the item is an alias of other items it depends on.
         * @param string[]         $deps   Optional. An array of registered item handles this item depends on.
         *                                 Default empty array.
         * @param string|bool|null $ver    Optional. String specifying item version number, if it has one,
         *                                 which is added to the URL as a query string for cache busting purposes.
         *                                 If version is set to false, a version number is automatically added
         *                                 equal to current installed WordPress version.
         *                                 If set to null, no version is added.
         * @param mixed            $args   Optional. Custom property of the item. NOT the class property $args.
         *                                 Examples: $media, $in_footer.
         * @return bool Whether the item has been registered. True on success, false on failure.
         */
        public function add($handle, $src, $deps = array(), $ver = \false, $args = \null)
        {
        }
        /**
         * Add extra item data.
         *
         * Adds data to a registered item.
         *
         * @since 2.6.0
         *
         * @param string $handle Name of the item. Should be unique.
         * @param string $key    The data key.
         * @param mixed  $value  The data value.
         * @return bool True on success, false on failure.
         */
        public function add_data($handle, $key, $value)
        {
        }
        /**
         * Get extra item data.
         *
         * Gets data associated with a registered item.
         *
         * @since 3.3.0
         *
         * @param string $handle Name of the item. Should be unique.
         * @param string $key    The data key.
         * @return mixed Extra item data (string), false otherwise.
         */
        public function get_data($handle, $key)
        {
        }
        /**
         * Un-register an item or items.
         *
         * @since 2.1.0
         * @since 2.6.0 Moved from `WP_Scripts`.
         *
         * @param string|string[] $handles Item handle (string) or item handles (array of strings).
         */
        public function remove($handles)
        {
        }
        /**
         * Queue an item or items.
         *
         * Decodes handles and arguments, then queues handles and stores
         * arguments in the class property $args. For example in extending
         * classes, $args is appended to the item url as a query string.
         * Note $args is NOT the $args property of items in the $registered array.
         *
         * @since 2.1.0
         * @since 2.6.0 Moved from `WP_Scripts`.
         *
         * @param string|string[] $handles Item handle (string) or item handles (array of strings).
         */
        public function enqueue($handles)
        {
        }
        /**
         * Dequeue an item or items.
         *
         * Decodes handles and arguments, then dequeues handles
         * and removes arguments from the class property $args.
         *
         * @since 2.1.0
         * @since 2.6.0 Moved from `WP_Scripts`.
         *
         * @param string|string[] $handles Item handle (string) or item handles (array of strings).
         */
        public function dequeue($handles)
        {
        }
        /**
         * Recursively search the passed dependency tree for a handle.
         *
         * @since 4.0.0
         *
         * @param string[] $queue  An array of queued _WP_Dependency handles.
         * @param string   $handle Name of the item. Should be unique.
         * @return bool Whether the handle is found after recursively searching the dependency tree.
         */
        protected function recurse_deps($queue, $handle)
        {
        }
        /**
         * Query the list for an item.
         *
         * @since 2.1.0
         * @since 2.6.0 Moved from `WP_Scripts`.
         *
         * @param string $handle Name of the item. Should be unique.
         * @param string $status Optional. Status of the item to query. Default 'registered'.
         * @return bool|_WP_Dependency Found, or object Item data.
         */
        public function query($handle, $status = 'registered')
        {
        }
        /**
         * Set item group, unless already in a lower group.
         *
         * @since 2.8.0
         *
         * @param string    $handle    Name of the item. Should be unique.
         * @param bool      $recursion Internal flag that calling function was called recursively.
         * @param int|false $group     Group level: level (int), no group (false).
         * @return bool Not already in the group or a lower group.
         */
        public function set_group($handle, $recursion, $group)
        {
        }
        /**
         * Get etag header for cache validation.
         *
         * @since 6.7.0
         *
         * @global string $wp_version The WordPress version string.
         *
         * @param string[] $load Array of script or style handles to load.
         * @return string Etag header.
         */
        public function get_etag($load)
        {
        }
    }
    /**
     * Class _WP_Dependency
     *
     * Helper class to register a handle and associated data.
     *
     * @access private
     * @since 2.6.0
     */
    #[\AllowDynamicProperties]
    class _WP_Dependency
    {
        /**
         * The handle name.
         *
         * @since 2.6.0
         * @var string
         */
        public $handle;
        /**
         * The handle source.
         *
         * If source is set to false, the item is an alias of other items it depends on.
         *
         * @since 2.6.0
         * @var string|false
         */
        public $src;
        /**
         * An array of handle dependencies.
         *
         * @since 2.6.0
         * @var string[]
         */
        public $deps = array();
        /**
         * The handle version.
         *
         * Used for cache-busting.
         *
         * @since 2.6.0
         * @var bool|string
         */
        public $ver = \false;
        /**
         * Additional arguments for the handle.
         *
         * @since 2.6.0
         * @var array
         */
        public $args = \null;
        /**
         * Extra data to supply to the handle.
         *
         * @since 2.6.0
         * @var array
         */
        public $extra = array();
        /**
         * Translation textdomain set for this dependency.
         *
         * @since 5.0.0
         * @var string
         */
        public $textdomain;
        /**
         * Translation path set for this dependency.
         *
         * @since 5.0.0
         * @var string
         */
        public $translations_path;
        /**
         * Setup dependencies.
         *
         * @since 2.6.0
         * @since 5.3.0 Formalized the existing `...$args` parameter by adding it
         *              to the function signature.
         *
         * @param mixed ...$args Dependency information.
         */
        public function __construct(...$args)
        {
        }
        /**
         * Add handle data.
         *
         * @since 2.6.0
         *
         * @param string $name The data key to add.
         * @param mixed  $data The data value to add.
         * @return bool False if not scalar, true otherwise.
         */
        public function add_data($name, $data)
        {
        }
        /**
         * Sets the translation domain for this dependency.
         *
         * @since 5.0.0
         *
         * @param string $domain The translation textdomain.
         * @param string $path   Optional. The full file path to the directory containing translation files.
         * @return bool False if $domain is not a string, true otherwise.
         */
        public function set_translations($domain, $path = '')
        {
        }
    }
    /**
     * Manages duotone block supports and global styles.
     *
     * @access private
     */
    class WP_Duotone
    {
        /**
         * Returns the prefixed id for the duotone filter for use as a CSS id.
         *
         * Exported for the deprecated function wp_get_duotone_filter_id().
         *
         * @internal
         *
         * @since 6.3.0
         * @deprecated 6.3.0
         *
         * @param  array $preset Duotone preset value as seen in theme.json.
         * @return string        Duotone filter CSS id.
         */
        public static function get_filter_id_from_preset($preset)
        {
        }
        /**
         * Gets the SVG for the duotone filter definition from a preset.
         *
         * Exported for the deprecated function wp_get_duotone_filter_property().
         *
         * @internal
         *
         * @since 6.3.0
         * @deprecated 6.3.0
         *
         * @param array $preset The duotone preset.
         * @return string The SVG for the filter definition.
         */
        public static function get_filter_svg_from_preset($preset)
        {
        }
        /**
         * Registers the style and colors block attributes for block types that support it.
         *
         * Block support is added with `supports.filter.duotone` in block.json.
         *
         * @since 6.3.0
         *
         * @param WP_Block_Type $block_type Block Type.
         */
        public static function register_duotone_support($block_type)
        {
        }
        /**
         * Render out the duotone CSS styles and SVG.
         *
         * The hooks self::set_global_style_block_names and self::set_global_styles_presets
         * must be called before this function.
         *
         * @since 6.3.0
         *
         * @param  string   $block_content Rendered block content.
         * @param  array    $block         Block object.
         * @param  WP_Block $wp_block      The block instance.
         * @return string Filtered block content.
         */
        public static function render_duotone_support($block_content, $block, $wp_block)
        {
        }
        /**
         * Fixes the issue with our generated class name not being added to the block's outer container
         * in classic themes due to gutenberg_restore_image_outer_container from layout block supports.
         *
         * @since 6.6.0
         *
         * @param string $block_content Rendered block content.
         * @return string Filtered block content.
         */
        public static function restore_image_outer_container($block_content)
        {
        }
        /**
         * Appends the used block duotone filter declarations to the inline block supports CSS.
         *
         * Uses the declarations saved in earlier calls to self::enqueue_block_css.
         *
         * @since 6.3.0
         */
        public static function output_block_styles()
        {
        }
        /**
         * Appends the used global style duotone filter presets (CSS custom
         * properties) to the inline global styles CSS.
         *
         * Uses the declarations saved in earlier calls to self::enqueue_global_styles_preset.
         *
         * @since 6.3.0
         */
        public static function output_global_styles()
        {
        }
        /**
         * Outputs all necessary SVG for duotone filters, CSS for classic themes.
         *
         * Uses the declarations saved in earlier calls to self::enqueue_global_styles_preset
         * and self::enqueue_custom_filter.
         *
         * @since 6.3.0
         */
        public static function output_footer_assets()
        {
        }
        /**
         * Adds the duotone SVGs and CSS custom properties to the editor settings.
         *
         * This allows the properties to be pulled in by the EditorStyles component
         * in JS and rendered in the post editor.
         *
         * @since 6.3.0
         *
         * @param array $settings The block editor settings from the `block_editor_settings_all` filter.
         * @return array The editor settings with duotone SVGs and CSS custom properties.
         */
        public static function add_editor_settings($settings)
        {
        }
        /**
         * Migrates the experimental duotone support flag to the stabilized location.
         *
         * This moves `supports.color.__experimentalDuotone` to `supports.filter.duotone`.
         *
         * @since 6.3.0
         *
         * @param array $settings Current block type settings.
         * @param array $metadata Block metadata as read in via block.json.
         * @return array Filtered block type settings.
         */
        public static function migrate_experimental_duotone_support_flag($settings, $metadata)
        {
        }
        /**
         * Gets the CSS filter property value from a preset.
         *
         * Exported for the deprecated function wp_get_duotone_filter_id().
         *
         * @internal
         *
         * @since 6.3.0
         * @deprecated 6.3.0
         *
         * @param array $preset The duotone preset.
         * @return string The CSS filter property value.
         */
        public static function get_filter_css_property_value_from_preset($preset)
        {
        }
    }
    /**
     * Facilitates adding of the WordPress editor as used on the Write and Edit screens.
     *
     * @package WordPress
     * @since 3.3.0
     *
     * Private, not included by default. See wp_editor() in wp-includes/general-template.php.
     */
    #[\AllowDynamicProperties]
    final class _WP_Editors
    {
        public static $mce_locale;
        /**
         * Parse default arguments for the editor instance.
         *
         * @since 3.3.0
         *
         * @param string $editor_id HTML ID for the textarea and TinyMCE and Quicktags instances.
         *                          Should not contain square brackets.
         * @param array  $settings {
         *     Array of editor arguments.
         *
         *     @type bool       $wpautop           Whether to use wpautop(). Default true.
         *     @type bool       $media_buttons     Whether to show the Add Media/other media buttons.
         *     @type string     $default_editor    When both TinyMCE and Quicktags are used, set which
         *                                         editor is shown on page load. Default empty.
         *     @type bool       $drag_drop_upload  Whether to enable drag & drop on the editor uploading. Default false.
         *                                         Requires the media modal.
         *     @type string     $textarea_name     Give the textarea a unique name here. Square brackets
         *                                         can be used here. Default $editor_id.
         *     @type int        $textarea_rows     Number rows in the editor textarea. Default 20.
         *     @type string|int $tabindex          Tabindex value to use. Default empty.
         *     @type string     $tabfocus_elements The previous and next element ID to move the focus to
         *                                         when pressing the Tab key in TinyMCE. Default ':prev,:next'.
         *     @type string     $editor_css        Intended for extra styles for both Visual and Text editors.
         *                                         Should include `<style>` tags, and can use "scoped". Default empty.
         *     @type string     $editor_class      Extra classes to add to the editor textarea element. Default empty.
         *     @type bool       $teeny             Whether to output the minimal editor config. Examples include
         *                                         Press This and the Comment editor. Default false.
         *     @type bool       $dfw               Deprecated in 4.1. Unused.
         *     @type bool|array $tinymce           Whether to load TinyMCE. Can be used to pass settings directly to
         *                                         TinyMCE using an array. Default true.
         *     @type bool|array $quicktags         Whether to load Quicktags. Can be used to pass settings directly to
         *                                         Quicktags using an array. Default true.
         * }
         * @return array Parsed arguments array.
         * @phpstan-param array{
         *   wpautop?: bool,
         *   media_buttons?: bool,
         *   default_editor?: string,
         *   drag_drop_upload?: bool,
         *   textarea_name?: string,
         *   textarea_rows?: int,
         *   tabindex?: string|int,
         *   tabfocus_elements?: string,
         *   editor_css?: string,
         *   editor_class?: string,
         *   teeny?: bool,
         *   dfw?: bool,
         *   tinymce?: bool|array,
         *   quicktags?: bool|array,
         * } $settings
         */
        public static function parse_settings($editor_id, $settings)
        {
        }
        /**
         * Outputs the HTML for a single instance of the editor.
         *
         * @since 3.3.0
         *
         * @global WP_Screen $current_screen WordPress current screen object.
         *
         * @param string $content   Initial content for the editor.
         * @param string $editor_id HTML ID for the textarea and TinyMCE and Quicktags instances.
         *                          Should not contain square brackets.
         * @param array  $settings  See _WP_Editors::parse_settings() for description.
         * @phpstan-param array{
         *   wpautop?: bool,
         *   media_buttons?: bool,
         *   default_editor?: string,
         *   drag_drop_upload?: bool,
         *   textarea_name?: string,
         *   textarea_rows?: int,
         *   tabindex?: string|int,
         *   tabfocus_elements?: string,
         *   editor_css?: string,
         *   editor_class?: string,
         *   teeny?: bool,
         *   dfw?: bool,
         *   tinymce?: bool|array,
         *   quicktags?: bool|array,
         * } $settings See _WP_Editors::parse_settings()
         */
        public static function editor($content, $editor_id, $settings = array())
        {
        }
        /**
         * @since 3.3.0
         *
         * @param string $editor_id Unique editor identifier, e.g. 'content'.
         * @param array  $set       Array of editor arguments.
         */
        public static function editor_settings($editor_id, $set)
        {
        }
        /**
         * @since 3.3.0
         *
         * @param bool $default_scripts Optional. Whether default scripts should be enqueued. Default false.
         */
        public static function enqueue_scripts($default_scripts = \false)
        {
        }
        /**
         * Enqueue all editor scripts.
         * For use when the editor is going to be initialized after page load.
         *
         * @since 4.8.0
         * @phpstan-return void
         */
        public static function enqueue_default_editor()
        {
        }
        /**
         * Print (output) all editor scripts and default settings.
         * For use when the editor is going to be initialized after page load.
         *
         * @since 4.8.0
         */
        public static function print_default_editor_scripts()
        {
        }
        /**
         * Returns the TinyMCE locale.
         *
         * @since 4.8.0
         *
         * @return string
         */
        public static function get_mce_locale()
        {
        }
        /**
         * Returns the TinyMCE base URL.
         *
         * @since 4.8.0
         *
         * @return string
         */
        public static function get_baseurl()
        {
        }
        /**
         * Translates the default TinyMCE strings and returns them as JSON encoded object ready to be loaded with tinymce.addI18n(),
         * or as JS snippet that should run after tinymce.js is loaded.
         *
         * @since 3.9.0
         *
         * @param string $mce_locale The locale used for the editor.
         * @param bool   $json_only  Optional. Whether to include the JavaScript calls to tinymce.addI18n() and
         *                           tinymce.ScriptLoader.markDone(). Default false.
         * @return string Translation object, JSON encoded.
         */
        public static function wp_mce_translation($mce_locale = '', $json_only = \false)
        {
        }
        /**
         * Force uncompressed TinyMCE when a custom theme has been defined.
         *
         * The compressed TinyMCE file cannot deal with custom themes, so this makes
         * sure that WordPress uses the uncompressed TinyMCE file if a theme is defined.
         * Even if the website is running on a production environment.
         *
         * @since 5.0.0
         * @phpstan-return void
         */
        public static function force_uncompressed_tinymce()
        {
        }
        /**
         * Print (output) the main TinyMCE scripts.
         *
         * @since 4.8.0
         *
         * @global bool $concatenate_scripts
         * @phpstan-return void
         */
        public static function print_tinymce_scripts()
        {
        }
        /**
         * Print (output) the TinyMCE configuration and initialization scripts.
         *
         * @since 3.3.0
         *
         * @global string $tinymce_version
         */
        public static function editor_js()
        {
        }
        /**
         * Outputs the HTML for distraction-free writing mode.
         *
         * @since 3.2.0
         * @deprecated 4.3.0
         */
        public static function wp_fullscreen_html()
        {
        }
        /**
         * Performs post queries for internal linking.
         *
         * @since 3.1.0
         *
         * @param array $args {
         *     Optional. Array of link query arguments.
         *
         *     @type int    $pagenum Page number. Default 1.
         *     @type string $s       Search keywords.
         * }
         * @return array|false $results {
         *     An array of associative arrays of query results, false if there are none.
         *
         *     @type array ...$0 {
         *         @type int    $ID        Post ID.
         *         @type string $title     The trimmed, escaped post title.
         *         @type string $permalink Post permalink.
         *         @type string $info      A 'Y/m/d'-formatted date for 'post' post type,
         *                                 the 'singular_name' post type label otherwise.
         *     }
         * }
         * @phpstan-param array{
         *   pagenum?: int,
         *   s?: string,
         * } $args
         * @phpstan-return false|array<int|string, array{
         *   ID: int,
         *   title: string,
         *   permalink: string,
         *   info: string,
         * }>
         */
        public static function wp_link_query($args = array())
        {
        }
        /**
         * Dialog for internal linking.
         *
         * @since 3.1.0
         * @phpstan-return void
         */
        public static function wp_link_dialog()
        {
        }
    }
    /**
     * API for easily embedding rich media such as videos and images into content.
     *
     * @package WordPress
     * @subpackage Embed
     * @since 2.9.0
     */
    #[\AllowDynamicProperties]
    class WP_Embed
    {
        public $handlers = array();
        public $post_ID;
        public $usecache = \true;
        public $linkifunknown = \true;
        public $last_attr = array();
        public $last_url = '';
        /**
         * When a URL cannot be embedded, return false instead of returning a link
         * or the URL.
         *
         * Bypasses the {@see 'embed_maybe_make_link'} filter.
         *
         * @var bool
         */
        public $return_false_on_fail = \false;
        /**
         * Constructor
         */
        public function __construct()
        {
        }
        /**
         * Processes the [embed] shortcode.
         *
         * Since the [embed] shortcode needs to be run earlier than other shortcodes,
         * this function removes all existing shortcodes, registers the [embed] shortcode,
         * calls do_shortcode(), and then re-registers the old shortcodes.
         *
         * @global array $shortcode_tags
         *
         * @param string $content Content to parse.
         * @return string Content with shortcode parsed.
         */
        public function run_shortcode($content)
        {
        }
        /**
         * If a post/page was saved, then output JavaScript to make
         * an Ajax request that will call WP_Embed::cache_oembed().
         * @phpstan-return void
         */
        public function maybe_run_ajax_cache()
        {
        }
        /**
         * Registers an embed handler.
         *
         * Do not use this function directly, use wp_embed_register_handler() instead.
         *
         * This function should probably also only be used for sites that do not support oEmbed.
         *
         * @param string   $id       An internal ID/name for the handler. Needs to be unique.
         * @param string   $regex    The regex that will be used to see if this handler should be used for a URL.
         * @param callable $callback The callback function that will be called if the regex is matched.
         * @param int      $priority Optional. Used to specify the order in which the registered handlers will be tested.
         *                           Lower numbers correspond with earlier testing, and handlers with the same priority are
         *                           tested in the order in which they were added to the action. Default 10.
         */
        public function register_handler($id, $regex, $callback, $priority = 10)
        {
        }
        /**
         * Unregisters a previously-registered embed handler.
         *
         * Do not use this function directly, use wp_embed_unregister_handler() instead.
         *
         * @param string $id       The handler ID that should be removed.
         * @param int    $priority Optional. The priority of the handler to be removed (default: 10).
         */
        public function unregister_handler($id, $priority = 10)
        {
        }
        /**
         * Returns embed HTML for a given URL from embed handlers.
         *
         * Attempts to convert a URL into embed HTML by checking the URL
         * against the regex of the registered embed handlers.
         *
         * @since 5.5.0
         *
         * @param array  $attr {
         *     Shortcode attributes. Optional.
         *
         *     @type int $width  Width of the embed in pixels.
         *     @type int $height Height of the embed in pixels.
         * }
         * @param string $url The URL attempting to be embedded.
         * @return string|false The embed HTML on success, false otherwise.
         * @phpstan-param array{
         *   width?: int,
         *   height?: int,
         * } $attr
         */
        public function get_embed_handler_html($attr, $url)
        {
        }
        /**
         * The do_shortcode() callback function.
         *
         * Attempts to convert a URL into embed HTML. Starts by checking the URL against the regex of
         * the registered embed handlers. If none of the regex matches and it's enabled, then the URL
         * will be given to the WP_oEmbed class.
         *
         * @param array  $attr {
         *     Shortcode attributes. Optional.
         *
         *     @type int $width  Width of the embed in pixels.
         *     @type int $height Height of the embed in pixels.
         * }
         * @param string $url The URL attempting to be embedded.
         * @return string|false The embed HTML on success, otherwise the original URL.
         *                      `->maybe_make_link()` can return false on failure.
         * @phpstan-param array{
         *   width?: int,
         *   height?: int,
         * } $attr
         */
        public function shortcode($attr, $url = '')
        {
        }
        /**
         * Deletes all oEmbed caches. Unused by core as of 4.0.0.
         *
         * @param int $post_id Post ID to delete the caches for.
         * @phpstan-return void
         */
        public function delete_oembed_caches($post_id)
        {
        }
        /**
         * Triggers a caching of all oEmbed results.
         *
         * @param int $post_id Post ID to do the caching for.
         * @phpstan-return void
         */
        public function cache_oembed($post_id)
        {
        }
        /**
         * Passes any unlinked URLs that are on their own line to WP_Embed::shortcode() for potential embedding.
         *
         * @see WP_Embed::autoembed_callback()
         *
         * @param string $content The content to be searched.
         * @return string Potentially modified $content.
         */
        public function autoembed($content)
        {
        }
        /**
         * Callback function for WP_Embed::autoembed().
         *
         * @param array $matches A regex match array.
         * @return string The embed HTML on success, otherwise the original URL.
         */
        public function autoembed_callback($matches)
        {
        }
        /**
         * Conditionally makes a hyperlink based on an internal class variable.
         *
         * @param string $url URL to potentially be linked.
         * @return string|false Linked URL or the original URL. False if 'return_false_on_fail' is true.
         */
        public function maybe_make_link($url)
        {
        }
        /**
         * Finds the oEmbed cache post ID for a given cache key.
         *
         * @since 4.9.0
         *
         * @param string $cache_key oEmbed cache key.
         * @return int|null Post ID on success, null on failure.
         */
        public function find_oembed_post_id($cache_key)
        {
        }
    }
    /**
     * WordPress Error class.
     *
     * Container for checking for WordPress errors and error messages. Return
     * WP_Error and use is_wp_error() to check if this class is returned. Many
     * core WordPress functions pass this class in the event of an error and
     * if not handled properly will result in code errors.
     *
     * @since 2.1.0
     */
    #[\AllowDynamicProperties]
    class WP_Error
    {
        /**
         * Stores the list of errors.
         *
         * @since 2.1.0
         * @var array
         */
        public $errors = array();
        /**
         * Stores the most recently added data for each error code.
         *
         * @since 2.1.0
         * @var array
         */
        public $error_data = array();
        /**
         * Stores previously added data added for error codes, oldest-to-newest by code.
         *
         * @since 5.6.0
         * @var array[]
         */
        protected $additional_data = array();
        /**
         * Initializes the error.
         *
         * If `$code` is empty, the other parameters will be ignored.
         * When `$code` is not empty, `$message` will be used even if
         * it is empty. The `$data` parameter will be used only if it
         * is not empty.
         *
         * Though the class is constructed with a single error code and
         * message, multiple codes can be added using the `add()` method.
         *
         * @since 2.1.0
         *
         * @param string|int $code    Error code.
         * @param string     $message Error message.
         * @param mixed      $data    Optional. Error data. Default empty string.
         * @phpstan-return void
         */
        public function __construct($code = '', $message = '', $data = '')
        {
        }
        /**
         * Retrieves all error codes.
         *
         * @since 2.1.0
         *
         * @return array List of error codes, if available.
         */
        public function get_error_codes()
        {
        }
        /**
         * Retrieves the first error code available.
         *
         * @since 2.1.0
         *
         * @return string|int Empty string, if no error codes.
         */
        public function get_error_code()
        {
        }
        /**
         * Retrieves all error messages, or the error messages for the given error code.
         *
         * @since 2.1.0
         *
         * @param string|int $code Optional. Error code to retrieve the messages for.
         *                         Default empty string.
         * @return string[] Error strings on success, or empty array if there are none.
         */
        public function get_error_messages($code = '')
        {
        }
        /**
         * Gets a single error message.
         *
         * This will get the first message available for the code. If no code is
         * given then the first code available will be used.
         *
         * @since 2.1.0
         *
         * @param string|int $code Optional. Error code to retrieve the message for.
         *                         Default empty string.
         * @return string The error message.
         */
        public function get_error_message($code = '')
        {
        }
        /**
         * Retrieves the most recently added error data for an error code.
         *
         * @since 2.1.0
         *
         * @param string|int $code Optional. Error code. Default empty string.
         * @return mixed Error data, if it exists.
         */
        public function get_error_data($code = '')
        {
        }
        /**
         * Verifies if the instance contains errors.
         *
         * @since 5.1.0
         *
         * @return bool If the instance contains errors.
         */
        public function has_errors()
        {
        }
        /**
         * Adds an error or appends an additional message to an existing error.
         *
         * @since 2.1.0
         *
         * @param string|int $code    Error code.
         * @param string     $message Error message.
         * @param mixed      $data    Optional. Error data. Default empty string.
         */
        public function add($code, $message, $data = '')
        {
        }
        /**
         * Adds data to an error with the given code.
         *
         * @since 2.1.0
         * @since 5.6.0 Errors can now contain more than one item of error data. {@see WP_Error::$additional_data}.
         *
         * @param mixed      $data Error data.
         * @param string|int $code Error code.
         */
        public function add_data($data, $code = '')
        {
        }
        /**
         * Retrieves all error data for an error code in the order in which the data was added.
         *
         * @since 5.6.0
         *
         * @param string|int $code Error code.
         * @return mixed[] Array of error data, if it exists.
         */
        public function get_all_error_data($code = '')
        {
        }
        /**
         * Removes the specified error.
         *
         * This function removes all error messages associated with the specified
         * error code, along with any error data for that code.
         *
         * @since 4.1.0
         *
         * @param string|int $code Error code.
         */
        public function remove($code)
        {
        }
        /**
         * Merges the errors in the given error object into this one.
         *
         * @since 5.6.0
         *
         * @param WP_Error $error Error object to merge.
         */
        public function merge_from(\WP_Error $error)
        {
        }
        /**
         * Exports the errors in this object into the given one.
         *
         * @since 5.6.0
         *
         * @param WP_Error $error Error object to export into.
         */
        public function export_to(\WP_Error $error)
        {
        }
        /**
         * Copies errors from one WP_Error instance to another.
         *
         * @since 5.6.0
         *
         * @param WP_Error $from The WP_Error to copy from.
         * @param WP_Error $to   The WP_Error to copy to.
         */
        protected static function copy_errors(\WP_Error $from, \WP_Error $to)
        {
        }
    }
    /**
     * Core base Exception class.
     *
     * Future, more specific, Exceptions should always extend this base class.
     *
     * @since 6.7.0
     */
    class WP_Exception extends \Exception
    {
    }
    /**
     * Core class used as the default shutdown handler for fatal errors.
     *
     * A drop-in 'fatal-error-handler.php' can be used to override the instance of this class and use a custom
     * implementation for the fatal error handler that WordPress registers. The custom class should extend this class and
     * can override its methods individually as necessary. The file must return the instance of the class that should be
     * registered.
     *
     * @since 5.2.0
     */
    #[\AllowDynamicProperties]
    class WP_Fatal_Error_Handler
    {
        /**
         * Runs the shutdown handler.
         *
         * This method is registered via `register_shutdown_function()`.
         *
         * @since 5.2.0
         *
         * @global WP_Locale $wp_locale WordPress date and time locale object.
         * @phpstan-return void
         */
        public function handle()
        {
        }
        /**
         * Detects the error causing the crash if it should be handled.
         *
         * @since 5.2.0
         *
         * @return array|null Error information returned by `error_get_last()`, or null
         *                    if none was recorded or the error should not be handled.
         */
        protected function detect_error()
        {
        }
        /**
         * Determines whether we are dealing with an error that WordPress should handle
         * in order to protect the admin backend against WSODs.
         *
         * @since 5.2.0
         *
         * @param array $error Error information retrieved from `error_get_last()`.
         * @return bool Whether WordPress should handle this error.
         */
        protected function should_handle_error($error)
        {
        }
        /**
         * Displays the PHP error template and sends the HTTP status code, typically 500.
         *
         * A drop-in 'php-error.php' can be used as a custom template. This drop-in should control the HTTP status code and
         * print the HTML markup indicating that a PHP error occurred. Note that this drop-in may potentially be executed
         * very early in the WordPress bootstrap process, so any core functions used that are not part of
         * `wp-includes/load.php` should be checked for before being called.
         *
         * If no such drop-in is available, this will call {@see WP_Fatal_Error_Handler::display_default_error_template()}.
         *
         * @since 5.2.0
         * @since 5.3.0 The `$handled` parameter was added.
         *
         * @param array         $error   Error information retrieved from `error_get_last()`.
         * @param true|WP_Error $handled Whether Recovery Mode handled the fatal error.
         * @phpstan-return void
         */
        protected function display_error_template($error, $handled)
        {
        }
        /**
         * Displays the default PHP error template.
         *
         * This method is called conditionally if no 'php-error.php' drop-in is available.
         *
         * It calls {@see wp_die()} with a message indicating that the site is experiencing technical difficulties and a
         * login link to the admin backend. The {@see 'wp_php_error_message'} and {@see 'wp_php_error_args'} filters can
         * be used to modify these parameters.
         *
         * @since 5.2.0
         * @since 5.3.0 The `$handled` parameter was added.
         *
         * @param array         $error   Error information retrieved from `error_get_last()`.
         * @param true|WP_Error $handled Whether Recovery Mode handled the fatal error.
         */
        protected function display_default_error_template($error, $handled)
        {
        }
    }
    /**
     * Core class used to implement feed cache transients.
     *
     * @since 2.8.0
     * @since 6.7.0 Now properly implements the SimplePie\Cache\Base interface.
     */
    #[\AllowDynamicProperties]
    class WP_Feed_Cache_Transient implements \SimplePie\Cache\Base
    {
        /**
         * Holds the transient name.
         *
         * @since 2.8.0
         * @var string
         */
        public $name;
        /**
         * Holds the transient mod name.
         *
         * @since 2.8.0
         * @var string
         */
        public $mod_name;
        /**
         * Holds the cache duration in seconds.
         *
         * Defaults to 43200 seconds (12 hours).
         *
         * @since 2.8.0
         * @var int
         */
        public $lifetime = 43200;
        /**
         * Creates a new (transient) cache object.
         *
         * @since 2.8.0
         * @since 3.2.0 Updated to use a PHP5 constructor.
         * @since 6.7.0 Parameter names have been updated to be in line with the `SimplePie\Cache\Base` interface.
         *
         * @param string                           $location URL location (scheme is used to determine handler).
         * @param string                           $name     Unique identifier for cache object.
         * @param Base::TYPE_FEED|Base::TYPE_IMAGE $type     Either `TYPE_FEED` ('spc') for SimplePie data,
         *                                                   or `TYPE_IMAGE` ('spi') for image data.
         */
        public function __construct($location, $name, $type)
        {
        }
        /**
         * Saves data to the transient.
         *
         * @since 2.8.0
         *
         * @param array|SimplePie\SimplePie $data Data to save. If passed a SimplePie object,
         *                                        only cache the `$data` property.
         * @return true Always true.
         */
        public function save($data)
        {
        }
        /**
         * Retrieves the data saved in the transient.
         *
         * @since 2.8.0
         *
         * @return array Data for `SimplePie::$data`.
         */
        public function load()
        {
        }
        /**
         * Gets mod transient.
         *
         * @since 2.8.0
         *
         * @return int Timestamp.
         */
        public function mtime()
        {
        }
        /**
         * Sets mod transient.
         *
         * @since 2.8.0
         *
         * @return bool False if value was not set and true if value was set.
         */
        public function touch()
        {
        }
        /**
         * Deletes transients.
         *
         * @since 2.8.0
         *
         * @return true Always true.
         */
        public function unlink()
        {
        }
    }
    /**
     * Core class used to implement a feed cache.
     *
     * @since 2.8.0
     */
    #[\AllowDynamicProperties]
    class WP_Feed_Cache extends \SimplePie\Cache
    {
        /**
         * Creates a new SimplePie\Cache object.
         *
         * @since 2.8.0
         *
         * @param string $location  URL location (scheme is used to determine handler).
         * @param string $filename  Unique identifier for cache object.
         * @param string $extension 'spi' or 'spc'.
         * @return WP_Feed_Cache_Transient Feed cache handler object that uses transients.
         */
        public function create($location, $filename, $extension)
        {
        }
    }
    /**
     * Core class used to implement action and filter hook functionality.
     *
     * @since 4.7.0
     *
     * @see Iterator
     * @see ArrayAccess
     */
    #[\AllowDynamicProperties]
    final class WP_Hook implements \Iterator, \ArrayAccess
    {
        /**
         * Hook callbacks.
         *
         * @since 4.7.0
         * @var array
         */
        public $callbacks = array();
        /**
         * Adds a callback function to a filter hook.
         *
         * @since 4.7.0
         *
         * @param string   $hook_name     The name of the filter to add the callback to.
         * @param callable $callback      The callback to be run when the filter is applied.
         * @param int      $priority      The order in which the functions associated with a particular filter
         *                                are executed. Lower numbers correspond with earlier execution,
         *                                and functions with the same priority are executed in the order
         *                                in which they were added to the filter.
         * @param int      $accepted_args The number of arguments the function accepts.
         */
        public function add_filter($hook_name, $callback, $priority, $accepted_args)
        {
        }
        /**
         * Removes a callback function from a filter hook.
         *
         * @since 4.7.0
         *
         * @param string                $hook_name The filter hook to which the function to be removed is hooked.
         * @param callable|string|array $callback  The callback to be removed from running when the filter is applied.
         *                                         This method can be called unconditionally to speculatively remove
         *                                         a callback that may or may not exist.
         * @param int                   $priority  The exact priority used when adding the original filter callback.
         * @return bool Whether the callback existed before it was removed.
         */
        public function remove_filter($hook_name, $callback, $priority)
        {
        }
        /**
         * Checks if a specific callback has been registered for this hook.
         *
         * When using the `$callback` argument, this function may return a non-boolean value
         * that evaluates to false (e.g. 0), so use the `===` operator for testing the return value.
         *
         * @since 4.7.0
         *
         * @param string                      $hook_name Optional. The name of the filter hook. Default empty.
         * @param callable|string|array|false $callback  Optional. The callback to check for.
         *                                               This method can be called unconditionally to speculatively check
         *                                               a callback that may or may not exist. Default false.
         * @return bool|int If `$callback` is omitted, returns boolean for whether the hook has
         *                  anything registered. When checking a specific function, the priority
         *                  of that hook is returned, or false if the function is not attached.
         */
        public function has_filter($hook_name = '', $callback = \false)
        {
        }
        /**
         * Checks if any callbacks have been registered for this hook.
         *
         * @since 4.7.0
         *
         * @return bool True if callbacks have been registered for the current hook, otherwise false.
         */
        public function has_filters()
        {
        }
        /**
         * Removes all callbacks from the current filter.
         *
         * @since 4.7.0
         *
         * @param int|false $priority Optional. The priority number to remove. Default false.
         * @phpstan-return void
         */
        public function remove_all_filters($priority = \false)
        {
        }
        /**
         * Calls the callback functions that have been added to a filter hook.
         *
         * @since 4.7.0
         *
         * @param mixed $value The value to filter.
         * @param array $args  Additional parameters to pass to the callback functions.
         *                     This array is expected to include $value at index 0.
         * @return mixed The filtered value after all hooked functions are applied to it.
         */
        public function apply_filters($value, $args)
        {
        }
        /**
         * Calls the callback functions that have been added to an action hook.
         *
         * @since 4.7.0
         *
         * @param array $args Parameters to pass to the callback functions.
         */
        public function do_action($args)
        {
        }
        /**
         * Processes the functions hooked into the 'all' hook.
         *
         * @since 4.7.0
         *
         * @param array $args Arguments to pass to the hook callbacks. Passed by reference.
         */
        public function do_all_hook(&$args)
        {
        }
        /**
         * Return the current priority level of the currently running iteration of the hook.
         *
         * @since 4.7.0
         *
         * @return int|false If the hook is running, return the current priority level.
         *                   If it isn't running, return false.
         */
        public function current_priority()
        {
        }
        /**
         * Normalizes filters set up before WordPress has initialized to WP_Hook objects.
         *
         * The `$filters` parameter should be an array keyed by hook name, with values
         * containing either:
         *
         *  - A `WP_Hook` instance
         *  - An array of callbacks keyed by their priorities
         *
         * Examples:
         *
         *     $filters = array(
         *         'wp_fatal_error_handler_enabled' => array(
         *             10 => array(
         *                 array(
         *                     'accepted_args' => 0,
         *                     'function'      => function() {
         *                         return false;
         *                     },
         *                 ),
         *             ),
         *         ),
         *     );
         *
         * @since 4.7.0
         *
         * @param array $filters Filters to normalize. See documentation above for details.
         * @return WP_Hook[] Array of normalized filters.
         */
        public static function build_preinitialized_hooks($filters)
        {
        }
        /**
         * Determines whether an offset value exists.
         *
         * @since 4.7.0
         *
         * @link https://www.php.net/manual/en/arrayaccess.offsetexists.php
         *
         * @param mixed $offset An offset to check for.
         * @return bool True if the offset exists, false otherwise.
         */
        #[\ReturnTypeWillChange]
        public function offsetExists($offset)
        {
        }
        /**
         * Retrieves a value at a specified offset.
         *
         * @since 4.7.0
         *
         * @link https://www.php.net/manual/en/arrayaccess.offsetget.php
         *
         * @param mixed $offset The offset to retrieve.
         * @return mixed If set, the value at the specified offset, null otherwise.
         */
        #[\ReturnTypeWillChange]
        public function offsetGet($offset)
        {
        }
        /**
         * Sets a value at a specified offset.
         *
         * @since 4.7.0
         *
         * @link https://www.php.net/manual/en/arrayaccess.offsetset.php
         *
         * @param mixed $offset The offset to assign the value to.
         * @param mixed $value The value to set.
         */
        #[\ReturnTypeWillChange]
        public function offsetSet($offset, $value)
        {
        }
        /**
         * Unsets a specified offset.
         *
         * @since 4.7.0
         *
         * @link https://www.php.net/manual/en/arrayaccess.offsetunset.php
         *
         * @param mixed $offset The offset to unset.
         */
        #[\ReturnTypeWillChange]
        public function offsetUnset($offset)
        {
        }
        /**
         * Returns the current element.
         *
         * @since 4.7.0
         *
         * @link https://www.php.net/manual/en/iterator.current.php
         *
         * @return array Of callbacks at current priority.
         */
        #[\ReturnTypeWillChange]
        public function current()
        {
        }
        /**
         * Moves forward to the next element.
         *
         * @since 4.7.0
         *
         * @link https://www.php.net/manual/en/iterator.next.php
         *
         * @return array Of callbacks at next priority.
         */
        #[\ReturnTypeWillChange]
        public function next()
        {
        }
        /**
         * Returns the key of the current element.
         *
         * @since 4.7.0
         *
         * @link https://www.php.net/manual/en/iterator.key.php
         *
         * @return mixed Returns current priority on success, or NULL on failure
         */
        #[\ReturnTypeWillChange]
        public function key()
        {
        }
        /**
         * Checks if current position is valid.
         *
         * @since 4.7.0
         *
         * @link https://www.php.net/manual/en/iterator.valid.php
         *
         * @return bool Whether the current position is valid.
         */
        #[\ReturnTypeWillChange]
        public function valid()
        {
        }
        /**
         * Rewinds the Iterator to the first element.
         *
         * @since 4.7.0
         *
         * @link https://www.php.net/manual/en/iterator.rewind.php
         */
        #[\ReturnTypeWillChange]
        public function rewind()
        {
        }
    }
    /**
     * Core class used to encapsulate a single cookie object for internal use.
     *
     * Returned cookies are represented using this class, and when cookies are set, if they are not
     * already a WP_Http_Cookie() object, then they are turned into one.
     *
     * @todo The WordPress convention is to use underscores instead of camelCase for function and method
     * names. Need to switch to use underscores instead for the methods.
     *
     * @since 2.8.0
     */
    #[\AllowDynamicProperties]
    class WP_Http_Cookie
    {
        /**
         * Cookie name.
         *
         * @since 2.8.0
         *
         * @var string
         */
        public $name;
        /**
         * Cookie value.
         *
         * @since 2.8.0
         *
         * @var string
         */
        public $value;
        /**
         * When the cookie expires. Unix timestamp or formatted date.
         *
         * @since 2.8.0
         *
         * @var string|int|null
         */
        public $expires;
        /**
         * Cookie URL path.
         *
         * @since 2.8.0
         *
         * @var string
         */
        public $path;
        /**
         * Cookie Domain.
         *
         * @since 2.8.0
         *
         * @var string
         */
        public $domain;
        /**
         * Cookie port or comma-separated list of ports.
         *
         * @since 2.8.0
         *
         * @var int|string
         */
        public $port;
        /**
         * host-only flag.
         *
         * @since 5.2.0
         *
         * @var bool
         */
        public $host_only;
        /**
         * Sets up this cookie object.
         *
         * The parameter $data should be either an associative array containing the indices names below
         * or a header string detailing it.
         *
         * @since 2.8.0
         * @since 5.2.0 Added `host_only` to the `$data` parameter.
         *
         * @param string|array $data {
         *     Raw cookie data as header string or data array.
         *
         *     @type string          $name      Cookie name.
         *     @type mixed           $value     Value. Should NOT already be urlencoded.
         *     @type string|int|null $expires   Optional. Unix timestamp or formatted date. Default null.
         *     @type string          $path      Optional. Path. Default '/'.
         *     @type string          $domain    Optional. Domain. Default host of parsed $requested_url.
         *     @type int|string      $port      Optional. Port or comma-separated list of ports. Default null.
         *     @type bool            $host_only Optional. host-only storage flag. Default true.
         * }
         * @param string       $requested_url The URL which the cookie was set on, used for default $domain
         *                                    and $port values.
         * @phpstan-param array{
         *   name?: string,
         *   value?: mixed,
         *   expires?: string|int|null,
         *   path?: string,
         *   domain?: string,
         *   port?: int|string,
         *   host_only?: bool,
         * } $data
         * @phpstan-return void
         */
        public function __construct($data, $requested_url = '')
        {
        }
        /**
         * Confirms that it's OK to send this cookie to the URL checked against.
         *
         * Decision is based on RFC 2109/2965, so look there for details on validity.
         *
         * @since 2.8.0
         *
         * @param string $url URL you intend to send this cookie to
         * @return bool true if allowed, false otherwise.
         */
        public function test($url)
        {
        }
        /**
         * Convert cookie name and value back to header string.
         *
         * @since 2.8.0
         *
         * @return string Header encoded cookie name and value.
         */
        public function getHeaderValue()
        {
        }
        /**
         * Retrieve cookie header for usage in the rest of the WordPress HTTP API.
         *
         * @since 2.8.0
         *
         * @return string
         */
        public function getFullHeader()
        {
        }
        /**
         * Retrieves cookie attributes.
         *
         * @since 4.6.0
         *
         * @return array {
         *     List of attributes.
         *
         *     @type string|int|null $expires When the cookie expires. Unix timestamp or formatted date.
         *     @type string          $path    Cookie URL path.
         *     @type string          $domain  Cookie domain.
         * }
         * @phpstan-return array{
         *   expires: string|int|null,
         *   path: string,
         *   domain: string,
         * }
         */
        public function get_attributes()
        {
        }
    }
    /**
     * Core class used to integrate Curl as an HTTP transport.
     *
     * HTTP request method uses Curl extension to retrieve the url.
     *
     * Requires the Curl extension to be installed.
     *
     * @since 2.7.0
     * @deprecated 6.4.0 Use WP_Http
     * @see WP_Http
     */
    #[\AllowDynamicProperties]
    class WP_Http_Curl
    {
        /**
         * Send a HTTP request to a URI using cURL extension.
         *
         * @since 2.7.0
         *
         * @param string       $url  The request URL.
         * @param string|array $args Optional. Override the defaults.
         * @return array|WP_Error Array containing 'headers', 'body', 'response', 'cookies', 'filename'. A WP_Error instance upon error
         */
        public function request($url, $args = array())
        {
        }
        /**
         * Determines whether this class can be used for retrieving a URL.
         *
         * @since 2.7.0
         *
         * @param array $args Optional. Array of request arguments. Default empty array.
         * @return bool False means this class can not be used, true means it can.
         */
        public static function test($args = array())
        {
        }
    }
    /**
     * Core class used to implement deflate and gzip transfer encoding support for HTTP requests.
     *
     * Includes RFC 1950, RFC 1951, and RFC 1952.
     *
     * @since 2.8.0
     */
    #[\AllowDynamicProperties]
    class WP_Http_Encoding
    {
        /**
         * Compress raw string using the deflate format.
         *
         * Supports the RFC 1951 standard.
         *
         * @since 2.8.0
         *
         * @param string $raw      String to compress.
         * @param int    $level    Optional. Compression level, 9 is highest. Default 9.
         * @param string $supports Optional, not used. When implemented it will choose
         *                         the right compression based on what the server supports.
         * @return string|false Compressed string on success, false on failure.
         */
        public static function compress($raw, $level = 9, $supports = \null)
        {
        }
        /**
         * Decompression of deflated string.
         *
         * Will attempt to decompress using the RFC 1950 standard, and if that fails
         * then the RFC 1951 standard deflate will be attempted. Finally, the RFC
         * 1952 standard gzip decode will be attempted. If all fail, then the
         * original compressed string will be returned.
         *
         * @since 2.8.0
         *
         * @param string $compressed String to decompress.
         * @param int    $length     The optional length of the compressed data.
         * @return string|false Decompressed string on success, false on failure.
         */
        public static function decompress($compressed, $length = \null)
        {
        }
        /**
         * Decompression of deflated string while staying compatible with the majority of servers.
         *
         * Certain Servers will return deflated data with headers which PHP's gzinflate()
         * function cannot handle out of the box. The following function has been created from
         * various snippets on the gzinflate() PHP documentation.
         *
         * Warning: Magic numbers within. Due to the potential different formats that the compressed
         * data may be returned in, some "magic offsets" are needed to ensure proper decompression
         * takes place. For a simple pragmatic way to determine the magic offset in use, see:
         * https://core.trac.wordpress.org/ticket/18273
         *
         * @since 2.8.1
         *
         * @link https://core.trac.wordpress.org/ticket/18273
         * @link https://www.php.net/manual/en/function.gzinflate.php#70875
         * @link https://www.php.net/manual/en/function.gzinflate.php#77336
         *
         * @param string $gz_data String to decompress.
         * @return string|false Decompressed string on success, false on failure.
         */
        public static function compatible_gzinflate($gz_data)
        {
        }
        /**
         * What encoding types to accept and their priority values.
         *
         * @since 2.8.0
         *
         * @param string $url
         * @param array  $args
         * @return string Types of encoding to accept.
         */
        public static function accept_encoding($url, $args)
        {
        }
        /**
         * What encoding the content used when it was compressed to send in the headers.
         *
         * @since 2.8.0
         *
         * @return string Content-Encoding string to send in the header.
         */
        public static function content_encoding()
        {
        }
        /**
         * Whether the content be decoded based on the headers.
         *
         * @since 2.8.0
         *
         * @param array|string $headers All of the available headers.
         * @return bool
         */
        public static function should_decode($headers)
        {
        }
        /**
         * Whether decompression and compression are supported by the PHP version.
         *
         * Each function is tested instead of checking for the zlib extension, to
         * ensure that the functions all exist in the PHP version and aren't
         * disabled.
         *
         * @since 2.8.0
         *
         * @return bool
         */
        public static function is_available()
        {
        }
    }
    /**
     * WP_HTTP_IXR_Client
     *
     * @package WordPress
     * @since 3.1.0
     */
    #[\AllowDynamicProperties]
    class WP_HTTP_IXR_Client extends \IXR_Client
    {
        public $scheme;
        /**
         * @var IXR_Error
         */
        public $error;
        /**
         * @param string       $server
         * @param string|false $path
         * @param int|false    $port
         * @param int          $timeout
         */
        public function __construct($server, $path = \false, $port = \false, $timeout = 15)
        {
        }
        /**
         * @since 3.1.0
         * @since 5.5.0 Formalized the existing `...$args` parameter by adding it
         *              to the function signature.
         *
         * @return bool
         */
        public function query(...$args)
        {
        }
    }
    /**
     * Core class used to implement HTTP API proxy support.
     *
     * There are caveats to proxy support. It requires that defines be made in the wp-config.php file to
     * enable proxy support. There are also a few filters that plugins can hook into for some of the
     * constants.
     *
     * Please note that only BASIC authentication is supported by most transports.
     * cURL MAY support more methods (such as NTLM authentication) depending on your environment.
     *
     * The constants are as follows:
     * <ol>
     * <li>WP_PROXY_HOST - Enable proxy support and host for connecting.</li>
     * <li>WP_PROXY_PORT - Proxy port for connection. No default, must be defined.</li>
     * <li>WP_PROXY_USERNAME - Proxy username, if it requires authentication.</li>
     * <li>WP_PROXY_PASSWORD - Proxy password, if it requires authentication.</li>
     * <li>WP_PROXY_BYPASS_HOSTS - Will prevent the hosts in this list from going through the proxy.
     * You do not need to have localhost and the site host in this list, because they will not be passed
     * through the proxy. The list should be presented in a comma separated list, wildcards using * are supported. Example: *.wordpress.org</li>
     * </ol>
     *
     * An example can be as seen below.
     *
     *     define('WP_PROXY_HOST', '192.168.84.101');
     *     define('WP_PROXY_PORT', '8080');
     *     define('WP_PROXY_BYPASS_HOSTS', 'localhost, www.example.com, *.wordpress.org');
     *
     * @link https://core.trac.wordpress.org/ticket/4011 Proxy support ticket in WordPress.
     * @link https://core.trac.wordpress.org/ticket/14636 Allow wildcard domains in WP_PROXY_BYPASS_HOSTS
     *
     * @since 2.8.0
     */
    #[\AllowDynamicProperties]
    class WP_HTTP_Proxy
    {
        /**
         * Whether proxy connection should be used.
         *
         * Constants which control this behavior:
         *
         * - `WP_PROXY_HOST`
         * - `WP_PROXY_PORT`
         *
         * @since 2.8.0
         *
         * @return bool
         */
        public function is_enabled()
        {
        }
        /**
         * Whether authentication should be used.
         *
         * Constants which control this behavior:
         *
         * - `WP_PROXY_USERNAME`
         * - `WP_PROXY_PASSWORD`
         *
         * @since 2.8.0
         *
         * @return bool
         */
        public function use_authentication()
        {
        }
        /**
         * Retrieve the host for the proxy server.
         *
         * @since 2.8.0
         *
         * @return string
         */
        public function host()
        {
        }
        /**
         * Retrieve the port for the proxy server.
         *
         * @since 2.8.0
         *
         * @return string
         */
        public function port()
        {
        }
        /**
         * Retrieve the username for proxy authentication.
         *
         * @since 2.8.0
         *
         * @return string
         */
        public function username()
        {
        }
        /**
         * Retrieve the password for proxy authentication.
         *
         * @since 2.8.0
         *
         * @return string
         */
        public function password()
        {
        }
        /**
         * Retrieve authentication string for proxy authentication.
         *
         * @since 2.8.0
         *
         * @return string
         */
        public function authentication()
        {
        }
        /**
         * Retrieve header string for proxy authentication.
         *
         * @since 2.8.0
         *
         * @return string
         */
        public function authentication_header()
        {
        }
        /**
         * Determines whether the request should be sent through a proxy.
         *
         * We want to keep localhost and the site URL from being sent through the proxy, because
         * some proxies can not handle this. We also have the constant available for defining other
         * hosts that won't be sent through the proxy.
         *
         * @since 2.8.0
         *
         * @param string $uri URL of the request.
         * @return bool Whether to send the request through the proxy.
         */
        public function send_through_proxy($uri)
        {
        }
    }
    /**
     * Bridge to connect Requests internal hooks to WordPress actions.
     *
     * @since 4.7.0
     *
     * @see WpOrg\Requests\Hooks
     */
    #[\AllowDynamicProperties]
    class WP_HTTP_Requests_Hooks extends \WpOrg\Requests\Hooks
    {
        /**
         * Requested URL.
         *
         * @var string Requested URL.
         */
        protected $url;
        /**
         * WordPress WP_HTTP request data.
         *
         * @var array Request data in WP_Http format.
         */
        protected $request = array();
        /**
         * Constructor.
         *
         * @param string $url     URL to request.
         * @param array  $request Request data in WP_Http format.
         */
        public function __construct($url, $request)
        {
        }
        /**
         * Dispatch a Requests hook to a native WordPress action.
         *
         * @param string $hook       Hook name.
         * @param array  $parameters Parameters to pass to callbacks.
         * @return bool True if hooks were run, false if nothing was hooked.
         */
        public function dispatch($hook, $parameters = array())
        {
        }
    }
    /**
     * Core class used to prepare HTTP responses.
     *
     * @since 4.4.0
     */
    #[\AllowDynamicProperties]
    class WP_HTTP_Response
    {
        /**
         * Response data.
         *
         * @since 4.4.0
         * @var mixed
         */
        public $data;
        /**
         * Response headers.
         *
         * @since 4.4.0
         * @var array
         */
        public $headers;
        /**
         * Response status.
         *
         * @since 4.4.0
         * @var int
         */
        public $status;
        /**
         * Constructor.
         *
         * @since 4.4.0
         *
         * @param mixed $data    Response data. Default null.
         * @param int   $status  Optional. HTTP status code. Default 200.
         * @param array $headers Optional. HTTP header map. Default empty array.
         */
        public function __construct($data = \null, $status = 200, $headers = array())
        {
        }
        /**
         * Retrieves headers associated with the response.
         *
         * @since 4.4.0
         *
         * @return array Map of header name to header value.
         */
        public function get_headers()
        {
        }
        /**
         * Sets all header values.
         *
         * @since 4.4.0
         *
         * @param array $headers Map of header name to header value.
         */
        public function set_headers($headers)
        {
        }
        /**
         * Sets a single HTTP header.
         *
         * @since 4.4.0
         *
         * @param string $key     Header name.
         * @param string $value   Header value.
         * @param bool   $replace Optional. Whether to replace an existing header of the same name.
         *                        Default true.
         */
        public function header($key, $value, $replace = \true)
        {
        }
        /**
         * Retrieves the HTTP return code for the response.
         *
         * @since 4.4.0
         *
         * @return int The 3-digit HTTP status code.
         */
        public function get_status()
        {
        }
        /**
         * Sets the 3-digit HTTP status code.
         *
         * @since 4.4.0
         *
         * @param int $code HTTP status.
         */
        public function set_status($code)
        {
        }
        /**
         * Retrieves the response data.
         *
         * @since 4.4.0
         *
         * @return mixed Response data.
         */
        public function get_data()
        {
        }
        /**
         * Sets the response data.
         *
         * @since 4.4.0
         *
         * @param mixed $data Response data.
         */
        public function set_data($data)
        {
        }
        /**
         * Retrieves the response data for JSON serialization.
         *
         * It is expected that in most implementations, this will return the same as get_data(),
         * however this may be different if you want to do custom JSON data handling.
         *
         * @since 4.4.0
         *
         * @return mixed Any JSON-serializable value.
         */
        public function jsonSerialize()
        {
        }
    }
    /**
     * Core wrapper object for a WpOrg\Requests\Response for standardization.
     *
     * @since 4.6.0
     *
     * @see WP_HTTP_Response
     */
    class WP_HTTP_Requests_Response extends \WP_HTTP_Response
    {
        /**
         * Requests Response object.
         *
         * @since 4.6.0
         * @var \WpOrg\Requests\Response
         */
        protected $response;
        /**
         * Filename the response was saved to.
         *
         * @since 4.6.0
         * @var string|null
         */
        protected $filename;
        /**
         * Constructor.
         *
         * @since 4.6.0
         *
         * @param \WpOrg\Requests\Response $response HTTP response.
         * @param string                   $filename Optional. File name. Default empty.
         */
        public function __construct(\WpOrg\Requests\Response $response, $filename = '')
        {
        }
        /**
         * Retrieves the response object for the request.
         *
         * @since 4.6.0
         *
         * @return WpOrg\Requests\Response HTTP response.
         */
        public function get_response_object()
        {
        }
        /**
         * Retrieves headers associated with the response.
         *
         * @since 4.6.0
         *
         * @return \WpOrg\Requests\Utility\CaseInsensitiveDictionary Map of header name to header value.
         */
        public function get_headers()
        {
        }
        /**
         * Sets all header values.
         *
         * @since 4.6.0
         *
         * @param array $headers Map of header name to header value.
         */
        public function set_headers($headers)
        {
        }
        /**
         * Sets a single HTTP header.
         *
         * @since 4.6.0
         *
         * @param string $key     Header name.
         * @param string $value   Header value.
         * @param bool   $replace Optional. Whether to replace an existing header of the same name.
         *                        Default true.
         */
        public function header($key, $value, $replace = \true)
        {
        }
        /**
         * Retrieves the HTTP return code for the response.
         *
         * @since 4.6.0
         *
         * @return int The 3-digit HTTP status code.
         */
        public function get_status()
        {
        }
        /**
         * Sets the 3-digit HTTP status code.
         *
         * @since 4.6.0
         *
         * @param int $code HTTP status.
         */
        public function set_status($code)
        {
        }
        /**
         * Retrieves the response data.
         *
         * @since 4.6.0
         *
         * @return string Response data.
         */
        public function get_data()
        {
        }
        /**
         * Sets the response data.
         *
         * @since 4.6.0
         *
         * @param string $data Response data.
         */
        public function set_data($data)
        {
        }
        /**
         * Retrieves cookies from the response.
         *
         * @since 4.6.0
         *
         * @return WP_HTTP_Cookie[] List of cookie objects.
         */
        public function get_cookies()
        {
        }
        /**
         * Converts the object to a WP_Http response array.
         *
         * @since 4.6.0
         *
         * @return array WP_Http response array, per WP_Http::request().
         */
        public function to_array()
        {
        }
    }
    /**
     * Core class used to integrate PHP Streams as an HTTP transport.
     *
     * @since 2.7.0
     * @since 3.7.0 Combined with the fsockopen transport and switched to `stream_socket_client()`.
     * @deprecated 6.4.0 Use WP_Http
     * @see WP_Http
     */
    #[\AllowDynamicProperties]
    class WP_Http_Streams
    {
        /**
         * Send a HTTP request to a URI using PHP Streams.
         *
         * @see WP_Http::request() For default options descriptions.
         *
         * @since 2.7.0
         * @since 3.7.0 Combined with the fsockopen transport and switched to stream_socket_client().
         *
         * @param string       $url  The request URL.
         * @param string|array $args Optional. Override the defaults.
         * @return array|WP_Error Array containing 'headers', 'body', 'response', 'cookies', 'filename'. A WP_Error instance upon error
         */
        public function request($url, $args = array())
        {
        }
        /**
         * Verifies the received SSL certificate against its Common Names and subjectAltName fields.
         *
         * PHP's SSL verifications only verify that it's a valid Certificate, it doesn't verify if
         * the certificate is valid for the hostname which was requested.
         * This function verifies the requested hostname against certificate's subjectAltName field,
         * if that is empty, or contains no DNS entries, a fallback to the Common Name field is used.
         *
         * IP Address support is included if the request is being made to an IP address.
         *
         * @since 3.7.0
         *
         * @param resource $stream The PHP Stream which the SSL request is being made over
         * @param string   $host   The hostname being requested
         * @return bool If the certificate presented in $stream is valid for $host
         */
        public static function verify_ssl_certificate($stream, $host)
        {
        }
        /**
         * Determines whether this class can be used for retrieving a URL.
         *
         * @since 2.7.0
         * @since 3.7.0 Combined with the fsockopen transport and switched to stream_socket_client().
         *
         * @param array $args Optional. Array of request arguments. Default empty array.
         * @return bool False means this class can not be used, true means it can.
         */
        public static function test($args = array())
        {
        }
    }
    /**
     * Deprecated HTTP Transport method which used fsockopen.
     *
     * This class is not used, and is included for backward compatibility only.
     * All code should make use of WP_Http directly through its API.
     *
     * @see WP_HTTP::request
     *
     * @since 2.7.0
     * @deprecated 3.7.0 Please use WP_HTTP::request() directly
     */
    class WP_HTTP_Fsockopen extends \WP_Http_Streams
    {
        // For backward compatibility for users who are using the class directly.
    }
    /**
     * Core class used for managing HTTP transports and making HTTP requests.
     *
     * This class is used to consistently make outgoing HTTP requests easy for developers
     * while still being compatible with the many PHP configurations under which
     * WordPress runs.
     *
     * Debugging includes several actions, which pass different variables for debugging the HTTP API.
     *
     * @since 2.7.0
     */
    #[\AllowDynamicProperties]
    class WP_Http
    {
        // Aliases for HTTP response codes.
        const HTTP_CONTINUE = 100;
        const SWITCHING_PROTOCOLS = 101;
        const PROCESSING = 102;
        const EARLY_HINTS = 103;
        const OK = 200;
        const CREATED = 201;
        const ACCEPTED = 202;
        const NON_AUTHORITATIVE_INFORMATION = 203;
        const NO_CONTENT = 204;
        const RESET_CONTENT = 205;
        const PARTIAL_CONTENT = 206;
        const MULTI_STATUS = 207;
        const IM_USED = 226;
        const MULTIPLE_CHOICES = 300;
        const MOVED_PERMANENTLY = 301;
        const FOUND = 302;
        const SEE_OTHER = 303;
        const NOT_MODIFIED = 304;
        const USE_PROXY = 305;
        const RESERVED = 306;
        const TEMPORARY_REDIRECT = 307;
        const PERMANENT_REDIRECT = 308;
        const BAD_REQUEST = 400;
        const UNAUTHORIZED = 401;
        const PAYMENT_REQUIRED = 402;
        const FORBIDDEN = 403;
        const NOT_FOUND = 404;
        const METHOD_NOT_ALLOWED = 405;
        const NOT_ACCEPTABLE = 406;
        const PROXY_AUTHENTICATION_REQUIRED = 407;
        const REQUEST_TIMEOUT = 408;
        const CONFLICT = 409;
        const GONE = 410;
        const LENGTH_REQUIRED = 411;
        const PRECONDITION_FAILED = 412;
        const REQUEST_ENTITY_TOO_LARGE = 413;
        const REQUEST_URI_TOO_LONG = 414;
        const UNSUPPORTED_MEDIA_TYPE = 415;
        const REQUESTED_RANGE_NOT_SATISFIABLE = 416;
        const EXPECTATION_FAILED = 417;
        const IM_A_TEAPOT = 418;
        const MISDIRECTED_REQUEST = 421;
        const UNPROCESSABLE_ENTITY = 422;
        const LOCKED = 423;
        const FAILED_DEPENDENCY = 424;
        const TOO_EARLY = 425;
        const UPGRADE_REQUIRED = 426;
        const PRECONDITION_REQUIRED = 428;
        const TOO_MANY_REQUESTS = 429;
        const REQUEST_HEADER_FIELDS_TOO_LARGE = 431;
        const UNAVAILABLE_FOR_LEGAL_REASONS = 451;
        const INTERNAL_SERVER_ERROR = 500;
        const NOT_IMPLEMENTED = 501;
        const BAD_GATEWAY = 502;
        const SERVICE_UNAVAILABLE = 503;
        const GATEWAY_TIMEOUT = 504;
        const HTTP_VERSION_NOT_SUPPORTED = 505;
        const VARIANT_ALSO_NEGOTIATES = 506;
        const INSUFFICIENT_STORAGE = 507;
        const NOT_EXTENDED = 510;
        const NETWORK_AUTHENTICATION_REQUIRED = 511;
        /**
         * Send an HTTP request to a URI.
         *
         * Please note: The only URI that are supported in the HTTP Transport implementation
         * are the HTTP and HTTPS protocols.
         *
         * @since 2.7.0
         *
         * @param string       $url  The request URL.
         * @param string|array $args {
         *     Optional. Array or string of HTTP request arguments.
         *
         *     @type string       $method              Request method. Accepts 'GET', 'POST', 'HEAD', 'PUT', 'DELETE',
         *                                             'TRACE', 'OPTIONS', or 'PATCH'.
         *                                             Some transports technically allow others, but should not be
         *                                             assumed. Default 'GET'.
         *     @type float        $timeout             How long the connection should stay open in seconds. Default 5.
         *     @type int          $redirection         Number of allowed redirects. Not supported by all transports.
         *                                             Default 5.
         *     @type string       $httpversion         Version of the HTTP protocol to use. Accepts '1.0' and '1.1'.
         *                                             Default '1.0'.
         *     @type string       $user-agent          User-agent value sent.
         *                                             Default 'WordPress/' . get_bloginfo( 'version' ) . '; ' . get_bloginfo( 'url' ).
         *     @type bool         $reject_unsafe_urls  Whether to pass URLs through wp_http_validate_url().
         *                                             Default false.
         *     @type bool         $blocking            Whether the calling code requires the result of the request.
         *                                             If set to false, the request will be sent to the remote server,
         *                                             and processing returned to the calling code immediately, the caller
         *                                             will know if the request succeeded or failed, but will not receive
         *                                             any response from the remote server. Default true.
         *     @type string|array $headers             Array or string of headers to send with the request.
         *                                             Default empty array.
         *     @type array        $cookies             List of cookies to send with the request. Default empty array.
         *     @type string|array $body                Body to send with the request. Default null.
         *     @type bool         $compress            Whether to compress the $body when sending the request.
         *                                             Default false.
         *     @type bool         $decompress          Whether to decompress a compressed response. If set to false and
         *                                             compressed content is returned in the response anyway, it will
         *                                             need to be separately decompressed. Default true.
         *     @type bool         $sslverify           Whether to verify SSL for the request. Default true.
         *     @type string       $sslcertificates     Absolute path to an SSL certificate .crt file.
         *                                             Default ABSPATH . WPINC . '/certificates/ca-bundle.crt'.
         *     @type bool         $stream              Whether to stream to a file. If set to true and no filename was
         *                                             given, it will be dropped it in the WP temp dir and its name will
         *                                             be set using the basename of the URL. Default false.
         *     @type string       $filename            Filename of the file to write to when streaming. $stream must be
         *                                             set to true. Default null.
         *     @type int          $limit_response_size Size in bytes to limit the response to. Default null.
         *
         * }
         * @return array|WP_Error {
         *     Array of response data, or a WP_Error instance upon error.
         *
         *     @type \WpOrg\Requests\Utility\CaseInsensitiveDictionary $headers       Response headers keyed by name.
         *     @type string                                            $body          Response body.
         *     @type array                                             $response      {
         *         Array of HTTP response data.
         *
         *         @type int|false    $code    HTTP response status code.
         *         @type string|false $message HTTP response message.
         *     }
         *     @type WP_HTTP_Cookie[]                                  $cookies       Array of cookies set by the server.
         *     @type string|null                                       $filename      Optional. Filename of the response.
         *     @type WP_HTTP_Requests_Response|null                    $http_response Response object.
         * }
         * @phpstan-param array{
         *   method?: string,
         *   timeout?: float,
         *   redirection?: int,
         *   httpversion?: string,
         *   user-agent?: string,
         *   reject_unsafe_urls?: bool,
         *   blocking?: bool,
         *   headers?: string|array,
         *   cookies?: array,
         *   body?: string|array,
         *   compress?: bool,
         *   decompress?: bool,
         *   sslverify?: bool,
         *   sslcertificates?: string,
         *   stream?: bool,
         *   filename?: string,
         *   limit_response_size?: int,
         * } $args
         * @phpstan-return \WP_Error|array{
         *   headers: \WpOrg\Requests\Utility\CaseInsensitiveDictionary,
         *   body: string,
         *   response: array{
         *     code: int|false,
         *     message: string|false,
         *   },
         *   cookies: WP_HTTP_Cookie[],
         *   filename: string|null,
         *   http_response: WP_HTTP_Requests_Response|null,
         * }
         * @phpstan-return array{headers: \WpOrg\Requests\Utility\CaseInsensitiveDictionary, body: string, response: array{code: int, message: string}, cookies: array<int, \WP_Http_Cookie>, filename: string|null, http_response: \WP_HTTP_Requests_Response}|\WP_Error
         */
        public function request($url, $args = array())
        {
        }
        /**
         * Normalizes cookies for using in Requests.
         *
         * @since 4.6.0
         *
         * @param array $cookies Array of cookies to send with the request.
         * @return WpOrg\Requests\Cookie\Jar Cookie holder object.
         */
        public static function normalize_cookies($cookies)
        {
        }
        /**
         * Match redirect behavior to browser handling.
         *
         * Changes 302 redirects from POST to GET to match browser handling. Per
         * RFC 7231, user agents can deviate from the strict reading of the
         * specification for compatibility purposes.
         *
         * @since 4.6.0
         *
         * @param string                  $location URL to redirect to.
         * @param array                   $headers  Headers for the redirect.
         * @param string|array            $data     Body to send with the request.
         * @param array                   $options  Redirect request options.
         * @param WpOrg\Requests\Response $original Response object.
         */
        public static function browser_redirect_compatibility($location, $headers, $data, &$options, $original)
        {
        }
        /**
         * Validate redirected URLs.
         *
         * @since 4.7.5
         *
         * @throws WpOrg\Requests\Exception On unsuccessful URL validation.
         * @param string $location URL to redirect to.
         */
        public static function validate_redirects($location)
        {
        }
        /**
         * Tests which transports are capable of supporting the request.
         *
         * @since 3.2.0
         * @deprecated 6.4.0 Use WpOrg\Requests\Requests::get_transport_class()
         * @see WpOrg\Requests\Requests::get_transport_class()
         *
         * @param array  $args Request arguments.
         * @param string $url  URL to request.
         * @return string|false Class name for the first transport that claims to support the request.
         *                      False if no transport claims to support the request.
         */
        public function _get_first_available_transport($args, $url = \null)
        {
        }
        /**
         * Uses the POST HTTP method.
         *
         * Used for sending data that is expected to be in the body.
         *
         * @since 2.7.0
         *
         * @param string       $url  The request URL.
         * @param string|array $args Optional. Override the defaults.
         * @return array|WP_Error Array containing 'headers', 'body', 'response', 'cookies', 'filename'.
         *                        A WP_Error instance upon error. See WP_Http::response() for details.
         * @phpstan-return array{headers: \WpOrg\Requests\Utility\CaseInsensitiveDictionary, body: string, response: array{code: int, message: string}, cookies: array<int, \WP_Http_Cookie>, filename: string|null, http_response: \WP_HTTP_Requests_Response}|\WP_Error
         */
        public function post($url, $args = array())
        {
        }
        /**
         * Uses the GET HTTP method.
         *
         * Used for sending data that is expected to be in the body.
         *
         * @since 2.7.0
         *
         * @param string       $url  The request URL.
         * @param string|array $args Optional. Override the defaults.
         * @return array|WP_Error Array containing 'headers', 'body', 'response', 'cookies', 'filename'.
         *                        A WP_Error instance upon error. See WP_Http::response() for details.
         * @phpstan-return array{headers: \WpOrg\Requests\Utility\CaseInsensitiveDictionary, body: string, response: array{code: int, message: string}, cookies: array<int, \WP_Http_Cookie>, filename: string|null, http_response: \WP_HTTP_Requests_Response}|\WP_Error
         */
        public function get($url, $args = array())
        {
        }
        /**
         * Uses the HEAD HTTP method.
         *
         * Used for sending data that is expected to be in the body.
         *
         * @since 2.7.0
         *
         * @param string       $url  The request URL.
         * @param string|array $args Optional. Override the defaults.
         * @return array|WP_Error Array containing 'headers', 'body', 'response', 'cookies', 'filename'.
         *                        A WP_Error instance upon error. See WP_Http::response() for details.
         * @phpstan-return array{headers: \WpOrg\Requests\Utility\CaseInsensitiveDictionary, body: string, response: array{code: int, message: string}, cookies: array<int, \WP_Http_Cookie>, filename: string|null, http_response: \WP_HTTP_Requests_Response}|\WP_Error
         */
        public function head($url, $args = array())
        {
        }
        /**
         * Parses the responses and splits the parts into headers and body.
         *
         * @since 2.7.0
         *
         * @param string $response The full response string.
         * @return array {
         *     Array with response headers and body.
         *
         *     @type string $headers HTTP response headers.
         *     @type string $body    HTTP response body.
         * }
         * @phpstan-return array{
         *   headers: string,
         *   body: string,
         * }
         */
        public static function processResponse($response)
        {
        }
        /**
         * Transforms header string into an array.
         *
         * @since 2.7.0
         *
         * @param string|array $headers The original headers. If a string is passed, it will be converted
         *                              to an array. If an array is passed, then it is assumed to be
         *                              raw header data with numeric keys with the headers as the values.
         *                              No headers must be passed that were already processed.
         * @param string       $url     Optional. The URL that was requested. Default empty.
         * @return array {
         *     Processed string headers. If duplicate headers are encountered,
         *     then a numbered array is returned as the value of that header-key.
         *
         *     @type array            $response {
         *         @type int    $code    The response status code. Default 0.
         *         @type string $message The response message. Default empty.
         *     }
         *     @type array            $newheaders The processed header data as a multidimensional array.
         *     @type WP_Http_Cookie[] $cookies    If the original headers contain the 'Set-Cookie' key,
         *                                        an array containing `WP_Http_Cookie` objects is returned.
         * }
         * @phpstan-return array{
         *   response: array{
         *     code: int,
         *     message: string,
         *   },
         *   newheaders: array,
         *   cookies: WP_Http_Cookie[],
         * }
         */
        public static function processHeaders($headers, $url = '')
        {
        }
        /**
         * Takes the arguments for a ::request() and checks for the cookie array.
         *
         * If it's found, then it upgrades any basic name => value pairs to WP_Http_Cookie instances,
         * which are each parsed into strings and added to the Cookie: header (within the arguments array).
         * Edits the array by reference.
         *
         * @since 2.8.0
         *
         * @param array $r Full array of args passed into ::request()
         */
        public static function buildCookieHeader(&$r)
        {
        }
        /**
         * Decodes chunk transfer-encoding, based off the HTTP 1.1 specification.
         *
         * Based off the HTTP http_encoding_dechunk function.
         *
         * @link https://tools.ietf.org/html/rfc2616#section-19.4.6 Process for chunked decoding.
         *
         * @since 2.7.0
         *
         * @param string $body Body content.
         * @return string Chunked decoded body on success or raw body on failure.
         */
        public static function chunkTransferDecode($body)
        {
        }
        /**
         * Determines whether an HTTP API request to the given URL should be blocked.
         *
         * Those who are behind a proxy and want to prevent access to certain hosts may do so. This will
         * prevent plugins from working and core functionality, if you don't include `api.wordpress.org`.
         *
         * You block external URL requests by defining `WP_HTTP_BLOCK_EXTERNAL` as true in your `wp-config.php`
         * file and this will only allow localhost and your site to make requests. The constant
         * `WP_ACCESSIBLE_HOSTS` will allow additional hosts to go through for requests. The format of the
         * `WP_ACCESSIBLE_HOSTS` constant is a comma separated list of hostnames to allow, wildcard domains
         * are supported, eg `*.wordpress.org` will allow for all subdomains of `wordpress.org` to be contacted.
         *
         * @since 2.8.0
         *
         * @link https://core.trac.wordpress.org/ticket/8927 Allow preventing external requests.
         * @link https://core.trac.wordpress.org/ticket/14636 Allow wildcard domains in WP_ACCESSIBLE_HOSTS
         *
         * @param string $uri URI of url.
         * @return bool True to block, false to allow.
         */
        public function block_request($uri)
        {
        }
        /**
         * Used as a wrapper for PHP's parse_url() function that handles edgecases in < PHP 5.4.7.
         *
         * @deprecated 4.4.0 Use wp_parse_url()
         * @see wp_parse_url()
         *
         * @param string $url The URL to parse.
         * @return bool|array False on failure; Array of URL components on success;
         *                    See parse_url()'s return values.
         */
        protected static function parse_url($url)
        {
        }
        /**
         * Converts a relative URL to an absolute URL relative to a given URL.
         *
         * If an Absolute URL is provided, no processing of that URL is done.
         *
         * @since 3.4.0
         *
         * @param string $maybe_relative_path The URL which might be relative.
         * @param string $url                 The URL which $maybe_relative_path is relative to.
         * @return string An Absolute URL, in a failure condition where the URL cannot be parsed, the relative URL will be returned.
         */
        public static function make_absolute_url($maybe_relative_path, $url)
        {
        }
        /**
         * Handles an HTTP redirect and follows it if appropriate.
         *
         * @since 3.7.0
         *
         * @param string $url      The URL which was requested.
         * @param array  $args     The arguments which were used to make the request.
         * @param array  $response The response of the HTTP request.
         * @return array|false|WP_Error An HTTP API response array if the redirect is successfully followed,
         *                              false if no redirect is present, or a WP_Error object if there's an error.
         */
        public static function handle_redirects($url, $args, $response)
        {
        }
        /**
         * Determines if a specified string represents an IP address or not.
         *
         * This function also detects the type of the IP address, returning either
         * '4' or '6' to represent an IPv4 and IPv6 address respectively.
         * This does not verify if the IP is a valid IP, only that it appears to be
         * an IP address.
         *
         * @link http://home.deds.nl/~aeron/regex/ for IPv6 regex.
         *
         * @since 3.7.0
         *
         * @param string $maybe_ip A suspected IP address.
         * @return int|false Upon success, '4' or '6' to represent an IPv4 or IPv6 address, false upon failure.
         */
        public static function is_ip_address($maybe_ip)
        {
        }
    }
    /**
     * Base image editor class from which implementations extend
     *
     * @since 3.5.0
     */
    #[\AllowDynamicProperties]
    abstract class WP_Image_Editor
    {
        protected $file = \null;
        protected $size = \null;
        protected $mime_type = \null;
        protected $output_mime_type = \null;
        protected $default_mime_type = 'image/jpeg';
        protected $quality = \false;
        protected $default_quality = 82;
        /**
         * Each instance handles a single file.
         *
         * @param string $file Path to the file to load.
         */
        public function __construct($file)
        {
        }
        /**
         * Checks to see if current environment supports the editor chosen.
         * Must be overridden in a subclass.
         *
         * @since 3.5.0
         *
         * @abstract
         *
         * @param array $args
         * @return bool
         */
        public static function test($args = array())
        {
        }
        /**
         * Checks to see if editor supports the mime-type specified.
         * Must be overridden in a subclass.
         *
         * @since 3.5.0
         *
         * @abstract
         *
         * @param string $mime_type
         * @return bool
         */
        public static function supports_mime_type($mime_type)
        {
        }
        /**
         * Loads image from $this->file into editor.
         *
         * @since 3.5.0
         * @abstract
         *
         * @return true|WP_Error True if loaded; WP_Error on failure.
         */
        public abstract function load();
        /**
         * Saves current image to file.
         *
         * @since 3.5.0
         * @since 6.0.0 The `$filesize` value was added to the returned array.
         * @abstract
         *
         * @param string $destfilename Optional. Destination filename. Default null.
         * @param string $mime_type    Optional. The mime-type. Default null.
         * @return array|WP_Error {
         *     Array on success or WP_Error if the file failed to save.
         *
         *     @type string $path      Path to the image file.
         *     @type string $file      Name of the image file.
         *     @type int    $width     Image width.
         *     @type int    $height    Image height.
         *     @type string $mime-type The mime type of the image.
         *     @type int    $filesize  File size of the image.
         * }
         * @phpstan-return \WP_Error|array{
         *   path: string,
         *   file: string,
         *   width: int,
         *   height: int,
         *   mime-type: string,
         *   filesize: int,
         * }
         */
        public abstract function save($destfilename = \null, $mime_type = \null);
        /**
         * Resizes current image.
         *
         * At minimum, either a height or width must be provided.
         * If one of the two is set to null, the resize will
         * maintain aspect ratio according to the provided dimension.
         *
         * @since 3.5.0
         * @abstract
         *
         * @param int|null   $max_w Image width.
         * @param int|null   $max_h Image height.
         * @param bool|array $crop  {
         *     Optional. Image cropping behavior. If false, the image will be scaled (default).
         *     If true, image will be cropped to the specified dimensions using center positions.
         *     If an array, the image will be cropped using the array to specify the crop location:
         *
         *     @type string $0 The x crop position. Accepts 'left' 'center', or 'right'.
         *     @type string $1 The y crop position. Accepts 'top', 'center', or 'bottom'.
         * }
         * @return true|WP_Error
         * @phpstan-param bool|array{
         *   0: string,
         *   1: string,
         * } $crop
         */
        public abstract function resize($max_w, $max_h, $crop = \false);
        /**
         * Resize multiple images from a single source.
         *
         * @since 3.5.0
         * @abstract
         *
         * @param array $sizes {
         *     An array of image size arrays. Default sizes are 'small', 'medium', 'large'.
         *
         *     @type array ...$0 {
         *         @type int        $width  Image width.
         *         @type int        $height Image height.
         *         @type bool|array $crop   Optional. Whether to crop the image. Default false.
         *     }
         * }
         * @return array An array of resized images metadata by size.
         * @phpstan-param array<int|string, array{
         *   width: int,
         *   height: int,
         *   crop?: bool|array,
         * }> $sizes
         */
        public abstract function multi_resize($sizes);
        /**
         * Crops Image.
         *
         * @since 3.5.0
         * @abstract
         *
         * @param int  $src_x   The start x position to crop from.
         * @param int  $src_y   The start y position to crop from.
         * @param int  $src_w   The width to crop.
         * @param int  $src_h   The height to crop.
         * @param int  $dst_w   Optional. The destination width.
         * @param int  $dst_h   Optional. The destination height.
         * @param bool $src_abs Optional. If the source crop points are absolute.
         * @return true|WP_Error
         */
        public abstract function crop($src_x, $src_y, $src_w, $src_h, $dst_w = \null, $dst_h = \null, $src_abs = \false);
        /**
         * Rotates current image counter-clockwise by $angle.
         *
         * @since 3.5.0
         * @abstract
         *
         * @param float $angle
         * @return true|WP_Error
         */
        public abstract function rotate($angle);
        /**
         * Flips current image.
         *
         * @since 3.5.0
         * @abstract
         *
         * @param bool $horz Flip along Horizontal Axis
         * @param bool $vert Flip along Vertical Axis
         * @return true|WP_Error
         */
        public abstract function flip($horz, $vert);
        /**
         * Streams current image to browser.
         *
         * @since 3.5.0
         * @abstract
         *
         * @param string $mime_type The mime type of the image.
         * @return true|WP_Error True on success, WP_Error object on failure.
         */
        public abstract function stream($mime_type = \null);
        /**
         * Gets dimensions of image.
         *
         * @since 3.5.0
         *
         * @return int[] {
         *     Dimensions of the image.
         *
         *     @type int $width  The image width.
         *     @type int $height The image height.
         * }
         * @phpstan-return array{
         *   width: int,
         *   height: int,
         * }
         */
        public function get_size()
        {
        }
        /**
         * Sets current image size.
         *
         * @since 3.5.0
         *
         * @param int $width
         * @param int $height
         * @return true
         */
        protected function update_size($width = \null, $height = \null)
        {
        }
        /**
         * Gets the Image Compression quality on a 1-100% scale.
         *
         * @since 4.0.0
         *
         * @return int Compression Quality. Range: [1,100]
         */
        public function get_quality()
        {
        }
        /**
         * Sets Image Compression quality on a 1-100% scale.
         *
         * @since 3.5.0
         *
         * @param int $quality Compression Quality. Range: [1,100]
         * @return true|WP_Error True if set successfully; WP_Error on failure.
         */
        public function set_quality($quality = \null)
        {
        }
        /**
         * Returns the default compression quality setting for the mime type.
         *
         * @since 5.8.1
         *
         * @param string $mime_type
         * @return int The default quality setting for the mime type.
         */
        protected function get_default_quality($mime_type)
        {
        }
        /**
         * Returns preferred mime-type and extension based on provided
         * file's extension and mime, or current file's extension and mime.
         *
         * Will default to $this->default_mime_type if requested is not supported.
         *
         * Provides corrected filename only if filename is provided.
         *
         * @since 3.5.0
         *
         * @param string $filename
         * @param string $mime_type
         * @return array { filename|null, extension, mime-type }
         */
        protected function get_output_format($filename = \null, $mime_type = \null)
        {
        }
        /**
         * Builds an output filename based on current file, and adding proper suffix
         *
         * @since 3.5.0
         *
         * @param string $suffix
         * @param string $dest_path
         * @param string $extension
         * @return string filename
         */
        public function generate_filename($suffix = \null, $dest_path = \null, $extension = \null)
        {
        }
        /**
         * Builds and returns proper suffix for file based on height and width.
         *
         * @since 3.5.0
         *
         * @return string|false suffix
         */
        public function get_suffix()
        {
        }
        /**
         * Check if a JPEG image has EXIF Orientation tag and rotate it if needed.
         *
         * @since 5.3.0
         *
         * @return bool|WP_Error True if the image was rotated. False if not rotated (no EXIF data or the image doesn't need to be rotated).
         *                       WP_Error if error while rotating.
         */
        public function maybe_exif_rotate()
        {
        }
        /**
         * Either calls editor's save function or handles file as a stream.
         *
         * @since 3.5.0
         *
         * @param string   $filename
         * @param callable $callback
         * @param array    $arguments
         * @return bool
         */
        protected function make_image($filename, $callback, $arguments)
        {
        }
        /**
         * Returns first matched mime-type from extension,
         * as mapped from wp_get_mime_types()
         *
         * @since 3.5.0
         *
         * @param string $extension
         * @return string|false
         */
        protected static function get_mime_type($extension = \null)
        {
        }
        /**
         * Returns first matched extension from Mime-type,
         * as mapped from wp_get_mime_types()
         *
         * @since 3.5.0
         *
         * @param string $mime_type
         * @return string|false
         */
        protected static function get_extension($mime_type = \null)
        {
        }
    }
    /**
     * WordPress Image Editor Class for Image Manipulation through GD
     *
     * @since 3.5.0
     *
     * @see WP_Image_Editor
     */
    class WP_Image_Editor_GD extends \WP_Image_Editor
    {
        /**
         * GD Resource.
         *
         * @var resource|GdImage
         */
        protected $image;
        public function __destruct()
        {
        }
        /**
         * Checks to see if current environment supports GD.
         *
         * @since 3.5.0
         *
         * @param array $args
         * @return bool
         */
        public static function test($args = array())
        {
        }
        /**
         * Checks to see if editor supports the mime-type specified.
         *
         * @since 3.5.0
         *
         * @param string $mime_type
         * @return bool
         */
        public static function supports_mime_type($mime_type)
        {
        }
        /**
         * Loads image from $this->file into new GD Resource.
         *
         * @since 3.5.0
         *
         * @return true|WP_Error True if loaded successfully; WP_Error on failure.
         */
        public function load()
        {
        }
        /**
         * Sets or updates current image size.
         *
         * @since 3.5.0
         *
         * @param int $width
         * @param int $height
         * @return true
         */
        protected function update_size($width = \false, $height = \false)
        {
        }
        /**
         * Resizes current image.
         *
         * Wraps `::_resize()` which returns a GD resource or GdImage instance.
         *
         * At minimum, either a height or width must be provided. If one of the two is set
         * to null, the resize will maintain aspect ratio according to the provided dimension.
         *
         * @since 3.5.0
         *
         * @param int|null   $max_w Image width.
         * @param int|null   $max_h Image height.
         * @param bool|array $crop  {
         *     Optional. Image cropping behavior. If false, the image will be scaled (default).
         *     If true, image will be cropped to the specified dimensions using center positions.
         *     If an array, the image will be cropped using the array to specify the crop location:
         *
         *     @type string $0 The x crop position. Accepts 'left' 'center', or 'right'.
         *     @type string $1 The y crop position. Accepts 'top', 'center', or 'bottom'.
         * }
         * @return true|WP_Error
         * @phpstan-param bool|array{
         *   0: string,
         *   1: string,
         * } $crop
         */
        public function resize($max_w, $max_h, $crop = \false)
        {
        }
        /**
         * @param int        $max_w
         * @param int        $max_h
         * @param bool|array $crop  {
         *     Optional. Image cropping behavior. If false, the image will be scaled (default).
         *     If true, image will be cropped to the specified dimensions using center positions.
         *     If an array, the image will be cropped using the array to specify the crop location:
         *
         *     @type string $0 The x crop position. Accepts 'left' 'center', or 'right'.
         *     @type string $1 The y crop position. Accepts 'top', 'center', or 'bottom'.
         * }
         * @return resource|GdImage|WP_Error
         * @phpstan-param bool|array{
         *   0: string,
         *   1: string,
         * } $crop
         */
        protected function _resize($max_w, $max_h, $crop = \false)
        {
        }
        /**
         * Create multiple smaller images from a single source.
         *
         * Attempts to create all sub-sizes and returns the meta data at the end. This
         * may result in the server running out of resources. When it fails there may be few
         * "orphaned" images left over as the meta data is never returned and saved.
         *
         * As of 5.3.0 the preferred way to do this is with `make_subsize()`. It creates
         * the new images one at a time and allows for the meta data to be saved after
         * each new image is created.
         *
         * @since 3.5.0
         *
         * @param array $sizes {
         *     An array of image size data arrays.
         *
         *     Either a height or width must be provided.
         *     If one of the two is set to null, the resize will
         *     maintain aspect ratio according to the source image.
         *
         *     @type array ...$0 {
         *         Array of height, width values, and whether to crop.
         *
         *         @type int        $width  Image width. Optional if `$height` is specified.
         *         @type int        $height Image height. Optional if `$width` is specified.
         *         @type bool|array $crop   Optional. Whether to crop the image. Default false.
         *     }
         * }
         * @return array An array of resized images' metadata by size.
         * @phpstan-param array<int|string, array{
         *   width?: int,
         *   height?: int,
         *   crop?: bool|array,
         * }> $sizes
         */
        public function multi_resize($sizes)
        {
        }
        /**
         * Create an image sub-size and return the image meta data value for it.
         *
         * @since 5.3.0
         *
         * @param array $size_data {
         *     Array of size data.
         *
         *     @type int        $width  The maximum width in pixels.
         *     @type int        $height The maximum height in pixels.
         *     @type bool|array $crop   Whether to crop the image to exact dimensions.
         * }
         * @return array|WP_Error The image data array for inclusion in the `sizes` array in the image meta,
         *                        WP_Error object on error.
         * @phpstan-param array{
         *   width?: int,
         *   height?: int,
         *   crop?: bool|array,
         * } $size_data
         */
        public function make_subsize($size_data)
        {
        }
        /**
         * Crops Image.
         *
         * @since 3.5.0
         *
         * @param int  $src_x   The start x position to crop from.
         * @param int  $src_y   The start y position to crop from.
         * @param int  $src_w   The width to crop.
         * @param int  $src_h   The height to crop.
         * @param int  $dst_w   Optional. The destination width.
         * @param int  $dst_h   Optional. The destination height.
         * @param bool $src_abs Optional. If the source crop points are absolute.
         * @return true|WP_Error
         */
        public function crop($src_x, $src_y, $src_w, $src_h, $dst_w = \null, $dst_h = \null, $src_abs = \false)
        {
        }
        /**
         * Rotates current image counter-clockwise by $angle.
         * Ported from image-edit.php
         *
         * @since 3.5.0
         *
         * @param float $angle
         * @return true|WP_Error
         */
        public function rotate($angle)
        {
        }
        /**
         * Flips current image.
         *
         * @since 3.5.0
         *
         * @param bool $horz Flip along Horizontal Axis.
         * @param bool $vert Flip along Vertical Axis.
         * @return true|WP_Error
         */
        public function flip($horz, $vert)
        {
        }
        /**
         * Saves current in-memory image to file.
         *
         * @since 3.5.0
         * @since 5.9.0 Renamed `$filename` to `$destfilename` to match parent class
         *              for PHP 8 named parameter support.
         * @since 6.0.0 The `$filesize` value was added to the returned array.
         *
         * @param string|null $destfilename Optional. Destination filename. Default null.
         * @param string|null $mime_type    Optional. The mime-type. Default null.
         * @return array|WP_Error {
         *     Array on success or WP_Error if the file failed to save.
         *
         *     @type string $path      Path to the image file.
         *     @type string $file      Name of the image file.
         *     @type int    $width     Image width.
         *     @type int    $height    Image height.
         *     @type string $mime-type The mime type of the image.
         *     @type int    $filesize  File size of the image.
         * }
         * @phpstan-return \WP_Error|array{
         *   path: string,
         *   file: string,
         *   width: int,
         *   height: int,
         *   mime-type: string,
         *   filesize: int,
         * }
         */
        public function save($destfilename = \null, $mime_type = \null)
        {
        }
        /**
         * @since 3.5.0
         * @since 6.0.0 The `$filesize` value was added to the returned array.
         *
         * @param resource|GdImage $image
         * @param string|null      $filename
         * @param string|null      $mime_type
         * @return array|WP_Error {
         *     Array on success or WP_Error if the file failed to save.
         *
         *     @type string $path      Path to the image file.
         *     @type string $file      Name of the image file.
         *     @type int    $width     Image width.
         *     @type int    $height    Image height.
         *     @type string $mime-type The mime type of the image.
         *     @type int    $filesize  File size of the image.
         * }
         * @phpstan-return \WP_Error|array{
         *   path: string,
         *   file: string,
         *   width: int,
         *   height: int,
         *   mime-type: string,
         *   filesize: int,
         * }
         */
        protected function _save($image, $filename = \null, $mime_type = \null)
        {
        }
        /**
         * Sets Image Compression quality on a 1-100% scale. Handles WebP lossless images.
         *
         * @since 6.7.0
         *
         * @param int $quality Compression Quality. Range: [1,100]
         * @return true|WP_Error True if set successfully; WP_Error on failure.
         */
        public function set_quality($quality = \null)
        {
        }
        /**
         * Returns stream of current image.
         *
         * @since 3.5.0
         *
         * @param string $mime_type The mime type of the image.
         * @return bool True on success, false on failure.
         */
        public function stream($mime_type = \null)
        {
        }
        /**
         * Either calls editor's save function or handles file as a stream.
         *
         * @since 3.5.0
         *
         * @param string   $filename
         * @param callable $callback
         * @param array    $arguments
         * @return bool
         */
        protected function make_image($filename, $callback, $arguments)
        {
        }
    }
    /**
     * WordPress Image Editor Class for Image Manipulation through Imagick PHP Module
     *
     * @since 3.5.0
     *
     * @see WP_Image_Editor
     */
    class WP_Image_Editor_Imagick extends \WP_Image_Editor
    {
        /**
         * Imagick object.
         *
         * @var Imagick
         */
        protected $image;
        public function __destruct()
        {
        }
        /**
         * Checks to see if current environment supports Imagick.
         *
         * We require Imagick 2.2.0 or greater, based on whether the queryFormats()
         * method can be called statically.
         *
         * @since 3.5.0
         *
         * @param array $args
         * @return bool
         */
        public static function test($args = array())
        {
        }
        /**
         * Checks to see if editor supports the mime-type specified.
         *
         * @since 3.5.0
         *
         * @param string $mime_type
         * @return bool
         */
        public static function supports_mime_type($mime_type)
        {
        }
        /**
         * Loads image from $this->file into new Imagick Object.
         *
         * @since 3.5.0
         *
         * @return true|WP_Error True if loaded; WP_Error on failure.
         */
        public function load()
        {
        }
        /**
         * Sets Image Compression quality on a 1-100% scale.
         *
         * @since 3.5.0
         *
         * @param int $quality Compression Quality. Range: [1,100]
         * @return true|WP_Error True if set successfully; WP_Error on failure.
         */
        public function set_quality($quality = \null)
        {
        }
        /**
         * Sets or updates current image size.
         *
         * @since 3.5.0
         *
         * @param int $width
         * @param int $height
         * @return true|WP_Error
         */
        protected function update_size($width = \null, $height = \null)
        {
        }
        /**
         * Sets Imagick time limit.
         *
         * Depending on configuration, Imagick processing may take time.
         *
         * Multiple problems exist if PHP times out before ImageMagick completed:
         * 1. Temporary files aren't cleaned by ImageMagick garbage collection.
         * 2. No clear error is provided.
         * 3. The cause of such timeout can be hard to pinpoint.
         *
         * This function, which is expected to be run before heavy image routines, resolves
         * point 1 above by aligning Imagick's timeout with PHP's timeout, assuming it is set.
         *
         * However seems it introduces more problems than it fixes,
         * see https://core.trac.wordpress.org/ticket/58202.
         *
         * Note:
         *  - Imagick resource exhaustion does not issue catchable exceptions (yet).
         *    See https://github.com/Imagick/imagick/issues/333.
         *  - The resource limit is not saved/restored. It applies to subsequent
         *    image operations within the time of the HTTP request.
         *
         * @since 6.2.0
         * @since 6.3.0 This method was deprecated.
         *
         * @return int|null The new limit on success, null on failure.
         */
        public static function set_imagick_time_limit()
        {
        }
        /**
         * Resizes current image.
         *
         * At minimum, either a height or width must be provided.
         * If one of the two is set to null, the resize will
         * maintain aspect ratio according to the provided dimension.
         *
         * @since 3.5.0
         *
         * @param int|null   $max_w Image width.
         * @param int|null   $max_h Image height.
         * @param bool|array $crop  {
         *     Optional. Image cropping behavior. If false, the image will be scaled (default).
         *     If true, image will be cropped to the specified dimensions using center positions.
         *     If an array, the image will be cropped using the array to specify the crop location:
         *
         *     @type string $0 The x crop position. Accepts 'left' 'center', or 'right'.
         *     @type string $1 The y crop position. Accepts 'top', 'center', or 'bottom'.
         * }
         * @return true|WP_Error
         * @phpstan-param bool|array{
         *   0: string,
         *   1: string,
         * } $crop
         */
        public function resize($max_w, $max_h, $crop = \false)
        {
        }
        /**
         * Efficiently resize the current image
         *
         * This is a WordPress specific implementation of Imagick::thumbnailImage(),
         * which resizes an image to given dimensions and removes any associated profiles.
         *
         * @since 4.5.0
         *
         * @param int    $dst_w       The destination width.
         * @param int    $dst_h       The destination height.
         * @param string $filter_name Optional. The Imagick filter to use when resizing. Default 'FILTER_TRIANGLE'.
         * @param bool   $strip_meta  Optional. Strip all profiles, excluding color profiles, from the image. Default true.
         * @return void|WP_Error
         */
        protected function thumbnail_image($dst_w, $dst_h, $filter_name = 'FILTER_TRIANGLE', $strip_meta = \true)
        {
        }
        /**
         * Create multiple smaller images from a single source.
         *
         * Attempts to create all sub-sizes and returns the meta data at the end. This
         * may result in the server running out of resources. When it fails there may be few
         * "orphaned" images left over as the meta data is never returned and saved.
         *
         * As of 5.3.0 the preferred way to do this is with `make_subsize()`. It creates
         * the new images one at a time and allows for the meta data to be saved after
         * each new image is created.
         *
         * @since 3.5.0
         *
         * @param array $sizes {
         *     An array of image size data arrays.
         *
         *     Either a height or width must be provided.
         *     If one of the two is set to null, the resize will
         *     maintain aspect ratio according to the provided dimension.
         *
         *     @type array ...$0 {
         *         Array of height, width values, and whether to crop.
         *
         *         @type int        $width  Image width. Optional if `$height` is specified.
         *         @type int        $height Image height. Optional if `$width` is specified.
         *         @type bool|array $crop   Optional. Whether to crop the image. Default false.
         *     }
         * }
         * @return array An array of resized images' metadata by size.
         * @phpstan-param array<int|string, array{
         *   width?: int,
         *   height?: int,
         *   crop?: bool|array,
         * }> $sizes
         */
        public function multi_resize($sizes)
        {
        }
        /**
         * Create an image sub-size and return the image meta data value for it.
         *
         * @since 5.3.0
         *
         * @param array $size_data {
         *     Array of size data.
         *
         *     @type int        $width  The maximum width in pixels.
         *     @type int        $height The maximum height in pixels.
         *     @type bool|array $crop   Whether to crop the image to exact dimensions.
         * }
         * @return array|WP_Error The image data array for inclusion in the `sizes` array in the image meta,
         *                        WP_Error object on error.
         * @phpstan-param array{
         *   width?: int,
         *   height?: int,
         *   crop?: bool|array,
         * } $size_data
         */
        public function make_subsize($size_data)
        {
        }
        /**
         * Crops Image.
         *
         * @since 3.5.0
         *
         * @param int  $src_x   The start x position to crop from.
         * @param int  $src_y   The start y position to crop from.
         * @param int  $src_w   The width to crop.
         * @param int  $src_h   The height to crop.
         * @param int  $dst_w   Optional. The destination width.
         * @param int  $dst_h   Optional. The destination height.
         * @param bool $src_abs Optional. If the source crop points are absolute.
         * @return true|WP_Error
         */
        public function crop($src_x, $src_y, $src_w, $src_h, $dst_w = \null, $dst_h = \null, $src_abs = \false)
        {
        }
        /**
         * Rotates current image counter-clockwise by $angle.
         *
         * @since 3.5.0
         *
         * @param float $angle
         * @return true|WP_Error
         */
        public function rotate($angle)
        {
        }
        /**
         * Flips current image.
         *
         * @since 3.5.0
         *
         * @param bool $horz Flip along Horizontal Axis
         * @param bool $vert Flip along Vertical Axis
         * @return true|WP_Error
         */
        public function flip($horz, $vert)
        {
        }
        /**
         * Check if a JPEG image has EXIF Orientation tag and rotate it if needed.
         *
         * As ImageMagick copies the EXIF data to the flipped/rotated image, proceed only
         * if EXIF Orientation can be reset afterwards.
         *
         * @since 5.3.0
         *
         * @return bool|WP_Error True if the image was rotated. False if no EXIF data or if the image doesn't need rotation.
         *                       WP_Error if error while rotating.
         */
        public function maybe_exif_rotate()
        {
        }
        /**
         * Saves current image to file.
         *
         * @since 3.5.0
         * @since 6.0.0 The `$filesize` value was added to the returned array.
         *
         * @param string $destfilename Optional. Destination filename. Default null.
         * @param string $mime_type    Optional. The mime-type. Default null.
         * @return array|WP_Error {
         *     Array on success or WP_Error if the file failed to save.
         *
         *     @type string $path      Path to the image file.
         *     @type string $file      Name of the image file.
         *     @type int    $width     Image width.
         *     @type int    $height    Image height.
         *     @type string $mime-type The mime type of the image.
         *     @type int    $filesize  File size of the image.
         * }
         * @phpstan-return \WP_Error|array{
         *   path: string,
         *   file: string,
         *   width: int,
         *   height: int,
         *   mime-type: string,
         *   filesize: int,
         * }
         */
        public function save($destfilename = \null, $mime_type = \null)
        {
        }
        /**
         * Removes PDF alpha after it's been read.
         *
         * @since 6.4.0
         */
        protected function remove_pdf_alpha_channel()
        {
        }
        /**
         * @since 3.5.0
         * @since 6.0.0 The `$filesize` value was added to the returned array.
         *
         * @param Imagick $image
         * @param string  $filename
         * @param string  $mime_type
         * @return array|WP_Error {
         *     Array on success or WP_Error if the file failed to save.
         *
         *     @type string $path      Path to the image file.
         *     @type string $file      Name of the image file.
         *     @type int    $width     Image width.
         *     @type int    $height    Image height.
         *     @type string $mime-type The mime type of the image.
         *     @type int    $filesize  File size of the image.
         * }
         * @phpstan-return \WP_Error|array{
         *   path: string,
         *   file: string,
         *   width: int,
         *   height: int,
         *   mime-type: string,
         *   filesize: int,
         * }
         */
        protected function _save($image, $filename = \null, $mime_type = \null)
        {
        }
        /**
         * Streams current image to browser.
         *
         * @since 3.5.0
         *
         * @param string $mime_type The mime type of the image.
         * @return true|WP_Error True on success, WP_Error object on failure.
         */
        public function stream($mime_type = \null)
        {
        }
        /**
         * Strips all image meta except color profiles from an image.
         *
         * @since 4.5.0
         *
         * @return true|WP_Error True if stripping metadata was successful. WP_Error object on error.
         */
        protected function strip_meta()
        {
        }
        /**
         * Sets up Imagick for PDF processing.
         * Increases rendering DPI and only loads first page.
         *
         * @since 4.7.0
         *
         * @return string|WP_Error File to load or WP_Error on failure.
         */
        protected function pdf_setup()
        {
        }
        /**
         * Load the image produced by Ghostscript.
         *
         * Includes a workaround for a bug in Ghostscript 8.70 that prevents processing of some PDF files
         * when `use-cropbox` is set.
         *
         * @since 5.6.0
         *
         * @return true|WP_Error
         */
        protected function pdf_load_source()
        {
        }
    }
    /**
     * List utility.
     *
     * Utility class to handle operations on an array of objects or arrays.
     *
     * @since 4.7.0
     */
    #[\AllowDynamicProperties]
    class WP_List_Util
    {
        /**
         * Constructor.
         *
         * Sets the input array.
         *
         * @since 4.7.0
         *
         * @param array $input Array to perform operations on.
         */
        public function __construct($input)
        {
        }
        /**
         * Returns the original input array.
         *
         * @since 4.7.0
         *
         * @return array The input array.
         */
        public function get_input()
        {
        }
        /**
         * Returns the output array.
         *
         * @since 4.7.0
         *
         * @return array The output array.
         */
        public function get_output()
        {
        }
        /**
         * Filters the list, based on a set of key => value arguments.
         *
         * Retrieves the objects from the list that match the given arguments.
         * Key represents property name, and value represents property value.
         *
         * If an object has more properties than those specified in arguments,
         * that will not disqualify it. When using the 'AND' operator,
         * any missing properties will disqualify it.
         *
         * @since 4.7.0
         *
         * @param array  $args     Optional. An array of key => value arguments to match
         *                         against each object. Default empty array.
         * @param string $operator Optional. The logical operation to perform. 'AND' means
         *                         all elements from the array must match. 'OR' means only
         *                         one element needs to match. 'NOT' means no elements may
         *                         match. Default 'AND'.
         * @return array Array of found values.
         */
        public function filter($args = array(), $operator = 'AND')
        {
        }
        /**
         * Plucks a certain field out of each element in the input array.
         *
         * This has the same functionality and prototype of
         * array_column() (PHP 5.5) but also supports objects.
         *
         * @since 4.7.0
         *
         * @param int|string $field     Field to fetch from the object or array.
         * @param int|string $index_key Optional. Field from the element to use as keys for the new array.
         *                              Default null.
         * @return array Array of found values. If `$index_key` is set, an array of found values with keys
         *               corresponding to `$index_key`. If `$index_key` is null, array keys from the original
         *               `$list` will be preserved in the results.
         */
        public function pluck($field, $index_key = \null)
        {
        }
        /**
         * Sorts the input array based on one or more orderby arguments.
         *
         * @since 4.7.0
         *
         * @param string|array $orderby       Optional. Either the field name to order by or an array
         *                                    of multiple orderby fields as `$orderby => $order`.
         *                                    Default empty array.
         * @param string       $order         Optional. Either 'ASC' or 'DESC'. Only used if `$orderby`
         *                                    is a string. Default 'ASC'.
         * @param bool         $preserve_keys Optional. Whether to preserve keys. Default false.
         * @return array The sorted array.
         * @phpstan-param 'ASC'|'DESC' $order
         */
        public function sort($orderby = array(), $order = 'ASC', $preserve_keys = \false)
        {
        }
    }
    /**
     * Core class used for switching locales.
     *
     * @since 4.7.0
     */
    #[\AllowDynamicProperties]
    class WP_Locale_Switcher
    {
        /**
         * Constructor.
         *
         * Stores the original locale as well as a list of all available languages.
         *
         * @since 4.7.0
         */
        public function __construct()
        {
        }
        /**
         * Initializes the locale switcher.
         *
         * Hooks into the {@see 'locale'} and {@see 'determine_locale'} filters
         * to change the locale on the fly.
         *
         * @since 4.7.0
         */
        public function init()
        {
        }
        /**
         * Switches the translations according to the given locale.
         *
         * @since 4.7.0
         *
         * @param string    $locale  The locale to switch to.
         * @param int|false $user_id Optional. User ID as context. Default false.
         * @return bool True on success, false on failure.
         */
        public function switch_to_locale($locale, $user_id = \false)
        {
        }
        /**
         * Switches the translations according to the given user's locale.
         *
         * @since 6.2.0
         *
         * @param int $user_id User ID.
         * @return bool True on success, false on failure.
         */
        public function switch_to_user_locale($user_id)
        {
        }
        /**
         * Restores the translations according to the previous locale.
         *
         * @since 4.7.0
         *
         * @return string|false Locale on success, false on failure.
         */
        public function restore_previous_locale()
        {
        }
        /**
         * Restores the translations according to the original locale.
         *
         * @since 4.7.0
         *
         * @return string|false Locale on success, false on failure.
         */
        public function restore_current_locale()
        {
        }
        /**
         * Whether switch_to_locale() is in effect.
         *
         * @since 4.7.0
         *
         * @return bool True if the locale has been switched, false otherwise.
         */
        public function is_switched()
        {
        }
        /**
         * Returns the locale currently switched to.
         *
         * @since 6.2.0
         *
         * @return string|false Locale if the locale has been switched, false otherwise.
         */
        public function get_switched_locale()
        {
        }
        /**
         * Returns the user ID related to the currently switched locale.
         *
         * @since 6.2.0
         *
         * @return int|false User ID if set and if the locale has been switched, false otherwise.
         */
        public function get_switched_user_id()
        {
        }
        /**
         * Filters the locale of the WordPress installation.
         *
         * @since 4.7.0
         *
         * @param string $locale The locale of the WordPress installation.
         * @return string The locale currently being switched to.
         */
        public function filter_locale($locale)
        {
        }
    }
    /**
     * Core class used to store translated data for a locale.
     *
     * @since 2.1.0
     * @since 4.6.0 Moved to its own file from wp-includes/locale.php.
     */
    #[\AllowDynamicProperties]
    class WP_Locale
    {
        /**
         * Stores the translated strings for the full weekday names.
         *
         * @since 2.1.0
         * @since 6.2.0 Initialized to an empty array.
         * @var string[]
         */
        public $weekday = array();
        /**
         * Stores the translated strings for the one character weekday names.
         *
         * There is a hack to make sure that Tuesday and Thursday, as well
         * as Sunday and Saturday, don't conflict. See init() method for more.
         *
         * @see WP_Locale::init() for how to handle the hack.
         *
         * @since 2.1.0
         * @since 6.2.0 Initialized to an empty array.
         * @var string[]
         */
        public $weekday_initial = array();
        /**
         * Stores the translated strings for the abbreviated weekday names.
         *
         * @since 2.1.0
         * @since 6.2.0 Initialized to an empty array.
         * @var string[]
         */
        public $weekday_abbrev = array();
        /**
         * Stores the translated strings for the full month names.
         *
         * @since 2.1.0
         * @since 6.2.0 Initialized to an empty array.
         * @var string[]
         */
        public $month = array();
        /**
         * Stores the translated strings for the month names in genitive case, if the locale specifies.
         *
         * @since 4.4.0
         * @since 6.2.0 Initialized to an empty array.
         * @var string[]
         */
        public $month_genitive = array();
        /**
         * Stores the translated strings for the abbreviated month names.
         *
         * @since 2.1.0
         * @since 6.2.0 Initialized to an empty array.
         * @var string[]
         */
        public $month_abbrev = array();
        /**
         * Stores the translated strings for 'am' and 'pm'.
         *
         * Also the capitalized versions.
         *
         * @since 2.1.0
         * @since 6.2.0 Initialized to an empty array.
         * @var string[]
         */
        public $meridiem = array();
        /**
         * The text direction of the locale language.
         *
         * Default is left to right 'ltr'.
         *
         * @since 2.1.0
         * @var string
         */
        public $text_direction = 'ltr';
        /**
         * The thousands separator and decimal point values used for localizing numbers.
         *
         * @since 2.3.0
         * @since 6.2.0 Initialized to an empty array.
         * @var array
         */
        public $number_format = array();
        /**
         * The separator string used for localizing list item separator.
         *
         * @since 6.0.0
         * @var string
         */
        public $list_item_separator;
        /**
         * The word count type of the locale language.
         *
         * Default is 'words'.
         *
         * @since 6.2.0
         * @var string
         */
        public $word_count_type;
        /**
         * Constructor which calls helper methods to set up object variables.
         *
         * @since 2.1.0
         */
        public function __construct()
        {
        }
        /**
         * Sets up the translated strings and object properties.
         *
         * The method creates the translatable strings for various
         * calendar elements. Which allows for specifying locale
         * specific calendar names and text direction.
         *
         * @since 2.1.0
         *
         * @global string $text_direction
         */
        public function init()
        {
        }
        /**
         * Retrieves the full translated weekday word.
         *
         * Week starts on translated Sunday and can be fetched
         * by using 0 (zero). So the week starts with 0 (zero)
         * and ends on Saturday with is fetched by using 6 (six).
         *
         * @since 2.1.0
         *
         * @param int $weekday_number 0 for Sunday through 6 Saturday.
         * @return string Full translated weekday.
         */
        public function get_weekday($weekday_number)
        {
        }
        /**
         * Retrieves the translated weekday initial.
         *
         * The weekday initial is retrieved by the translated
         * full weekday word. When translating the weekday initial
         * pay attention to make sure that the starting letter does
         * not conflict.
         *
         * @since 2.1.0
         *
         * @param string $weekday_name Full translated weekday word.
         * @return string Translated weekday initial.
         */
        public function get_weekday_initial($weekday_name)
        {
        }
        /**
         * Retrieves the translated weekday abbreviation.
         *
         * The weekday abbreviation is retrieved by the translated
         * full weekday word.
         *
         * @since 2.1.0
         *
         * @param string $weekday_name Full translated weekday word.
         * @return string Translated weekday abbreviation.
         */
        public function get_weekday_abbrev($weekday_name)
        {
        }
        /**
         * Retrieves the full translated month by month number.
         *
         * The $month_number parameter has to be a string
         * because it must have the '0' in front of any number
         * that is less than 10. Starts from '01' and ends at
         * '12'.
         *
         * You can use an integer instead and it will add the
         * '0' before the numbers less than 10 for you.
         *
         * @since 2.1.0
         *
         * @param string|int $month_number '01' through '12'.
         * @return string Translated full month name.
         */
        public function get_month($month_number)
        {
        }
        /**
         * Retrieves translated version of month abbreviation string.
         *
         * The $month_name parameter is expected to be the translated or
         * translatable version of the month.
         *
         * @since 2.1.0
         *
         * @param string $month_name Translated month to get abbreviated version.
         * @return string Translated abbreviated month.
         */
        public function get_month_abbrev($month_name)
        {
        }
        /**
         * Retrieves translated version of meridiem string.
         *
         * The $meridiem parameter is expected to not be translated.
         *
         * @since 2.1.0
         *
         * @param string $meridiem Either 'am', 'pm', 'AM', or 'PM'. Not translated version.
         * @return string Translated version
         * @phpstan-param 'am'|'pm'|'AM'|'PM' $meridiem
         */
        public function get_meridiem($meridiem)
        {
        }
        /**
         * Global variables are deprecated.
         *
         * For backward compatibility only.
         *
         * @since 2.1.0
         * @deprecated For backward compatibility only.
         *
         * @global array $weekday
         * @global array $weekday_initial
         * @global array $weekday_abbrev
         * @global array $month
         * @global array $month_abbrev
         */
        public function register_globals()
        {
        }
        /**
         * Checks if current locale is RTL.
         *
         * @since 3.0.0
         * @return bool Whether locale is RTL.
         */
        public function is_rtl()
        {
        }
        /**
         * Registers date/time format strings for general POT.
         *
         * Private, unused method to add some date/time formats translated
         * on wp-admin/options-general.php to the general POT that would
         * otherwise be added to the admin POT.
         *
         * @since 3.6.0
         */
        public function _strings_for_pot()
        {
        }
        /**
         * Retrieves the localized list item separator.
         *
         * @since 6.0.0
         *
         * @return string Localized list item separator.
         */
        public function get_list_item_separator()
        {
        }
        /**
         * Retrieves the localized word count type.
         *
         * @since 6.2.0
         *
         * @return string Localized word count type. Possible values are `characters_excluding_spaces`,
         *                `characters_including_spaces`, or `words`. Defaults to `words`.
         */
        public function get_word_count_type()
        {
        }
    }
    /**
     * Helper class to remove the need to use eval to replace $matches[] in query strings.
     *
     * @since 2.9.0
     */
    #[\AllowDynamicProperties]
    class WP_MatchesMapRegex
    {
        /**
         * store for mapping result
         *
         * @var string
         */
        public $output;
        /**
         * regexp pattern to match $matches[] references
         *
         * @var string
         */
        public $_pattern = '(\\$matches\\[[1-9]+[0-9]*\\])';
        /**
         * constructor
         *
         * @param string $subject subject if regex
         * @param array  $matches data to use in map
         */
        public function __construct($subject, $matches)
        {
        }
        /**
         * Substitute substring matches in subject.
         *
         * static helper function to ease use
         *
         * @param string $subject subject
         * @param array  $matches data used for substitution
         * @return string
         */
        public static function apply($subject, $matches)
        {
        }
        /**
         * preg_replace_callback hook
         *
         * @param array $matches preg_replace regexp matches
         * @return string
         */
        public function callback($matches)
        {
        }
    }
    /**
     * Core class used to implement meta queries for the Meta API.
     *
     * Used for generating SQL clauses that filter a primary query according to metadata keys and values.
     *
     * WP_Meta_Query is a helper that allows primary query classes, such as WP_Query and WP_User_Query,
     *
     * to filter their results by object metadata, by generating `JOIN` and `WHERE` subclauses to be attached
     * to the primary SQL query string.
     *
     * @since 3.2.0
     */
    #[\AllowDynamicProperties]
    class WP_Meta_Query
    {
        /**
         * Array of metadata queries.
         *
         * See WP_Meta_Query::__construct() for information on meta query arguments.
         *
         * @since 3.2.0
         * @var array
         */
        public $queries = array();
        /**
         * The relation between the queries. Can be one of 'AND' or 'OR'.
         *
         * @since 3.2.0
         * @var string
         */
        public $relation;
        /**
         * Database table to query for the metadata.
         *
         * @since 4.1.0
         * @var string
         */
        public $meta_table;
        /**
         * Column in meta_table that represents the ID of the object the metadata belongs to.
         *
         * @since 4.1.0
         * @var string
         */
        public $meta_id_column;
        /**
         * Database table that where the metadata's objects are stored (eg $wpdb->users).
         *
         * @since 4.1.0
         * @var string
         */
        public $primary_table;
        /**
         * Column in primary_table that represents the ID of the object.
         *
         * @since 4.1.0
         * @var string
         */
        public $primary_id_column;
        /**
         * A flat list of table aliases used in JOIN clauses.
         *
         * @since 4.1.0
         * @var array
         */
        protected $table_aliases = array();
        /**
         * A flat list of clauses, keyed by clause 'name'.
         *
         * @since 4.2.0
         * @var array
         */
        protected $clauses = array();
        /**
         * Whether the query contains any OR relations.
         *
         * @since 4.3.0
         * @var bool
         */
        protected $has_or_relation = \false;
        /**
         * Constructor.
         *
         * @since 3.2.0
         * @since 4.2.0 Introduced support for naming query clauses by associative array keys.
         * @since 5.1.0 Introduced `$compare_key` clause parameter, which enables LIKE key matches.
         * @since 5.3.0 Increased the number of operators available to `$compare_key`. Introduced `$type_key`,
         *              which enables the `$key` to be cast to a new data type for comparisons.
         *
         * @param array $meta_query {
         *     Array of meta query clauses. When first-order clauses or sub-clauses use strings as
         *     their array keys, they may be referenced in the 'orderby' parameter of the parent query.
         *
         *     @type string $relation Optional. The MySQL keyword used to join the clauses of the query.
         *                            Accepts 'AND' or 'OR'. Default 'AND'.
         *     @type array  ...$0 {
         *         Optional. An array of first-order clause parameters, or another fully-formed meta query.
         *
         *         @type string|string[] $key         Meta key or keys to filter by.
         *         @type string          $compare_key MySQL operator used for comparing the $key. Accepts:
         *                                            - '='
         *                                            - '!='
         *                                            - 'LIKE'
         *                                            - 'NOT LIKE'
         *                                            - 'IN'
         *                                            - 'NOT IN'
         *                                            - 'REGEXP'
         *                                            - 'NOT REGEXP'
         *                                            - 'RLIKE'
         *                                            - 'EXISTS' (alias of '=')
         *                                            - 'NOT EXISTS' (alias of '!=')
         *                                            Default is 'IN' when `$key` is an array, '=' otherwise.
         *         @type string          $type_key    MySQL data type that the meta_key column will be CAST to for
         *                                            comparisons. Accepts 'BINARY' for case-sensitive regular expression
         *                                            comparisons. Default is ''.
         *         @type string|string[] $value       Meta value or values to filter by.
         *         @type string          $compare     MySQL operator used for comparing the $value. Accepts:
         *                                            - '='
         *                                            - '!='
         *                                            - '>'
         *                                            - '>='
         *                                            - '<'
         *                                            - '<='
         *                                            - 'LIKE'
         *                                            - 'NOT LIKE'
         *                                            - 'IN'
         *                                            - 'NOT IN'
         *                                            - 'BETWEEN'
         *                                            - 'NOT BETWEEN'
         *                                            - 'REGEXP'
         *                                            - 'NOT REGEXP'
         *                                            - 'RLIKE'
         *                                            - 'EXISTS'
         *                                            - 'NOT EXISTS'
         *                                            Default is 'IN' when `$value` is an array, '=' otherwise.
         *         @type string          $type        MySQL data type that the meta_value column will be CAST to for
         *                                            comparisons. Accepts:
         *                                            - 'NUMERIC'
         *                                            - 'BINARY'
         *                                            - 'CHAR'
         *                                            - 'DATE'
         *                                            - 'DATETIME'
         *                                            - 'DECIMAL'
         *                                            - 'SIGNED'
         *                                            - 'TIME'
         *                                            - 'UNSIGNED'
         *                                            Default is 'CHAR'.
         *     }
         * }
         * @phpstan-return void
         */
        public function __construct($meta_query = \false)
        {
        }
        /**
         * Ensures the 'meta_query' argument passed to the class constructor is well-formed.
         *
         * Eliminates empty items and ensures that a 'relation' is set.
         *
         * @since 4.1.0
         *
         * @param array $queries Array of query clauses.
         * @return array Sanitized array of query clauses.
         */
        public function sanitize_query($queries)
        {
        }
        /**
         * Determines whether a query clause is first-order.
         *
         * A first-order meta query clause is one that has either a 'key' or
         * a 'value' array key.
         *
         * @since 4.1.0
         *
         * @param array $query Meta query arguments.
         * @return bool Whether the query clause is a first-order clause.
         */
        protected function is_first_order_clause($query)
        {
        }
        /**
         * Constructs a meta query based on 'meta_*' query vars
         *
         * @since 3.2.0
         *
         * @param array $qv The query variables.
         */
        public function parse_query_vars($qv)
        {
        }
        /**
         * Returns the appropriate alias for the given meta type if applicable.
         *
         * @since 3.7.0
         *
         * @param string $type MySQL type to cast meta_value.
         * @return string MySQL type.
         */
        public function get_cast_for_type($type = '')
        {
        }
        /**
         * Generates SQL clauses to be appended to a main query.
         *
         * @since 3.2.0
         *
         * @param string $type              Type of meta. Possible values include but are not limited
         *                                  to 'post', 'comment', 'blog', 'term', and 'user'.
         * @param string $primary_table     Database table where the object being filtered is stored (eg wp_users).
         * @param string $primary_id_column ID column for the filtered object in $primary_table.
         * @param object $context           Optional. The main query object that corresponds to the type, for
         *                                  example a `WP_Query`, `WP_User_Query`, or `WP_Site_Query`.
         *                                  Default null.
         * @return string[]|false {
         *     Array containing JOIN and WHERE SQL clauses to append to the main query,
         *     or false if no table exists for the requested meta type.
         *
         *     @type string $join  SQL fragment to append to the main JOIN clause.
         *     @type string $where SQL fragment to append to the main WHERE clause.
         * }
         * @phpstan-return false|array{
         *   join: string,
         *   where: string,
         * }
         */
        public function get_sql($type, $primary_table, $primary_id_column, $context = \null)
        {
        }
        /**
         * Generates SQL clauses to be appended to a main query.
         *
         * Called by the public WP_Meta_Query::get_sql(), this method is abstracted
         * out to maintain parity with the other Query classes.
         *
         * @since 4.1.0
         *
         * @return string[] {
         *     Array containing JOIN and WHERE SQL clauses to append to the main query.
         *
         *     @type string $join  SQL fragment to append to the main JOIN clause.
         *     @type string $where SQL fragment to append to the main WHERE clause.
         * }
         * @phpstan-return array{
         *   join: string,
         *   where: string,
         * }
         */
        protected function get_sql_clauses()
        {
        }
        /**
         * Generates SQL clauses for a single query array.
         *
         * If nested subqueries are found, this method recurses the tree to
         * produce the properly nested SQL.
         *
         * @since 4.1.0
         *
         * @param array $query Query to parse (passed by reference).
         * @param int   $depth Optional. Number of tree levels deep we currently are.
         *                     Used to calculate indentation. Default 0.
         * @return string[] {
         *     Array containing JOIN and WHERE SQL clauses to append to a single query array.
         *
         *     @type string $join  SQL fragment to append to the main JOIN clause.
         *     @type string $where SQL fragment to append to the main WHERE clause.
         * }
         * @phpstan-return array{
         *   join: string,
         *   where: string,
         * }
         */
        protected function get_sql_for_query(&$query, $depth = 0)
        {
        }
        /**
         * Generates SQL JOIN and WHERE clauses for a first-order query clause.
         *
         * "First-order" means that it's an array with a 'key' or 'value'.
         *
         * @since 4.1.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param array  $clause       Query clause (passed by reference).
         * @param array  $parent_query Parent query array.
         * @param string $clause_key   Optional. The array key used to name the clause in the original `$meta_query`
         *                             parameters. If not provided, a key will be generated automatically.
         *                             Default empty string.
         * @return array {
         *     Array containing JOIN and WHERE SQL clauses to append to a first-order query.
         *
         *     @type string[] $join  Array of SQL fragments to append to the main JOIN clause.
         *     @type string[] $where Array of SQL fragments to append to the main WHERE clause.
         * }
         * @phpstan-return array{
         *   join: string[],
         *   where: string[],
         * }
         */
        public function get_sql_for_clause(&$clause, $parent_query, $clause_key = '')
        {
        }
        /**
         * Gets a flattened list of sanitized meta clauses.
         *
         * This array should be used for clause lookup, as when the table alias and CAST type must be determined for
         * a value of 'orderby' corresponding to a meta clause.
         *
         * @since 4.2.0
         *
         * @return array Meta clauses.
         */
        public function get_clauses()
        {
        }
        /**
         * Identifies an existing table alias that is compatible with the current
         * query clause.
         *
         * We avoid unnecessary table joins by allowing each clause to look for
         * an existing table alias that is compatible with the query that it
         * needs to perform.
         *
         * An existing alias is compatible if (a) it is a sibling of `$clause`
         * (ie, it's under the scope of the same relation), and (b) the combination
         * of operator and relation between the clauses allows for a shared table join.
         * In the case of WP_Meta_Query, this only applies to 'IN' clauses that are
         * connected by the relation 'OR'.
         *
         * @since 4.1.0
         *
         * @param array $clause       Query clause.
         * @param array $parent_query Parent query of $clause.
         * @return string|false Table alias if found, otherwise false.
         */
        protected function find_compatible_table_alias($clause, $parent_query)
        {
        }
        /**
         * Checks whether the current query has any OR relations.
         *
         * In some cases, the presence of an OR relation somewhere in the query will require
         * the use of a `DISTINCT` or `GROUP BY` keyword in the `SELECT` clause. The current
         * method can be used in these cases to determine whether such a clause is necessary.
         *
         * @since 4.3.0
         *
         * @return bool True if the query contains any `OR` relations, otherwise false.
         */
        public function has_or_relation()
        {
        }
    }
    /**
     * Core class used for lazy-loading object metadata.
     *
     * When loading many objects of a given type, such as posts in a WP_Query loop, it often makes
     * sense to prime various metadata caches at the beginning of the loop. This means fetching all
     * relevant metadata with a single database query, a technique that has the potential to improve
     * performance dramatically in some cases.
     *
     * In cases where the given metadata may not even be used in the loop, we can improve performance
     * even more by only priming the metadata cache for affected items the first time a piece of metadata
     * is requested - ie, by lazy-loading it. So, for example, comment meta may not be loaded into the
     * cache in the comments section of a post until the first time get_comment_meta() is called in the
     * context of the comment loop.
     *
     * WP uses the WP_Metadata_Lazyloader class to queue objects for metadata cache priming. The class
     * then detects the relevant get_*_meta() function call, and queries the metadata of all queued objects.
     *
     * Do not access this class directly. Use the wp_metadata_lazyloader() function.
     *
     * @since 4.5.0
     */
    #[\AllowDynamicProperties]
    class WP_Metadata_Lazyloader
    {
        /**
         * Pending objects queue.
         *
         * @since 4.5.0
         * @var array
         */
        protected $pending_objects;
        /**
         * Settings for supported object types.
         *
         * @since 4.5.0
         * @var array
         */
        protected $settings = array();
        /**
         * Constructor.
         *
         * @since 4.5.0
         */
        public function __construct()
        {
        }
        /**
         * Adds objects to the metadata lazy-load queue.
         *
         * @since 4.5.0
         *
         * @param string $object_type Type of object whose meta is to be lazy-loaded. Accepts 'term' or 'comment'.
         * @param array  $object_ids  Array of object IDs.
         * @return void|WP_Error WP_Error on failure.
         * @phpstan-param 'term'|'comment' $object_type
         */
        public function queue_objects($object_type, $object_ids)
        {
        }
        /**
         * Resets lazy-load queue for a given object type.
         *
         * @since 4.5.0
         *
         * @param string $object_type Object type. Accepts 'comment' or 'term'.
         * @return void|WP_Error WP_Error on failure.
         * @phpstan-param 'comment'|'term' $object_type
         */
        public function reset_queue($object_type)
        {
        }
        /**
         * Lazy-loads term meta for queued terms.
         *
         * This method is public so that it can be used as a filter callback. As a rule, there
         * is no need to invoke it directly.
         *
         * @since 4.5.0
         * @deprecated 6.3.0 Use WP_Metadata_Lazyloader::lazyload_meta_callback() instead.
         *
         * @param mixed $check The `$check` param passed from the 'get_term_metadata' hook.
         * @return mixed In order not to short-circuit `get_metadata()`. Generally, this is `null`, but it could be
         *               another value if filtered by a plugin.
         */
        public function lazyload_term_meta($check)
        {
        }
        /**
         * Lazy-loads comment meta for queued comments.
         *
         * This method is public so that it can be used as a filter callback. As a rule, there is no need to invoke it
         * directly, from either inside or outside the `WP_Query` object.
         *
         * @since 4.5.0
         * @deprecated 6.3.0 Use WP_Metadata_Lazyloader::lazyload_meta_callback() instead.
         *
         * @param mixed $check The `$check` param passed from the {@see 'get_comment_metadata'} hook.
         * @return mixed The original value of `$check`, so as not to short-circuit `get_comment_metadata()`.
         */
        public function lazyload_comment_meta($check)
        {
        }
        /**
         * Lazy-loads meta for queued objects.
         *
         * This method is public so that it can be used as a filter callback. As a rule, there
         * is no need to invoke it directly.
         *
         * @since 6.3.0
         *
         * @param mixed  $check     The `$check` param passed from the 'get_*_metadata' hook.
         * @param int    $object_id ID of the object metadata is for.
         * @param string $meta_key  Unused.
         * @param bool   $single    Unused.
         * @param string $meta_type Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
         *                          or any other object type with an associated meta table.
         * @return mixed In order not to short-circuit `get_metadata()`. Generally, this is `null`, but it could be
         *               another value if filtered by a plugin.
         */
        public function lazyload_meta_callback($check, $object_id, $meta_key, $single, $meta_type)
        {
        }
    }
    /**
     * Manages fallback behavior for Navigation menus.
     *
     * @access public
     * @since 6.3.0
     */
    class WP_Navigation_Fallback
    {
        /**
         * Updates the wp_navigation custom post type schema, in order to expose
         * additional fields in the embeddable links of WP_REST_Navigation_Fallback_Controller.
         *
         * The Navigation Fallback endpoint may embed the full Navigation Menu object
         * into the response as the `self` link. By default, the Posts Controller
         * will only expose a limited subset of fields but the editor requires
         * additional fields to be available in order to utilize the menu.
         *
         * Used with the `rest_wp_navigation_item_schema` hook.
         *
         * @since 6.4.0
         *
         * @param array $schema The schema for the `wp_navigation` post.
         * @return array The modified schema.
         */
        public static function update_wp_navigation_post_schema($schema)
        {
        }
        /**
         * Gets (and/or creates) an appropriate fallback Navigation Menu.
         *
         * @since 6.3.0
         *
         * @return WP_Post|null the fallback Navigation Post or null.
         */
        public static function get_fallback()
        {
        }
    }
    /**
     * Core class used for querying networks.
     *
     * @since 4.6.0
     *
     * @see WP_Network_Query::__construct() for accepted arguments.
     */
    #[\AllowDynamicProperties]
    class WP_Network_Query
    {
        /**
         * SQL for database query.
         *
         * @since 4.6.0
         * @var string
         */
        public $request;
        /**
         * SQL query clauses.
         *
         * @since 4.6.0
         * @var array
         */
        protected $sql_clauses = array('select' => '', 'from' => '', 'where' => array(), 'groupby' => '', 'orderby' => '', 'limits' => '');
        /**
         * Query vars set by the user.
         *
         * @since 4.6.0
         * @var array
         */
        public $query_vars;
        /**
         * Default values for query vars.
         *
         * @since 4.6.0
         * @var array
         */
        public $query_var_defaults;
        /**
         * List of networks located by the query.
         *
         * @since 4.6.0
         * @var array
         */
        public $networks;
        /**
         * The amount of found networks for the current query.
         *
         * @since 4.6.0
         * @var int
         */
        public $found_networks = 0;
        /**
         * The number of pages.
         *
         * @since 4.6.0
         * @var int
         */
        public $max_num_pages = 0;
        /**
         * Constructor.
         *
         * Sets up the network query, based on the query vars passed.
         *
         * @since 4.6.0
         *
         * @param string|array $query {
         *     Optional. Array or query string of network query parameters. Default empty.
         *
         *     @type int[]        $network__in          Array of network IDs to include. Default empty.
         *     @type int[]        $network__not_in      Array of network IDs to exclude. Default empty.
         *     @type bool         $count                Whether to return a network count (true) or array of network objects.
         *                                              Default false.
         *     @type string       $fields               Network fields to return. Accepts 'ids' (returns an array of network IDs)
         *                                              or empty (returns an array of complete network objects). Default empty.
         *     @type int          $number               Maximum number of networks to retrieve. Default empty (no limit).
         *     @type int          $offset               Number of networks to offset the query. Used to build LIMIT clause.
         *                                              Default 0.
         *     @type bool         $no_found_rows        Whether to disable the `SQL_CALC_FOUND_ROWS` query. Default true.
         *     @type string|array $orderby              Network status or array of statuses. Accepts 'id', 'domain', 'path',
         *                                              'domain_length', 'path_length' and 'network__in'. Also accepts false,
         *                                              an empty array, or 'none' to disable `ORDER BY` clause. Default 'id'.
         *     @type string       $order                How to order retrieved networks. Accepts 'ASC', 'DESC'. Default 'ASC'.
         *     @type string       $domain               Limit results to those affiliated with a given domain. Default empty.
         *     @type string[]     $domain__in           Array of domains to include affiliated networks for. Default empty.
         *     @type string[]     $domain__not_in       Array of domains to exclude affiliated networks for. Default empty.
         *     @type string       $path                 Limit results to those affiliated with a given path. Default empty.
         *     @type string[]     $path__in             Array of paths to include affiliated networks for. Default empty.
         *     @type string[]     $path__not_in         Array of paths to exclude affiliated networks for. Default empty.
         *     @type string       $search               Search term(s) to retrieve matching networks for. Default empty.
         *     @type bool         $update_network_cache Whether to prime the cache for found networks. Default true.
         * }
         * @phpstan-param array{
         *   network__in?: int[],
         *   network__not_in?: int[],
         *   count?: bool,
         *   fields?: string,
         *   number?: int,
         *   offset?: int,
         *   no_found_rows?: bool,
         *   orderby?: string|array,
         *   order?: string,
         *   domain?: string,
         *   domain__in?: string[],
         *   domain__not_in?: string[],
         *   path?: string,
         *   path__in?: string[],
         *   path__not_in?: string[],
         *   search?: string,
         *   update_network_cache?: bool,
         * } $query
         */
        public function __construct($query = '')
        {
        }
        /**
         * Parses arguments passed to the network query with default query parameters.
         *
         * @since 4.6.0
         *
         * @param string|array $query WP_Network_Query arguments. See WP_Network_Query::__construct() for accepted arguments.
         * @phpstan-param array{
         *   network__in?: int[],
         *   network__not_in?: int[],
         *   count?: bool,
         *   fields?: string,
         *   number?: int,
         *   offset?: int,
         *   no_found_rows?: bool,
         *   orderby?: string|array,
         *   order?: string,
         *   domain?: string,
         *   domain__in?: string[],
         *   domain__not_in?: string[],
         *   path?: string,
         *   path__in?: string[],
         *   path__not_in?: string[],
         *   search?: string,
         *   update_network_cache?: bool,
         * } $query See WP_Network_Query::__construct()
         */
        public function parse_query($query = '')
        {
        }
        /**
         * Sets up the WordPress query for retrieving networks.
         *
         * @since 4.6.0
         *
         * @param string|array $query Array or URL query string of parameters.
         * @return array|int List of WP_Network objects, a list of network IDs when 'fields' is set to 'ids',
         *                   or the number of networks when 'count' is passed as a query var.
         */
        public function query($query)
        {
        }
        /**
         * Gets a list of networks matching the query vars.
         *
         * @since 4.6.0
         *
         * @return array|int List of WP_Network objects, a list of network IDs when 'fields' is set to 'ids',
         *                   or the number of networks when 'count' is passed as a query var.
         */
        public function get_networks()
        {
        }
        /**
         * Used internally to get a list of network IDs matching the query vars.
         *
         * @since 4.6.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @return int|array A single count of network IDs if a count query. An array of network IDs if a full query.
         */
        protected function get_network_ids()
        {
        }
        /**
         * Used internally to generate an SQL string for searching across multiple columns.
         *
         * @since 4.6.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string   $search  Search string.
         * @param string[] $columns Array of columns to search.
         * @return string Search SQL.
         */
        protected function get_search_sql($search, $columns)
        {
        }
        /**
         * Parses and sanitizes 'orderby' keys passed to the network query.
         *
         * @since 4.6.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $orderby Alias for the field to order by.
         * @return string|false Value to used in the ORDER clause. False otherwise.
         */
        protected function parse_orderby($orderby)
        {
        }
        /**
         * Parses an 'order' query variable and cast it to 'ASC' or 'DESC' as necessary.
         *
         * @since 4.6.0
         *
         * @param string $order The 'order' query variable.
         * @return string The sanitized 'order' query variable.
         */
        protected function parse_order($order)
        {
        }
    }
    /**
     * Core class used for interacting with a multisite network.
     *
     * This class is used during load to populate the `$current_site` global and
     * setup the current network.
     *
     * This class is most useful in WordPress multi-network installations where the
     * ability to interact with any network of sites is required.
     *
     * @since 4.4.0
     *
     * @property int $id
     * @property int $site_id
     */
    #[\AllowDynamicProperties]
    class WP_Network
    {
        /**
         * Domain of the network.
         *
         * @since 4.4.0
         * @var string
         */
        public $domain = '';
        /**
         * Path of the network.
         *
         * @since 4.4.0
         * @var string
         */
        public $path = '';
        /**
         * Domain used to set cookies for this network.
         *
         * @since 4.4.0
         * @var string
         */
        public $cookie_domain = '';
        /**
         * Name of this network.
         *
         * Named "site" vs. "network" for legacy reasons.
         *
         * @since 4.4.0
         * @var string
         */
        public $site_name = '';
        /**
         * Retrieves a network from the database by its ID.
         *
         * @since 4.4.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param int $network_id The ID of the network to retrieve.
         * @return WP_Network|false The network's object if found. False if not.
         */
        public static function get_instance($network_id)
        {
        }
        /**
         * Creates a new WP_Network object.
         *
         * Will populate object properties from the object provided and assign other
         * default properties based on that information.
         *
         * @since 4.4.0
         *
         * @param WP_Network|object $network A network object.
         */
        public function __construct($network)
        {
        }
        /**
         * Getter.
         *
         * Allows current multisite naming conventions when getting properties.
         *
         * @since 4.6.0
         *
         * @param string $key Property to get.
         * @return mixed Value of the property. Null if not available.
         */
        public function __get($key)
        {
        }
        /**
         * Isset-er.
         *
         * Allows current multisite naming conventions when checking for properties.
         *
         * @since 4.6.0
         *
         * @param string $key Property to check if set.
         * @return bool Whether the property is set.
         */
        public function __isset($key)
        {
        }
        /**
         * Setter.
         *
         * Allows current multisite naming conventions while setting properties.
         *
         * @since 4.6.0
         *
         * @param string $key   Property to set.
         * @param mixed  $value Value to assign to the property.
         */
        public function __set($key, $value)
        {
        }
        /**
         * Retrieves the closest matching network for a domain and path.
         *
         * This will not necessarily return an exact match for a domain and path. Instead, it
         * breaks the domain and path into pieces that are then used to match the closest
         * possibility from a query.
         *
         * The intent of this method is to match a network during bootstrap for a
         * requested site address.
         *
         * @since 4.4.0
         *
         * @param string   $domain   Domain to check.
         * @param string   $path     Path to check.
         * @param int|null $segments Path segments to use. Defaults to null, or the full path.
         * @return WP_Network|false Network object if successful. False when no network is found.
         */
        public static function get_by_path($domain = '', $path = '', $segments = \null)
        {
        }
    }
    /**
     * Core class that implements an object cache.
     *
     * The WordPress Object Cache is used to save on trips to the database. The
     * Object Cache stores all of the cache data to memory and makes the cache
     * contents available by using a key, which is used to name and later retrieve
     * the cache contents.
     *
     * The Object Cache can be replaced by other caching mechanisms by placing files
     * in the wp-content folder which is looked at in wp-settings. If that file
     * exists, then this file will not be included.
     *
     * @since 2.0.0
     */
    #[\AllowDynamicProperties]
    class WP_Object_Cache
    {
        /**
         * The amount of times the cache data was already stored in the cache.
         *
         * @since 2.5.0
         * @var int
         */
        public $cache_hits = 0;
        /**
         * Amount of times the cache did not have the request in cache.
         *
         * @since 2.0.0
         * @var int
         */
        public $cache_misses = 0;
        /**
         * List of global cache groups.
         *
         * @since 3.0.0
         * @var string[]
         */
        protected $global_groups = array();
        /**
         * Sets up object properties.
         *
         * @since 2.0.8
         */
        public function __construct()
        {
        }
        /**
         * Makes private properties readable for backward compatibility.
         *
         * @since 4.0.0
         *
         * @param string $name Property to get.
         * @return mixed Property.
         */
        public function __get($name)
        {
        }
        /**
         * Makes private properties settable for backward compatibility.
         *
         * @since 4.0.0
         *
         * @param string $name  Property to set.
         * @param mixed  $value Property value.
         */
        public function __set($name, $value)
        {
        }
        /**
         * Makes private properties checkable for backward compatibility.
         *
         * @since 4.0.0
         *
         * @param string $name Property to check if set.
         * @return bool Whether the property is set.
         */
        public function __isset($name)
        {
        }
        /**
         * Makes private properties un-settable for backward compatibility.
         *
         * @since 4.0.0
         *
         * @param string $name Property to unset.
         */
        public function __unset($name)
        {
        }
        /**
         * Serves as a utility function to determine whether a key is valid.
         *
         * @since 6.1.0
         *
         * @param int|string $key Cache key to check for validity.
         * @return bool Whether the key is valid.
         */
        protected function is_valid_key($key)
        {
        }
        /**
         * Serves as a utility function to determine whether a key exists in the cache.
         *
         * @since 3.4.0
         *
         * @param int|string $key   Cache key to check for existence.
         * @param string     $group Cache group for the key existence check.
         * @return bool Whether the key exists in the cache for the given group.
         */
        protected function _exists($key, $group)
        {
        }
        /**
         * Adds data to the cache if it doesn't already exist.
         *
         * @since 2.0.0
         *
         * @uses WP_Object_Cache::_exists() Checks to see if the cache already has data.
         * @uses WP_Object_Cache::set()     Sets the data after the checking the cache
         *                                  contents existence.
         *
         * @param int|string $key    What to call the contents in the cache.
         * @param mixed      $data   The contents to store in the cache.
         * @param string     $group  Optional. Where to group the cache contents. Default 'default'.
         * @param int        $expire Optional. When to expire the cache contents, in seconds.
         *                           Default 0 (no expiration).
         * @return bool True on success, false if cache key and group already exist.
         */
        public function add($key, $data, $group = 'default', $expire = 0)
        {
        }
        /**
         * Adds multiple values to the cache in one call.
         *
         * @since 6.0.0
         *
         * @param array  $data   Array of keys and values to be added.
         * @param string $group  Optional. Where the cache contents are grouped. Default empty.
         * @param int    $expire Optional. When to expire the cache contents, in seconds.
         *                       Default 0 (no expiration).
         * @return bool[] Array of return values, grouped by key. Each value is either
         *                true on success, or false if cache key and group already exist.
         */
        public function add_multiple(array $data, $group = '', $expire = 0)
        {
        }
        /**
         * Replaces the contents in the cache, if contents already exist.
         *
         * @since 2.0.0
         *
         * @see WP_Object_Cache::set()
         *
         * @param int|string $key    What to call the contents in the cache.
         * @param mixed      $data   The contents to store in the cache.
         * @param string     $group  Optional. Where to group the cache contents. Default 'default'.
         * @param int        $expire Optional. When to expire the cache contents, in seconds.
         *                           Default 0 (no expiration).
         * @return bool True if contents were replaced, false if original value does not exist.
         */
        public function replace($key, $data, $group = 'default', $expire = 0)
        {
        }
        /**
         * Sets the data contents into the cache.
         *
         * The cache contents are grouped by the $group parameter followed by the
         * $key. This allows for duplicate IDs in unique groups. Therefore, naming of
         * the group should be used with care and should follow normal function
         * naming guidelines outside of core WordPress usage.
         *
         * The $expire parameter is not used, because the cache will automatically
         * expire for each time a page is accessed and PHP finishes. The method is
         * more for cache plugins which use files.
         *
         * @since 2.0.0
         * @since 6.1.0 Returns false if cache key is invalid.
         *
         * @param int|string $key    What to call the contents in the cache.
         * @param mixed      $data   The contents to store in the cache.
         * @param string     $group  Optional. Where to group the cache contents. Default 'default'.
         * @param int        $expire Optional. Not used.
         * @return bool True if contents were set, false if key is invalid.
         */
        public function set($key, $data, $group = 'default', $expire = 0)
        {
        }
        /**
         * Sets multiple values to the cache in one call.
         *
         * @since 6.0.0
         *
         * @param array  $data   Array of key and value to be set.
         * @param string $group  Optional. Where the cache contents are grouped. Default empty.
         * @param int    $expire Optional. When to expire the cache contents, in seconds.
         *                       Default 0 (no expiration).
         * @return bool[] Array of return values, grouped by key. Each value is always true.
         */
        public function set_multiple(array $data, $group = '', $expire = 0)
        {
        }
        /**
         * Retrieves the cache contents, if it exists.
         *
         * The contents will be first attempted to be retrieved by searching by the
         * key in the cache group. If the cache is hit (success) then the contents
         * are returned.
         *
         * On failure, the number of cache misses will be incremented.
         *
         * @since 2.0.0
         *
         * @param int|string $key   The key under which the cache contents are stored.
         * @param string     $group Optional. Where the cache contents are grouped. Default 'default'.
         * @param bool       $force Optional. Unused. Whether to force an update of the local cache
         *                          from the persistent cache. Default false.
         * @param bool       $found Optional. Whether the key was found in the cache (passed by reference).
         *                          Disambiguates a return of false, a storable value. Default null.
         * @return mixed|false The cache contents on success, false on failure to retrieve contents.
         */
        public function get($key, $group = 'default', $force = \false, &$found = \null)
        {
        }
        /**
         * Retrieves multiple values from the cache in one call.
         *
         * @since 5.5.0
         *
         * @param array  $keys  Array of keys under which the cache contents are stored.
         * @param string $group Optional. Where the cache contents are grouped. Default 'default'.
         * @param bool   $force Optional. Whether to force an update of the local cache
         *                      from the persistent cache. Default false.
         * @return array Array of return values, grouped by key. Each value is either
         *               the cache contents on success, or false on failure.
         */
        public function get_multiple($keys, $group = 'default', $force = \false)
        {
        }
        /**
         * Removes the contents of the cache key in the group.
         *
         * If the cache key does not exist in the group, then nothing will happen.
         *
         * @since 2.0.0
         *
         * @param int|string $key        What the contents in the cache are called.
         * @param string     $group      Optional. Where the cache contents are grouped. Default 'default'.
         * @param bool       $deprecated Optional. Unused. Default false.
         * @return bool True on success, false if the contents were not deleted.
         */
        public function delete($key, $group = 'default', $deprecated = \false)
        {
        }
        /**
         * Deletes multiple values from the cache in one call.
         *
         * @since 6.0.0
         *
         * @param array  $keys  Array of keys to be deleted.
         * @param string $group Optional. Where the cache contents are grouped. Default empty.
         * @return bool[] Array of return values, grouped by key. Each value is either
         *                true on success, or false if the contents were not deleted.
         */
        public function delete_multiple(array $keys, $group = '')
        {
        }
        /**
         * Increments numeric cache item's value.
         *
         * @since 3.3.0
         *
         * @param int|string $key    The cache key to increment.
         * @param int        $offset Optional. The amount by which to increment the item's value.
         *                           Default 1.
         * @param string     $group  Optional. The group the key is in. Default 'default'.
         * @return int|false The item's new value on success, false on failure.
         */
        public function incr($key, $offset = 1, $group = 'default')
        {
        }
        /**
         * Decrements numeric cache item's value.
         *
         * @since 3.3.0
         *
         * @param int|string $key    The cache key to decrement.
         * @param int        $offset Optional. The amount by which to decrement the item's value.
         *                           Default 1.
         * @param string     $group  Optional. The group the key is in. Default 'default'.
         * @return int|false The item's new value on success, false on failure.
         */
        public function decr($key, $offset = 1, $group = 'default')
        {
        }
        /**
         * Clears the object cache of all data.
         *
         * @since 2.0.0
         *
         * @return true Always returns true.
         */
        public function flush()
        {
        }
        /**
         * Removes all cache items in a group.
         *
         * @since 6.1.0
         *
         * @param string $group Name of group to remove from cache.
         * @return true Always returns true.
         */
        public function flush_group($group)
        {
        }
        /**
         * Sets the list of global cache groups.
         *
         * @since 3.0.0
         *
         * @param string|string[] $groups List of groups that are global.
         */
        public function add_global_groups($groups)
        {
        }
        /**
         * Switches the internal blog ID.
         *
         * This changes the blog ID used to create keys in blog specific groups.
         *
         * @since 3.5.0
         *
         * @param int $blog_id Blog ID.
         */
        public function switch_to_blog($blog_id)
        {
        }
        /**
         * Resets cache keys.
         *
         * @since 3.0.0
         *
         * @deprecated 3.5.0 Use WP_Object_Cache::switch_to_blog()
         * @see switch_to_blog()
         */
        public function reset()
        {
        }
        /**
         * Echoes the stats of the caching.
         *
         * Gives the cache hits, and cache misses. Also prints every cached group,
         * key and the data.
         *
         * @since 2.0.0
         */
        public function stats()
        {
        }
    }
    /**
     * oEmbed API endpoint controller.
     *
     * Registers the REST API route and delivers the response data.
     * The output format (XML or JSON) is handled by the REST API.
     *
     * @since 4.4.0
     */
    #[\AllowDynamicProperties]
    final class WP_oEmbed_Controller
    {
        /**
         * Register the oEmbed REST API route.
         *
         * @since 4.4.0
         */
        public function register_routes()
        {
        }
        /**
         * Callback for the embed API endpoint.
         *
         * Returns the JSON object for the post.
         *
         * @since 4.4.0
         *
         * @param WP_REST_Request $request Full data about the request.
         * @return array|WP_Error oEmbed response data or WP_Error on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Checks if current user can make a proxy oEmbed request.
         *
         * @since 4.8.0
         *
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_proxy_item_permissions_check()
        {
        }
        /**
         * Callback for the proxy API endpoint.
         *
         * Returns the JSON object for the proxied item.
         *
         * @since 4.8.0
         *
         * @see WP_oEmbed::get_html()
         * @global WP_Embed   $wp_embed   WordPress Embed object.
         * @global WP_Scripts $wp_scripts
         *
         * @param WP_REST_Request $request Full data about the request.
         * @return object|WP_Error oEmbed response data or WP_Error on failure.
         */
        public function get_proxy_item($request)
        {
        }
    }
    /**
     * Core class used to implement oEmbed functionality.
     *
     * @since 2.9.0
     */
    #[\AllowDynamicProperties]
    class WP_oEmbed
    {
        /**
         * A list of oEmbed providers.
         *
         * @since 2.9.0
         * @var array
         */
        public $providers = array();
        /**
         * A list of an early oEmbed providers.
         *
         * @since 4.0.0
         * @var array
         */
        public static $early_providers = array();
        /**
         * Constructor.
         *
         * @since 2.9.0
         */
        public function __construct()
        {
        }
        /**
         * Exposes private/protected methods for backward compatibility.
         *
         * @since 4.0.0
         *
         * @param string $name      Method to call.
         * @param array  $arguments Arguments to pass when calling.
         * @return mixed|false Return value of the callback, false otherwise.
         */
        public function __call($name, $arguments)
        {
        }
        /**
         * Takes a URL and returns the corresponding oEmbed provider's URL, if there is one.
         *
         * @since 4.0.0
         *
         * @see WP_oEmbed::discover()
         *
         * @param string       $url  The URL to the content.
         * @param string|array $args {
         *     Optional. Additional provider arguments. Default empty.
         *
         *     @type bool $discover Optional. Determines whether to attempt to discover link tags
         *                          at the given URL for an oEmbed provider when the provider URL
         *                          is not found in the built-in providers list. Default true.
         * }
         * @return string|false The oEmbed provider URL on success, false on failure.
         * @phpstan-param array{
         *   discover?: bool,
         * } $args
         */
        public function get_provider($url, $args = '')
        {
        }
        /**
         * Adds an oEmbed provider.
         *
         * The provider is added just-in-time when wp_oembed_add_provider() is called before
         * the {@see 'plugins_loaded'} hook.
         *
         * The just-in-time addition is for the benefit of the {@see 'oembed_providers'} filter.
         *
         * @since 4.0.0
         *
         * @see wp_oembed_add_provider()
         *
         * @param string $format   Format of URL that this provider can handle. You can use
         *                         asterisks as wildcards.
         * @param string $provider The URL to the oEmbed provider..
         * @param bool   $regex    Optional. Whether the $format parameter is in a regex format.
         *                         Default false.
         */
        public static function _add_provider_early($format, $provider, $regex = \false)
        {
        }
        /**
         * Removes an oEmbed provider.
         *
         * The provider is removed just-in-time when wp_oembed_remove_provider() is called before
         * the {@see 'plugins_loaded'} hook.
         *
         * The just-in-time removal is for the benefit of the {@see 'oembed_providers'} filter.
         *
         * @since 4.0.0
         *
         * @see wp_oembed_remove_provider()
         *
         * @param string $format The format of URL that this provider can handle. You can use
         *                       asterisks as wildcards.
         */
        public static function _remove_provider_early($format)
        {
        }
        /**
         * Takes a URL and attempts to return the oEmbed data.
         *
         * @see WP_oEmbed::fetch()
         *
         * @since 4.8.0
         *
         * @param string       $url  The URL to the content that should be attempted to be embedded.
         * @param string|array $args Optional. Additional arguments for retrieving embed HTML.
         *                           See wp_oembed_get() for accepted arguments. Default empty.
         * @return object|false The result in the form of an object on success, false on failure.
         * @phpstan-param array{
         *   width?: int|string,
         *   height?: int|string,
         *   discover?: bool,
         * } $args See wp_oembed_get()
         */
        public function get_data($url, $args = '')
        {
        }
        /**
         * The do-it-all function that takes a URL and attempts to return the HTML.
         *
         * @see WP_oEmbed::fetch()
         * @see WP_oEmbed::data2html()
         *
         * @since 2.9.0
         *
         * @param string       $url  The URL to the content that should be attempted to be embedded.
         * @param string|array $args Optional. Additional arguments for retrieving embed HTML.
         *                           See wp_oembed_get() for accepted arguments. Default empty.
         * @return string|false The UNSANITIZED (and potentially unsafe) HTML that should be used to embed
         *                      on success, false on failure.
         * @phpstan-param array{
         *   width?: int|string,
         *   height?: int|string,
         *   discover?: bool,
         * } $args See wp_oembed_get()
         */
        public function get_html($url, $args = '')
        {
        }
        /**
         * Attempts to discover link tags at the given URL for an oEmbed provider.
         *
         * @since 2.9.0
         *
         * @param string $url The URL that should be inspected for discovery `<link>` tags.
         * @return string|false The oEmbed provider URL on success, false on failure.
         */
        public function discover($url)
        {
        }
        /**
         * Connects to an oEmbed provider and returns the result.
         *
         * @since 2.9.0
         *
         * @param string       $provider The URL to the oEmbed provider.
         * @param string       $url      The URL to the content that is desired to be embedded.
         * @param string|array $args     Optional. Additional arguments for retrieving embed HTML.
         *                               See wp_oembed_get() for accepted arguments. Default empty.
         * @return object|false The result in the form of an object on success, false on failure.
         * @phpstan-param array{
         *   width?: int|string,
         *   height?: int|string,
         *   discover?: bool,
         * } $args See wp_oembed_get()
         */
        public function fetch($provider, $url, $args = '')
        {
        }
        /**
         * Converts a data object from WP_oEmbed::fetch() and returns the HTML.
         *
         * @since 2.9.0
         *
         * @param object $data A data object result from an oEmbed provider.
         * @param string $url  The URL to the content that is desired to be embedded.
         * @return string|false The HTML needed to embed on success, false on failure.
         */
        public function data2html($data, $url)
        {
        }
        /**
         * Strips any new lines from the HTML.
         *
         * @since 2.9.0 as strip_scribd_newlines()
         * @since 3.0.0
         *
         * @param string $html Existing HTML.
         * @param object $data Data object from WP_oEmbed::data2html()
         * @param string $url The original URL passed to oEmbed.
         * @return string Possibly modified $html
         */
        public function _strip_newlines($html, $data, $url)
        {
        }
    }
    /**
     * Core class used for storing paused extensions.
     *
     * @since 5.2.0
     */
    #[\AllowDynamicProperties]
    class WP_Paused_Extensions_Storage
    {
        /**
         * Type of extension. Used to key extension storage. Either 'plugin' or 'theme'.
         *
         * @since 5.2.0
         * @var string
         */
        protected $type;
        /**
         * Constructor.
         *
         * @since 5.2.0
         *
         * @param string $extension_type Extension type. Either 'plugin' or 'theme'.
         * @phpstan-param 'plugin'|'theme' $extension_type
         */
        public function __construct($extension_type)
        {
        }
        /**
         * Records an extension error.
         *
         * Only one error is stored per extension, with subsequent errors for the same extension overriding the
         * previously stored error.
         *
         * @since 5.2.0
         *
         * @param string $extension Plugin or theme directory name.
         * @param array  $error     {
         *     Error information returned by `error_get_last()`.
         *
         *     @type int    $type    The error type.
         *     @type string $file    The name of the file in which the error occurred.
         *     @type int    $line    The line number in which the error occurred.
         *     @type string $message The error message.
         * }
         * @return bool True on success, false on failure.
         * @phpstan-param array{
         *   type?: int,
         *   file?: string,
         *   line?: int,
         *   message?: string,
         * } $error
         */
        public function set($extension, $error)
        {
        }
        /**
         * Forgets a previously recorded extension error.
         *
         * @since 5.2.0
         *
         * @param string $extension Plugin or theme directory name.
         * @return bool True on success, false on failure.
         */
        public function delete($extension)
        {
        }
        /**
         * Gets the error for an extension, if paused.
         *
         * @since 5.2.0
         *
         * @param string $extension Plugin or theme directory name.
         * @return array|null Error that is stored, or null if the extension is not paused.
         */
        public function get($extension)
        {
        }
        /**
         * Gets the paused extensions with their errors.
         *
         * @since 5.2.0
         *
         * @return array {
         *     Associative array of errors keyed by extension slug.
         *
         *     @type array ...$0 Error information returned by `error_get_last()`.
         * }
         * @phpstan-return array<int|string, array>
         */
        public function get_all()
        {
        }
        /**
         * Remove all paused extensions.
         *
         * @since 5.2.0
         *
         * @return bool
         */
        public function delete_all()
        {
        }
        /**
         * Checks whether the underlying API to store paused extensions is loaded.
         *
         * @since 5.2.0
         *
         * @return bool True if the API is loaded, false otherwise.
         */
        protected function is_api_loaded()
        {
        }
        /**
         * Get the option name for storing paused extensions.
         *
         * @since 5.2.0
         *
         * @return string
         */
        protected function get_option_name()
        {
        }
    }
    /**
     * Core class for installing plugin dependencies.
     *
     * It is designed to add plugin dependencies as designated in the
     * `Requires Plugins` header to a new view in the plugins install page.
     */
    class WP_Plugin_Dependencies
    {
        /**
         * Holds 'get_plugins()'.
         *
         * @since 6.5.0
         *
         * @var array
         */
        protected static $plugins;
        /**
         * Holds plugin directory names to compare with cache.
         *
         * @since 6.5.0
         *
         * @var array
         */
        protected static $plugin_dirnames;
        /**
         * Holds sanitized plugin dependency slugs.
         *
         * Keyed on the dependent plugin's filepath,
         * relative to the plugins directory.
         *
         * @since 6.5.0
         *
         * @var array
         */
        protected static $dependencies;
        /**
         * Holds an array of sanitized plugin dependency slugs.
         *
         * @since 6.5.0
         *
         * @var array
         */
        protected static $dependency_slugs;
        /**
         * Holds an array of dependent plugin slugs.
         *
         * Keyed on the dependent plugin's filepath,
         * relative to the plugins directory.
         *
         * @since 6.5.0
         *
         * @var array
         */
        protected static $dependent_slugs;
        /**
         * Holds 'plugins_api()' data for plugin dependencies.
         *
         * @since 6.5.0
         *
         * @var array
         */
        protected static $dependency_api_data;
        /**
         * Holds plugin dependency filepaths, relative to the plugins directory.
         *
         * Keyed on the dependency's slug.
         *
         * @since 6.5.0
         *
         * @var string[]
         */
        protected static $dependency_filepaths;
        /**
         * An array of circular dependency pairings.
         *
         * @since 6.5.0
         *
         * @var array[]
         */
        protected static $circular_dependencies_pairs;
        /**
         * An array of circular dependency slugs.
         *
         * @since 6.5.0
         *
         * @var string[]
         */
        protected static $circular_dependencies_slugs;
        /**
         * Whether Plugin Dependencies have been initialized.
         *
         * @since 6.5.0
         *
         * @var bool
         */
        protected static $initialized = \false;
        /**
         * Initializes by fetching plugin header and plugin API data.
         *
         * @since 6.5.0
         */
        public static function initialize()
        {
        }
        /**
         * Determines whether the plugin has plugins that depend on it.
         *
         * @since 6.5.0
         *
         * @param string $plugin_file The plugin's filepath, relative to the plugins directory.
         * @return bool Whether the plugin has plugins that depend on it.
         */
        public static function has_dependents($plugin_file)
        {
        }
        /**
         * Determines whether the plugin has plugin dependencies.
         *
         * @since 6.5.0
         *
         * @param string $plugin_file The plugin's filepath, relative to the plugins directory.
         * @return bool Whether a plugin has plugin dependencies.
         */
        public static function has_dependencies($plugin_file)
        {
        }
        /**
         * Determines whether the plugin has active dependents.
         *
         * @since 6.5.0
         *
         * @param string $plugin_file The plugin's filepath, relative to the plugins directory.
         * @return bool Whether the plugin has active dependents.
         */
        public static function has_active_dependents($plugin_file)
        {
        }
        /**
         * Gets filepaths of plugins that require the dependency.
         *
         * @since 6.5.0
         *
         * @param string $slug The dependency's slug.
         * @return array An array of dependent plugin filepaths, relative to the plugins directory.
         */
        public static function get_dependents($slug)
        {
        }
        /**
         * Gets the slugs of plugins that the dependent requires.
         *
         * @since 6.5.0
         *
         * @param string $plugin_file The dependent plugin's filepath, relative to the plugins directory.
         * @return array An array of dependency plugin slugs.
         */
        public static function get_dependencies($plugin_file)
        {
        }
        /**
         * Gets a dependent plugin's filepath.
         *
         * @since 6.5.0
         *
         * @param string $slug  The dependent plugin's slug.
         * @return string|false The dependent plugin's filepath, relative to the plugins directory,
         *                      or false if the plugin has no dependencies.
         */
        public static function get_dependent_filepath($slug)
        {
        }
        /**
         * Determines whether the plugin has unmet dependencies.
         *
         * @since 6.5.0
         *
         * @param string $plugin_file The plugin's filepath, relative to the plugins directory.
         * @return bool Whether the plugin has unmet dependencies.
         */
        public static function has_unmet_dependencies($plugin_file)
        {
        }
        /**
         * Determines whether the plugin has a circular dependency.
         *
         * @since 6.5.0
         *
         * @param string $plugin_file The plugin's filepath, relative to the plugins directory.
         * @return bool Whether the plugin has a circular dependency.
         */
        public static function has_circular_dependency($plugin_file)
        {
        }
        /**
         * Gets the names of plugins that require the plugin.
         *
         * @since 6.5.0
         *
         * @param string $plugin_file The plugin's filepath, relative to the plugins directory.
         * @return array An array of dependent names.
         */
        public static function get_dependent_names($plugin_file)
        {
        }
        /**
         * Gets the names of plugins required by the plugin.
         *
         * @since 6.5.0
         *
         * @param string $plugin_file The dependent plugin's filepath, relative to the plugins directory.
         * @return array An array of dependency names.
         */
        public static function get_dependency_names($plugin_file)
        {
        }
        /**
         * Gets the filepath for a dependency, relative to the plugin's directory.
         *
         * @since 6.5.0
         *
         * @param string $slug The dependency's slug.
         * @return string|false If installed, the dependency's filepath relative to the plugins directory, otherwise false.
         */
        public static function get_dependency_filepath($slug)
        {
        }
        /**
         * Returns API data for the dependency.
         *
         * @since 6.5.0
         *
         * @param string $slug The dependency's slug.
         * @return array|false The dependency's API data on success, otherwise false.
         */
        public static function get_dependency_data($slug)
        {
        }
        /**
         * Displays an admin notice if dependencies are not installed.
         *
         * @since 6.5.0
         */
        public static function display_admin_notice_for_unmet_dependencies()
        {
        }
        /**
         * Displays an admin notice if circular dependencies are installed.
         *
         * @since 6.5.0
         */
        public static function display_admin_notice_for_circular_dependencies()
        {
        }
        /**
         * Checks plugin dependencies after a plugin is installed via AJAX.
         *
         * @since 6.5.0
         */
        public static function check_plugin_dependencies_during_ajax()
        {
        }
        /**
         * Gets data for installed plugins.
         *
         * @since 6.5.0
         *
         * @return array An array of plugin data.
         */
        protected static function get_plugins()
        {
        }
        /**
         * Reads and stores dependency slugs from a plugin's 'Requires Plugins' header.
         *
         * @since 6.5.0
         */
        protected static function read_dependencies_from_plugin_headers()
        {
        }
        /**
         * Sanitizes slugs.
         *
         * @since 6.5.0
         *
         * @param string $slugs A comma-separated string of plugin dependency slugs.
         * @return array An array of sanitized plugin dependency slugs.
         */
        protected static function sanitize_dependency_slugs($slugs)
        {
        }
        /**
         * Gets the filepath of installed dependencies.
         * If a dependency is not installed, the filepath defaults to false.
         *
         * @since 6.5.0
         *
         * @return array An array of install dependencies filepaths, relative to the plugins directory.
         */
        protected static function get_dependency_filepaths()
        {
        }
        /**
         * Retrieves and stores dependency plugin data from the WordPress.org Plugin API.
         *
         * @since 6.5.0
         *
         * @global string $pagenow The filename of the current screen.
         *
         * @return array|void An array of dependency API data, or void on early exit.
         */
        protected static function get_dependency_api_data()
        {
        }
        /**
         * Gets plugin directory names.
         *
         * @since 6.5.0
         *
         * @return array An array of plugin directory names.
         */
        protected static function get_plugin_dirnames()
        {
        }
        /**
         * Gets circular dependency data.
         *
         * @since 6.5.0
         *
         * @return array[] An array of circular dependency pairings.
         */
        protected static function get_circular_dependencies()
        {
        }
        /**
         * Checks for circular dependencies.
         *
         * @since 6.5.0
         *
         * @param array $dependents   Array of dependent plugins.
         * @param array $dependencies Array of plugins dependencies.
         * @return array A circular dependency pairing, or an empty array if none exists.
         */
        protected static function check_for_circular_dependencies($dependents, $dependencies)
        {
        }
        /**
         * Converts a plugin filepath to a slug.
         *
         * @since 6.5.0
         *
         * @param string $plugin_file The plugin's filepath, relative to the plugins directory.
         * @return string The plugin's slug.
         */
        protected static function convert_to_slug($plugin_file)
        {
        }
    }
    /**
     * Core class used for interacting with post types.
     *
     * @since 4.6.0
     *
     * @see register_post_type()
     */
    #[\AllowDynamicProperties]
    final class WP_Post_Type
    {
        /**
         * Post type key.
         *
         * @since 4.6.0
         * @var string $name
         */
        public $name;
        /**
         * Name of the post type shown in the menu. Usually plural.
         *
         * @since 4.6.0
         * @var string $label
         */
        public $label;
        /**
         * Labels object for this post type.
         *
         * If not set, post labels are inherited for non-hierarchical types
         * and page labels for hierarchical ones.
         *
         * @see get_post_type_labels()
         *
         * @since 4.6.0
         * @var stdClass $labels
         */
        public $labels;
        /**
         * A short descriptive summary of what the post type is.
         *
         * Default empty.
         *
         * @since 4.6.0
         * @var string $description
         */
        public $description = '';
        /**
         * Whether a post type is intended for use publicly either via the admin interface or by front-end users.
         *
         * While the default settings of $exclude_from_search, $publicly_queryable, $show_ui, and $show_in_nav_menus
         * are inherited from public, each does not rely on this relationship and controls a very specific intention.
         *
         * Default false.
         *
         * @since 4.6.0
         * @var bool $public
         */
        public $public = \false;
        /**
         * Whether the post type is hierarchical (e.g. page).
         *
         * Default false.
         *
         * @since 4.6.0
         * @var bool $hierarchical
         */
        public $hierarchical = \false;
        /**
         * Whether to exclude posts with this post type from front end search
         * results.
         *
         * Default is the opposite value of $public.
         *
         * @since 4.6.0
         * @var bool $exclude_from_search
         */
        public $exclude_from_search = \null;
        /**
         * Whether queries can be performed on the front end for the post type as part of `parse_request()`.
         *
         * Endpoints would include:
         *
         * - `?post_type={post_type_key}`
         * - `?{post_type_key}={single_post_slug}`
         * - `?{post_type_query_var}={single_post_slug}`
         *
         * Default is the value of $public.
         *
         * @since 4.6.0
         * @var bool $publicly_queryable
         */
        public $publicly_queryable = \null;
        /**
         * Whether to generate and allow a UI for managing this post type in the admin.
         *
         * Default is the value of $public.
         *
         * @since 4.6.0
         * @var bool $show_ui
         */
        public $show_ui = \null;
        /**
         * Where to show the post type in the admin menu.
         *
         * To work, $show_ui must be true. If true, the post type is shown in its own top level menu. If false, no menu is
         * shown. If a string of an existing top level menu ('tools.php' or 'edit.php?post_type=page', for example), the
         * post type will be placed as a sub-menu of that.
         *
         * Default is the value of $show_ui.
         *
         * @since 4.6.0
         * @var bool|string $show_in_menu
         */
        public $show_in_menu = \null;
        /**
         * Makes this post type available for selection in navigation menus.
         *
         * Default is the value $public.
         *
         * @since 4.6.0
         * @var bool $show_in_nav_menus
         */
        public $show_in_nav_menus = \null;
        /**
         * Makes this post type available via the admin bar.
         *
         * Default is the value of $show_in_menu.
         *
         * @since 4.6.0
         * @var bool $show_in_admin_bar
         */
        public $show_in_admin_bar = \null;
        /**
         * The position in the menu order the post type should appear.
         *
         * To work, $show_in_menu must be true. Default null (at the bottom).
         *
         * @since 4.6.0
         * @var int $menu_position
         */
        public $menu_position = \null;
        /**
         * The URL or reference to the icon to be used for this menu.
         *
         * Pass a base64-encoded SVG using a data URI, which will be colored to match the color scheme.
         * This should begin with 'data:image/svg+xml;base64,'. Pass the name of a Dashicons helper class
         * to use a font icon, e.g. 'dashicons-chart-pie'. Pass 'none' to leave div.wp-menu-image empty
         * so an icon can be added via CSS.
         *
         * Defaults to use the posts icon.
         *
         * @since 4.6.0
         * @var string $menu_icon
         */
        public $menu_icon = \null;
        /**
         * The string to use to build the read, edit, and delete capabilities.
         *
         * May be passed as an array to allow for alternative plurals when using
         * this argument as a base to construct the capabilities, e.g.
         * array( 'story', 'stories' ). Default 'post'.
         *
         * @since 4.6.0
         * @var string $capability_type
         */
        public $capability_type = 'post';
        /**
         * Whether to use the internal default meta capability handling.
         *
         * Default false.
         *
         * @since 4.6.0
         * @var bool $map_meta_cap
         */
        public $map_meta_cap = \false;
        /**
         * Provide a callback function that sets up the meta boxes for the edit form.
         *
         * Do `remove_meta_box()` and `add_meta_box()` calls in the callback. Default null.
         *
         * @since 4.6.0
         * @var callable $register_meta_box_cb
         */
        public $register_meta_box_cb = \null;
        /**
         * An array of taxonomy identifiers that will be registered for the post type.
         *
         * Taxonomies can be registered later with `register_taxonomy()` or `register_taxonomy_for_object_type()`.
         *
         * Default empty array.
         *
         * @since 4.6.0
         * @var string[] $taxonomies
         */
        public $taxonomies = array();
        /**
         * Whether there should be post type archives, or if a string, the archive slug to use.
         *
         * Will generate the proper rewrite rules if $rewrite is enabled. Default false.
         *
         * @since 4.6.0
         * @var bool|string $has_archive
         */
        public $has_archive = \false;
        /**
         * Sets the query_var key for this post type.
         *
         * Defaults to $post_type key. If false, a post type cannot be loaded at `?{query_var}={post_slug}`.
         * If specified as a string, the query `?{query_var_string}={post_slug}` will be valid.
         *
         * @since 4.6.0
         * @var string|bool $query_var
         */
        public $query_var;
        /**
         * Whether to allow this post type to be exported.
         *
         * Default true.
         *
         * @since 4.6.0
         * @var bool $can_export
         */
        public $can_export = \true;
        /**
         * Whether to delete posts of this type when deleting a user.
         *
         * - If true, posts of this type belonging to the user will be moved to Trash when the user is deleted.
         * - If false, posts of this type belonging to the user will *not* be trashed or deleted.
         * - If not set (the default), posts are trashed if post type supports the 'author' feature.
         *   Otherwise posts are not trashed or deleted.
         *
         * Default null.
         *
         * @since 4.6.0
         * @var bool $delete_with_user
         */
        public $delete_with_user = \null;
        /**
         * Array of blocks to use as the default initial state for an editor session.
         *
         * Each item should be an array containing block name and optional attributes.
         *
         * Default empty array.
         *
         * @link https://developer.wordpress.org/block-editor/developers/block-api/block-templates/
         *
         * @since 5.0.0
         * @var array[] $template
         */
        public $template = array();
        /**
         * Whether the block template should be locked if $template is set.
         *
         * - If set to 'all', the user is unable to insert new blocks, move existing blocks
         *   and delete blocks.
         * - If set to 'insert', the user is able to move existing blocks but is unable to insert
         *   new blocks and delete blocks.
         *
         * Default false.
         *
         * @link https://developer.wordpress.org/block-editor/developers/block-api/block-templates/
         *
         * @since 5.0.0
         * @var string|false $template_lock
         */
        public $template_lock = \false;
        /**
         * Whether this post type is a native or "built-in" post_type.
         *
         * Default false.
         *
         * @since 4.6.0
         * @var bool $_builtin
         */
        public $_builtin = \false;
        /**
         * URL segment to use for edit link of this post type.
         *
         * Default 'post.php?post=%d'.
         *
         * @since 4.6.0
         * @var string $_edit_link
         */
        public $_edit_link = 'post.php?post=%d';
        /**
         * Post type capabilities.
         *
         * @since 4.6.0
         * @var stdClass $cap
         */
        public $cap;
        /**
         * Triggers the handling of rewrites for this post type.
         *
         * Defaults to true, using $post_type as slug.
         *
         * @since 4.6.0
         * @var array|false $rewrite
         */
        public $rewrite;
        /**
         * The features supported by the post type.
         *
         * @since 4.6.0
         * @var array|bool $supports
         */
        public $supports;
        /**
         * Whether this post type should appear in the REST API.
         *
         * Default false. If true, standard endpoints will be registered with
         * respect to $rest_base and $rest_controller_class.
         *
         * @since 4.7.4
         * @var bool $show_in_rest
         */
        public $show_in_rest;
        /**
         * The base path for this post type's REST API endpoints.
         *
         * @since 4.7.4
         * @var string|bool $rest_base
         */
        public $rest_base;
        /**
         * The namespace for this post type's REST API endpoints.
         *
         * @since 5.9.0
         * @var string|bool $rest_namespace
         */
        public $rest_namespace;
        /**
         * The controller for this post type's REST API endpoints.
         *
         * Custom controllers must extend WP_REST_Controller.
         *
         * @since 4.7.4
         * @var string|bool $rest_controller_class
         */
        public $rest_controller_class;
        /**
         * The controller instance for this post type's REST API endpoints.
         *
         * Lazily computed. Should be accessed using {@see WP_Post_Type::get_rest_controller()}.
         *
         * @since 5.3.0
         * @var WP_REST_Controller $rest_controller
         */
        public $rest_controller;
        /**
         * The controller for this post type's revisions REST API endpoints.
         *
         * Custom controllers must extend WP_REST_Controller.
         *
         * @since 6.4.0
         * @var string|bool $revisions_rest_controller_class
         */
        public $revisions_rest_controller_class;
        /**
         * The controller instance for this post type's revisions REST API endpoints.
         *
         * Lazily computed. Should be accessed using {@see WP_Post_Type::get_revisions_rest_controller()}.
         *
         * @since 6.4.0
         * @var WP_REST_Controller $revisions_rest_controller
         */
        public $revisions_rest_controller;
        /**
         * The controller for this post type's autosave REST API endpoints.
         *
         * Custom controllers must extend WP_REST_Controller.
         *
         * @since 6.4.0
         * @var string|bool $autosave_rest_controller_class
         */
        public $autosave_rest_controller_class;
        /**
         * The controller instance for this post type's autosave REST API endpoints.
         *
         * Lazily computed. Should be accessed using {@see WP_Post_Type::get_autosave_rest_controller()}.
         *
         * @since 6.4.0
         * @var WP_REST_Controller $autosave_rest_controller
         */
        public $autosave_rest_controller;
        /**
         * A flag to register the post type REST API controller after its associated autosave / revisions controllers, instead of before. Registration order affects route matching priority.
         *
         * @since 6.4.0
         * @var bool $late_route_registration
         */
        public $late_route_registration;
        /**
         * Constructor.
         *
         * See the register_post_type() function for accepted arguments for `$args`.
         *
         * Will populate object properties from the provided arguments and assign other
         * default properties based on that information.
         *
         * @since 4.6.0
         *
         * @see register_post_type()
         *
         * @param string       $post_type Post type key.
         * @param array|string $args      Optional. Array or string of arguments for registering a post type.
         *                                See register_post_type() for information on accepted arguments.
         *                                Default empty array.
         * @phpstan-param array{
         *   label?: string,
         *   labels?: string[],
         *   description?: string,
         *   public?: bool,
         *   hierarchical?: bool,
         *   exclude_from_search?: bool,
         *   publicly_queryable?: bool,
         *   show_ui?: bool,
         *   show_in_menu?: bool|string,
         *   show_in_nav_menus?: bool,
         *   show_in_admin_bar?: bool,
         *   show_in_rest?: bool,
         *   rest_base?: string,
         *   rest_namespace?: string,
         *   rest_controller_class?: string,
         *   autosave_rest_controller_class?: string|bool,
         *   revisions_rest_controller_class?: string|bool,
         *   late_route_registration?: bool,
         *   menu_position?: int,
         *   menu_icon?: string,
         *   capability_type?: string|array,
         *   capabilities?: string[],
         *   map_meta_cap?: bool,
         *   supports?: array|false,
         *   register_meta_box_cb?: callable,
         *   taxonomies?: string[],
         *   has_archive?: bool|string,
         *   rewrite?: bool|array{
         *     slug?: string,
         *     with_front?: bool,
         *     feeds?: bool,
         *     pages?: bool,
         *     ep_mask?: int,
         *   },
         *   query_var?: string|bool,
         *   can_export?: bool,
         *   delete_with_user?: bool,
         *   template?: array,
         *   template_lock?: string|false,
         *   _builtin?: bool,
         *   _edit_link?: string,
         * } $args See register_post_type()
         */
        public function __construct($post_type, $args = array())
        {
        }
        /**
         * Sets post type properties.
         *
         * See the register_post_type() function for accepted arguments for `$args`.
         *
         * @since 4.6.0
         *
         * @param array|string $args Array or string of arguments for registering a post type.
         */
        public function set_props($args)
        {
        }
        /**
         * Sets the features support for the post type.
         *
         * @since 4.6.0
         */
        public function add_supports()
        {
        }
        /**
         * Adds the necessary rewrite rules for the post type.
         *
         * @since 4.6.0
         *
         * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
         * @global WP         $wp         Current WordPress environment instance.
         */
        public function add_rewrite_rules()
        {
        }
        /**
         * Registers the post type meta box if a custom callback was specified.
         *
         * @since 4.6.0
         */
        public function register_meta_boxes()
        {
        }
        /**
         * Adds the future post hook action for the post type.
         *
         * @since 4.6.0
         */
        public function add_hooks()
        {
        }
        /**
         * Registers the taxonomies for the post type.
         *
         * @since 4.6.0
         */
        public function register_taxonomies()
        {
        }
        /**
         * Removes the features support for the post type.
         *
         * @since 4.6.0
         *
         * @global array $_wp_post_type_features Post type features.
         */
        public function remove_supports()
        {
        }
        /**
         * Removes any rewrite rules, permastructs, and rules for the post type.
         *
         * @since 4.6.0
         *
         * @global WP_Rewrite $wp_rewrite          WordPress rewrite component.
         * @global WP         $wp                  Current WordPress environment instance.
         * @global array      $post_type_meta_caps Used to remove meta capabilities.
         */
        public function remove_rewrite_rules()
        {
        }
        /**
         * Unregisters the post type meta box if a custom callback was specified.
         *
         * @since 4.6.0
         */
        public function unregister_meta_boxes()
        {
        }
        /**
         * Removes the post type from all taxonomies.
         *
         * @since 4.6.0
         */
        public function unregister_taxonomies()
        {
        }
        /**
         * Removes the future post hook action for the post type.
         *
         * @since 4.6.0
         */
        public function remove_hooks()
        {
        }
        /**
         * Gets the REST API controller for this post type.
         *
         * Will only instantiate the controller class once per request.
         *
         * @since 5.3.0
         *
         * @return WP_REST_Controller|null The controller instance, or null if the post type
         *                                 is set not to show in rest.
         */
        public function get_rest_controller()
        {
        }
        /**
         * Gets the REST API revisions controller for this post type.
         *
         * Will only instantiate the controller class once per request.
         *
         * @since 6.4.0
         *
         * @return WP_REST_Controller|null The controller instance, or null if the post type
         *                                 is set not to show in rest.
         */
        public function get_revisions_rest_controller()
        {
        }
        /**
         * Gets the REST API autosave controller for this post type.
         *
         * Will only instantiate the controller class once per request.
         *
         * @since 6.4.0
         *
         * @return WP_REST_Controller|null The controller instance, or null if the post type
         *                                 is set not to show in rest.
         */
        public function get_autosave_rest_controller()
        {
        }
        /**
         * Returns the default labels for post types.
         *
         * @since 6.0.0
         *
         * @return (string|null)[][] The default labels for post types.
         */
        public static function get_default_labels()
        {
        }
        /**
         * Resets the cache for the default labels.
         *
         * @since 6.0.0
         */
        public static function reset_default_labels()
        {
        }
    }
    /**
     * Core class used to implement the WP_Post object.
     *
     * @since 3.5.0
     *
     * @property string $page_template
     *
     * @property-read int[]    $ancestors
     * @property-read int[]    $post_category
     * @property-read string[] $tags_input
     */
    #[\AllowDynamicProperties]
    final class WP_Post
    {
        /**
         * Post ID.
         *
         * @since 3.5.0
         * @var int
         */
        public $ID;
        /**
         * ID of post author.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_author = 0;
        /**
         * The post's local publication time.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_date = '0000-00-00 00:00:00';
        /**
         * The post's GMT publication time.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_date_gmt = '0000-00-00 00:00:00';
        /**
         * The post's content.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_content = '';
        /**
         * The post's title.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_title = '';
        /**
         * The post's excerpt.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_excerpt = '';
        /**
         * The post's status.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_status = 'publish';
        /**
         * Whether comments are allowed.
         *
         * @since 3.5.0
         * @var string
         */
        public $comment_status = 'open';
        /**
         * Whether pings are allowed.
         *
         * @since 3.5.0
         * @var string
         */
        public $ping_status = 'open';
        /**
         * The post's password in plain text.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_password = '';
        /**
         * The post's slug.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_name = '';
        /**
         * URLs queued to be pinged.
         *
         * @since 3.5.0
         * @var string
         */
        public $to_ping = '';
        /**
         * URLs that have been pinged.
         *
         * @since 3.5.0
         * @var string
         */
        public $pinged = '';
        /**
         * The post's local modified time.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_modified = '0000-00-00 00:00:00';
        /**
         * The post's GMT modified time.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_modified_gmt = '0000-00-00 00:00:00';
        /**
         * A utility DB field for post content.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_content_filtered = '';
        /**
         * ID of a post's parent post.
         *
         * @since 3.5.0
         * @var int
         */
        public $post_parent = 0;
        /**
         * The unique identifier for a post, not necessarily a URL, used as the feed GUID.
         *
         * @since 3.5.0
         * @var string
         */
        public $guid = '';
        /**
         * A field used for ordering posts.
         *
         * @since 3.5.0
         * @var int
         */
        public $menu_order = 0;
        /**
         * The post's type, like post or page.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_type = 'post';
        /**
         * An attachment's mime type.
         *
         * @since 3.5.0
         * @var string
         */
        public $post_mime_type = '';
        /**
         * Cached comment count.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 3.5.0
         * @var string
         */
        public $comment_count = 0;
        /**
         * Stores the post object's sanitization level.
         *
         * Does not correspond to a DB field.
         *
         * @since 3.5.0
         * @var string
         */
        public $filter;
        /**
         * Retrieve WP_Post instance.
         *
         * @since 3.5.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param int $post_id Post ID.
         * @return WP_Post|false Post object, false otherwise.
         */
        public static function get_instance($post_id)
        {
        }
        /**
         * Constructor.
         *
         * @since 3.5.0
         *
         * @param WP_Post|object $post Post object.
         */
        public function __construct($post)
        {
        }
        /**
         * Isset-er.
         *
         * @since 3.5.0
         *
         * @param string $key Property to check if set.
         * @return bool
         */
        public function __isset($key)
        {
        }
        /**
         * Getter.
         *
         * @since 3.5.0
         *
         * @param string $key Key to get.
         * @return mixed
         */
        public function __get($key)
        {
        }
        /**
         * {@Missing Summary}
         *
         * @since 3.5.0
         *
         * @param string $filter Filter.
         * @return WP_Post
         */
        public function filter($filter)
        {
        }
        /**
         * Convert object to array.
         *
         * @since 3.5.0
         *
         * @return array Object as array.
         */
        public function to_array()
        {
        }
    }
    /**
     * The WordPress Query class.
     *
     * @link https://developer.wordpress.org/reference/classes/wp_query/
     *
     * @since 1.5.0
     * @since 4.5.0 Removed the `$comments_popup` property.
     * @phpstan-property-read bool $query_vars_changed
     * @phpstan-property-read bool|string $query_vars_hash
     * @phpstan-method void init_query_flags()
     */
    #[\AllowDynamicProperties]
    class WP_Query
    {
        /**
         * Query vars set by the user.
         *
         * @since 1.5.0
         * @var array
         */
        public $query;
        /**
         * Query vars, after parsing.
         *
         * @since 1.5.0
         * @var array
         */
        public $query_vars = array();
        /**
         * Taxonomy query, as passed to get_tax_sql().
         *
         * @since 3.1.0
         * @var WP_Tax_Query|null A taxonomy query instance.
         */
        public $tax_query;
        /**
         * Metadata query container.
         *
         * @since 3.2.0
         * @var WP_Meta_Query A meta query instance.
         */
        public $meta_query = \false;
        /**
         * Date query container.
         *
         * @since 3.7.0
         * @var WP_Date_Query A date query instance.
         */
        public $date_query = \false;
        /**
         * Holds the data for a single object that is queried.
         *
         * Holds the contents of a post, page, category, attachment.
         *
         * @since 1.5.0
         * @var WP_Term|WP_Post_Type|WP_Post|WP_User|null
         */
        public $queried_object;
        /**
         * The ID of the queried object.
         *
         * @since 1.5.0
         * @var int
         */
        public $queried_object_id;
        /**
         * SQL for the database query.
         *
         * @since 2.0.1
         * @var string
         */
        public $request;
        /**
         * Array of post objects or post IDs.
         *
         * @since 1.5.0
         * @var WP_Post[]|int[]
         */
        public $posts;
        /**
         * The number of posts for the current query.
         *
         * @since 1.5.0
         * @var int
         */
        public $post_count = 0;
        /**
         * Index of the current item in the loop.
         *
         * @since 1.5.0
         * @var int
         */
        public $current_post = -1;
        /**
         * Whether the caller is before the loop.
         *
         * @since 6.3.0
         * @var bool
         */
        public $before_loop = \true;
        /**
         * Whether the loop has started and the caller is in the loop.
         *
         * @since 2.0.0
         * @var bool
         */
        public $in_the_loop = \false;
        /**
         * The current post.
         *
         * This property does not get populated when the `fields` argument is set to
         * `ids` or `id=>parent`.
         *
         * @since 1.5.0
         * @var WP_Post|null
         */
        public $post;
        /**
         * The list of comments for current post.
         *
         * @since 2.2.0
         * @var WP_Comment[]
         */
        public $comments;
        /**
         * The number of comments for the posts.
         *
         * @since 2.2.0
         * @var int
         */
        public $comment_count = 0;
        /**
         * The index of the comment in the comment loop.
         *
         * @since 2.2.0
         * @var int
         */
        public $current_comment = -1;
        /**
         * Current comment object.
         *
         * @since 2.2.0
         * @var WP_Comment
         */
        public $comment;
        /**
         * The number of found posts for the current query.
         *
         * If limit clause was not used, equals $post_count.
         *
         * @since 2.1.0
         * @var int
         */
        public $found_posts = 0;
        /**
         * The number of pages.
         *
         * @since 2.1.0
         * @var int
         */
        public $max_num_pages = 0;
        /**
         * The number of comment pages.
         *
         * @since 2.7.0
         * @var int
         */
        public $max_num_comment_pages = 0;
        /**
         * Signifies whether the current query is for a single post.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_single = \false;
        /**
         * Signifies whether the current query is for a preview.
         *
         * @since 2.0.0
         * @var bool
         */
        public $is_preview = \false;
        /**
         * Signifies whether the current query is for a page.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_page = \false;
        /**
         * Signifies whether the current query is for an archive.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_archive = \false;
        /**
         * Signifies whether the current query is for a date archive.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_date = \false;
        /**
         * Signifies whether the current query is for a year archive.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_year = \false;
        /**
         * Signifies whether the current query is for a month archive.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_month = \false;
        /**
         * Signifies whether the current query is for a day archive.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_day = \false;
        /**
         * Signifies whether the current query is for a specific time.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_time = \false;
        /**
         * Signifies whether the current query is for an author archive.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_author = \false;
        /**
         * Signifies whether the current query is for a category archive.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_category = \false;
        /**
         * Signifies whether the current query is for a tag archive.
         *
         * @since 2.3.0
         * @var bool
         */
        public $is_tag = \false;
        /**
         * Signifies whether the current query is for a taxonomy archive.
         *
         * @since 2.5.0
         * @var bool
         */
        public $is_tax = \false;
        /**
         * Signifies whether the current query is for a search.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_search = \false;
        /**
         * Signifies whether the current query is for a feed.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_feed = \false;
        /**
         * Signifies whether the current query is for a comment feed.
         *
         * @since 2.2.0
         * @var bool
         */
        public $is_comment_feed = \false;
        /**
         * Signifies whether the current query is for trackback endpoint call.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_trackback = \false;
        /**
         * Signifies whether the current query is for the site homepage.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_home = \false;
        /**
         * Signifies whether the current query is for the Privacy Policy page.
         *
         * @since 5.2.0
         * @var bool
         */
        public $is_privacy_policy = \false;
        /**
         * Signifies whether the current query couldn't find anything.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_404 = \false;
        /**
         * Signifies whether the current query is for an embed.
         *
         * @since 4.4.0
         * @var bool
         */
        public $is_embed = \false;
        /**
         * Signifies whether the current query is for a paged result and not for the first page.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_paged = \false;
        /**
         * Signifies whether the current query is for an administrative interface page.
         *
         * @since 1.5.0
         * @var bool
         */
        public $is_admin = \false;
        /**
         * Signifies whether the current query is for an attachment page.
         *
         * @since 2.0.0
         * @var bool
         */
        public $is_attachment = \false;
        /**
         * Signifies whether the current query is for an existing single post of any post type
         * (post, attachment, page, custom post types).
         *
         * @since 2.1.0
         * @var bool
         */
        public $is_singular = \false;
        /**
         * Signifies whether the current query is for the robots.txt file.
         *
         * @since 2.1.0
         * @var bool
         */
        public $is_robots = \false;
        /**
         * Signifies whether the current query is for the favicon.ico file.
         *
         * @since 5.4.0
         * @var bool
         */
        public $is_favicon = \false;
        /**
         * Signifies whether the current query is for the page_for_posts page.
         *
         * Basically, the homepage if the option isn't set for the static homepage.
         *
         * @since 2.1.0
         * @var bool
         */
        public $is_posts_page = \false;
        /**
         * Signifies whether the current query is for a post type archive.
         *
         * @since 3.1.0
         * @var bool
         */
        public $is_post_type_archive = \false;
        /**
         * Set if post thumbnails are cached
         *
         * @since 3.2.0
         * @var bool
         */
        public $thumbnails_cached = \false;
        /**
         * Controls whether an attachment query should include filenames or not.
         *
         * @since 6.0.3
         * @var bool
         */
        protected $allow_query_attachment_by_filename = \false;
        /**
         * Initiates object properties and sets default values.
         *
         * @since 1.5.0
         */
        public function init()
        {
        }
        /**
         * Reparses the query vars.
         *
         * @since 1.5.0
         */
        public function parse_query_vars()
        {
        }
        /**
         * Fills in the query variables, which do not exist within the parameter.
         *
         * @since 2.1.0
         * @since 4.5.0 Removed the `comments_popup` public query variable.
         *
         * @param array $query_vars Defined query variables.
         * @return array Complete query variables with undefined ones filled in empty.
         */
        public function fill_query_vars($query_vars)
        {
        }
        /**
         * Parses a query string and sets query type booleans.
         *
         * @since 1.5.0
         * @since 4.2.0 Introduced the ability to order by specific clauses of a `$meta_query`, by passing the clause's
         *              array key to `$orderby`.
         * @since 4.4.0 Introduced `$post_name__in` and `$title` parameters. `$s` was updated to support excluded
         *              search terms, by prepending a hyphen.
         * @since 4.5.0 Removed the `$comments_popup` parameter.
         *              Introduced the `$comment_status` and `$ping_status` parameters.
         *              Introduced `RAND(x)` syntax for `$orderby`, which allows an integer seed value to random sorts.
         * @since 4.6.0 Added 'post_name__in' support for `$orderby`. Introduced the `$lazy_load_term_meta` argument.
         * @since 4.9.0 Introduced the `$comment_count` parameter.
         * @since 5.1.0 Introduced the `$meta_compare_key` parameter.
         * @since 5.3.0 Introduced the `$meta_type_key` parameter.
         * @since 6.1.0 Introduced the `$update_menu_item_cache` parameter.
         * @since 6.2.0 Introduced the `$search_columns` parameter.
         *
         * @param string|array $query {
         *     Optional. Array or string of Query parameters.
         *
         *     @type int             $attachment_id          Attachment post ID. Used for 'attachment' post_type.
         *     @type int|string      $author                 Author ID, or comma-separated list of IDs.
         *     @type string          $author_name            User 'user_nicename'.
         *     @type int[]           $author__in             An array of author IDs to query from.
         *     @type int[]           $author__not_in         An array of author IDs not to query from.
         *     @type bool            $cache_results          Whether to cache post information. Default true.
         *     @type int|string      $cat                    Category ID or comma-separated list of IDs (this or any children).
         *     @type int[]           $category__and          An array of category IDs (AND in).
         *     @type int[]           $category__in           An array of category IDs (OR in, no children).
         *     @type int[]           $category__not_in       An array of category IDs (NOT in).
         *     @type string          $category_name          Use category slug (not name, this or any children).
         *     @type array|int       $comment_count          Filter results by comment count. Provide an integer to match
         *                                                   comment count exactly. Provide an array with integer 'value'
         *                                                   and 'compare' operator ('=', '!=', '>', '>=', '<', '<=' ) to
         *                                                   compare against comment_count in a specific way.
         *     @type string          $comment_status         Comment status.
         *     @type int             $comments_per_page      The number of comments to return per page.
         *                                                   Default 'comments_per_page' option.
         *     @type array           $date_query             An associative array of WP_Date_Query arguments.
         *                                                   See WP_Date_Query::__construct().
         *     @type int             $day                    Day of the month. Default empty. Accepts numbers 1-31.
         *     @type bool            $exact                  Whether to search by exact keyword. Default false.
         *     @type string          $fields                 Post fields to query for. Accepts:
         *                                                   - '' Returns an array of complete post objects (`WP_Post[]`).
         *                                                   - 'ids' Returns an array of post IDs (`int[]`).
         *                                                   - 'id=>parent' Returns an associative array of parent post IDs,
         *                                                     keyed by post ID (`int[]`).
         *                                                   Default ''.
         *     @type int             $hour                   Hour of the day. Default empty. Accepts numbers 0-23.
         *     @type int|bool        $ignore_sticky_posts    Whether to ignore sticky posts or not. Setting this to false
         *                                                   excludes stickies from 'post__in'. Accepts 1|true, 0|false.
         *                                                   Default false.
         *     @type int             $m                      Combination YearMonth. Accepts any four-digit year and month
         *                                                   numbers 01-12. Default empty.
         *     @type string|string[] $meta_key               Meta key or keys to filter by.
         *     @type string|string[] $meta_value             Meta value or values to filter by.
         *     @type string          $meta_compare           MySQL operator used for comparing the meta value.
         *                                                   See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_compare_key       MySQL operator used for comparing the meta key.
         *                                                   See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_type              MySQL data type that the meta_value column will be CAST to for comparisons.
         *                                                   See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_type_key          MySQL data type that the meta_key column will be CAST to for comparisons.
         *                                                   See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type array           $meta_query             An associative array of WP_Meta_Query arguments.
         *                                                   See WP_Meta_Query::__construct() for accepted values.
         *     @type int             $menu_order             The menu order of the posts.
         *     @type int             $minute                 Minute of the hour. Default empty. Accepts numbers 0-59.
         *     @type int             $monthnum               The two-digit month. Default empty. Accepts numbers 1-12.
         *     @type string          $name                   Post slug.
         *     @type bool            $nopaging               Show all posts (true) or paginate (false). Default false.
         *     @type bool            $no_found_rows          Whether to skip counting the total rows found. Enabling can improve
         *                                                   performance. Default false.
         *     @type int             $offset                 The number of posts to offset before retrieval.
         *     @type string          $order                  Designates ascending or descending order of posts. Default 'DESC'.
         *                                                   Accepts 'ASC', 'DESC'.
         *     @type string|array    $orderby                Sort retrieved posts by parameter. One or more options may be passed.
         *                                                   To use 'meta_value', or 'meta_value_num', 'meta_key=keyname' must be
         *                                                   also be defined. To sort by a specific `$meta_query` clause, use that
         *                                                   clause's array key. Accepts:
         *                                                   - 'none'
         *                                                   - 'name'
         *                                                   - 'author'
         *                                                   - 'date'
         *                                                   - 'title'
         *                                                   - 'modified'
         *                                                   - 'menu_order'
         *                                                   - 'parent'
         *                                                   - 'ID'
         *                                                   - 'rand'
         *                                                   - 'relevance'
         *                                                   - 'RAND(x)' (where 'x' is an integer seed value)
         *                                                   - 'comment_count'
         *                                                   - 'meta_value'
         *                                                   - 'meta_value_num'
         *                                                   - 'post__in'
         *                                                   - 'post_name__in'
         *                                                   - 'post_parent__in'
         *                                                   - The array keys of `$meta_query`.
         *                                                   Default is 'date', except when a search is being performed, when
         *                                                   the default is 'relevance'.
         *     @type int             $p                      Post ID.
         *     @type int             $page                   Show the number of posts that would show up on page X of a
         *                                                   static front page.
         *     @type int             $paged                  The number of the current page.
         *     @type int             $page_id                Page ID.
         *     @type string          $pagename               Page slug.
         *     @type string          $perm                   Show posts if user has the appropriate capability.
         *     @type string          $ping_status            Ping status.
         *     @type int[]           $post__in               An array of post IDs to retrieve, sticky posts will be included.
         *     @type int[]           $post__not_in           An array of post IDs not to retrieve. Note: a string of comma-
         *                                                   separated IDs will NOT work.
         *     @type string          $post_mime_type         The mime type of the post. Used for 'attachment' post_type.
         *     @type string[]        $post_name__in          An array of post slugs that results must match.
         *     @type int             $post_parent            Page ID to retrieve child pages for. Use 0 to only retrieve
         *                                                   top-level pages.
         *     @type int[]           $post_parent__in        An array containing parent page IDs to query child pages from.
         *     @type int[]           $post_parent__not_in    An array containing parent page IDs not to query child pages from.
         *     @type string|string[] $post_type              A post type slug (string) or array of post type slugs.
         *                                                   Default 'any' if using 'tax_query'.
         *     @type string|string[] $post_status            A post status (string) or array of post statuses.
         *     @type int             $posts_per_page         The number of posts to query for. Use -1 to request all posts.
         *     @type int             $posts_per_archive_page The number of posts to query for by archive page. Overrides
         *                                                   'posts_per_page' when is_archive(), or is_search() are true.
         *     @type string          $s                      Search keyword(s). Prepending a term with a hyphen will
         *                                                   exclude posts matching that term. Eg, 'pillow -sofa' will
         *                                                   return posts containing 'pillow' but not 'sofa'. The
         *                                                   character used for exclusion can be modified using the
         *                                                   the 'wp_query_search_exclusion_prefix' filter.
         *     @type string[]        $search_columns         Array of column names to be searched. Accepts 'post_title',
         *                                                   'post_excerpt' and 'post_content'. Default empty array.
         *     @type int             $second                 Second of the minute. Default empty. Accepts numbers 0-59.
         *     @type bool            $sentence               Whether to search by phrase. Default false.
         *     @type bool            $suppress_filters       Whether to suppress filters. Default false.
         *     @type string          $tag                    Tag slug. Comma-separated (either), Plus-separated (all).
         *     @type int[]           $tag__and               An array of tag IDs (AND in).
         *     @type int[]           $tag__in                An array of tag IDs (OR in).
         *     @type int[]           $tag__not_in            An array of tag IDs (NOT in).
         *     @type int             $tag_id                 Tag id or comma-separated list of IDs.
         *     @type string[]        $tag_slug__and          An array of tag slugs (AND in).
         *     @type string[]        $tag_slug__in           An array of tag slugs (OR in). unless 'ignore_sticky_posts' is
         *                                                   true. Note: a string of comma-separated IDs will NOT work.
         *     @type array           $tax_query              An associative array of WP_Tax_Query arguments.
         *                                                   See WP_Tax_Query::__construct().
         *     @type string          $title                  Post title.
         *     @type bool            $update_post_meta_cache Whether to update the post meta cache. Default true.
         *     @type bool            $update_post_term_cache Whether to update the post term cache. Default true.
         *     @type bool            $update_menu_item_cache Whether to update the menu item cache. Default false.
         *     @type bool            $lazy_load_term_meta    Whether to lazy-load term meta. Setting to false will
         *                                                   disable cache priming for term meta, so that each
         *                                                   get_term_meta() call will hit the database.
         *                                                   Defaults to the value of `$update_post_term_cache`.
         *     @type int             $w                      The week number of the year. Default empty. Accepts numbers 0-53.
         *     @type int             $year                   The four-digit year. Default empty. Accepts any four-digit year.
         * }
         * @phpstan-param array{
         *   attachment_id?: int,
         *   author?: int|string,
         *   author_name?: string,
         *   author__in?: int[],
         *   author__not_in?: int[],
         *   cache_results?: bool,
         *   cat?: int|string,
         *   category__and?: int[],
         *   category__in?: int[],
         *   category__not_in?: int[],
         *   category_name?: string,
         *   comment_count?: array|int,
         *   comment_status?: string,
         *   comments_per_page?: int,
         *   date_query?: array,
         *   day?: int,
         *   exact?: bool,
         *   fields?: string,
         *   hour?: int,
         *   ignore_sticky_posts?: int|bool,
         *   m?: int,
         *   meta_key?: string|string[],
         *   meta_value?: string|string[],
         *   meta_compare?: string,
         *   meta_compare_key?: string,
         *   meta_type?: string,
         *   meta_type_key?: string,
         *   meta_query?: array,
         *   menu_order?: int,
         *   minute?: int,
         *   monthnum?: int,
         *   name?: string,
         *   nopaging?: bool,
         *   no_found_rows?: bool,
         *   offset?: int,
         *   order?: string,
         *   orderby?: string|array,
         *   p?: int,
         *   page?: int,
         *   paged?: int,
         *   page_id?: int,
         *   pagename?: string,
         *   perm?: string,
         *   ping_status?: string,
         *   post__in?: int[],
         *   post__not_in?: int[],
         *   post_mime_type?: string,
         *   post_name__in?: string[],
         *   post_parent?: int,
         *   post_parent__in?: int[],
         *   post_parent__not_in?: int[],
         *   post_type?: string|string[],
         *   post_status?: string|string[],
         *   posts_per_page?: int,
         *   posts_per_archive_page?: int,
         *   s?: string,
         *   search_columns?: string[],
         *   second?: int,
         *   sentence?: bool,
         *   suppress_filters?: bool,
         *   tag?: string,
         *   tag__and?: int[],
         *   tag__in?: int[],
         *   tag__not_in?: int[],
         *   tag_id?: int,
         *   tag_slug__and?: string[],
         *   tag_slug__in?: string[],
         *   tax_query?: array,
         *   title?: string,
         *   update_post_meta_cache?: bool,
         *   update_post_term_cache?: bool,
         *   update_menu_item_cache?: bool,
         *   lazy_load_term_meta?: bool,
         *   w?: int,
         *   year?: int,
         * } $query
         */
        public function parse_query($query = '')
        {
        }
        /**
         * Parses various taxonomy related query vars.
         *
         * For BC, this method is not marked as protected. See [28987].
         *
         * @since 3.1.0
         *
         * @param array $q The query variables. Passed by reference.
         */
        public function parse_tax_query(&$q)
        {
        }
        /**
         * Generates SQL for the WHERE clause based on passed search terms.
         *
         * @since 3.7.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param array $q Query variables.
         * @return string WHERE clause.
         */
        protected function parse_search(&$q)
        {
        }
        /**
         * Checks if the terms are suitable for searching.
         *
         * Uses an array of stopwords (terms) that are excluded from the separate
         * term matching when searching for posts. The list of English stopwords is
         * the approximate search engines list, and is translatable.
         *
         * @since 3.7.0
         *
         * @param string[] $terms Array of terms to check.
         * @return string[] Terms that are not stopwords.
         */
        protected function parse_search_terms($terms)
        {
        }
        /**
         * Retrieves stopwords used when parsing search terms.
         *
         * @since 3.7.0
         *
         * @return string[] Stopwords.
         */
        protected function get_search_stopwords()
        {
        }
        /**
         * Generates SQL for the ORDER BY condition based on passed search terms.
         *
         * @since 3.7.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param array $q Query variables.
         * @return string ORDER BY clause.
         */
        protected function parse_search_order(&$q)
        {
        }
        /**
         * Converts the given orderby alias (if allowed) to a properly-prefixed value.
         *
         * @since 4.0.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $orderby Alias for the field to order by.
         * @return string|false Table-prefixed value to used in the ORDER clause. False otherwise.
         */
        protected function parse_orderby($orderby)
        {
        }
        /**
         * Parse an 'order' query variable and cast it to ASC or DESC as necessary.
         *
         * @since 4.0.0
         *
         * @param string $order The 'order' query variable.
         * @return string The sanitized 'order' query variable.
         */
        protected function parse_order($order)
        {
        }
        /**
         * Sets the 404 property and saves whether query is feed.
         *
         * @since 2.0.0
         */
        public function set_404()
        {
        }
        /**
         * Retrieves the value of a query variable.
         *
         * @since 1.5.0
         * @since 3.9.0 The `$default_value` argument was introduced.
         *
         * @param string $query_var     Query variable key.
         * @param mixed  $default_value Optional. Value to return if the query variable is not set.
         *                              Default empty string.
         * @return mixed Contents of the query variable.
         */
        public function get($query_var, $default_value = '')
        {
        }
        /**
         * Sets the value of a query variable.
         *
         * @since 1.5.0
         *
         * @param string $query_var Query variable key.
         * @param mixed  $value     Query variable value.
         */
        public function set($query_var, $value)
        {
        }
        /**
         * Retrieves an array of posts based on query variables.
         *
         * There are a few filters and actions that can be used to modify the post
         * database query.
         *
         * @since 1.5.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @return WP_Post[]|int[] Array of post objects or post IDs.
         */
        public function get_posts()
        {
        }
        /**
         * Sets up the next post and iterate current post index.
         *
         * @since 1.5.0
         *
         * @return WP_Post Next post.
         */
        public function next_post()
        {
        }
        /**
         * Sets up the current post.
         *
         * Retrieves the next post, sets up the post, sets the 'in the loop'
         * property to true.
         *
         * @since 1.5.0
         *
         * @global WP_Post $post Global post object.
         */
        public function the_post()
        {
        }
        /**
         * Determines whether there are more posts available in the loop.
         *
         * Calls the {@see 'loop_end'} action when the loop is complete.
         *
         * @since 1.5.0
         *
         * @return bool True if posts are available, false if end of the loop.
         * @phpstan-impure
         */
        public function have_posts()
        {
        }
        /**
         * Rewinds the posts and resets post index.
         *
         * @since 1.5.0
         */
        public function rewind_posts()
        {
        }
        /**
         * Iterates current comment index and returns WP_Comment object.
         *
         * @since 2.2.0
         *
         * @return WP_Comment Comment object.
         */
        public function next_comment()
        {
        }
        /**
         * Sets up the current comment.
         *
         * @since 2.2.0
         *
         * @global WP_Comment $comment Global comment object.
         */
        public function the_comment()
        {
        }
        /**
         * Determines whether there are more comments available.
         *
         * Automatically rewinds comments when finished.
         *
         * @since 2.2.0
         *
         * @return bool True if comments are available, false if no more comments.
         */
        public function have_comments()
        {
        }
        /**
         * Rewinds the comments, resets the comment index and comment to first.
         *
         * @since 2.2.0
         */
        public function rewind_comments()
        {
        }
        /**
         * Sets up the WordPress query by parsing query string.
         *
         * @since 1.5.0
         *
         * @see WP_Query::parse_query() for all available arguments.
         *
         * @param string|array $query URL query string or array of query arguments.
         * @return WP_Post[]|int[] Array of post objects or post IDs.
         */
        public function query($query)
        {
        }
        /**
         * Retrieves the currently queried object.
         *
         * If queried object is not set, then the queried object will be set from
         * the category, tag, taxonomy, posts page, single post, page, or author
         * query variable. After it is set up, it will be returned.
         *
         * @since 1.5.0
         *
         * @return WP_Term|WP_Post_Type|WP_Post|WP_User|null The queried object.
         */
        public function get_queried_object()
        {
        }
        /**
         * Retrieves the ID of the currently queried object.
         *
         * @since 1.5.0
         *
         * @return int
         */
        public function get_queried_object_id()
        {
        }
        /**
         * Constructor.
         *
         * Sets up the WordPress query, if parameter is not empty.
         *
         * @since 1.5.0
         *
         * @see WP_Query::parse_query() for all available arguments.
         *
         * @param string|array $query URL query string or array of vars.
         */
        public function __construct($query = '')
        {
        }
        /**
         * Makes private properties readable for backward compatibility.
         *
         * @since 4.0.0
         *
         * @param string $name Property to get.
         * @return mixed Property.
         */
        public function __get($name)
        {
        }
        /**
         * Makes private properties checkable for backward compatibility.
         *
         * @since 4.0.0
         *
         * @param string $name Property to check if set.
         * @return bool Whether the property is set.
         */
        public function __isset($name)
        {
        }
        /**
         * Makes private/protected methods readable for backward compatibility.
         *
         * @since 4.0.0
         *
         * @param string $name      Method to call.
         * @param array  $arguments Arguments to pass when calling.
         * @return mixed|false Return value of the callback, false otherwise.
         */
        public function __call($name, $arguments)
        {
        }
        /**
         * Determines whether the query is for an existing archive page.
         *
         * Archive pages include category, tag, author, date, custom post type,
         * and custom taxonomy based archives.
         *
         * @since 3.1.0
         *
         * @see WP_Query::is_category()
         * @see WP_Query::is_tag()
         * @see WP_Query::is_author()
         * @see WP_Query::is_date()
         * @see WP_Query::is_post_type_archive()
         * @see WP_Query::is_tax()
         *
         * @return bool Whether the query is for an existing archive page.
         */
        public function is_archive()
        {
        }
        /**
         * Determines whether the query is for an existing post type archive page.
         *
         * @since 3.1.0
         *
         * @param string|string[] $post_types Optional. Post type or array of posts types
         *                                    to check against. Default empty.
         * @return bool Whether the query is for an existing post type archive page.
         */
        public function is_post_type_archive($post_types = '')
        {
        }
        /**
         * Determines whether the query is for an existing attachment page.
         *
         * @since 3.1.0
         *
         * @param int|string|int[]|string[] $attachment Optional. Attachment ID, title, slug, or array of such
         *                                              to check against. Default empty.
         * @return bool Whether the query is for an existing attachment page.
         */
        public function is_attachment($attachment = '')
        {
        }
        /**
         * Determines whether the query is for an existing author archive page.
         *
         * If the $author parameter is specified, this function will additionally
         * check if the query is for one of the authors specified.
         *
         * @since 3.1.0
         *
         * @param int|string|int[]|string[] $author Optional. User ID, nickname, nicename, or array of such
         *                                          to check against. Default empty.
         * @return bool Whether the query is for an existing author archive page.
         */
        public function is_author($author = '')
        {
        }
        /**
         * Determines whether the query is for an existing category archive page.
         *
         * If the $category parameter is specified, this function will additionally
         * check if the query is for one of the categories specified.
         *
         * @since 3.1.0
         *
         * @param int|string|int[]|string[] $category Optional. Category ID, name, slug, or array of such
         *                                            to check against. Default empty.
         * @return bool Whether the query is for an existing category archive page.
         */
        public function is_category($category = '')
        {
        }
        /**
         * Determines whether the query is for an existing tag archive page.
         *
         * If the $tag parameter is specified, this function will additionally
         * check if the query is for one of the tags specified.
         *
         * @since 3.1.0
         *
         * @param int|string|int[]|string[] $tag Optional. Tag ID, name, slug, or array of such
         *                                       to check against. Default empty.
         * @return bool Whether the query is for an existing tag archive page.
         */
        public function is_tag($tag = '')
        {
        }
        /**
         * Determines whether the query is for an existing custom taxonomy archive page.
         *
         * If the $taxonomy parameter is specified, this function will additionally
         * check if the query is for that specific $taxonomy.
         *
         * If the $term parameter is specified in addition to the $taxonomy parameter,
         * this function will additionally check if the query is for one of the terms
         * specified.
         *
         * @since 3.1.0
         *
         * @global WP_Taxonomy[] $wp_taxonomies Registered taxonomies.
         *
         * @param string|string[]           $taxonomy Optional. Taxonomy slug or slugs to check against.
         *                                            Default empty.
         * @param int|string|int[]|string[] $term     Optional. Term ID, name, slug, or array of such
         *                                            to check against. Default empty.
         * @return bool Whether the query is for an existing custom taxonomy archive page.
         *              True for custom taxonomy archive pages, false for built-in taxonomies
         *              (category and tag archives).
         */
        public function is_tax($taxonomy = '', $term = '')
        {
        }
        /**
         * Determines whether the current URL is within the comments popup window.
         *
         * @since 3.1.0
         * @deprecated 4.5.0
         *
         * @return false Always returns false.
         */
        public function is_comments_popup()
        {
        }
        /**
         * Determines whether the query is for an existing date archive.
         *
         * @since 3.1.0
         *
         * @return bool Whether the query is for an existing date archive.
         */
        public function is_date()
        {
        }
        /**
         * Determines whether the query is for an existing day archive.
         *
         * @since 3.1.0
         *
         * @return bool Whether the query is for an existing day archive.
         */
        public function is_day()
        {
        }
        /**
         * Determines whether the query is for a feed.
         *
         * @since 3.1.0
         *
         * @param string|string[] $feeds Optional. Feed type or array of feed types
         *                                         to check against. Default empty.
         * @return bool Whether the query is for a feed.
         */
        public function is_feed($feeds = '')
        {
        }
        /**
         * Determines whether the query is for a comments feed.
         *
         * @since 3.1.0
         *
         * @return bool Whether the query is for a comments feed.
         */
        public function is_comment_feed()
        {
        }
        /**
         * Determines whether the query is for the front page of the site.
         *
         * This is for what is displayed at your site's main URL.
         *
         * Depends on the site's "Front page displays" Reading Settings 'show_on_front' and 'page_on_front'.
         *
         * If you set a static page for the front page of your site, this function will return
         * true when viewing that page.
         *
         * Otherwise the same as {@see WP_Query::is_home()}.
         *
         * @since 3.1.0
         *
         * @return bool Whether the query is for the front page of the site.
         */
        public function is_front_page()
        {
        }
        /**
         * Determines whether the query is for the blog homepage.
         *
         * This is the page which shows the time based blog content of your site.
         *
         * Depends on the site's "Front page displays" Reading Settings 'show_on_front' and 'page_for_posts'.
         *
         * If you set a static page for the front page of your site, this function will return
         * true only on the page you set as the "Posts page".
         *
         * @since 3.1.0
         *
         * @see WP_Query::is_front_page()
         *
         * @return bool Whether the query is for the blog homepage.
         */
        public function is_home()
        {
        }
        /**
         * Determines whether the query is for the Privacy Policy page.
         *
         * This is the page which shows the Privacy Policy content of your site.
         *
         * Depends on the site's "Change your Privacy Policy page" Privacy Settings 'wp_page_for_privacy_policy'.
         *
         * This function will return true only on the page you set as the "Privacy Policy page".
         *
         * @since 5.2.0
         *
         * @return bool Whether the query is for the Privacy Policy page.
         */
        public function is_privacy_policy()
        {
        }
        /**
         * Determines whether the query is for an existing month archive.
         *
         * @since 3.1.0
         *
         * @return bool Whether the query is for an existing month archive.
         */
        public function is_month()
        {
        }
        /**
         * Determines whether the query is for an existing single page.
         *
         * If the $page parameter is specified, this function will additionally
         * check if the query is for one of the pages specified.
         *
         * @since 3.1.0
         *
         * @see WP_Query::is_single()
         * @see WP_Query::is_singular()
         *
         * @param int|string|int[]|string[] $page Optional. Page ID, title, slug, path, or array of such
         *                                        to check against. Default empty.
         * @return bool Whether the query is for an existing single page.
         */
        public function is_page($page = '')
        {
        }
        /**
         * Determines whether the query is for a paged result and not for the first page.
         *
         * @since 3.1.0
         *
         * @return bool Whether the query is for a paged result.
         */
        public function is_paged()
        {
        }
        /**
         * Determines whether the query is for a post or page preview.
         *
         * @since 3.1.0
         *
         * @return bool Whether the query is for a post or page preview.
         */
        public function is_preview()
        {
        }
        /**
         * Determines whether the query is for the robots.txt file.
         *
         * @since 3.1.0
         *
         * @return bool Whether the query is for the robots.txt file.
         */
        public function is_robots()
        {
        }
        /**
         * Determines whether the query is for the favicon.ico file.
         *
         * @since 5.4.0
         *
         * @return bool Whether the query is for the favicon.ico file.
         */
        public function is_favicon()
        {
        }
        /**
         * Determines whether the query is for a search.
         *
         * @since 3.1.0
         *
         * @return bool Whether the query is for a search.
         */
        public function is_search()
        {
        }
        /**
         * Determines whether the query is for an existing single post.
         *
         * Works for any post type excluding pages.
         *
         * If the $post parameter is specified, this function will additionally
         * check if the query is for one of the Posts specified.
         *
         * @since 3.1.0
         *
         * @see WP_Query::is_page()
         * @see WP_Query::is_singular()
         *
         * @param int|string|int[]|string[] $post Optional. Post ID, title, slug, path, or array of such
         *                                        to check against. Default empty.
         * @return bool Whether the query is for an existing single post.
         */
        public function is_single($post = '')
        {
        }
        /**
         * Determines whether the query is for an existing single post of any post type
         * (post, attachment, page, custom post types).
         *
         * If the $post_types parameter is specified, this function will additionally
         * check if the query is for one of the Posts Types specified.
         *
         * @since 3.1.0
         *
         * @see WP_Query::is_page()
         * @see WP_Query::is_single()
         *
         * @param string|string[] $post_types Optional. Post type or array of post types
         *                                    to check against. Default empty.
         * @return bool Whether the query is for an existing single post
         *              or any of the given post types.
         */
        public function is_singular($post_types = '')
        {
        }
        /**
         * Determines whether the query is for a specific time.
         *
         * @since 3.1.0
         *
         * @return bool Whether the query is for a specific time.
         */
        public function is_time()
        {
        }
        /**
         * Determines whether the query is for a trackback endpoint call.
         *
         * @since 3.1.0
         *
         * @return bool Whether the query is for a trackback endpoint call.
         */
        public function is_trackback()
        {
        }
        /**
         * Determines whether the query is for an existing year archive.
         *
         * @since 3.1.0
         *
         * @return bool Whether the query is for an existing year archive.
         */
        public function is_year()
        {
        }
        /**
         * Determines whether the query is a 404 (returns no results).
         *
         * @since 3.1.0
         *
         * @return bool Whether the query is a 404 error.
         */
        public function is_404()
        {
        }
        /**
         * Determines whether the query is for an embedded post.
         *
         * @since 4.4.0
         *
         * @return bool Whether the query is for an embedded post.
         */
        public function is_embed()
        {
        }
        /**
         * Determines whether the query is the main query.
         *
         * @since 3.3.0
         *
         * @global WP_Query $wp_the_query WordPress Query object.
         *
         * @return bool Whether the query is the main query.
         */
        public function is_main_query()
        {
        }
        /**
         * Sets up global post data.
         *
         * @since 4.1.0
         * @since 4.4.0 Added the ability to pass a post ID to `$post`.
         *
         * @global int     $id
         * @global WP_User $authordata
         * @global string  $currentday
         * @global string  $currentmonth
         * @global int     $page
         * @global array   $pages
         * @global int     $multipage
         * @global int     $more
         * @global int     $numpages
         *
         * @param WP_Post|object|int $post WP_Post instance or Post ID/object.
         * @return true True when finished.
         */
        public function setup_postdata($post)
        {
        }
        /**
         * Generates post data.
         *
         * @since 5.2.0
         *
         * @param WP_Post|object|int $post WP_Post instance or Post ID/object.
         * @return array|false Elements of post or false on failure.
         */
        public function generate_postdata($post)
        {
        }
        /**
         * Generates cache key.
         *
         * @since 6.1.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param array  $args Query arguments.
         * @param string $sql  SQL statement.
         * @return string Cache key.
         */
        protected function generate_cache_key(array $args, $sql)
        {
        }
        /**
         * After looping through a nested query, this function
         * restores the $post global to the current post in this query.
         *
         * @since 3.7.0
         *
         * @global WP_Post $post Global post object.
         */
        public function reset_postdata()
        {
        }
        /**
         * Lazyloads term meta for posts in the loop.
         *
         * @since 4.4.0
         * @deprecated 4.5.0 See wp_queue_posts_for_term_meta_lazyload().
         *
         * @param mixed $check
         * @param int   $term_id
         * @return mixed
         */
        public function lazyload_term_meta($check, $term_id)
        {
        }
        /**
         * Lazyloads comment meta for comments in the loop.
         *
         * @since 4.4.0
         * @deprecated 4.5.0 See wp_lazyload_comment_meta().
         *
         * @param mixed $check
         * @param int   $comment_id
         * @return mixed
         */
        public function lazyload_comment_meta($check, $comment_id)
        {
        }
    }
    /**
     * Core class used to set, validate, and clear cookies that identify a Recovery Mode session.
     *
     * @since 5.2.0
     */
    #[\AllowDynamicProperties]
    final class WP_Recovery_Mode_Cookie_Service
    {
        /**
         * Checks whether the recovery mode cookie is set.
         *
         * @since 5.2.0
         *
         * @return bool True if the cookie is set, false otherwise.
         */
        public function is_cookie_set()
        {
        }
        /**
         * Sets the recovery mode cookie.
         *
         * This must be immediately followed by exiting the request.
         *
         * @since 5.2.0
         */
        public function set_cookie()
        {
        }
        /**
         * Clears the recovery mode cookie.
         *
         * @since 5.2.0
         */
        public function clear_cookie()
        {
        }
        /**
         * Validates the recovery mode cookie.
         *
         * @since 5.2.0
         *
         * @param string $cookie Optionally specify the cookie string.
         *                       If omitted, it will be retrieved from the super global.
         * @return true|WP_Error True on success, error object on failure.
         */
        public function validate_cookie($cookie = '')
        {
        }
        /**
         * Gets the session identifier from the cookie.
         *
         * The cookie should be validated before calling this API.
         *
         * @since 5.2.0
         *
         * @param string $cookie Optionally specify the cookie string.
         *                       If omitted, it will be retrieved from the super global.
         * @return string|WP_Error Session ID on success, or error object on failure.
         */
        public function get_session_id_from_cookie($cookie = '')
        {
        }
    }
    /**
     * Core class used to send an email with a link to begin Recovery Mode.
     *
     * @since 5.2.0
     */
    #[\AllowDynamicProperties]
    final class WP_Recovery_Mode_Email_Service
    {
        const RATE_LIMIT_OPTION = 'recovery_mode_email_last_sent';
        /**
         * WP_Recovery_Mode_Email_Service constructor.
         *
         * @since 5.2.0
         *
         * @param WP_Recovery_Mode_Link_Service $link_service
         */
        public function __construct(\WP_Recovery_Mode_Link_Service $link_service)
        {
        }
        /**
         * Sends the recovery mode email if the rate limit has not been sent.
         *
         * @since 5.2.0
         *
         * @param int   $rate_limit Number of seconds before another email can be sent.
         * @param array $error      Error details from `error_get_last()`.
         * @param array $extension {
         *     The extension that caused the error.
         *
         *     @type string $slug The extension slug. The plugin or theme's directory.
         *     @type string $type The extension type. Either 'plugin' or 'theme'.
         * }
         * @return true|WP_Error True if email sent, WP_Error otherwise.
         * @phpstan-param array{
         *   slug?: string,
         *   type?: string,
         * } $extension
         */
        public function maybe_send_recovery_mode_email($rate_limit, $error, $extension)
        {
        }
        /**
         * Clears the rate limit, allowing a new recovery mode email to be sent immediately.
         *
         * @since 5.2.0
         *
         * @return bool True on success, false on failure.
         */
        public function clear_rate_limit()
        {
        }
    }
    /**
     * Core class used to generate and validate keys used to enter Recovery Mode.
     *
     * @since 5.2.0
     */
    #[\AllowDynamicProperties]
    final class WP_Recovery_Mode_Key_Service
    {
        /**
         * Creates a recovery mode token.
         *
         * @since 5.2.0
         *
         * @return string A random string to identify its associated key in storage.
         */
        public function generate_recovery_mode_token()
        {
        }
        /**
         * Creates a recovery mode key.
         *
         * @since 5.2.0
         *
         * @global PasswordHash $wp_hasher Portable PHP password hashing framework instance.
         *
         * @param string $token A token generated by {@see generate_recovery_mode_token()}.
         * @return string Recovery mode key.
         */
        public function generate_and_store_recovery_mode_key($token)
        {
        }
        /**
         * Verifies if the recovery mode key is correct.
         *
         * Recovery mode keys can only be used once; the key will be consumed in the process.
         *
         * @since 5.2.0
         *
         * @global PasswordHash $wp_hasher Portable PHP password hashing framework instance.
         *
         * @param string $token The token used when generating the given key.
         * @param string $key   The unhashed key.
         * @param int    $ttl   Time in seconds for the key to be valid for.
         * @return true|WP_Error True on success, error object on failure.
         */
        public function validate_recovery_mode_key($token, $key, $ttl)
        {
        }
        /**
         * Removes expired recovery mode keys.
         *
         * @since 5.2.0
         *
         * @param int $ttl Time in seconds for the keys to be valid for.
         */
        public function clean_expired_keys($ttl)
        {
        }
    }
    /**
     * Core class used to generate and handle recovery mode links.
     *
     * @since 5.2.0
     */
    #[\AllowDynamicProperties]
    class WP_Recovery_Mode_Link_Service
    {
        const LOGIN_ACTION_ENTER = 'enter_recovery_mode';
        const LOGIN_ACTION_ENTERED = 'entered_recovery_mode';
        /**
         * WP_Recovery_Mode_Link_Service constructor.
         *
         * @since 5.2.0
         *
         * @param WP_Recovery_Mode_Cookie_Service $cookie_service Service to handle setting the recovery mode cookie.
         * @param WP_Recovery_Mode_Key_Service    $key_service    Service to handle generating recovery mode keys.
         */
        public function __construct(\WP_Recovery_Mode_Cookie_Service $cookie_service, \WP_Recovery_Mode_Key_Service $key_service)
        {
        }
        /**
         * Generates a URL to begin recovery mode.
         *
         * Only one recovery mode URL can may be valid at the same time.
         *
         * @since 5.2.0
         *
         * @return string Generated URL.
         */
        public function generate_url()
        {
        }
        /**
         * Enters recovery mode when the user hits wp-login.php with a valid recovery mode link.
         *
         * @since 5.2.0
         *
         * @global string $pagenow The filename of the current screen.
         *
         * @param int $ttl Number of seconds the link should be valid for.
         * @phpstan-return void
         */
        public function handle_begin_link($ttl)
        {
        }
    }
    /**
     * Core class used to implement Recovery Mode.
     *
     * @since 5.2.0
     */
    #[\AllowDynamicProperties]
    class WP_Recovery_Mode
    {
        const EXIT_ACTION = 'exit_recovery_mode';
        /**
         * WP_Recovery_Mode constructor.
         *
         * @since 5.2.0
         */
        public function __construct()
        {
        }
        /**
         * Initialize recovery mode for the current request.
         *
         * @since 5.2.0
         * @phpstan-return void
         */
        public function initialize()
        {
        }
        /**
         * Checks whether recovery mode is active.
         *
         * This will not change after recovery mode has been initialized. {@see WP_Recovery_Mode::run()}.
         *
         * @since 5.2.0
         *
         * @return bool True if recovery mode is active, false otherwise.
         */
        public function is_active()
        {
        }
        /**
         * Gets the recovery mode session ID.
         *
         * @since 5.2.0
         *
         * @return string The session ID if recovery mode is active, empty string otherwise.
         */
        public function get_session_id()
        {
        }
        /**
         * Checks whether recovery mode has been initialized.
         *
         * Recovery mode should not be used until this point. Initialization happens immediately before loading plugins.
         *
         * @since 5.2.0
         *
         * @return bool
         */
        public function is_initialized()
        {
        }
        /**
         * Handles a fatal error occurring.
         *
         * The calling API should immediately die() after calling this function.
         *
         * @since 5.2.0
         *
         * @param array $error Error details from `error_get_last()`.
         * @return true|WP_Error True if the error was handled and headers have already been sent.
         *                       Or the request will exit to try and catch multiple errors at once.
         *                       WP_Error if an error occurred preventing it from being handled.
         */
        public function handle_error(array $error)
        {
        }
        /**
         * Ends the current recovery mode session.
         *
         * @since 5.2.0
         *
         * @return bool True on success, false on failure.
         */
        public function exit_recovery_mode()
        {
        }
        /**
         * Handles a request to exit Recovery Mode.
         *
         * @since 5.2.0
         * @phpstan-return void
         */
        public function handle_exit_recovery_mode()
        {
        }
        /**
         * Cleans any recovery mode keys that have expired according to the link TTL.
         *
         * Executes on a daily cron schedule.
         *
         * @since 5.2.0
         */
        public function clean_expired_keys()
        {
        }
        /**
         * Handles checking for the recovery mode cookie and validating it.
         *
         * @since 5.2.0
         */
        protected function handle_cookie()
        {
        }
        /**
         * Gets the rate limit between sending new recovery mode email links.
         *
         * @since 5.2.0
         *
         * @return int Rate limit in seconds.
         */
        protected function get_email_rate_limit()
        {
        }
        /**
         * Gets the number of seconds the recovery mode link is valid for.
         *
         * @since 5.2.0
         *
         * @return int Interval in seconds.
         */
        protected function get_link_ttl()
        {
        }
        /**
         * Gets the extension that the error occurred in.
         *
         * @since 5.2.0
         *
         * @global array $wp_theme_directories
         *
         * @param array $error Error details from `error_get_last()`.
         * @return array|false {
         *     Extension details.
         *
         *     @type string $slug The extension slug. This is the plugin or theme's directory.
         *     @type string $type The extension type. Either 'plugin' or 'theme'.
         * }
         * @phpstan-return false|array{
         *   slug: string,
         *   type: string,
         * }
         */
        protected function get_extension_for_error($error)
        {
        }
        /**
         * Checks whether the given extension a network activated plugin.
         *
         * @since 5.2.0
         *
         * @param array $extension Extension data.
         * @return bool True if network plugin, false otherwise.
         */
        protected function is_network_plugin($extension)
        {
        }
        /**
         * Stores the given error so that the extension causing it is paused.
         *
         * @since 5.2.0
         *
         * @param array $error Error details from `error_get_last()`.
         * @return bool True if the error was stored successfully, false otherwise.
         */
        protected function store_error($error)
        {
        }
        /**
         * Redirects the current request to allow recovering multiple errors in one go.
         *
         * The redirection will only happen when on a protected endpoint.
         *
         * It must be ensured that this method is only called when an error actually occurred and will not occur on the
         * next request again. Otherwise it will create a redirect loop.
         *
         * @since 5.2.0
         * @phpstan-return never
         */
        protected function redirect_protected()
        {
        }
    }
    /**
     * Core class used to implement a rewrite component API.
     *
     * The WordPress Rewrite class writes the rewrite module rules to the .htaccess
     * file. It also handles parsing the request to get the correct setup for the
     * WordPress Query class.
     *
     * The Rewrite along with WP class function as a front controller for WordPress.
     * You can add rules to trigger your page view and processing using this
     * component. The full functionality of a front controller does not exist,
     * meaning you can't define how the template files load based on the rewrite
     * rules.
     *
     * @since 1.5.0
     */
    #[\AllowDynamicProperties]
    class WP_Rewrite
    {
        /**
         * Permalink structure for posts.
         *
         * @since 1.5.0
         * @var string
         */
        public $permalink_structure;
        /**
         * Whether to add trailing slashes.
         *
         * @since 2.2.0
         * @var bool
         */
        public $use_trailing_slashes;
        /**
         * Base for the author permalink structure (example.com/$author_base/authorname).
         *
         * @since 1.5.0
         * @var string
         */
        public $author_base = 'author';
        /**
         * Permalink structure for author archives.
         *
         * @since 1.5.0
         * @var string
         */
        public $author_structure;
        /**
         * Permalink structure for date archives.
         *
         * @since 1.5.0
         * @var string
         */
        public $date_structure;
        /**
         * Permalink structure for pages.
         *
         * @since 1.5.0
         * @var string
         */
        public $page_structure;
        /**
         * Base of the search permalink structure (example.com/$search_base/query).
         *
         * @since 1.5.0
         * @var string
         */
        public $search_base = 'search';
        /**
         * Permalink structure for searches.
         *
         * @since 1.5.0
         * @var string
         */
        public $search_structure;
        /**
         * Comments permalink base.
         *
         * @since 1.5.0
         * @var string
         */
        public $comments_base = 'comments';
        /**
         * Pagination permalink base.
         *
         * @since 3.1.0
         * @var string
         */
        public $pagination_base = 'page';
        /**
         * Comments pagination permalink base.
         *
         * @since 4.2.0
         * @var string
         */
        public $comments_pagination_base = 'comment-page';
        /**
         * Feed permalink base.
         *
         * @since 1.5.0
         * @var string
         */
        public $feed_base = 'feed';
        /**
         * Comments feed permalink structure.
         *
         * @since 1.5.0
         * @var string
         */
        public $comment_feed_structure;
        /**
         * Feed request permalink structure.
         *
         * @since 1.5.0
         * @var string
         */
        public $feed_structure;
        /**
         * The static portion of the post permalink structure.
         *
         * If the permalink structure is "/archive/%post_id%" then the front
         * is "/archive/". If the permalink structure is "/%year%/%postname%/"
         * then the front is "/".
         *
         * @since 1.5.0
         * @var string
         *
         * @see WP_Rewrite::init()
         */
        public $front;
        /**
         * The prefix for all permalink structures.
         *
         * If PATHINFO/index permalinks are in use then the root is the value of
         * `WP_Rewrite::$index` with a trailing slash appended. Otherwise the root
         * will be empty.
         *
         * @since 1.5.0
         * @var string
         *
         * @see WP_Rewrite::init()
         * @see WP_Rewrite::using_index_permalinks()
         */
        public $root = '';
        /**
         * The name of the index file which is the entry point to all requests.
         *
         * @since 1.5.0
         * @var string
         */
        public $index = 'index.php';
        /**
         * Variable name to use for regex matches in the rewritten query.
         *
         * @since 1.5.0
         * @var string
         */
        public $matches = '';
        /**
         * Rewrite rules to match against the request to find the redirect or query.
         *
         * @since 1.5.0
         * @var string[]
         */
        public $rules;
        /**
         * Additional rules added external to the rewrite class.
         *
         * Those not generated by the class, see add_rewrite_rule().
         *
         * @since 2.1.0
         * @var string[]
         */
        public $extra_rules = array();
        /**
         * Additional rules that belong at the beginning to match first.
         *
         * Those not generated by the class, see add_rewrite_rule().
         *
         * @since 2.3.0
         * @var string[]
         */
        public $extra_rules_top = array();
        /**
         * Rules that don't redirect to WordPress' index.php.
         *
         * These rules are written to the mod_rewrite portion of the .htaccess,
         * and are added by add_external_rule().
         *
         * @since 2.1.0
         * @var string[]
         */
        public $non_wp_rules = array();
        /**
         * Extra permalink structures, e.g. categories, added by add_permastruct().
         *
         * @since 2.1.0
         * @var array[]
         */
        public $extra_permastructs = array();
        /**
         * Endpoints (like /trackback/) added by add_rewrite_endpoint().
         *
         * @since 2.1.0
         * @var array[]
         */
        public $endpoints;
        /**
         * Whether to write every mod_rewrite rule for WordPress into the .htaccess file.
         *
         * This is off by default, turning it on might print a lot of rewrite rules
         * to the .htaccess file.
         *
         * @since 2.0.0
         * @var bool
         *
         * @see WP_Rewrite::mod_rewrite_rules()
         */
        public $use_verbose_rules = \false;
        /**
         * Could post permalinks be confused with those of pages?
         *
         * If the first rewrite tag in the post permalink structure is one that could
         * also match a page name (e.g. %postname% or %author%) then this flag is
         * set to true. Prior to WordPress 3.3 this flag indicated that every page
         * would have a set of rules added to the top of the rewrite rules array.
         * Now it tells WP::parse_request() to check if a URL matching the page
         * permastruct is actually a page before accepting it.
         *
         * @since 2.5.0
         * @var bool
         *
         * @see WP_Rewrite::init()
         */
        public $use_verbose_page_rules = \true;
        /**
         * Rewrite tags that can be used in permalink structures.
         *
         * These are translated into the regular expressions stored in
         * `WP_Rewrite::$rewritereplace` and are rewritten to the query
         * variables listed in WP_Rewrite::$queryreplace.
         *
         * Additional tags can be added with add_rewrite_tag().
         *
         * @since 1.5.0
         * @var string[]
         */
        public $rewritecode = array('%year%', '%monthnum%', '%day%', '%hour%', '%minute%', '%second%', '%postname%', '%post_id%', '%author%', '%pagename%', '%search%');
        /**
         * Regular expressions to be substituted into rewrite rules in place
         * of rewrite tags, see WP_Rewrite::$rewritecode.
         *
         * @since 1.5.0
         * @var string[]
         */
        public $rewritereplace = array('([0-9]{4})', '([0-9]{1,2})', '([0-9]{1,2})', '([0-9]{1,2})', '([0-9]{1,2})', '([0-9]{1,2})', '([^/]+)', '([0-9]+)', '([^/]+)', '([^/]+?)', '(.+)');
        /**
         * Query variables that rewrite tags map to, see WP_Rewrite::$rewritecode.
         *
         * @since 1.5.0
         * @var string[]
         */
        public $queryreplace = array('year=', 'monthnum=', 'day=', 'hour=', 'minute=', 'second=', 'name=', 'p=', 'author_name=', 'pagename=', 's=');
        /**
         * Supported default feeds.
         *
         * @since 1.5.0
         * @var string[]
         */
        public $feeds = array('feed', 'rdf', 'rss', 'rss2', 'atom');
        /**
         * Determines whether permalinks are being used.
         *
         * This can be either rewrite module or permalink in the HTTP query string.
         *
         * @since 1.5.0
         *
         * @return bool True, if permalinks are enabled.
         */
        public function using_permalinks()
        {
        }
        /**
         * Determines whether permalinks are being used and rewrite module is not enabled.
         *
         * Means that permalink links are enabled and index.php is in the URL.
         *
         * @since 1.5.0
         *
         * @return bool Whether permalink links are enabled and index.php is in the URL.
         */
        public function using_index_permalinks()
        {
        }
        /**
         * Determines whether permalinks are being used and rewrite module is enabled.
         *
         * Using permalinks and index.php is not in the URL.
         *
         * @since 1.5.0
         *
         * @return bool Whether permalink links are enabled and index.php is NOT in the URL.
         */
        public function using_mod_rewrite_permalinks()
        {
        }
        /**
         * Indexes for matches for usage in preg_*() functions.
         *
         * The format of the string is, with empty matches property value, '$NUM'.
         * The 'NUM' will be replaced with the value in the $number parameter. With
         * the matches property not empty, the value of the returned string will
         * contain that value of the matches property. The format then will be
         * '$MATCHES[NUM]', with MATCHES as the value in the property and NUM the
         * value of the $number parameter.
         *
         * @since 1.5.0
         *
         * @param int $number Index number.
         * @return string
         */
        public function preg_index($number)
        {
        }
        /**
         * Retrieves all pages and attachments for pages URIs.
         *
         * The attachments are for those that have pages as parents and will be
         * retrieved.
         *
         * @since 2.5.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @return array Array of page URIs as first element and attachment URIs as second element.
         */
        public function page_uri_index()
        {
        }
        /**
         * Retrieves all of the rewrite rules for pages.
         *
         * @since 1.5.0
         *
         * @return string[] Page rewrite rules.
         */
        public function page_rewrite_rules()
        {
        }
        /**
         * Retrieves date permalink structure, with year, month, and day.
         *
         * The permalink structure for the date, if not set already depends on the
         * permalink structure. It can be one of three formats. The first is year,
         * month, day; the second is day, month, year; and the last format is month,
         * day, year. These are matched against the permalink structure for which
         * one is used. If none matches, then the default will be used, which is
         * year, month, day.
         *
         * Prevents post ID and date permalinks from overlapping. In the case of
         * post_id, the date permalink will be prepended with front permalink with
         * 'date/' before the actual permalink to form the complete date permalink
         * structure.
         *
         * @since 1.5.0
         *
         * @return string|false Date permalink structure on success, false on failure.
         */
        public function get_date_permastruct()
        {
        }
        /**
         * Retrieves the year permalink structure without month and day.
         *
         * Gets the date permalink structure and strips out the month and day
         * permalink structures.
         *
         * @since 1.5.0
         *
         * @return string|false Year permalink structure on success, false on failure.
         */
        public function get_year_permastruct()
        {
        }
        /**
         * Retrieves the month permalink structure without day and with year.
         *
         * Gets the date permalink structure and strips out the day permalink
         * structures. Keeps the year permalink structure.
         *
         * @since 1.5.0
         *
         * @return string|false Year/Month permalink structure on success, false on failure.
         */
        public function get_month_permastruct()
        {
        }
        /**
         * Retrieves the day permalink structure with month and year.
         *
         * Keeps date permalink structure with all year, month, and day.
         *
         * @since 1.5.0
         *
         * @return string|false Year/Month/Day permalink structure on success, false on failure.
         */
        public function get_day_permastruct()
        {
        }
        /**
         * Retrieves the permalink structure for categories.
         *
         * If the category_base property has no value, then the category structure
         * will have the front property value, followed by 'category', and finally
         * '%category%'. If it does, then the root property will be used, along with
         * the category_base property value.
         *
         * @since 1.5.0
         *
         * @return string|false Category permalink structure on success, false on failure.
         */
        public function get_category_permastruct()
        {
        }
        /**
         * Retrieves the permalink structure for tags.
         *
         * If the tag_base property has no value, then the tag structure will have
         * the front property value, followed by 'tag', and finally '%tag%'. If it
         * does, then the root property will be used, along with the tag_base
         * property value.
         *
         * @since 2.3.0
         *
         * @return string|false Tag permalink structure on success, false on failure.
         */
        public function get_tag_permastruct()
        {
        }
        /**
         * Retrieves an extra permalink structure by name.
         *
         * @since 2.5.0
         *
         * @param string $name Permalink structure name.
         * @return string|false Permalink structure string on success, false on failure.
         */
        public function get_extra_permastruct($name)
        {
        }
        /**
         * Retrieves the author permalink structure.
         *
         * The permalink structure is front property, author base, and finally
         * '/%author%'. Will set the author_structure property and then return it
         * without attempting to set the value again.
         *
         * @since 1.5.0
         *
         * @return string|false Author permalink structure on success, false on failure.
         */
        public function get_author_permastruct()
        {
        }
        /**
         * Retrieves the search permalink structure.
         *
         * The permalink structure is root property, search base, and finally
         * '/%search%'. Will set the search_structure property and then return it
         * without attempting to set the value again.
         *
         * @since 1.5.0
         *
         * @return string|false Search permalink structure on success, false on failure.
         */
        public function get_search_permastruct()
        {
        }
        /**
         * Retrieves the page permalink structure.
         *
         * The permalink structure is root property, and '%pagename%'. Will set the
         * page_structure property and then return it without attempting to set the
         * value again.
         *
         * @since 1.5.0
         *
         * @return string|false Page permalink structure on success, false on failure.
         */
        public function get_page_permastruct()
        {
        }
        /**
         * Retrieves the feed permalink structure.
         *
         * The permalink structure is root property, feed base, and finally
         * '/%feed%'. Will set the feed_structure property and then return it
         * without attempting to set the value again.
         *
         * @since 1.5.0
         *
         * @return string|false Feed permalink structure on success, false on failure.
         */
        public function get_feed_permastruct()
        {
        }
        /**
         * Retrieves the comment feed permalink structure.
         *
         * The permalink structure is root property, comment base property, feed
         * base and finally '/%feed%'. Will set the comment_feed_structure property
         * and then return it without attempting to set the value again.
         *
         * @since 1.5.0
         *
         * @return string|false Comment feed permalink structure on success, false on failure.
         */
        public function get_comment_feed_permastruct()
        {
        }
        /**
         * Adds or updates existing rewrite tags (e.g. %postname%).
         *
         * If the tag already exists, replace the existing pattern and query for
         * that tag, otherwise add the new tag.
         *
         * @since 1.5.0
         *
         * @see WP_Rewrite::$rewritecode
         * @see WP_Rewrite::$rewritereplace
         * @see WP_Rewrite::$queryreplace
         *
         * @param string $tag   Name of the rewrite tag to add or update.
         * @param string $regex Regular expression to substitute the tag for in rewrite rules.
         * @param string $query String to append to the rewritten query. Must end in '='.
         */
        public function add_rewrite_tag($tag, $regex, $query)
        {
        }
        /**
         * Removes an existing rewrite tag.
         *
         * @since 4.5.0
         *
         * @see WP_Rewrite::$rewritecode
         * @see WP_Rewrite::$rewritereplace
         * @see WP_Rewrite::$queryreplace
         *
         * @param string $tag Name of the rewrite tag to remove.
         */
        public function remove_rewrite_tag($tag)
        {
        }
        /**
         * Generates rewrite rules from a permalink structure.
         *
         * The main WP_Rewrite function for building the rewrite rule list. The
         * contents of the function is a mix of black magic and regular expressions,
         * so best just ignore the contents and move to the parameters.
         *
         * @since 1.5.0
         *
         * @param string $permalink_structure The permalink structure.
         * @param int    $ep_mask             Optional. Endpoint mask defining what endpoints are added to the structure.
         *                                    Accepts a mask of:
         *                                    - `EP_ALL`
         *                                    - `EP_NONE`
         *                                    - `EP_ALL_ARCHIVES`
         *                                    - `EP_ATTACHMENT`
         *                                    - `EP_AUTHORS`
         *                                    - `EP_CATEGORIES`
         *                                    - `EP_COMMENTS`
         *                                    - `EP_DATE`
         *                                    - `EP_DAY`
         *                                    - `EP_MONTH`
         *                                    - `EP_PAGES`
         *                                    - `EP_PERMALINK`
         *                                    - `EP_ROOT`
         *                                    - `EP_SEARCH`
         *                                    - `EP_TAGS`
         *                                    - `EP_YEAR`
         *                                    Default `EP_NONE`.
         * @param bool   $paged               Optional. Whether archive pagination rules should be added for the structure.
         *                                    Default true.
         * @param bool   $feed                Optional. Whether feed rewrite rules should be added for the structure.
         *                                    Default true.
         * @param bool   $forcomments         Optional. Whether the feed rules should be a query for a comments feed.
         *                                    Default false.
         * @param bool   $walk_dirs           Optional. Whether the 'directories' making up the structure should be walked
         *                                    over and rewrite rules built for each in-turn. Default true.
         * @param bool   $endpoints           Optional. Whether endpoints should be applied to the generated rewrite rules.
         *                                    Default true.
         * @return string[] Array of rewrite rules keyed by their regex pattern.
         */
        public function generate_rewrite_rules($permalink_structure, $ep_mask = \EP_NONE, $paged = \true, $feed = \true, $forcomments = \false, $walk_dirs = \true, $endpoints = \true)
        {
        }
        /**
         * Generates rewrite rules with permalink structure and walking directory only.
         *
         * Shorten version of WP_Rewrite::generate_rewrite_rules() that allows for shorter
         * list of parameters. See the method for longer description of what generating
         * rewrite rules does.
         *
         * @since 1.5.0
         *
         * @see WP_Rewrite::generate_rewrite_rules() See for long description and rest of parameters.
         *
         * @param string $permalink_structure The permalink structure to generate rules.
         * @param bool   $walk_dirs           Optional. Whether to create list of directories to walk over.
         *                                    Default false.
         * @return array An array of rewrite rules keyed by their regex pattern.
         */
        public function generate_rewrite_rule($permalink_structure, $walk_dirs = \false)
        {
        }
        /**
         * Constructs rewrite matches and queries from permalink structure.
         *
         * Runs the action {@see 'generate_rewrite_rules'} with the parameter that is an
         * reference to the current WP_Rewrite instance to further manipulate the
         * permalink structures and rewrite rules. Runs the {@see 'rewrite_rules_array'}
         * filter on the full rewrite rule array.
         *
         * There are two ways to manipulate the rewrite rules, one by hooking into
         * the {@see 'generate_rewrite_rules'} action and gaining full control of the
         * object or just manipulating the rewrite rule array before it is passed
         * from the function.
         *
         * @since 1.5.0
         *
         * @return string[] An associative array of matches and queries.
         */
        public function rewrite_rules()
        {
        }
        /**
         * Retrieves the rewrite rules.
         *
         * The difference between this method and WP_Rewrite::rewrite_rules() is that
         * this method stores the rewrite rules in the 'rewrite_rules' option and retrieves
         * it. This prevents having to process all of the permalinks to get the rewrite rules
         * in the form of caching.
         *
         * @since 1.5.0
         *
         * @return string[] Array of rewrite rules keyed by their regex pattern.
         */
        public function wp_rewrite_rules()
        {
        }
        /**
         * Retrieves mod_rewrite-formatted rewrite rules to write to .htaccess.
         *
         * Does not actually write to the .htaccess file, but creates the rules for
         * the process that will.
         *
         * Will add the non_wp_rules property rules to the .htaccess file before
         * the WordPress rewrite rules one.
         *
         * @since 1.5.0
         *
         * @return string
         */
        public function mod_rewrite_rules()
        {
        }
        /**
         * Retrieves IIS7 URL Rewrite formatted rewrite rules to write to web.config file.
         *
         * Does not actually write to the web.config file, but creates the rules for
         * the process that will.
         *
         * @since 2.8.0
         *
         * @param bool $add_parent_tags Optional. Whether to add parent tags to the rewrite rule sets.
         *                              Default false.
         * @return string IIS7 URL rewrite rule sets.
         */
        public function iis7_url_rewrite_rules($add_parent_tags = \false)
        {
        }
        /**
         * Adds a rewrite rule that transforms a URL structure to a set of query vars.
         *
         * Any value in the $after parameter that isn't 'bottom' will result in the rule
         * being placed at the top of the rewrite rules.
         *
         * @since 2.1.0
         * @since 4.4.0 Array support was added to the `$query` parameter.
         *
         * @param string       $regex Regular expression to match request against.
         * @param string|array $query The corresponding query vars for this rewrite rule.
         * @param string       $after Optional. Priority of the new rule. Accepts 'top'
         *                            or 'bottom'. Default 'bottom'.
         * @phpstan-param 'top'|'bottom' $after
         */
        public function add_rule($regex, $query, $after = 'bottom')
        {
        }
        /**
         * Adds a rewrite rule that doesn't correspond to index.php.
         *
         * @since 2.1.0
         *
         * @param string $regex Regular expression to match request against.
         * @param string $query The corresponding query vars for this rewrite rule.
         */
        public function add_external_rule($regex, $query)
        {
        }
        /**
         * Adds an endpoint, like /trackback/.
         *
         * @since 2.1.0
         * @since 3.9.0 $query_var parameter added.
         * @since 4.3.0 Added support for skipping query var registration by passing `false` to `$query_var`.
         *
         * @see add_rewrite_endpoint() for full documentation.
         * @global WP $wp Current WordPress environment instance.
         *
         * @param string      $name      Name of the endpoint.
         * @param int         $places    Endpoint mask describing the places the endpoint should be added.
         *                               Accepts a mask of:
         *                               - `EP_ALL`
         *                               - `EP_NONE`
         *                               - `EP_ALL_ARCHIVES`
         *                               - `EP_ATTACHMENT`
         *                               - `EP_AUTHORS`
         *                               - `EP_CATEGORIES`
         *                               - `EP_COMMENTS`
         *                               - `EP_DATE`
         *                               - `EP_DAY`
         *                               - `EP_MONTH`
         *                               - `EP_PAGES`
         *                               - `EP_PERMALINK`
         *                               - `EP_ROOT`
         *                               - `EP_SEARCH`
         *                               - `EP_TAGS`
         *                               - `EP_YEAR`
         * @param string|bool $query_var Optional. Name of the corresponding query variable. Pass `false` to
         *                               skip registering a query_var for this endpoint. Defaults to the
         *                               value of `$name`.
         */
        public function add_endpoint($name, $places, $query_var = \true)
        {
        }
        /**
         * Adds a new permalink structure.
         *
         * A permalink structure (permastruct) is an abstract definition of a set of rewrite rules;
         * it is an easy way of expressing a set of regular expressions that rewrite to a set of
         * query strings. The new permastruct is added to the WP_Rewrite::$extra_permastructs array.
         *
         * When the rewrite rules are built by WP_Rewrite::rewrite_rules(), all of these extra
         * permastructs are passed to WP_Rewrite::generate_rewrite_rules() which transforms them
         * into the regular expressions that many love to hate.
         *
         * The `$args` parameter gives you control over how WP_Rewrite::generate_rewrite_rules()
         * works on the new permastruct.
         *
         * @since 2.5.0
         *
         * @param string $name   Name for permalink structure.
         * @param string $struct Permalink structure (e.g. category/%category%)
         * @param array  $args   {
         *     Optional. Arguments for building rewrite rules based on the permalink structure.
         *     Default empty array.
         *
         *     @type bool $with_front  Whether the structure should be prepended with `WP_Rewrite::$front`.
         *                             Default true.
         *     @type int  $ep_mask     The endpoint mask defining which endpoints are added to the structure.
         *                             Accepts a mask of:
         *                             - `EP_ALL`
         *                             - `EP_NONE`
         *                             - `EP_ALL_ARCHIVES`
         *                             - `EP_ATTACHMENT`
         *                             - `EP_AUTHORS`
         *                             - `EP_CATEGORIES`
         *                             - `EP_COMMENTS`
         *                             - `EP_DATE`
         *                             - `EP_DAY`
         *                             - `EP_MONTH`
         *                             - `EP_PAGES`
         *                             - `EP_PERMALINK`
         *                             - `EP_ROOT`
         *                             - `EP_SEARCH`
         *                             - `EP_TAGS`
         *                             - `EP_YEAR`
         *                             Default `EP_NONE`.
         *     @type bool $paged       Whether archive pagination rules should be added for the structure.
         *                             Default true.
         *     @type bool $feed        Whether feed rewrite rules should be added for the structure. Default true.
         *     @type bool $forcomments Whether the feed rules should be a query for a comments feed. Default false.
         *     @type bool $walk_dirs   Whether the 'directories' making up the structure should be walked over
         *                             and rewrite rules built for each in-turn. Default true.
         *     @type bool $endpoints   Whether endpoints should be applied to the generated rules. Default true.
         * }
         * @phpstan-param array{
         *   with_front?: bool,
         *   ep_mask?: int,
         *   paged?: bool,
         *   feed?: bool,
         *   forcomments?: bool,
         *   walk_dirs?: bool,
         *   endpoints?: bool,
         * } $args
         */
        public function add_permastruct($name, $struct, $args = array())
        {
        }
        /**
         * Removes a permalink structure.
         *
         * @since 4.5.0
         *
         * @param string $name Name for permalink structure.
         */
        public function remove_permastruct($name)
        {
        }
        /**
         * Removes rewrite rules and then recreate rewrite rules.
         *
         * Calls WP_Rewrite::wp_rewrite_rules() after removing the 'rewrite_rules' option.
         * If the function named 'save_mod_rewrite_rules' exists, it will be called.
         *
         * @since 2.0.1
         *
         * @param bool $hard Whether to update .htaccess (hard flush) or just update rewrite_rules option (soft flush). Default is true (hard).
         * @phpstan-return void
         */
        public function flush_rules($hard = \true)
        {
        }
        /**
         * Sets up the object's properties.
         *
         * The 'use_verbose_page_rules' object property will be set to true if the
         * permalink structure begins with one of the following: '%postname%', '%category%',
         * '%tag%', or '%author%'.
         *
         * @since 1.5.0
         */
        public function init()
        {
        }
        /**
         * Sets the main permalink structure for the site.
         *
         * Will update the 'permalink_structure' option, if there is a difference
         * between the current permalink structure and the parameter value. Calls
         * WP_Rewrite::init() after the option is updated.
         *
         * Fires the {@see 'permalink_structure_changed'} action once the init call has
         * processed passing the old and new values
         *
         * @since 1.5.0
         *
         * @param string $permalink_structure Permalink structure.
         */
        public function set_permalink_structure($permalink_structure)
        {
        }
        /**
         * Sets the category base for the category permalink.
         *
         * Will update the 'category_base' option, if there is a difference between
         * the current category base and the parameter value. Calls WP_Rewrite::init()
         * after the option is updated.
         *
         * @since 1.5.0
         *
         * @param string $category_base Category permalink structure base.
         */
        public function set_category_base($category_base)
        {
        }
        /**
         * Sets the tag base for the tag permalink.
         *
         * Will update the 'tag_base' option, if there is a difference between the
         * current tag base and the parameter value. Calls WP_Rewrite::init() after
         * the option is updated.
         *
         * @since 2.3.0
         *
         * @param string $tag_base Tag permalink structure base.
         */
        public function set_tag_base($tag_base)
        {
        }
        /**
         * Constructor - Calls init(), which runs setup.
         *
         * @since 1.5.0
         */
        public function __construct()
        {
        }
    }
    /**
     * Core class used to extend the user roles API.
     *
     * @since 2.0.0
     */
    #[\AllowDynamicProperties]
    class WP_Role
    {
        /**
         * Role name.
         *
         * @since 2.0.0
         * @var string
         */
        public $name;
        /**
         * List of capabilities the role contains.
         *
         * @since 2.0.0
         * @var bool[] Array of key/value pairs where keys represent a capability name and boolean values
         *             represent whether the role has that capability.
         */
        public $capabilities;
        /**
         * Constructor - Set up object properties.
         *
         * The list of capabilities must have the key as the name of the capability
         * and the value a boolean of whether it is granted to the role.
         *
         * @since 2.0.0
         *
         * @param string $role         Role name.
         * @param bool[] $capabilities Array of key/value pairs where keys represent a capability name and boolean values
         *                             represent whether the role has that capability.
         */
        public function __construct($role, $capabilities)
        {
        }
        /**
         * Assign role a capability.
         *
         * @since 2.0.0
         *
         * @param string $cap   Capability name.
         * @param bool   $grant Whether role has capability privilege.
         */
        public function add_cap($cap, $grant = \true)
        {
        }
        /**
         * Removes a capability from a role.
         *
         * @since 2.0.0
         *
         * @param string $cap Capability name.
         */
        public function remove_cap($cap)
        {
        }
        /**
         * Determines whether the role has the given capability.
         *
         * @since 2.0.0
         *
         * @param string $cap Capability name.
         * @return bool Whether the role has the given capability.
         */
        public function has_cap($cap)
        {
        }
    }
    /**
     * Core class used to implement a user roles API.
     *
     * The role option is simple, the structure is organized by role name that store
     * the name in value of the 'name' key. The capabilities are stored as an array
     * in the value of the 'capability' key.
     *
     *     array (
     *          'rolename' => array (
     *              'name' => 'rolename',
     *              'capabilities' => array()
     *          )
     *     )
     *
     * @since 2.0.0
     */
    #[\AllowDynamicProperties]
    class WP_Roles
    {
        /**
         * List of roles and capabilities.
         *
         * @since 2.0.0
         * @var array[]
         */
        public $roles;
        /**
         * List of the role objects.
         *
         * @since 2.0.0
         * @var WP_Role[]
         */
        public $role_objects = array();
        /**
         * List of role names.
         *
         * @since 2.0.0
         * @var string[]
         */
        public $role_names = array();
        /**
         * Option name for storing role list.
         *
         * @since 2.0.0
         * @var string
         */
        public $role_key;
        /**
         * Whether to use the database for retrieval and storage.
         *
         * @since 2.1.0
         * @var bool
         */
        public $use_db = \true;
        /**
         * The site ID the roles are initialized for.
         *
         * @since 4.9.0
         * @var int
         */
        protected $site_id = 0;
        /**
         * Constructor.
         *
         * @since 2.0.0
         * @since 4.9.0 The `$site_id` argument was added.
         *
         * @global array $wp_user_roles Used to set the 'roles' property value.
         *
         * @param int $site_id Site ID to initialize roles for. Default is the current site.
         */
        public function __construct($site_id = \null)
        {
        }
        /**
         * Makes private/protected methods readable for backward compatibility.
         *
         * @since 4.0.0
         *
         * @param string $name      Method to call.
         * @param array  $arguments Arguments to pass when calling.
         * @return mixed|false Return value of the callback, false otherwise.
         */
        public function __call($name, $arguments)
        {
        }
        /**
         * Sets up the object properties.
         *
         * The role key is set to the current prefix for the $wpdb object with
         * 'user_roles' appended. If the $wp_user_roles global is set, then it will
         * be used and the role option will not be updated or used.
         *
         * @since 2.1.0
         * @deprecated 4.9.0 Use WP_Roles::for_site()
         */
        protected function _init()
        {
        }
        /**
         * Reinitializes the object.
         *
         * Recreates the role objects. This is typically called only by switch_to_blog()
         * after switching wpdb to a new site ID.
         *
         * @since 3.5.0
         * @deprecated 4.7.0 Use WP_Roles::for_site()
         */
        public function reinit()
        {
        }
        /**
         * Adds a role name with capabilities to the list.
         *
         * Updates the list of roles, if the role doesn't already exist.
         *
         * The capabilities are defined in the following format: `array( 'read' => true )`.
         * To explicitly deny the role a capability, set the value for that capability to false.
         *
         * @since 2.0.0
         *
         * @param string $role         Role name.
         * @param string $display_name Role display name.
         * @param bool[] $capabilities Optional. List of capabilities keyed by the capability name,
         *                             e.g. `array( 'edit_posts' => true, 'delete_posts' => false )`.
         *                             Default empty array.
         * @return WP_Role|void WP_Role object, if the role is added.
         */
        public function add_role($role, $display_name, $capabilities = array())
        {
        }
        /**
         * Removes a role by name.
         *
         * @since 2.0.0
         *
         * @param string $role Role name.
         * @phpstan-return void
         */
        public function remove_role($role)
        {
        }
        /**
         * Adds a capability to role.
         *
         * @since 2.0.0
         *
         * @param string $role  Role name.
         * @param string $cap   Capability name.
         * @param bool   $grant Optional. Whether role is capable of performing capability.
         *                      Default true.
         * @phpstan-return void
         */
        public function add_cap($role, $cap, $grant = \true)
        {
        }
        /**
         * Removes a capability from role.
         *
         * @since 2.0.0
         *
         * @param string $role Role name.
         * @param string $cap  Capability name.
         * @phpstan-return void
         */
        public function remove_cap($role, $cap)
        {
        }
        /**
         * Retrieves a role object by name.
         *
         * @since 2.0.0
         *
         * @param string $role Role name.
         * @return WP_Role|null WP_Role object if found, null if the role does not exist.
         */
        public function get_role($role)
        {
        }
        /**
         * Retrieves a list of role names.
         *
         * @since 2.0.0
         *
         * @return string[] List of role names.
         */
        public function get_names()
        {
        }
        /**
         * Determines whether a role name is currently in the list of available roles.
         *
         * @since 2.0.0
         *
         * @param string $role Role name to look up.
         * @return bool
         */
        public function is_role($role)
        {
        }
        /**
         * Initializes all of the available roles.
         *
         * @since 4.9.0
         * @phpstan-return void
         */
        public function init_roles()
        {
        }
        /**
         * Sets the site to operate on. Defaults to the current site.
         *
         * @since 4.9.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param int $site_id Site ID to initialize roles for. Default is the current site.
         * @phpstan-return void
         */
        public function for_site($site_id = \null)
        {
        }
        /**
         * Gets the ID of the site for which roles are currently initialized.
         *
         * @since 4.9.0
         *
         * @return int Site ID.
         */
        public function get_site_id()
        {
        }
        /**
         * Gets the available roles data.
         *
         * @since 4.9.0
         *
         * @global array $wp_user_roles Used to set the 'roles' property value.
         *
         * @return array Roles array.
         */
        protected function get_roles_data()
        {
        }
    }
    /**
     * Core class used to register script modules.
     *
     * @since 6.5.0
     */
    class WP_Script_Modules
    {
        /**
         * Registers the script module if no script module with that script module
         * identifier has already been registered.
         *
         * @since 6.5.0
         *
         * @param string            $id       The identifier of the script module. Should be unique. It will be used in the
         *                                    final import map.
         * @param string            $src      Optional. Full URL of the script module, or path of the script module relative
         *                                    to the WordPress root directory. If it is provided and the script module has
         *                                    not been registered yet, it will be registered.
         * @param array             $deps     {
         *                                        Optional. List of dependencies.
         *
         *                                        @type string|array ...$0 {
         *                                            An array of script module identifiers of the dependencies of this script
         *                                            module. The dependencies can be strings or arrays. If they are arrays,
         *                                            they need an `id` key with the script module identifier, and can contain
         *                                            an `import` key with either `static` or `dynamic`. By default,
         *                                            dependencies that don't contain an `import` key are considered static.
         *
         *                                            @type string $id     The script module identifier.
         *                                            @type string $import Optional. Import type. May be either `static` or
         *                                                                 `dynamic`. Defaults to `static`.
         *                                        }
         *                                    }
         * @param string|false|null $version  Optional. String specifying the script module version number. Defaults to false.
         *                                    It is added to the URL as a query string for cache busting purposes. If $version
         *                                    is set to false, the version number is the currently installed WordPress version.
         *                                    If $version is set to null, no version is added.
         * @phpstan-param array<int|string, array{
         *   id: string,
         *   import?: string,
         * }> $deps
         */
        public function register(string $id, string $src, array $deps = array(), $version = \false)
        {
        }
        /**
         * Marks the script module to be enqueued in the page.
         *
         * If a src is provided and the script module has not been registered yet, it
         * will be registered.
         *
         * @since 6.5.0
         *
         * @param string            $id       The identifier of the script module. Should be unique. It will be used in the
         *                                    final import map.
         * @param string            $src      Optional. Full URL of the script module, or path of the script module relative
         *                                    to the WordPress root directory. If it is provided and the script module has
         *                                    not been registered yet, it will be registered.
         * @param array             $deps     {
         *                                        Optional. List of dependencies.
         *
         *                                        @type string|array ...$0 {
         *                                            An array of script module identifiers of the dependencies of this script
         *                                            module. The dependencies can be strings or arrays. If they are arrays,
         *                                            they need an `id` key with the script module identifier, and can contain
         *                                            an `import` key with either `static` or `dynamic`. By default,
         *                                            dependencies that don't contain an `import` key are considered static.
         *
         *                                            @type string $id     The script module identifier.
         *                                            @type string $import Optional. Import type. May be either `static` or
         *                                                                 `dynamic`. Defaults to `static`.
         *                                        }
         *                                    }
         * @param string|false|null $version  Optional. String specifying the script module version number. Defaults to false.
         *                                    It is added to the URL as a query string for cache busting purposes. If $version
         *                                    is set to false, the version number is the currently installed WordPress version.
         *                                    If $version is set to null, no version is added.
         * @phpstan-param array<int|string, array{
         *   id: string,
         *   import?: string,
         * }> $deps
         */
        public function enqueue(string $id, string $src = '', array $deps = array(), $version = \false)
        {
        }
        /**
         * Unmarks the script module so it will no longer be enqueued in the page.
         *
         * @since 6.5.0
         *
         * @param string $id The identifier of the script module.
         */
        public function dequeue(string $id)
        {
        }
        /**
         * Removes a registered script module.
         *
         * @since 6.5.0
         *
         * @param string $id The identifier of the script module.
         */
        public function deregister(string $id)
        {
        }
        /**
         * Adds the hooks to print the import map, enqueued script modules and script
         * module preloads.
         *
         * In classic themes, the script modules used by the blocks are not yet known
         * when the `wp_head` actions is fired, so it needs to print everything in the
         * footer.
         *
         * @since 6.5.0
         */
        public function add_hooks()
        {
        }
        /**
         * Prints the enqueued script modules using script tags with type="module"
         * attributes.
         *
         * @since 6.5.0
         */
        public function print_enqueued_script_modules()
        {
        }
        /**
         * Prints the the static dependencies of the enqueued script modules using
         * link tags with rel="modulepreload" attributes.
         *
         * If a script module is marked for enqueue, it will not be preloaded.
         *
         * @since 6.5.0
         */
        public function print_script_module_preloads()
        {
        }
        /**
         * Prints the import map using a script tag with a type="importmap" attribute.
         *
         * @since 6.5.0
         */
        public function print_import_map()
        {
        }
        /**
         * Print data associated with Script Modules.
         *
         * The data will be embedded in the page HTML and can be read by Script Modules on page load.
         *
         * @since 6.7.0
         *
         * Data can be associated with a Script Module via the
         * {@see "script_module_data_{$module_id}"} filter.
         *
         * The data for a Script Module will be serialized as JSON in a script tag with an ID of the
         * form `wp-script-module-data-{$module_id}`.
         */
        public function print_script_module_data() : void
        {
        }
        /**
         * @access private This is only intended to be called by the registered actions.
         *
         * @since 6.7.0
         * @phpstan-return void
         */
        public function print_a11y_script_module_html()
        {
        }
    }
    /**
     * Core class used to register scripts.
     *
     * @since 2.1.0
     *
     * @see WP_Dependencies
     */
    class WP_Scripts extends \WP_Dependencies
    {
        /**
         * Base URL for scripts.
         *
         * Full URL with trailing slash.
         *
         * @since 2.6.0
         * @var string
         */
        public $base_url;
        /**
         * URL of the content directory.
         *
         * @since 2.8.0
         * @var string
         */
        public $content_url;
        /**
         * Default version string for scripts.
         *
         * @since 2.6.0
         * @var string
         */
        public $default_version;
        /**
         * Holds handles of scripts which are enqueued in footer.
         *
         * @since 2.8.0
         * @var array
         */
        public $in_footer = array();
        /**
         * Holds a list of script handles which will be concatenated.
         *
         * @since 2.8.0
         * @var string
         */
        public $concat = '';
        /**
         * Holds a string which contains script handles and their version.
         *
         * @since 2.8.0
         * @deprecated 3.4.0
         * @var string
         */
        public $concat_version = '';
        /**
         * Whether to perform concatenation.
         *
         * @since 2.8.0
         * @var bool
         */
        public $do_concat = \false;
        /**
         * Holds HTML markup of scripts and additional data if concatenation
         * is enabled.
         *
         * @since 2.8.0
         * @var string
         */
        public $print_html = '';
        /**
         * Holds inline code if concatenation is enabled.
         *
         * @since 2.8.0
         * @var string
         */
        public $print_code = '';
        /**
         * Holds a list of script handles which are not in the default directory
         * if concatenation is enabled.
         *
         * Unused in core.
         *
         * @since 2.8.0
         * @var string
         */
        public $ext_handles = '';
        /**
         * Holds a string which contains handles and versions of scripts which
         * are not in the default directory if concatenation is enabled.
         *
         * Unused in core.
         *
         * @since 2.8.0
         * @var string
         */
        public $ext_version = '';
        /**
         * List of default directories.
         *
         * @since 2.8.0
         * @var array
         */
        public $default_dirs;
        /**
         * Constructor.
         *
         * @since 2.6.0
         */
        public function __construct()
        {
        }
        /**
         * Initialize the class.
         *
         * @since 3.4.0
         */
        public function init()
        {
        }
        /**
         * Prints scripts.
         *
         * Prints the scripts passed to it or the print queue. Also prints all necessary dependencies.
         *
         * @since 2.1.0
         * @since 2.8.0 Added the `$group` parameter.
         *
         * @param string|string[]|false $handles Optional. Scripts to be printed: queue (false),
         *                                       single script (string), or multiple scripts (array of strings).
         *                                       Default false.
         * @param int|false             $group   Optional. Group level: level (int), no groups (false).
         *                                       Default false.
         * @return string[] Handles of scripts that have been printed.
         */
        public function print_scripts($handles = \false, $group = \false)
        {
        }
        /**
         * Prints extra scripts of a registered script.
         *
         * @since 2.1.0
         * @since 2.8.0 Added the `$display` parameter.
         * @deprecated 3.3.0
         *
         * @see print_extra_script()
         *
         * @param string $handle  The script's registered handle.
         * @param bool   $display Optional. Whether to print the extra script
         *                        instead of just returning it. Default true.
         * @return bool|string|void Void if no data exists, extra scripts if `$display` is true,
         *                          true otherwise.
         */
        public function print_scripts_l10n($handle, $display = \true)
        {
        }
        /**
         * Prints extra scripts of a registered script.
         *
         * @since 3.3.0
         *
         * @param string $handle  The script's registered handle.
         * @param bool   $display Optional. Whether to print the extra script
         *                        instead of just returning it. Default true.
         * @return bool|string|void Void if no data exists, extra scripts if `$display` is true,
         *                          true otherwise.
         */
        public function print_extra_script($handle, $display = \true)
        {
        }
        /**
         * Processes a script dependency.
         *
         * @since 2.6.0
         * @since 2.8.0 Added the `$group` parameter.
         *
         * @see WP_Dependencies::do_item()
         *
         * @param string    $handle The script's registered handle.
         * @param int|false $group  Optional. Group level: level (int), no groups (false).
         *                          Default false.
         * @return bool True on success, false on failure.
         */
        public function do_item($handle, $group = \false)
        {
        }
        /**
         * Adds extra code to a registered script.
         *
         * @since 4.5.0
         *
         * @param string $handle   Name of the script to add the inline script to.
         *                         Must be lowercase.
         * @param string $data     String containing the JavaScript to be added.
         * @param string $position Optional. Whether to add the inline script
         *                         before the handle or after. Default 'after'.
         * @return bool True on success, false on failure.
         */
        public function add_inline_script($handle, $data, $position = 'after')
        {
        }
        /**
         * Prints inline scripts registered for a specific handle.
         *
         * @since 4.5.0
         * @deprecated 6.3.0 Use methods get_inline_script_tag() or get_inline_script_data() instead.
         *
         * @param string $handle   Name of the script to print inline scripts for.
         *                         Must be lowercase.
         * @param string $position Optional. Whether to add the inline script
         *                         before the handle or after. Default 'after'.
         * @param bool   $display  Optional. Whether to print the script tag
         *                         instead of just returning the script data. Default true.
         * @return string|false Script data on success, false otherwise.
         */
        public function print_inline_script($handle, $position = 'after', $display = \true)
        {
        }
        /**
         * Gets data for inline scripts registered for a specific handle.
         *
         * @since 6.3.0
         *
         * @param string $handle   Name of the script to get data for.
         *                         Must be lowercase.
         * @param string $position Optional. Whether to add the inline script
         *                         before the handle or after. Default 'after'.
         * @return string Inline script, which may be empty string.
         */
        public function get_inline_script_data($handle, $position = 'after')
        {
        }
        /**
         * Gets tags for inline scripts registered for a specific handle.
         *
         * @since 6.3.0
         *
         * @param string $handle   Name of the script to get associated inline script tag for.
         *                         Must be lowercase.
         * @param string $position Optional. Whether to get tag for inline
         *                         scripts in the before or after position. Default 'after'.
         * @return string Inline script, which may be empty string.
         */
        public function get_inline_script_tag($handle, $position = 'after')
        {
        }
        /**
         * Localizes a script, only if the script has already been added.
         *
         * @since 2.1.0
         *
         * @param string $handle      Name of the script to attach data to.
         * @param string $object_name Name of the variable that will contain the data.
         * @param array  $l10n        Array of data to localize.
         * @return bool True on success, false on failure.
         */
        public function localize($handle, $object_name, $l10n)
        {
        }
        /**
         * Sets handle group.
         *
         * @since 2.8.0
         *
         * @see WP_Dependencies::set_group()
         *
         * @param string    $handle    Name of the item. Should be unique.
         * @param bool      $recursion Internal flag that calling function was called recursively.
         * @param int|false $group     Optional. Group level: level (int), no groups (false).
         *                             Default false.
         * @return bool Not already in the group or a lower group.
         */
        public function set_group($handle, $recursion, $group = \false)
        {
        }
        /**
         * Sets a translation textdomain.
         *
         * @since 5.0.0
         * @since 5.1.0 The `$domain` parameter was made optional.
         *
         * @param string $handle Name of the script to register a translation domain to.
         * @param string $domain Optional. Text domain. Default 'default'.
         * @param string $path   Optional. The full file path to the directory containing translation files.
         * @return bool True if the text domain was registered, false if not.
         */
        public function set_translations($handle, $domain = 'default', $path = '')
        {
        }
        /**
         * Prints translations set for a specific handle.
         *
         * @since 5.0.0
         *
         * @param string $handle  Name of the script to add the inline script to.
         *                        Must be lowercase.
         * @param bool   $display Optional. Whether to print the script
         *                        instead of just returning it. Default true.
         * @return string|false Script on success, false otherwise.
         */
        public function print_translations($handle, $display = \true)
        {
        }
        /**
         * Determines script dependencies.
         *
         * @since 2.1.0
         *
         * @see WP_Dependencies::all_deps()
         *
         * @param string|string[] $handles   Item handle (string) or item handles (array of strings).
         * @param bool            $recursion Optional. Internal flag that function is calling itself.
         *                                   Default false.
         * @param int|false       $group     Optional. Group level: level (int), no groups (false).
         *                                   Default false.
         * @return bool True on success, false on failure.
         */
        public function all_deps($handles, $recursion = \false, $group = \false)
        {
        }
        /**
         * Processes items and dependencies for the head group.
         *
         * @since 2.8.0
         *
         * @see WP_Dependencies::do_items()
         *
         * @return string[] Handles of items that have been processed.
         */
        public function do_head_items()
        {
        }
        /**
         * Processes items and dependencies for the footer group.
         *
         * @since 2.8.0
         *
         * @see WP_Dependencies::do_items()
         *
         * @return string[] Handles of items that have been processed.
         */
        public function do_footer_items()
        {
        }
        /**
         * Whether a handle's source is in a default directory.
         *
         * @since 2.8.0
         *
         * @param string $src The source of the enqueued script.
         * @return bool True if found, false if not.
         */
        public function in_default_dir($src)
        {
        }
        /**
         * This overrides the add_data method from WP_Dependencies, to support normalizing of $args.
         *
         * @since 6.3.0
         *
         * @param string $handle Name of the item. Should be unique.
         * @param string $key    The data key.
         * @param mixed  $value  The data value.
         * @return bool True on success, false on failure.
         */
        public function add_data($handle, $key, $value)
        {
        }
        /**
         * Resets class properties.
         *
         * @since 2.8.0
         */
        public function reset()
        {
        }
    }
    /**
     * Abstract class for managing user session tokens.
     *
     * @since 4.0.0
     */
    #[\AllowDynamicProperties]
    abstract class WP_Session_Tokens
    {
        /**
         * User ID.
         *
         * @since 4.0.0
         * @var int User ID.
         */
        protected $user_id;
        /**
         * Protected constructor. Use the `get_instance()` method to get the instance.
         *
         * @since 4.0.0
         *
         * @param int $user_id User whose session to manage.
         */
        protected function __construct($user_id)
        {
        }
        /**
         * Retrieves a session manager instance for a user.
         *
         * This method contains a {@see 'session_token_manager'} filter, allowing a plugin to swap out
         * the session manager for a subclass of `WP_Session_Tokens`.
         *
         * @since 4.0.0
         *
         * @param int $user_id User whose session to manage.
         * @return WP_Session_Tokens The session object, which is by default an instance of
         *                           the `WP_User_Meta_Session_Tokens` class.
         */
        public static final function get_instance($user_id)
        {
        }
        /**
         * Retrieves a user's session for the given token.
         *
         * @since 4.0.0
         *
         * @param string $token Session token.
         * @return array|null The session, or null if it does not exist.
         */
        public final function get($token)
        {
        }
        /**
         * Validates the given session token for authenticity and validity.
         *
         * Checks that the given token is present and hasn't expired.
         *
         * @since 4.0.0
         *
         * @param string $token Token to verify.
         * @return bool Whether the token is valid for the user.
         */
        public final function verify($token)
        {
        }
        /**
         * Generates a session token and attaches session information to it.
         *
         * A session token is a long, random string. It is used in a cookie
         * to link that cookie to an expiration time and to ensure the cookie
         * becomes invalidated when the user logs out.
         *
         * This function generates a token and stores it with the associated
         * expiration time (and potentially other session information via the
         * {@see 'attach_session_information'} filter).
         *
         * @since 4.0.0
         *
         * @param int $expiration Session expiration timestamp.
         * @return string Session token.
         */
        public final function create($expiration)
        {
        }
        /**
         * Updates the data for the session with the given token.
         *
         * @since 4.0.0
         *
         * @param string $token Session token to update.
         * @param array  $session Session information.
         */
        public final function update($token, $session)
        {
        }
        /**
         * Destroys the session with the given token.
         *
         * @since 4.0.0
         *
         * @param string $token Session token to destroy.
         */
        public final function destroy($token)
        {
        }
        /**
         * Destroys all sessions for this user except the one with the given token (presumably the one in use).
         *
         * @since 4.0.0
         *
         * @param string $token_to_keep Session token to keep.
         */
        public final function destroy_others($token_to_keep)
        {
        }
        /**
         * Determines whether a session is still valid, based on its expiration timestamp.
         *
         * @since 4.0.0
         *
         * @param array $session Session to check.
         * @return bool Whether session is valid.
         */
        protected final function is_still_valid($session)
        {
        }
        /**
         * Destroys all sessions for a user.
         *
         * @since 4.0.0
         */
        public final function destroy_all()
        {
        }
        /**
         * Destroys all sessions for all users.
         *
         * @since 4.0.0
         */
        public static final function destroy_all_for_all_users()
        {
        }
        /**
         * Retrieves all sessions for a user.
         *
         * @since 4.0.0
         *
         * @return array Sessions for a user.
         */
        public final function get_all()
        {
        }
        /**
         * Retrieves all sessions of the user.
         *
         * @since 4.0.0
         *
         * @return array Sessions of the user.
         */
        protected abstract function get_sessions();
        /**
         * Retrieves a session based on its verifier (token hash).
         *
         * @since 4.0.0
         *
         * @param string $verifier Verifier for the session to retrieve.
         * @return array|null The session, or null if it does not exist.
         */
        protected abstract function get_session($verifier);
        /**
         * Updates a session based on its verifier (token hash).
         *
         * Omitting the second argument destroys the session.
         *
         * @since 4.0.0
         *
         * @param string $verifier Verifier for the session to update.
         * @param array  $session  Optional. Session. Omitting this argument destroys the session.
         */
        protected abstract function update_session($verifier, $session = \null);
        /**
         * Destroys all sessions for this user, except the single session with the given verifier.
         *
         * @since 4.0.0
         *
         * @param string $verifier Verifier of the session to keep.
         */
        protected abstract function destroy_other_sessions($verifier);
        /**
         * Destroys all sessions for the user.
         *
         * @since 4.0.0
         */
        protected abstract function destroy_all_sessions();
        /**
         * Destroys all sessions for all users.
         *
         * @since 4.0.0
         */
        public static function drop_sessions()
        {
        }
    }
    /**
     * Core class for fetching remote files and reading local files with SimplePie.
     *
     * This uses Core's HTTP API to make requests, which gives plugins the ability
     * to hook into the process.
     *
     * @since 2.8.0
     */
    #[\AllowDynamicProperties]
    class WP_SimplePie_File extends \SimplePie\File
    {
        /**
         * Timeout.
         *
         * @var int How long the connection should stay open in seconds.
         */
        public $timeout = 10;
        /**
         * Constructor.
         *
         * @since 2.8.0
         * @since 3.2.0 Updated to use a PHP5 constructor.
         * @since 5.6.1 Multiple headers are concatenated into a comma-separated string,
         *              rather than remaining an array.
         *
         * @param string       $url             Remote file URL.
         * @param int          $timeout         Optional. How long the connection should stay open in seconds.
         *                                      Default 10.
         * @param int          $redirects       Optional. The number of allowed redirects. Default 5.
         * @param string|array $headers         Optional. Array or string of headers to send with the request.
         *                                      Default null.
         * @param string       $useragent       Optional. User-agent value sent. Default null.
         * @param bool         $force_fsockopen Optional. Whether to force opening internet or unix domain socket
         *                                      connection or not. Default false.
         */
        public function __construct($url, $timeout = 10, $redirects = 5, $headers = \null, $useragent = \null, $force_fsockopen = \false)
        {
        }
    }
    /**
     * Core class used to implement SimplePie feed sanitization.
     *
     * Extends the SimplePie\Sanitize class to use KSES, because
     * we cannot universally count on DOMDocument being available.
     *
     * @since 3.5.0
     */
    #[\AllowDynamicProperties]
    class WP_SimplePie_Sanitize_KSES extends \SimplePie\Sanitize
    {
        /**
         * WordPress SimplePie sanitization using KSES.
         *
         * Sanitizes the incoming data, to ensure that it matches the type of data expected, using KSES.
         *
         * @since 3.5.0
         *
         * @param mixed   $data The data that needs to be sanitized.
         * @param int     $type The type of data that it's supposed to be.
         * @param string  $base Optional. The `xml:base` value to use when converting relative
         *                      URLs to absolute ones. Default empty.
         * @return mixed Sanitized data.
         */
        public function sanitize($data, $type, $base = '')
        {
        }
    }
    /**
     * Core class used for querying sites.
     *
     * @since 4.6.0
     *
     * @see WP_Site_Query::__construct() for accepted arguments.
     */
    #[\AllowDynamicProperties]
    class WP_Site_Query
    {
        /**
         * SQL for database query.
         *
         * @since 4.6.0
         * @var string
         */
        public $request;
        /**
         * SQL query clauses.
         *
         * @since 4.6.0
         * @var array
         */
        protected $sql_clauses = array('select' => '', 'from' => '', 'where' => array(), 'groupby' => '', 'orderby' => '', 'limits' => '');
        /**
         * Metadata query container.
         *
         * @since 5.1.0
         * @var WP_Meta_Query
         */
        public $meta_query = \false;
        /**
         * Metadata query clauses.
         *
         * @since 5.1.0
         * @var array
         */
        protected $meta_query_clauses;
        /**
         * Date query container.
         *
         * @since 4.6.0
         * @var WP_Date_Query A date query instance.
         */
        public $date_query = \false;
        /**
         * Query vars set by the user.
         *
         * @since 4.6.0
         * @var array
         */
        public $query_vars;
        /**
         * Default values for query vars.
         *
         * @since 4.6.0
         * @var array
         */
        public $query_var_defaults;
        /**
         * List of sites located by the query.
         *
         * @since 4.6.0
         * @var array
         */
        public $sites;
        /**
         * The amount of found sites for the current query.
         *
         * @since 4.6.0
         * @var int
         */
        public $found_sites = 0;
        /**
         * The number of pages.
         *
         * @since 4.6.0
         * @var int
         */
        public $max_num_pages = 0;
        /**
         * Sets up the site query, based on the query vars passed.
         *
         * @since 4.6.0
         * @since 4.8.0 Introduced the 'lang_id', 'lang__in', and 'lang__not_in' parameters.
         * @since 5.1.0 Introduced the 'update_site_meta_cache', 'meta_query', 'meta_key',
         *              'meta_compare_key', 'meta_value', 'meta_type', and 'meta_compare' parameters.
         * @since 5.3.0 Introduced the 'meta_type_key' parameter.
         *
         * @param string|array $query {
         *     Optional. Array or query string of site query parameters. Default empty.
         *
         *     @type int[]           $site__in               Array of site IDs to include. Default empty.
         *     @type int[]           $site__not_in           Array of site IDs to exclude. Default empty.
         *     @type bool            $count                  Whether to return a site count (true) or array of site objects.
         *                                                   Default false.
         *     @type array           $date_query             Date query clauses to limit sites by. See WP_Date_Query.
         *                                                   Default null.
         *     @type string          $fields                 Site fields to return. Accepts 'ids' (returns an array of site IDs)
         *                                                   or empty (returns an array of complete site objects). Default empty.
         *     @type int             $ID                     A site ID to only return that site. Default empty.
         *     @type int             $number                 Maximum number of sites to retrieve. Default 100.
         *     @type int             $offset                 Number of sites to offset the query. Used to build LIMIT clause.
         *                                                   Default 0.
         *     @type bool            $no_found_rows          Whether to disable the `SQL_CALC_FOUND_ROWS` query. Default true.
         *     @type string|array    $orderby                Site status or array of statuses. Accepts:
         *                                                   - 'id'
         *                                                   - 'domain'
         *                                                   - 'path'
         *                                                   - 'network_id'
         *                                                   - 'last_updated'
         *                                                   - 'registered'
         *                                                   - 'domain_length'
         *                                                   - 'path_length'
         *                                                   - 'site__in'
         *                                                   - 'network__in'
         *                                                   - 'deleted'
         *                                                   - 'mature'
         *                                                   - 'spam'
         *                                                   - 'archived'
         *                                                   - 'public'
         *                                                   - false, an empty array, or 'none' to disable `ORDER BY` clause.
         *                                                   Default 'id'.
         *     @type string          $order                  How to order retrieved sites. Accepts 'ASC', 'DESC'. Default 'ASC'.
         *     @type int             $network_id             Limit results to those affiliated with a given network ID. If 0,
         *                                                   include all networks. Default 0.
         *     @type int[]           $network__in            Array of network IDs to include affiliated sites for. Default empty.
         *     @type int[]           $network__not_in        Array of network IDs to exclude affiliated sites for. Default empty.
         *     @type string          $domain                 Limit results to those affiliated with a given domain. Default empty.
         *     @type string[]        $domain__in             Array of domains to include affiliated sites for. Default empty.
         *     @type string[]        $domain__not_in         Array of domains to exclude affiliated sites for. Default empty.
         *     @type string          $path                   Limit results to those affiliated with a given path. Default empty.
         *     @type string[]        $path__in               Array of paths to include affiliated sites for. Default empty.
         *     @type string[]        $path__not_in           Array of paths to exclude affiliated sites for. Default empty.
         *     @type int             $public                 Limit results to public sites. Accepts 1 or 0. Default empty.
         *     @type int             $archived               Limit results to archived sites. Accepts 1 or 0. Default empty.
         *     @type int             $mature                 Limit results to mature sites. Accepts 1 or 0. Default empty.
         *     @type int             $spam                   Limit results to spam sites. Accepts 1 or 0. Default empty.
         *     @type int             $deleted                Limit results to deleted sites. Accepts 1 or 0. Default empty.
         *     @type int             $lang_id                Limit results to a language ID. Default empty.
         *     @type string[]        $lang__in               Array of language IDs to include affiliated sites for. Default empty.
         *     @type string[]        $lang__not_in           Array of language IDs to exclude affiliated sites for. Default empty.
         *     @type string          $search                 Search term(s) to retrieve matching sites for. Default empty.
         *     @type string[]        $search_columns         Array of column names to be searched. Accepts 'domain' and 'path'.
         *                                                   Default empty array.
         *     @type bool            $update_site_cache      Whether to prime the cache for found sites. Default true.
         *     @type bool            $update_site_meta_cache Whether to prime the metadata cache for found sites. Default true.
         *     @type string|string[] $meta_key               Meta key or keys to filter by.
         *     @type string|string[] $meta_value             Meta value or values to filter by.
         *     @type string          $meta_compare           MySQL operator used for comparing the meta value.
         *                                                   See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_compare_key       MySQL operator used for comparing the meta key.
         *                                                   See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_type              MySQL data type that the meta_value column will be CAST to for comparisons.
         *                                                   See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_type_key          MySQL data type that the meta_key column will be CAST to for comparisons.
         *                                                   See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type array           $meta_query             An associative array of WP_Meta_Query arguments.
         *                                                   See WP_Meta_Query::__construct() for accepted values.
         * }
         * @phpstan-param array{
         *   site__in?: int[],
         *   site__not_in?: int[],
         *   count?: bool,
         *   date_query?: array,
         *   fields?: string,
         *   ID?: int,
         *   number?: int,
         *   offset?: int,
         *   no_found_rows?: bool,
         *   orderby?: string|array,
         *   order?: string,
         *   network_id?: int,
         *   network__in?: int[],
         *   network__not_in?: int[],
         *   domain?: string,
         *   domain__in?: string[],
         *   domain__not_in?: string[],
         *   path?: string,
         *   path__in?: string[],
         *   path__not_in?: string[],
         *   public?: int,
         *   archived?: int,
         *   mature?: int,
         *   spam?: int,
         *   deleted?: int,
         *   lang_id?: int,
         *   lang__in?: string[],
         *   lang__not_in?: string[],
         *   search?: string,
         *   search_columns?: string[],
         *   update_site_cache?: bool,
         *   update_site_meta_cache?: bool,
         *   meta_key?: string|string[],
         *   meta_value?: string|string[],
         *   meta_compare?: string,
         *   meta_compare_key?: string,
         *   meta_type?: string,
         *   meta_type_key?: string,
         *   meta_query?: array,
         * } $query
         */
        public function __construct($query = '')
        {
        }
        /**
         * Parses arguments passed to the site query with default query parameters.
         *
         * @since 4.6.0
         *
         * @see WP_Site_Query::__construct()
         *
         * @param string|array $query Array or string of WP_Site_Query arguments. See WP_Site_Query::__construct().
         * @phpstan-param array{
         *   site__in?: int[],
         *   site__not_in?: int[],
         *   count?: bool,
         *   date_query?: array,
         *   fields?: string,
         *   ID?: int,
         *   number?: int,
         *   offset?: int,
         *   no_found_rows?: bool,
         *   orderby?: string|array,
         *   order?: string,
         *   network_id?: int,
         *   network__in?: int[],
         *   network__not_in?: int[],
         *   domain?: string,
         *   domain__in?: string[],
         *   domain__not_in?: string[],
         *   path?: string,
         *   path__in?: string[],
         *   path__not_in?: string[],
         *   public?: int,
         *   archived?: int,
         *   mature?: int,
         *   spam?: int,
         *   deleted?: int,
         *   lang_id?: int,
         *   lang__in?: string[],
         *   lang__not_in?: string[],
         *   search?: string,
         *   search_columns?: string[],
         *   update_site_cache?: bool,
         *   update_site_meta_cache?: bool,
         *   meta_key?: string|string[],
         *   meta_value?: string|string[],
         *   meta_compare?: string,
         *   meta_compare_key?: string,
         *   meta_type?: string,
         *   meta_type_key?: string,
         *   meta_query?: array,
         * } $query See WP_Site_Query::__construct()
         */
        public function parse_query($query = '')
        {
        }
        /**
         * Sets up the WordPress query for retrieving sites.
         *
         * @since 4.6.0
         *
         * @param string|array $query Array or URL query string of parameters.
         * @return WP_Site[]|int[]|int List of WP_Site objects, a list of site IDs when 'fields' is set to 'ids',
         *                             or the number of sites when 'count' is passed as a query var.
         */
        public function query($query)
        {
        }
        /**
         * Retrieves a list of sites matching the query vars.
         *
         * @since 4.6.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @return WP_Site[]|int[]|int List of WP_Site objects, a list of site IDs when 'fields' is set to 'ids',
         *                             or the number of sites when 'count' is passed as a query var.
         */
        public function get_sites()
        {
        }
        /**
         * Used internally to get a list of site IDs matching the query vars.
         *
         * @since 4.6.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @return int|array A single count of site IDs if a count query. An array of site IDs if a full query.
         */
        protected function get_site_ids()
        {
        }
        /**
         * Used internally to generate an SQL string for searching across multiple columns.
         *
         * @since 4.6.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string   $search  Search string.
         * @param string[] $columns Array of columns to search.
         * @return string Search SQL.
         */
        protected function get_search_sql($search, $columns)
        {
        }
        /**
         * Parses and sanitizes 'orderby' keys passed to the site query.
         *
         * @since 4.6.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $orderby Alias for the field to order by.
         * @return string|false Value to used in the ORDER clause. False otherwise.
         */
        protected function parse_orderby($orderby)
        {
        }
        /**
         * Parses an 'order' query variable and cast it to 'ASC' or 'DESC' as necessary.
         *
         * @since 4.6.0
         *
         * @param string $order The 'order' query variable.
         * @return string The sanitized 'order' query variable.
         */
        protected function parse_order($order)
        {
        }
    }
    /**
     * Core class used for interacting with a multisite site.
     *
     * This class is used during load to populate the `$current_blog` global and
     * setup the current site.
     *
     * @since 4.5.0
     *
     * @property int    $id
     * @property int    $network_id
     * @property string $blogname
     * @property string $siteurl
     * @property int    $post_count
     * @property string $home
     */
    #[\AllowDynamicProperties]
    final class WP_Site
    {
        /**
         * Site ID.
         *
         * Named "blog" vs. "site" for legacy reasons.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 4.5.0
         * @var string
         */
        public $blog_id;
        /**
         * Domain of the site.
         *
         * @since 4.5.0
         * @var string
         */
        public $domain = '';
        /**
         * Path of the site.
         *
         * @since 4.5.0
         * @var string
         */
        public $path = '';
        /**
         * The ID of the site's parent network.
         *
         * Named "site" vs. "network" for legacy reasons. An individual site's "site" is
         * its network.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 4.5.0
         * @var string
         */
        public $site_id = '0';
        /**
         * The date and time on which the site was created or registered.
         *
         * @since 4.5.0
         * @var string Date in MySQL's datetime format.
         */
        public $registered = '0000-00-00 00:00:00';
        /**
         * The date and time on which site settings were last updated.
         *
         * @since 4.5.0
         * @var string Date in MySQL's datetime format.
         */
        public $last_updated = '0000-00-00 00:00:00';
        /**
         * Whether the site should be treated as public.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 4.5.0
         * @var string
         */
        public $public = '1';
        /**
         * Whether the site should be treated as archived.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 4.5.0
         * @var string
         */
        public $archived = '0';
        /**
         * Whether the site should be treated as mature.
         *
         * Handling for this does not exist throughout WordPress core, but custom
         * implementations exist that require the property to be present.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 4.5.0
         * @var string
         */
        public $mature = '0';
        /**
         * Whether the site should be treated as spam.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 4.5.0
         * @var string
         */
        public $spam = '0';
        /**
         * Whether the site should be treated as deleted.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 4.5.0
         * @var string
         */
        public $deleted = '0';
        /**
         * The language pack associated with this site.
         *
         * A numeric string, for compatibility reasons.
         *
         * @since 4.5.0
         * @var string
         */
        public $lang_id = '0';
        /**
         * Retrieves a site from the database by its ID.
         *
         * @since 4.5.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param int $site_id The ID of the site to retrieve.
         * @return WP_Site|false The site's object if found. False if not.
         */
        public static function get_instance($site_id)
        {
        }
        /**
         * Creates a new WP_Site object.
         *
         * Will populate object properties from the object provided and assign other
         * default properties based on that information.
         *
         * @since 4.5.0
         *
         * @param WP_Site|object $site A site object.
         */
        public function __construct($site)
        {
        }
        /**
         * Converts an object to array.
         *
         * @since 4.6.0
         *
         * @return array Object as array.
         */
        public function to_array()
        {
        }
        /**
         * Getter.
         *
         * Allows current multisite naming conventions when getting properties.
         * Allows access to extended site properties.
         *
         * @since 4.6.0
         *
         * @param string $key Property to get.
         * @return mixed Value of the property. Null if not available.
         */
        public function __get($key)
        {
        }
        /**
         * Isset-er.
         *
         * Allows current multisite naming conventions when checking for properties.
         * Checks for extended site properties.
         *
         * @since 4.6.0
         *
         * @param string $key Property to check if set.
         * @return bool Whether the property is set.
         */
        public function __isset($key)
        {
        }
        /**
         * Setter.
         *
         * Allows current multisite naming conventions while setting properties.
         *
         * @since 4.6.0
         *
         * @param string $key   Property to set.
         * @param mixed  $value Value to assign to the property.
         */
        public function __set($key, $value)
        {
        }
    }
    /**
     * Core class used to register styles.
     *
     * @since 2.6.0
     *
     * @see WP_Dependencies
     */
    class WP_Styles extends \WP_Dependencies
    {
        /**
         * Base URL for styles.
         *
         * Full URL with trailing slash.
         *
         * @since 2.6.0
         * @var string
         */
        public $base_url;
        /**
         * URL of the content directory.
         *
         * @since 2.8.0
         * @var string
         */
        public $content_url;
        /**
         * Default version string for stylesheets.
         *
         * @since 2.6.0
         * @var string
         */
        public $default_version;
        /**
         * The current text direction.
         *
         * @since 2.6.0
         * @var string
         */
        public $text_direction = 'ltr';
        /**
         * Holds a list of style handles which will be concatenated.
         *
         * @since 2.8.0
         * @var string
         */
        public $concat = '';
        /**
         * Holds a string which contains style handles and their version.
         *
         * @since 2.8.0
         * @deprecated 3.4.0
         * @var string
         */
        public $concat_version = '';
        /**
         * Whether to perform concatenation.
         *
         * @since 2.8.0
         * @var bool
         */
        public $do_concat = \false;
        /**
         * Holds HTML markup of styles and additional data if concatenation
         * is enabled.
         *
         * @since 2.8.0
         * @var string
         */
        public $print_html = '';
        /**
         * Holds inline styles if concatenation is enabled.
         *
         * @since 3.3.0
         * @var string
         */
        public $print_code = '';
        /**
         * List of default directories.
         *
         * @since 2.8.0
         * @var array
         */
        public $default_dirs;
        /**
         * Constructor.
         *
         * @since 2.6.0
         */
        public function __construct()
        {
        }
        /**
         * Processes a style dependency.
         *
         * @since 2.6.0
         * @since 5.5.0 Added the `$group` parameter.
         *
         * @see WP_Dependencies::do_item()
         *
         * @param string    $handle The style's registered handle.
         * @param int|false $group  Optional. Group level: level (int), no groups (false).
         *                          Default false.
         * @return bool True on success, false on failure.
         */
        public function do_item($handle, $group = \false)
        {
        }
        /**
         * Adds extra CSS styles to a registered stylesheet.
         *
         * @since 3.3.0
         *
         * @param string $handle The style's registered handle.
         * @param string $code   String containing the CSS styles to be added.
         * @return bool True on success, false on failure.
         */
        public function add_inline_style($handle, $code)
        {
        }
        /**
         * Prints extra CSS styles of a registered stylesheet.
         *
         * @since 3.3.0
         *
         * @param string $handle  The style's registered handle.
         * @param bool   $display Optional. Whether to print the inline style
         *                        instead of just returning it. Default true.
         * @return string|bool False if no data exists, inline styles if `$display` is true,
         *                     true otherwise.
         */
        public function print_inline_style($handle, $display = \true)
        {
        }
        /**
         * Determines style dependencies.
         *
         * @since 2.6.0
         *
         * @see WP_Dependencies::all_deps()
         *
         * @param string|string[] $handles   Item handle (string) or item handles (array of strings).
         * @param bool            $recursion Optional. Internal flag that function is calling itself.
         *                                   Default false.
         * @param int|false       $group     Optional. Group level: level (int), no groups (false).
         *                                   Default false.
         * @return bool True on success, false on failure.
         */
        public function all_deps($handles, $recursion = \false, $group = \false)
        {
        }
        /**
         * Generates an enqueued style's fully-qualified URL.
         *
         * @since 2.6.0
         *
         * @param string $src    The source of the enqueued style.
         * @param string $ver    The version of the enqueued style.
         * @param string $handle The style's registered handle.
         * @return string Style's fully-qualified URL.
         */
        public function _css_href($src, $ver, $handle)
        {
        }
        /**
         * Whether a handle's source is in a default directory.
         *
         * @since 2.8.0
         *
         * @param string $src The source of the enqueued style.
         * @return bool True if found, false if not.
         */
        public function in_default_dir($src)
        {
        }
        /**
         * Processes items and dependencies for the footer group.
         *
         * HTML 5 allows styles in the body, grab late enqueued items and output them in the footer.
         *
         * @since 3.3.0
         *
         * @see WP_Dependencies::do_items()
         *
         * @return string[] Handles of items that have been processed.
         */
        public function do_footer_items()
        {
        }
        /**
         * Resets class properties.
         *
         * @since 3.3.0
         */
        public function reset()
        {
        }
    }
    /**
     * Core class used to implement taxonomy queries for the Taxonomy API.
     *
     * Used for generating SQL clauses that filter a primary query according to object
     * taxonomy terms.
     *
     * WP_Tax_Query is a helper that allows primary query classes, such as WP_Query, to filter
     * their results by object metadata, by generating `JOIN` and `WHERE` subclauses to be
     * attached to the primary SQL query string.
     *
     * @since 3.1.0
     */
    #[\AllowDynamicProperties]
    class WP_Tax_Query
    {
        /**
         * Array of taxonomy queries.
         *
         * See WP_Tax_Query::__construct() for information on tax query arguments.
         *
         * @since 3.1.0
         * @var array
         */
        public $queries = array();
        /**
         * The relation between the queries. Can be one of 'AND' or 'OR'.
         *
         * @since 3.1.0
         * @var string
         */
        public $relation;
        /**
         * A flat list of table aliases used in the JOIN clauses.
         *
         * @since 4.1.0
         * @var array
         */
        protected $table_aliases = array();
        /**
         * Terms and taxonomies fetched by this query.
         *
         * We store this data in a flat array because they are referenced in a
         * number of places by WP_Query.
         *
         * @since 4.1.0
         * @var array
         */
        public $queried_terms = array();
        /**
         * Database table that where the metadata's objects are stored (eg $wpdb->users).
         *
         * @since 4.1.0
         * @var string
         */
        public $primary_table;
        /**
         * Column in 'primary_table' that represents the ID of the object.
         *
         * @since 4.1.0
         * @var string
         */
        public $primary_id_column;
        /**
         * Constructor.
         *
         * @since 3.1.0
         * @since 4.1.0 Added support for `$operator` 'NOT EXISTS' and 'EXISTS' values.
         *
         * @param array $tax_query {
         *     Array of taxonomy query clauses.
         *
         *     @type string $relation Optional. The MySQL keyword used to join
         *                            the clauses of the query. Accepts 'AND', or 'OR'. Default 'AND'.
         *     @type array  ...$0 {
         *         An array of first-order clause parameters, or another fully-formed tax query.
         *
         *         @type string           $taxonomy         Taxonomy being queried. Optional when field=term_taxonomy_id.
         *         @type string|int|array $terms            Term or terms to filter by.
         *         @type string           $field            Field to match $terms against. Accepts 'term_id', 'slug',
         *                                                 'name', or 'term_taxonomy_id'. Default: 'term_id'.
         *         @type string           $operator         MySQL operator to be used with $terms in the WHERE clause.
         *                                                  Accepts 'AND', 'IN', 'NOT IN', 'EXISTS', 'NOT EXISTS'.
         *                                                  Default: 'IN'.
         *         @type bool             $include_children Optional. Whether to include child terms.
         *                                                  Requires a $taxonomy. Default: true.
         *     }
         * }
         */
        public function __construct($tax_query)
        {
        }
        /**
         * Ensures the 'tax_query' argument passed to the class constructor is well-formed.
         *
         * Ensures that each query-level clause has a 'relation' key, and that
         * each first-order clause contains all the necessary keys from `$defaults`.
         *
         * @since 4.1.0
         *
         * @param array $queries Array of queries clauses.
         * @return array Sanitized array of query clauses.
         */
        public function sanitize_query($queries)
        {
        }
        /**
         * Sanitizes a 'relation' operator.
         *
         * @since 4.1.0
         *
         * @param string $relation Raw relation key from the query argument.
         * @return string Sanitized relation. Either 'AND' or 'OR'.
         * @phpstan-return 'AND'|'OR'
         */
        public function sanitize_relation($relation)
        {
        }
        /**
         * Determines whether a clause is first-order.
         *
         * A "first-order" clause is one that contains any of the first-order
         * clause keys ('terms', 'taxonomy', 'include_children', 'field',
         * 'operator'). An empty clause also counts as a first-order clause,
         * for backward compatibility. Any clause that doesn't meet this is
         * determined, by process of elimination, to be a higher-order query.
         *
         * @since 4.1.0
         *
         * @param array $query Tax query arguments.
         * @return bool Whether the query clause is a first-order clause.
         */
        protected static function is_first_order_clause($query)
        {
        }
        /**
         * Generates SQL clauses to be appended to a main query.
         *
         * @since 3.1.0
         *
         * @param string $primary_table     Database table where the object being filtered is stored (eg wp_users).
         * @param string $primary_id_column ID column for the filtered object in $primary_table.
         * @return string[] {
         *     Array containing JOIN and WHERE SQL clauses to append to the main query.
         *
         *     @type string $join  SQL fragment to append to the main JOIN clause.
         *     @type string $where SQL fragment to append to the main WHERE clause.
         * }
         * @phpstan-return array{
         *   join: string,
         *   where: string,
         * }
         */
        public function get_sql($primary_table, $primary_id_column)
        {
        }
        /**
         * Generates SQL clauses to be appended to a main query.
         *
         * Called by the public WP_Tax_Query::get_sql(), this method
         * is abstracted out to maintain parity with the other Query classes.
         *
         * @since 4.1.0
         *
         * @return string[] {
         *     Array containing JOIN and WHERE SQL clauses to append to the main query.
         *
         *     @type string $join  SQL fragment to append to the main JOIN clause.
         *     @type string $where SQL fragment to append to the main WHERE clause.
         * }
         * @phpstan-return array{
         *   join: string,
         *   where: string,
         * }
         */
        protected function get_sql_clauses()
        {
        }
        /**
         * Generates SQL clauses for a single query array.
         *
         * If nested subqueries are found, this method recurses the tree to
         * produce the properly nested SQL.
         *
         * @since 4.1.0
         *
         * @param array $query Query to parse (passed by reference).
         * @param int   $depth Optional. Number of tree levels deep we currently are.
         *                     Used to calculate indentation. Default 0.
         * @return string[] {
         *     Array containing JOIN and WHERE SQL clauses to append to a single query array.
         *
         *     @type string $join  SQL fragment to append to the main JOIN clause.
         *     @type string $where SQL fragment to append to the main WHERE clause.
         * }
         * @phpstan-return array{
         *   join: string,
         *   where: string,
         * }
         */
        protected function get_sql_for_query(&$query, $depth = 0)
        {
        }
        /**
         * Generates SQL JOIN and WHERE clauses for a "first-order" query clause.
         *
         * @since 4.1.0
         *
         * @global wpdb $wpdb The WordPress database abstraction object.
         *
         * @param array $clause       Query clause (passed by reference).
         * @param array $parent_query Parent query array.
         * @return array {
         *     Array containing JOIN and WHERE SQL clauses to append to a first-order query.
         *
         *     @type string[] $join  Array of SQL fragments to append to the main JOIN clause.
         *     @type string[] $where Array of SQL fragments to append to the main WHERE clause.
         * }
         * @phpstan-return array{
         *   join: string[],
         *   where: string[],
         * }
         */
        public function get_sql_for_clause(&$clause, $parent_query)
        {
        }
        /**
         * Identifies an existing table alias that is compatible with the current query clause.
         *
         * We avoid unnecessary table joins by allowing each clause to look for
         * an existing table alias that is compatible with the query that it
         * needs to perform.
         *
         * An existing alias is compatible if (a) it is a sibling of `$clause`
         * (ie, it's under the scope of the same relation), and (b) the combination
         * of operator and relation between the clauses allows for a shared table
         * join. In the case of WP_Tax_Query, this only applies to 'IN'
         * clauses that are connected by the relation 'OR'.
         *
         * @since 4.1.0
         *
         * @param array $clause       Query clause.
         * @param array $parent_query Parent query of $clause.
         * @return string|false Table alias if found, otherwise false.
         */
        protected function find_compatible_table_alias($clause, $parent_query)
        {
        }
        /**
         * Transforms a single query, from one field to another.
         *
         * Operates on the `$query` object by reference. In the case of error,
         * `$query` is converted to a WP_Error object.
         *
         * @since 3.2.0
         *
         * @param array  $query           The single query. Passed by reference.
         * @param string $resulting_field The resulting field. Accepts 'slug', 'name', 'term_taxonomy_id',
         *                                or 'term_id'. Default 'term_id'.
         * @phpstan-param 'slug'|'name'|'term_taxonomy_id'|'term_id' $resulting_field
         * @phpstan-return void
         */
        public function transform_query(&$query, $resulting_field)
        {
        }
    }
    /**
     * Core class used for interacting with taxonomies.
     *
     * @since 4.7.0
     */
    #[\AllowDynamicProperties]
    final class WP_Taxonomy
    {
        /**
         * Taxonomy key.
         *
         * @since 4.7.0
         * @var string
         */
        public $name;
        /**
         * Name of the taxonomy shown in the menu. Usually plural.
         *
         * @since 4.7.0
         * @var string
         */
        public $label;
        /**
         * Labels object for this taxonomy.
         *
         * If not set, tag labels are inherited for non-hierarchical types
         * and category labels for hierarchical ones.
         *
         * @see get_taxonomy_labels()
         *
         * @since 4.7.0
         * @var stdClass
         */
        public $labels;
        /**
         * A short descriptive summary of what the taxonomy is for.
         *
         * @since 4.7.0
         * @var string
         */
        public $description = '';
        /**
         * Whether a taxonomy is intended for use publicly either via the admin interface or by front-end users.
         *
         * @since 4.7.0
         * @var bool
         */
        public $public = \true;
        /**
         * Whether the taxonomy is publicly queryable.
         *
         * @since 4.7.0
         * @var bool
         */
        public $publicly_queryable = \true;
        /**
         * Whether the taxonomy is hierarchical.
         *
         * @since 4.7.0
         * @var bool
         */
        public $hierarchical = \false;
        /**
         * Whether to generate and allow a UI for managing terms in this taxonomy in the admin.
         *
         * @since 4.7.0
         * @var bool
         */
        public $show_ui = \true;
        /**
         * Whether to show the taxonomy in the admin menu.
         *
         * If true, the taxonomy is shown as a submenu of the object type menu. If false, no menu is shown.
         *
         * @since 4.7.0
         * @var bool
         */
        public $show_in_menu = \true;
        /**
         * Whether the taxonomy is available for selection in navigation menus.
         *
         * @since 4.7.0
         * @var bool
         */
        public $show_in_nav_menus = \true;
        /**
         * Whether to list the taxonomy in the tag cloud widget controls.
         *
         * @since 4.7.0
         * @var bool
         */
        public $show_tagcloud = \true;
        /**
         * Whether to show the taxonomy in the quick/bulk edit panel.
         *
         * @since 4.7.0
         * @var bool
         */
        public $show_in_quick_edit = \true;
        /**
         * Whether to display a column for the taxonomy on its post type listing screens.
         *
         * @since 4.7.0
         * @var bool
         */
        public $show_admin_column = \false;
        /**
         * The callback function for the meta box display.
         *
         * @since 4.7.0
         * @var bool|callable
         */
        public $meta_box_cb = \null;
        /**
         * The callback function for sanitizing taxonomy data saved from a meta box.
         *
         * @since 5.1.0
         * @var callable
         */
        public $meta_box_sanitize_cb = \null;
        /**
         * An array of object types this taxonomy is registered for.
         *
         * @since 4.7.0
         * @var string[]
         */
        public $object_type = \null;
        /**
         * Capabilities for this taxonomy.
         *
         * @since 4.7.0
         * @var stdClass
         */
        public $cap;
        /**
         * Rewrites information for this taxonomy.
         *
         * @since 4.7.0
         * @var array|false
         */
        public $rewrite;
        /**
         * Query var string for this taxonomy.
         *
         * @since 4.7.0
         * @var string|false
         */
        public $query_var;
        /**
         * Function that will be called when the count is updated.
         *
         * @since 4.7.0
         * @var callable
         */
        public $update_count_callback;
        /**
         * Whether this taxonomy should appear in the REST API.
         *
         * Default false. If true, standard endpoints will be registered with
         * respect to $rest_base and $rest_controller_class.
         *
         * @since 4.7.4
         * @var bool $show_in_rest
         */
        public $show_in_rest;
        /**
         * The base path for this taxonomy's REST API endpoints.
         *
         * @since 4.7.4
         * @var string|bool $rest_base
         */
        public $rest_base;
        /**
         * The namespace for this taxonomy's REST API endpoints.
         *
         * @since 5.9.0
         * @var string|bool $rest_namespace
         */
        public $rest_namespace;
        /**
         * The controller for this taxonomy's REST API endpoints.
         *
         * Custom controllers must extend WP_REST_Controller.
         *
         * @since 4.7.4
         * @var string|bool $rest_controller_class
         */
        public $rest_controller_class;
        /**
         * The controller instance for this taxonomy's REST API endpoints.
         *
         * Lazily computed. Should be accessed using {@see WP_Taxonomy::get_rest_controller()}.
         *
         * @since 5.5.0
         * @var WP_REST_Controller $rest_controller
         */
        public $rest_controller;
        /**
         * The default term name for this taxonomy. If you pass an array you have
         * to set 'name' and optionally 'slug' and 'description'.
         *
         * @since 5.5.0
         * @var array|string
         */
        public $default_term;
        /**
         * Whether terms in this taxonomy should be sorted in the order they are provided to `wp_set_object_terms()`.
         *
         * Use this in combination with `'orderby' => 'term_order'` when fetching terms.
         *
         * @since 2.5.0
         * @var bool|null
         */
        public $sort = \null;
        /**
         * Array of arguments to automatically use inside `wp_get_object_terms()` for this taxonomy.
         *
         * @since 2.6.0
         * @var array|null
         */
        public $args = \null;
        /**
         * Whether it is a built-in taxonomy.
         *
         * @since 4.7.0
         * @var bool
         */
        public $_builtin;
        /**
         * Constructor.
         *
         * See the register_taxonomy() function for accepted arguments for `$args`.
         *
         * @since 4.7.0
         *
         * @param string       $taxonomy    Taxonomy key, must not exceed 32 characters.
         * @param array|string $object_type Name of the object type for the taxonomy object.
         * @param array|string $args        Optional. Array or query string of arguments for registering a taxonomy.
         *                                  See register_taxonomy() for information on accepted arguments.
         *                                  Default empty array.
         * @phpstan-param array{
         *   labels?: string[],
         *   description?: string,
         *   public?: bool,
         *   publicly_queryable?: bool,
         *   hierarchical?: bool,
         *   show_ui?: bool,
         *   show_in_menu?: bool,
         *   show_in_nav_menus?: bool,
         *   show_in_rest?: bool,
         *   rest_base?: string,
         *   rest_namespace?: string,
         *   rest_controller_class?: string,
         *   show_tagcloud?: bool,
         *   show_in_quick_edit?: bool,
         *   show_admin_column?: bool,
         *   meta_box_cb?: bool|callable,
         *   meta_box_sanitize_cb?: callable,
         *   capabilities?: array{
         *     manage_terms?: string,
         *     edit_terms?: string,
         *     delete_terms?: string,
         *     assign_terms?: string,
         *   },
         *   rewrite?: bool|array{
         *     slug?: string,
         *     with_front?: bool,
         *     hierarchical?: bool,
         *     ep_mask?: int,
         *   },
         *   query_var?: string|bool,
         *   update_count_callback?: callable,
         *   default_term?: string|array{
         *     name?: string,
         *     slug?: string,
         *     description?: string,
         *   },
         *   sort?: bool,
         *   args?: array,
         *   _builtin?: bool,
         * } $args See register_taxonomy()
         */
        public function __construct($taxonomy, $object_type, $args = array())
        {
        }
        /**
         * Sets taxonomy properties.
         *
         * See the register_taxonomy() function for accepted arguments for `$args`.
         *
         * @since 4.7.0
         *
         * @param string|string[] $object_type Name or array of names of the object types for the taxonomy.
         * @param array|string    $args        Array or query string of arguments for registering a taxonomy.
         */
        public function set_props($object_type, $args)
        {
        }
        /**
         * Adds the necessary rewrite rules for the taxonomy.
         *
         * @since 4.7.0
         *
         * @global WP $wp Current WordPress environment instance.
         */
        public function add_rewrite_rules()
        {
        }
        /**
         * Removes any rewrite rules, permastructs, and rules for the taxonomy.
         *
         * @since 4.7.0
         *
         * @global WP $wp Current WordPress environment instance.
         */
        public function remove_rewrite_rules()
        {
        }
        /**
         * Registers the ajax callback for the meta box.
         *
         * @since 4.7.0
         */
        public function add_hooks()
        {
        }
        /**
         * Removes the ajax callback for the meta box.
         *
         * @since 4.7.0
         */
        public function remove_hooks()
        {
        }
        /**
         * Gets the REST API controller for this taxonomy.
         *
         * Will only instantiate the controller class once per request.
         *
         * @since 5.5.0
         *
         * @return WP_REST_Controller|null The controller instance, or null if the taxonomy
         *                                 is set not to show in rest.
         */
        public function get_rest_controller()
        {
        }
        /**
         * Returns the default labels for taxonomies.
         *
         * @since 6.0.0
         *
         * @return (string|null)[][] The default labels for taxonomies.
         */
        public static function get_default_labels()
        {
        }
        /**
         * Resets the cache for the default labels.
         *
         * @since 6.0.0
         */
        public static function reset_default_labels()
        {
        }
    }
    /**
     * Class used for querying terms.
     *
     * @since 4.6.0
     *
     * @see WP_Term_Query::__construct() for accepted arguments.
     */
    #[\AllowDynamicProperties]
    class WP_Term_Query
    {
        /**
         * SQL string used to perform database query.
         *
         * @since 4.6.0
         * @var string
         */
        public $request;
        /**
         * Metadata query container.
         *
         * @since 4.6.0
         * @var WP_Meta_Query A meta query instance.
         */
        public $meta_query = \false;
        /**
         * Metadata query clauses.
         *
         * @since 4.6.0
         * @var array
         */
        protected $meta_query_clauses;
        /**
         * SQL query clauses.
         *
         * @since 4.6.0
         * @var array
         */
        protected $sql_clauses = array('select' => '', 'from' => '', 'where' => array(), 'orderby' => '', 'limits' => '');
        /**
         * Query vars set by the user.
         *
         * @since 4.6.0
         * @var array
         */
        public $query_vars;
        /**
         * Default values for query vars.
         *
         * @since 4.6.0
         * @var array
         */
        public $query_var_defaults;
        /**
         * List of terms located by the query.
         *
         * @since 4.6.0
         * @var array
         */
        public $terms;
        /**
         * Constructor.
         *
         * Sets up the term query, based on the query vars passed.
         *
         * @since 4.6.0
         * @since 4.6.0 Introduced 'term_taxonomy_id' parameter.
         * @since 4.7.0 Introduced 'object_ids' parameter.
         * @since 4.9.0 Added 'slug__in' support for 'orderby'.
         * @since 5.1.0 Introduced the 'meta_compare_key' parameter.
         * @since 5.3.0 Introduced the 'meta_type_key' parameter.
         * @since 6.4.0 Introduced the 'cache_results' parameter.
         *
         * @param string|array $query {
         *     Optional. Array or query string of term query parameters. Default empty.
         *
         *     @type string|string[] $taxonomy               Taxonomy name, or array of taxonomy names, to which results
         *                                                   should be limited.
         *     @type int|int[]       $object_ids             Object ID, or array of object IDs. Results will be
         *                                                   limited to terms associated with these objects.
         *     @type string          $orderby                Field(s) to order terms by. Accepts:
         *                                                   - Term fields ('name', 'slug', 'term_group', 'term_id', 'id',
         *                                                     'description', 'parent', 'term_order'). Unless `$object_ids`
         *                                                     is not empty, 'term_order' is treated the same as 'term_id'.
         *                                                   - 'count' to use the number of objects associated with the term.
         *                                                   - 'include' to match the 'order' of the `$include` param.
         *                                                   - 'slug__in' to match the 'order' of the `$slug` param.
         *                                                   - 'meta_value'
         *                                                   - 'meta_value_num'.
         *                                                   - The value of `$meta_key`.
         *                                                   - The array keys of `$meta_query`.
         *                                                   - 'none' to omit the ORDER BY clause.
         *                                                   Default 'name'.
         *     @type string          $order                  Whether to order terms in ascending or descending order.
         *                                                   Accepts 'ASC' (ascending) or 'DESC' (descending).
         *                                                   Default 'ASC'.
         *     @type bool|int        $hide_empty             Whether to hide terms not assigned to any posts. Accepts
         *                                                   1|true or 0|false. Default 1|true.
         *     @type int[]|string    $include                Array or comma/space-separated string of term IDs to include.
         *                                                   Default empty array.
         *     @type int[]|string    $exclude                Array or comma/space-separated string of term IDs to exclude.
         *                                                   If `$include` is non-empty, `$exclude` is ignored.
         *                                                   Default empty array.
         *     @type int[]|string    $exclude_tree           Array or comma/space-separated string of term IDs to exclude
         *                                                   along with all of their descendant terms. If `$include` is
         *                                                   non-empty, `$exclude_tree` is ignored. Default empty array.
         *     @type int|string      $number                 Maximum number of terms to return. Accepts ''|0 (all) or any
         *                                                   positive number. Default ''|0 (all). Note that `$number` may
         *                                                   not return accurate results when coupled with `$object_ids`.
         *                                                   See #41796 for details.
         *     @type int             $offset                 The number by which to offset the terms query. Default empty.
         *     @type string          $fields                 Term fields to query for. Accepts:
         *                                                   - 'all' Returns an array of complete term objects (`WP_Term[]`).
         *                                                   - 'all_with_object_id' Returns an array of term objects
         *                                                     with the 'object_id' param (`WP_Term[]`). Works only
         *                                                     when the `$object_ids` parameter is populated.
         *                                                   - 'ids' Returns an array of term IDs (`int[]`).
         *                                                   - 'tt_ids' Returns an array of term taxonomy IDs (`int[]`).
         *                                                   - 'names' Returns an array of term names (`string[]`).
         *                                                   - 'slugs' Returns an array of term slugs (`string[]`).
         *                                                   - 'count' Returns the number of matching terms (`int`).
         *                                                   - 'id=>parent' Returns an associative array of parent term IDs,
         *                                                      keyed by term ID (`int[]`).
         *                                                   - 'id=>name' Returns an associative array of term names,
         *                                                      keyed by term ID (`string[]`).
         *                                                   - 'id=>slug' Returns an associative array of term slugs,
         *                                                      keyed by term ID (`string[]`).
         *                                                   Default 'all'.
         *     @type string|string[] $name                   Name or array of names to return term(s) for.
         *                                                   Default empty.
         *     @type string|string[] $slug                   Slug or array of slugs to return term(s) for.
         *                                                   Default empty.
         *     @type int|int[]       $term_taxonomy_id       Term taxonomy ID, or array of term taxonomy IDs,
         *                                                   to match when querying terms.
         *     @type bool            $hierarchical           Whether to include terms that have non-empty descendants
         *                                                   (even if `$hide_empty` is set to true). Default true.
         *     @type string          $search                 Search criteria to match terms. Will be SQL-formatted with
         *                                                   wildcards before and after. Default empty.
         *     @type string          $name__like             Retrieve terms with criteria by which a term is LIKE
         *                                                   `$name__like`. Default empty.
         *     @type string          $description__like      Retrieve terms where the description is LIKE
         *                                                   `$description__like`. Default empty.
         *     @type bool            $pad_counts             Whether to pad the quantity of a term's children in the
         *                                                   quantity of each term's "count" object variable.
         *                                                   Default false.
         *     @type string          $get                    Whether to return terms regardless of ancestry or whether the
         *                                                   terms are empty. Accepts 'all' or '' (disabled).
         *                                                   Default ''.
         *     @type int             $child_of               Term ID to retrieve child terms of. If multiple taxonomies
         *                                                   are passed, `$child_of` is ignored. Default 0.
         *     @type int             $parent                 Parent term ID to retrieve direct-child terms of.
         *                                                   Default empty.
         *     @type bool            $childless              True to limit results to terms that have no children.
         *                                                   This parameter has no effect on non-hierarchical taxonomies.
         *                                                   Default false.
         *     @type string          $cache_domain           Unique cache key to be produced when this query is stored in
         *                                                   an object cache. Default 'core'.
         *     @type bool            $cache_results          Whether to cache term information. Default true.
         *     @type bool            $update_term_meta_cache Whether to prime meta caches for matched terms. Default true.
         *     @type string|string[] $meta_key               Meta key or keys to filter by.
         *     @type string|string[] $meta_value             Meta value or values to filter by.
         *     @type string          $meta_compare           MySQL operator used for comparing the meta value.
         *                                                   See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_compare_key       MySQL operator used for comparing the meta key.
         *                                                   See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_type              MySQL data type that the meta_value column will be CAST to for comparisons.
         *                                                   See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_type_key          MySQL data type that the meta_key column will be CAST to for comparisons.
         *                                                   See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type array           $meta_query             An associative array of WP_Meta_Query arguments.
         *                                                   See WP_Meta_Query::__construct() for accepted values.
         * }
         * @phpstan-param array{
         *   taxonomy?: string|string[],
         *   object_ids?: int|int[],
         *   orderby?: string,
         *   order?: string,
         *   hide_empty?: bool|int,
         *   include?: int[]|string,
         *   exclude?: int[]|string,
         *   exclude_tree?: int[]|string,
         *   number?: int|string,
         *   offset?: int,
         *   fields?: string,
         *   name?: string|string[],
         *   slug?: string|string[],
         *   term_taxonomy_id?: int|int[],
         *   hierarchical?: bool,
         *   search?: string,
         *   name__like?: string,
         *   description__like?: string,
         *   pad_counts?: bool,
         *   get?: string,
         *   child_of?: int,
         *   parent?: int,
         *   childless?: bool,
         *   cache_domain?: string,
         *   cache_results?: bool,
         *   update_term_meta_cache?: bool,
         *   meta_key?: string|string[],
         *   meta_value?: string|string[],
         *   meta_compare?: string,
         *   meta_compare_key?: string,
         *   meta_type?: string,
         *   meta_type_key?: string,
         *   meta_query?: array,
         * } $query
         */
        public function __construct($query = '')
        {
        }
        /**
         * Parse arguments passed to the term query with default query parameters.
         *
         * @since 4.6.0
         *
         * @param string|array $query WP_Term_Query arguments. See WP_Term_Query::__construct() for accepted arguments.
         * @phpstan-param array{
         *   taxonomy?: string|string[],
         *   object_ids?: int|int[],
         *   orderby?: string,
         *   order?: string,
         *   hide_empty?: bool|int,
         *   include?: int[]|string,
         *   exclude?: int[]|string,
         *   exclude_tree?: int[]|string,
         *   number?: int|string,
         *   offset?: int,
         *   fields?: string,
         *   name?: string|string[],
         *   slug?: string|string[],
         *   term_taxonomy_id?: int|int[],
         *   hierarchical?: bool,
         *   search?: string,
         *   name__like?: string,
         *   description__like?: string,
         *   pad_counts?: bool,
         *   get?: string,
         *   child_of?: int,
         *   parent?: int,
         *   childless?: bool,
         *   cache_domain?: string,
         *   cache_results?: bool,
         *   update_term_meta_cache?: bool,
         *   meta_key?: string|string[],
         *   meta_value?: string|string[],
         *   meta_compare?: string,
         *   meta_compare_key?: string,
         *   meta_type?: string,
         *   meta_type_key?: string,
         *   meta_query?: array,
         * } $query See WP_Term_Query::__construct()
         */
        public function parse_query($query = '')
        {
        }
        /**
         * Sets up the query and retrieves the results.
         *
         * The return type varies depending on the value passed to `$args['fields']`. See
         * WP_Term_Query::get_terms() for details.
         *
         * @since 4.6.0
         *
         * @param string|array $query Array or URL query string of parameters.
         * @return WP_Term[]|int[]|string[]|string Array of terms, or number of terms as numeric string
         *                                         when 'count' is passed to `$args['fields']`.
         */
        public function query($query)
        {
        }
        /**
         * Retrieves the query results.
         *
         * The return type varies depending on the value passed to `$args['fields']`.
         *
         * The following will result in an array of `WP_Term` objects being returned:
         *
         *   - 'all'
         *   - 'all_with_object_id'
         *
         * The following will result in a numeric string being returned:
         *
         *   - 'count'
         *
         * The following will result in an array of text strings being returned:
         *
         *   - 'id=>name'
         *   - 'id=>slug'
         *   - 'names'
         *   - 'slugs'
         *
         * The following will result in an array of numeric strings being returned:
         *
         *   - 'id=>parent'
         *
         * The following will result in an array of integers being returned:
         *
         *   - 'ids'
         *   - 'tt_ids'
         *
         * @since 4.6.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @return WP_Term[]|int[]|string[]|string Array of terms, or number of terms as numeric string
         *                                         when 'count' is passed to `$args['fields']`.
         */
        public function get_terms()
        {
        }
        /**
         * Parse and sanitize 'orderby' keys passed to the term query.
         *
         * @since 4.6.0
         *
         * @param string $orderby_raw Alias for the field to order by.
         * @return string|false Value to used in the ORDER clause. False otherwise.
         */
        protected function parse_orderby($orderby_raw)
        {
        }
        /**
         * Format response depending on field requested.
         *
         * @since 6.0.0
         *
         * @param WP_Term[] $term_objects Array of term objects.
         * @param string    $_fields      Field to format.
         *
         * @return WP_Term[]|int[]|string[] Array of terms / strings / ints depending on field requested.
         */
        protected function format_terms($term_objects, $_fields)
        {
        }
        /**
         * Generate the ORDER BY clause for an 'orderby' param that is potentially related to a meta query.
         *
         * @since 4.6.0
         *
         * @param string $orderby_raw Raw 'orderby' value passed to WP_Term_Query.
         * @return string ORDER BY clause.
         */
        protected function parse_orderby_meta($orderby_raw)
        {
        }
        /**
         * Parse an 'order' query variable and cast it to ASC or DESC as necessary.
         *
         * @since 4.6.0
         *
         * @param string $order The 'order' query variable.
         * @return string The sanitized 'order' query variable.
         */
        protected function parse_order($order)
        {
        }
        /**
         * Used internally to generate a SQL string related to the 'search' parameter.
         *
         * @since 4.6.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $search Search string.
         * @return string Search SQL.
         */
        protected function get_search_sql($search)
        {
        }
        /**
         * Creates an array of term objects from an array of term IDs.
         *
         * Also discards invalid term objects.
         *
         * @since 4.9.8
         *
         * @param Object[]|int[] $terms List of objects or term ids.
         * @return WP_Term[] Array of `WP_Term` objects.
         */
        protected function populate_terms($terms)
        {
        }
        /**
         * Generate cache key.
         *
         * @since 6.2.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param array  $args WP_Term_Query arguments.
         * @param string $sql  SQL statement.
         *
         * @return string Cache key.
         */
        protected function generate_cache_key(array $args, $sql)
        {
        }
    }
    /**
     * Core class used to implement the WP_Term object.
     *
     * @since 4.4.0
     *
     * @property-read object $data Sanitized term data.
     */
    #[\AllowDynamicProperties]
    final class WP_Term
    {
        /**
         * Term ID.
         *
         * @since 4.4.0
         * @var int
         */
        public $term_id;
        /**
         * The term's name.
         *
         * @since 4.4.0
         * @var string
         */
        public $name = '';
        /**
         * The term's slug.
         *
         * @since 4.4.0
         * @var string
         */
        public $slug = '';
        /**
         * The term's term_group.
         *
         * @since 4.4.0
         * @var int
         */
        public $term_group = '';
        /**
         * Term Taxonomy ID.
         *
         * @since 4.4.0
         * @var int
         */
        public $term_taxonomy_id = 0;
        /**
         * The term's taxonomy name.
         *
         * @since 4.4.0
         * @var string
         */
        public $taxonomy = '';
        /**
         * The term's description.
         *
         * @since 4.4.0
         * @var string
         */
        public $description = '';
        /**
         * ID of a term's parent term.
         *
         * @since 4.4.0
         * @var int
         */
        public $parent = 0;
        /**
         * Cached object count for this term.
         *
         * @since 4.4.0
         * @var int
         */
        public $count = 0;
        /**
         * Stores the term object's sanitization level.
         *
         * Does not correspond to a database field.
         *
         * @since 4.4.0
         * @var string
         */
        public $filter = 'raw';
        /**
         * Retrieve WP_Term instance.
         *
         * @since 4.4.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param int    $term_id  Term ID.
         * @param string $taxonomy Optional. Limit matched terms to those matching `$taxonomy`. Only used for
         *                         disambiguating potentially shared terms.
         * @return WP_Term|WP_Error|false Term object, if found. WP_Error if `$term_id` is shared between taxonomies and
         *                                there's insufficient data to distinguish which term is intended.
         *                                False for other failures.
         */
        public static function get_instance($term_id, $taxonomy = \null)
        {
        }
        /**
         * Constructor.
         *
         * @since 4.4.0
         *
         * @param WP_Term|object $term Term object.
         */
        public function __construct($term)
        {
        }
        /**
         * Sanitizes term fields, according to the filter type provided.
         *
         * @since 4.4.0
         *
         * @param string $filter Filter context. Accepts 'edit', 'db', 'display', 'attribute', 'js', 'rss', or 'raw'.
         * @phpstan-param 'edit'|'db'|'display'|'attribute'|'js'|'rss'|'raw' $filter
         */
        public function filter($filter)
        {
        }
        /**
         * Converts an object to array.
         *
         * @since 4.4.0
         *
         * @return array Object as array.
         */
        public function to_array()
        {
        }
        /**
         * Getter.
         *
         * @since 4.4.0
         *
         * @param string $key Property to get.
         * @return mixed Property value.
         */
        public function __get($key)
        {
        }
    }
    /**
     * Better word splitting than the PEAR package provides.
     *
     * @since 2.6.0
     * @uses Text_Diff_Renderer_inline Extends
     */
    #[\AllowDynamicProperties]
    class WP_Text_Diff_Renderer_inline extends \Text_Diff_Renderer_inline
    {
        /**
         * @ignore
         * @since 2.6.0
         *
         * @param string $string
         * @param string $newlineEscape
         * @return string
         */
        public function _splitOnWords($string, $newlineEscape = "\n")
        {
        }
    }
    /**
     * Table renderer to display the diff lines.
     *
     * @since 2.6.0
     * @uses Text_Diff_Renderer Extends
     */
    #[\AllowDynamicProperties]
    class WP_Text_Diff_Renderer_Table extends \Text_Diff_Renderer
    {
        /**
         * @see Text_Diff_Renderer::_leading_context_lines
         * @var int
         * @since 2.6.0
         */
        public $_leading_context_lines = 10000;
        /**
         * @see Text_Diff_Renderer::_trailing_context_lines
         * @var int
         * @since 2.6.0
         */
        public $_trailing_context_lines = 10000;
        /**
         * Title of the item being compared.
         *
         * @since 6.4.0 Declared a previously dynamic property.
         * @var string|null
         */
        public $_title;
        /**
         * Title for the left column.
         *
         * @since 6.4.0 Declared a previously dynamic property.
         * @var string|null
         */
        public $_title_left;
        /**
         * Title for the right column.
         *
         * @since 6.4.0 Declared a previously dynamic property.
         * @var string|null
         */
        public $_title_right;
        /**
         * Threshold for when a diff should be saved or omitted.
         *
         * @var float
         * @since 2.6.0
         */
        protected $_diff_threshold = 0.6;
        /**
         * Inline display helper object name.
         *
         * @var string
         * @since 2.6.0
         */
        protected $inline_diff_renderer = 'WP_Text_Diff_Renderer_inline';
        /**
         * Should we show the split view or not
         *
         * @var string
         * @since 3.6.0
         */
        protected $_show_split_view = \true;
        protected $compat_fields = array('_show_split_view', 'inline_diff_renderer', '_diff_threshold');
        /**
         * Caches the output of count_chars() in compute_string_distance()
         *
         * @var array
         * @since 5.0.0
         */
        protected $count_cache = array();
        /**
         * Caches the difference calculation in compute_string_distance()
         *
         * @var array
         * @since 5.0.0
         */
        protected $difference_cache = array();
        /**
         * Constructor - Call parent constructor with params array.
         *
         * This will set class properties based on the key value pairs in the array.
         *
         * @since 2.6.0
         *
         * @param array $params
         */
        public function __construct($params = array())
        {
        }
        /**
         * @ignore
         *
         * @param string $header
         * @return string
         */
        public function _startBlock($header)
        {
        }
        /**
         * @ignore
         *
         * @param array  $lines
         * @param string $prefix
         */
        public function _lines($lines, $prefix = ' ')
        {
        }
        /**
         * @ignore
         *
         * @param string $line HTML-escape the value.
         * @return string
         */
        public function addedLine($line)
        {
        }
        /**
         * @ignore
         *
         * @param string $line HTML-escape the value.
         * @return string
         */
        public function deletedLine($line)
        {
        }
        /**
         * @ignore
         *
         * @param string $line HTML-escape the value.
         * @return string
         */
        public function contextLine($line)
        {
        }
        /**
         * @ignore
         *
         * @return string
         */
        public function emptyLine()
        {
        }
        /**
         * @ignore
         *
         * @param array $lines
         * @param bool  $encode
         * @return string
         */
        public function _added($lines, $encode = \true)
        {
        }
        /**
         * @ignore
         *
         * @param array $lines
         * @param bool  $encode
         * @return string
         */
        public function _deleted($lines, $encode = \true)
        {
        }
        /**
         * @ignore
         *
         * @param array $lines
         * @param bool  $encode
         * @return string
         */
        public function _context($lines, $encode = \true)
        {
        }
        /**
         * Process changed lines to do word-by-word diffs for extra highlighting.
         *
         * (TRAC style) sometimes these lines can actually be deleted or added rows.
         * We do additional processing to figure that out
         *
         * @since 2.6.0
         *
         * @param array $orig
         * @param array $final
         * @return string
         */
        public function _changed($orig, $final)
        {
        }
        /**
         * Takes changed blocks and matches which rows in orig turned into which rows in final.
         *
         * @since 2.6.0
         *
         * @param array $orig  Lines of the original version of the text.
         * @param array $final Lines of the final version of the text.
         * @return array {
         *     Array containing results of comparing the original text to the final text.
         *
         *     @type array $orig_matches  Associative array of original matches. Index == row
         *                                number of `$orig`, value == corresponding row number
         *                                of that same line in `$final` or 'x' if there is no
         *                                corresponding row (indicating it is a deleted line).
         *     @type array $final_matches Associative array of final matches. Index == row
         *                                number of `$final`, value == corresponding row number
         *                                of that same line in `$orig` or 'x' if there is no
         *                                corresponding row (indicating it is a new line).
         *     @type array $orig_rows     Associative array of interleaved rows of `$orig` with
         *                                blanks to keep matches aligned with side-by-side diff
         *                                of `$final`. A value >= 0 corresponds to index of `$orig`.
         *                                Value < 0 indicates a blank row.
         *     @type array $final_rows    Associative array of interleaved rows of `$final` with
         *                                blanks to keep matches aligned with side-by-side diff
         *                                of `$orig`. A value >= 0 corresponds to index of `$final`.
         *                                Value < 0 indicates a blank row.
         * }
         * @phpstan-return array{
         *   orig_matches: array,
         *   final_matches: array,
         *   orig_rows: array,
         *   final_rows: array,
         * }
         */
        public function interleave_changed_lines($orig, $final)
        {
        }
        /**
         * Computes a number that is intended to reflect the "distance" between two strings.
         *
         * @since 2.6.0
         *
         * @param string $string1
         * @param string $string2
         * @return int
         */
        public function compute_string_distance($string1, $string2)
        {
        }
        /**
         * @ignore
         * @since 2.6.0
         *
         * @param int $a
         * @param int $b
         * @return int
         */
        public function difference($a, $b)
        {
        }
        /**
         * Make private properties readable for backward compatibility.
         *
         * @since 4.0.0
         * @since 6.4.0 Getting a dynamic property is deprecated.
         *
         * @param string $name Property to get.
         * @return mixed A declared property's value, else null.
         */
        public function __get($name)
        {
        }
        /**
         * Make private properties settable for backward compatibility.
         *
         * @since 4.0.0
         * @since 6.4.0 Setting a dynamic property is deprecated.
         *
         * @param string $name  Property to check if set.
         * @param mixed  $value Property value.
         * @phpstan-return void
         */
        public function __set($name, $value)
        {
        }
        /**
         * Make private properties checkable for backward compatibility.
         *
         * @since 4.0.0
         * @since 6.4.0 Checking a dynamic property is deprecated.
         *
         * @param string $name Property to check if set.
         * @return bool Whether the property is set.
         */
        public function __isset($name)
        {
        }
        /**
         * Make private properties un-settable for backward compatibility.
         *
         * @since 4.0.0
         * @since 6.4.0 Unsetting a dynamic property is deprecated.
         *
         * @param string $name Property to unset.
         * @phpstan-return void
         */
        public function __unset($name)
        {
        }
    }
    /**
     * Core class used for registering text domains.
     *
     * @since 6.1.0
     */
    #[\AllowDynamicProperties]
    class WP_Textdomain_Registry
    {
        /**
         * List of domains and all their language directory paths for each locale.
         *
         * @since 6.1.0
         *
         * @var array
         */
        protected $all = array();
        /**
         * List of domains and their language directory path for the current (most recent) locale.
         *
         * @since 6.1.0
         *
         * @var array
         */
        protected $current = array();
        /**
         * List of domains and their custom language directory paths.
         *
         * @see load_plugin_textdomain()
         * @see load_theme_textdomain()
         *
         * @since 6.1.0
         *
         * @var array
         */
        protected $custom_paths = array();
        /**
         * Holds a cached list of available .mo files to improve performance.
         *
         * @since 6.1.0
         * @since 6.5.0 This property is no longer used.
         *
         * @var array
         *
         * @deprecated
         */
        protected $cached_mo_files = array();
        /**
         * Holds a cached list of domains with translations to improve performance.
         *
         * @since 6.2.0
         *
         * @var string[]
         */
        protected $domains_with_translations = array();
        /**
         * Initializes the registry.
         *
         * Hooks into the {@see 'upgrader_process_complete'} filter
         * to invalidate MO files caches.
         *
         * @since 6.5.0
         */
        public function init()
        {
        }
        /**
         * Returns the languages directory path for a specific domain and locale.
         *
         * @since 6.1.0
         *
         * @param string $domain Text domain.
         * @param string $locale Locale.
         *
         * @return string|false Languages directory path or false if there is none available.
         */
        public function get($domain, $locale)
        {
        }
        /**
         * Determines whether any MO file paths are available for the domain.
         *
         * This is the case if a path has been set for the current locale,
         * or if there is no information stored yet, in which case
         * {@see _load_textdomain_just_in_time()} will fetch the information first.
         *
         * @since 6.1.0
         *
         * @param string $domain Text domain.
         * @return bool Whether any MO file paths are available for the domain.
         */
        public function has($domain)
        {
        }
        /**
         * Sets the language directory path for a specific domain and locale.
         *
         * Also sets the 'current' property for direct access
         * to the path for the current (most recent) locale.
         *
         * @since 6.1.0
         *
         * @param string       $domain Text domain.
         * @param string       $locale Locale.
         * @param string|false $path   Language directory path or false if there is none available.
         */
        public function set($domain, $locale, $path)
        {
        }
        /**
         * Sets the custom path to the plugin's/theme's languages directory.
         *
         * Used by {@see load_plugin_textdomain()} and {@see load_theme_textdomain()}.
         *
         * @since 6.1.0
         *
         * @param string $domain Text domain.
         * @param string $path   Language directory path.
         */
        public function set_custom_path($domain, $path)
        {
        }
        /**
         * Retrieves translation files from the specified path.
         *
         * Allows early retrieval through the {@see 'pre_get_mo_files_from_path'} filter to optimize
         * performance, especially in directories with many files.
         *
         * @since 6.5.0
         *
         * @param string $path The directory path to search for translation files.
         * @return array Array of translation file paths. Can contain .mo and .l10n.php files.
         */
        public function get_language_files_from_path($path)
        {
        }
        /**
         * Invalidate the cache for .mo files.
         *
         * This function deletes the cache entries related to .mo files when triggered
         * by specific actions, such as the completion of an upgrade process.
         *
         * @since 6.5.0
         *
         * @param WP_Upgrader $upgrader   Unused. WP_Upgrader instance. In other contexts this might be a
         *                                Theme_Upgrader, Plugin_Upgrader, Core_Upgrade, or Language_Pack_Upgrader instance.
         * @param array       $hook_extra {
         *     Array of bulk item update data.
         *
         *     @type string $action       Type of action. Default 'update'.
         *     @type string $type         Type of update process. Accepts 'plugin', 'theme', 'translation', or 'core'.
         *     @type bool   $bulk         Whether the update process is a bulk update. Default true.
         *     @type array  $plugins      Array of the basename paths of the plugins' main files.
         *     @type array  $themes       The theme slugs.
         *     @type array  $translations {
         *         Array of translations update data.
         *
         *         @type string $language The locale the translation is for.
         *         @type string $type     Type of translation. Accepts 'plugin', 'theme', or 'core'.
         *         @type string $slug     Text domain the translation is for. The slug of a theme/plugin or
         *                                'default' for core translations.
         *         @type string $version  The version of a theme, plugin, or core.
         *     }
         * }
         * @phpstan-param array{
         *   action?: string,
         *   type?: string,
         *   bulk?: bool,
         *   plugins?: array,
         *   themes?: array,
         *   translations?: array{
         *     language: string,
         *     type: string,
         *     slug: string,
         *     version: string,
         *   },
         * } $hook_extra
         * @phpstan-return void
         */
        public function invalidate_mo_files_cache($upgrader, $hook_extra)
        {
        }
    }
    /**
     * Class to provide access to update a theme.json structure.
     */
    #[\AllowDynamicProperties]
    class WP_Theme_JSON_Data
    {
        /**
         * Constructor.
         *
         * @since 6.1.0
         *
         * @link https://developer.wordpress.org/block-editor/reference-guides/theme-json-reference/
         *
         * @param array  $data   Array following the theme.json specification.
         * @param string $origin The origin of the data: default, theme, user.
         */
        public function __construct($data = array('version' => \WP_Theme_JSON::LATEST_SCHEMA), $origin = 'theme')
        {
        }
        /**
         * Updates the theme.json with the the given data.
         *
         * @since 6.1.0
         *
         * @param array $new_data Array following the theme.json specification.
         *
         * @return WP_Theme_JSON_Data The own instance with access to the modified data.
         */
        public function update_with($new_data)
        {
        }
        /**
         * Returns an array containing the underlying data
         * following the theme.json specification.
         *
         * @since 6.1.0
         *
         * @return array
         */
        public function get_data()
        {
        }
        /**
         * Returns theme JSON object.
         *
         * @since 6.6.0
         *
         * @return WP_Theme_JSON The theme JSON structure stored in this data object.
         */
        public function get_theme_json()
        {
        }
    }
    /**
     * Class that abstracts the processing of the different data sources
     * for site-level config and offers an API to work with them.
     *
     * This class is for internal core usage and is not supposed to be used by extenders (plugins and/or themes).
     * This is a low-level API that may need to do breaking changes. Please,
     * use get_global_settings(), get_global_styles(), and get_global_stylesheet() instead.
     *
     * @access private
     */
    #[\AllowDynamicProperties]
    class WP_Theme_JSON_Resolver
    {
        /**
         * Container for keep track of registered blocks.
         *
         * @since 6.1.0
         * @var array
         */
        protected static $blocks_cache = array('core' => array(), 'blocks' => array(), 'theme' => array(), 'user' => array());
        /**
         * Container for data coming from core.
         *
         * @since 5.8.0
         * @var WP_Theme_JSON
         */
        protected static $core = \null;
        /**
         * Container for data coming from the blocks.
         *
         * @since 6.1.0
         * @var WP_Theme_JSON
         */
        protected static $blocks = \null;
        /**
         * Container for data coming from the theme.
         *
         * @since 5.8.0
         * @var WP_Theme_JSON
         */
        protected static $theme = \null;
        /**
         * Container for data coming from the user.
         *
         * @since 5.9.0
         * @var WP_Theme_JSON
         */
        protected static $user = \null;
        /**
         * Stores the ID of the custom post type
         * that holds the user data.
         *
         * @since 5.9.0
         * @var int
         */
        protected static $user_custom_post_type_id = \null;
        /**
         * Container to keep loaded i18n schema for `theme.json`.
         *
         * @since 5.8.0 As `$theme_json_i18n`.
         * @since 5.9.0 Renamed from `$theme_json_i18n` to `$i18n_schema`.
         * @var array
         */
        protected static $i18n_schema = \null;
        /**
         * `theme.json` file cache.
         *
         * @since 6.1.0
         * @var array
         */
        protected static $theme_json_file_cache = array();
        /**
         * Processes a file that adheres to the theme.json schema
         * and returns an array with its contents, or a void array if none found.
         *
         * @since 5.8.0
         * @since 6.1.0 Added caching.
         *
         * @param string $file_path Path to file. Empty if no file.
         * @return array Contents that adhere to the theme.json schema.
         */
        protected static function read_json_file($file_path)
        {
        }
        /**
         * Returns a data structure used in theme.json translation.
         *
         * @since 5.8.0
         * @deprecated 5.9.0
         *
         * @return array An array of theme.json fields that are translatable and the keys that are translatable.
         */
        public static function get_fields_to_translate()
        {
        }
        /**
         * Given a theme.json structure modifies it in place to update certain values
         * by its translated strings according to the language set by the user.
         *
         * @since 5.8.0
         *
         * @param array  $theme_json The theme.json to translate.
         * @param string $domain     Optional. Text domain. Unique identifier for retrieving translated strings.
         *                           Default 'default'.
         * @return array Returns the modified $theme_json_structure.
         */
        protected static function translate($theme_json, $domain = 'default')
        {
        }
        /**
         * Returns core's origin config.
         *
         * @since 5.8.0
         *
         * @return WP_Theme_JSON Entity that holds core data.
         */
        public static function get_core_data()
        {
        }
        /**
         * Checks whether the registered blocks were already processed for this origin.
         *
         * @since 6.1.0
         *
         * @param string $origin Data source for which to cache the blocks.
         *                       Valid values are 'core', 'blocks', 'theme', and 'user'.
         * @return bool True on success, false otherwise.
         * @phpstan-param 'core'|'blocks'|'theme'|'user' $origin
         */
        protected static function has_same_registered_blocks($origin)
        {
        }
        /**
         * Returns the theme's data.
         *
         * Data from theme.json will be backfilled from existing
         * theme supports, if any. Note that if the same data
         * is present in theme.json and in theme supports,
         * the theme.json takes precedence.
         *
         * @since 5.8.0
         * @since 5.9.0 Theme supports have been inlined and the `$theme_support_data` argument removed.
         * @since 6.0.0 Added an `$options` parameter to allow the theme data to be returned without theme supports.
         * @since 6.6.0 Add support for 'default-font-sizes' and 'default-spacing-sizes' theme supports.
         *              Added registration and merging of block style variations from partial theme.json files and the block styles registry.
         *
         * @param array $deprecated Deprecated. Not used.
         * @param array $options {
         *     Options arguments.
         *
         *     @type bool $with_supports Whether to include theme supports in the data. Default true.
         * }
         * @return WP_Theme_JSON Entity that holds theme data.
         * @phpstan-param array{
         *   with_supports?: bool,
         * } $options
         */
        public static function get_theme_data($deprecated = array(), $options = array())
        {
        }
        /**
         * Gets the styles for blocks from the block.json file.
         *
         * @since 6.1.0
         *
         * @return WP_Theme_JSON
         */
        public static function get_block_data()
        {
        }
        /**
         * Returns the custom post type that contains the user's origin config
         * for the active theme or an empty array if none are found.
         *
         * This can also create and return a new draft custom post type.
         *
         * @since 5.9.0
         *
         * @param WP_Theme $theme              The theme object. If empty, it
         *                                     defaults to the active theme.
         * @param bool     $create_post        Optional. Whether a new custom post
         *                                     type should be created if none are
         *                                     found. Default false.
         * @param array    $post_status_filter Optional. Filter custom post type by
         *                                     post status. Default `array( 'publish' )`,
         *                                     so it only fetches published posts.
         * @return array Custom Post Type for the user's origin config.
         */
        public static function get_user_data_from_wp_global_styles($theme, $create_post = \false, $post_status_filter = array('publish'))
        {
        }
        /**
         * Returns the user's origin config.
         *
         * @since 5.9.0
         * @since 6.6.0 The 'isGlobalStylesUserThemeJSON' flag is left on the user data.
         *              Register the block style variations coming from the user data.
         *
         * @return WP_Theme_JSON Entity that holds styles for user data.
         */
        public static function get_user_data()
        {
        }
        /**
         * Returns the data merged from multiple origins.
         *
         * There are four sources of data (origins) for a site:
         *
         * - default => WordPress
         * - blocks  => each one of the blocks provides data for itself
         * - theme   => the active theme
         * - custom  => data provided by the user
         *
         * The custom's has higher priority than the theme's, the theme's higher than blocks',
         * and block's higher than default's.
         *
         * Unlike the getters
         * {@link https://developer.wordpress.org/reference/classes/wp_theme_json_resolver/get_core_data/ get_core_data},
         * {@link https://developer.wordpress.org/reference/classes/wp_theme_json_resolver/get_theme_data/ get_theme_data},
         * and {@link https://developer.wordpress.org/reference/classes/wp_theme_json_resolver/get_user_data/ get_user_data},
         * this method returns data after it has been merged with the previous origins.
         * This means that if the same piece of data is declared in different origins
         * (default, blocks, theme, custom), the last origin overrides the previous.
         *
         * For example, if the user has set a background color
         * for the paragraph block, and the theme has done it as well,
         * the user preference wins.
         *
         * @since 5.8.0
         * @since 5.9.0 Added user data, removed the `$settings` parameter,
         *              added the `$origin` parameter.
         * @since 6.1.0 Added block data and generation of spacingSizes array.
         * @since 6.2.0 Changed ' $origin' parameter values to 'default', 'blocks', 'theme' or 'custom'.
         *
         * @param string $origin Optional. To what level should we merge data: 'default', 'blocks', 'theme' or 'custom'.
         *                       'custom' is used as default value as well as fallback value if the origin is unknown.
         * @return WP_Theme_JSON
         * @phpstan-param 'default'|'blocks'|'theme'|'custom' $origin
         */
        public static function get_merged_data($origin = 'custom')
        {
        }
        /**
         * Returns the ID of the custom post type
         * that stores user data.
         *
         * @since 5.9.0
         *
         * @return integer|null
         */
        public static function get_user_global_styles_post_id()
        {
        }
        /**
         * Determines whether the active theme has a theme.json file.
         *
         * @since 5.8.0
         * @since 5.9.0 Added a check in the parent theme.
         * @deprecated 6.2.0 Use wp_theme_has_theme_json() instead.
         *
         * @return bool
         */
        public static function theme_has_support()
        {
        }
        /**
         * Builds the path to the given file and checks that it is readable.
         *
         * If it isn't, returns an empty string, otherwise returns the whole file path.
         *
         * @since 5.8.0
         * @since 5.9.0 Adapted to work with child themes, added the `$template` argument.
         *
         * @param string $file_name Name of the file.
         * @param bool   $template  Optional. Use template theme directory. Default false.
         * @return string The whole file path or empty if the file doesn't exist.
         */
        protected static function get_file_path_from_theme($file_name, $template = \false)
        {
        }
        /**
         * Cleans the cached data so it can be recalculated.
         *
         * @since 5.8.0
         * @since 5.9.0 Added the `$user`, `$user_custom_post_type_id`,
         *              and `$i18n_schema` variables to reset.
         * @since 6.1.0 Added the `$blocks` and `$blocks_cache` variables
         *              to reset.
         */
        public static function clean_cached_data()
        {
        }
        /**
         * Returns the style variations defined by the theme.
         *
         * @since 6.0.0
         * @since 6.2.0 Returns parent theme variations if theme is a child.
         * @since 6.6.0 Added configurable scope parameter to allow filtering
         *              theme.json partial files by the scope to which they
         *              can be applied e.g. theme vs block etc.
         *              Added basic caching for read theme.json partial files.
         *
         * @param string $scope The scope or type of style variation to retrieve e.g. theme, block etc.
         * @return array
         */
        public static function get_style_variations($scope = 'theme')
        {
        }
        /**
         * Resolves relative paths in theme.json styles to theme absolute paths
         * and returns them in an array that can be embedded
         * as the value of `_link` object in REST API responses.
         *
         * @since 6.6.0
         * @since 6.7.0 Resolve relative paths in block styles.
         *
         * @param WP_Theme_JSON $theme_json A theme json instance.
         * @return array An array of resolved paths.
         */
        public static function get_resolved_theme_uris($theme_json)
        {
        }
        /**
         * Resolves relative paths in theme.json styles to theme absolute paths
         * and merges them with incoming theme JSON.
         *
         * @since 6.6.0
         *
         * @param WP_Theme_JSON $theme_json A theme json instance.
         * @return WP_Theme_JSON Theme merged with resolved paths, if any found.
         */
        public static function resolve_theme_file_uris($theme_json)
        {
        }
    }
    /**
     * Class that migrates a given theme.json structure to the latest schema.
     *
     * This class is for internal core usage and is not supposed to be used by extenders (plugins and/or themes).
     * This is a low-level API that may need to do breaking changes. Please,
     * use get_global_settings, get_global_styles, and get_global_stylesheet instead.
     *
     * @since 5.9.0
     * @access private
     */
    #[\AllowDynamicProperties]
    class WP_Theme_JSON_Schema
    {
        /**
         * Maps old properties to their new location within the schema's settings.
         * This will be applied at both the defaults and individual block levels.
         */
        const V1_TO_V2_RENAMED_PATHS = array('border.customRadius' => 'border.radius', 'spacing.customMargin' => 'spacing.margin', 'spacing.customPadding' => 'spacing.padding', 'typography.customLineHeight' => 'typography.lineHeight');
        /**
         * Function that migrates a given theme.json structure to the last version.
         *
         * @since 5.9.0
         * @since 6.6.0 Migrate up to v3 and add $origin parameter.
         *
         * @param array $theme_json The structure to migrate.
         * @param string $origin    Optional. What source of data this object represents.
         *                          One of 'blocks', 'default', 'theme', or 'custom'. Default 'theme'.
         * @return array The structure in the last version.
         * @phpstan-param 'blocks'|'default'|'theme'|'custom' $origin
         */
        public static function migrate($theme_json, $origin = 'theme')
        {
        }
    }
    /**
     * Class that encapsulates the processing of structures that adhere to the theme.json spec.
     *
     * This class is for internal core usage and is not supposed to be used by extenders (plugins and/or themes).
     * This is a low-level API that may need to do breaking changes. Please,
     * use get_global_settings, get_global_styles, and get_global_stylesheet instead.
     *
     * @access private
     */
    #[\AllowDynamicProperties]
    class WP_Theme_JSON
    {
        /**
         * Container of data in theme.json format.
         *
         * @since 5.8.0
         * @var array
         */
        protected $theme_json = \null;
        /**
         * Holds block metadata extracted from block.json
         * to be shared among all instances so we don't
         * process it twice.
         *
         * @since 5.8.0
         * @since 6.1.0 Initialize as an empty array.
         * @var array
         */
        protected static $blocks_metadata = array();
        /**
         * The CSS selector for the top-level preset settings.
         *
         * @since 6.6.0
         * @var string
         */
        const ROOT_CSS_PROPERTIES_SELECTOR = ':root';
        /**
         * The CSS selector for the top-level styles.
         *
         * @since 5.8.0
         * @var string
         */
        const ROOT_BLOCK_SELECTOR = 'body';
        /**
         * The sources of data this object can represent.
         *
         * @since 5.8.0
         * @since 6.1.0 Added 'blocks'.
         * @var string[]
         */
        const VALID_ORIGINS = array('default', 'blocks', 'theme', 'custom');
        /**
         * Presets are a set of values that serve
         * to bootstrap some styles: colors, font sizes, etc.
         *
         * They are a unkeyed array of values such as:
         *
         *     array(
         *       array(
         *         'slug'      => 'unique-name-within-the-set',
         *         'name'      => 'Name for the UI',
         *         <value_key> => 'value'
         *       ),
         *     )
         *
         * This contains the necessary metadata to process them:
         *
         * - path             => Where to find the preset within the settings section.
         * - prevent_override => Disables override of default presets by theme presets.
         *                       The relationship between whether to override the defaults
         *                       and whether the defaults are enabled is inverse:
         *                         - If defaults are enabled  => theme presets should not be overridden
         *                         - If defaults are disabled => theme presets should be overridden
         *                       For example, a theme sets defaultPalette to false,
         *                       making the default palette hidden from the user.
         *                       In that case, we want all the theme presets to be present,
         *                       so they should override the defaults by setting this false.
         * - use_default_names => whether to use the default names
         * - value_key        => the key that represents the value
         * - value_func       => optionally, instead of value_key, a function to generate
         *                       the value that takes a preset as an argument
         *                       (either value_key or value_func should be present)
         * - css_vars         => template string to use in generating the CSS Custom Property.
         *                       Example output: "--wp--preset--duotone--blue: <value>" will generate as many CSS Custom Properties as presets defined
         *                       substituting the $slug for the slug's value for each preset value.
         * - classes          => array containing a structure with the classes to
         *                       generate for the presets, where for each array item
         *                       the key is the class name and the value the property name.
         *                       The "$slug" substring will be replaced by the slug of each preset.
         *                       For example:
         *                       'classes' => array(
         *                         '.has-$slug-color'            => 'color',
         *                         '.has-$slug-background-color' => 'background-color',
         *                         '.has-$slug-border-color'     => 'border-color',
         *                       )
         * - properties       => array of CSS properties to be used by kses to
         *                       validate the content of each preset
         *                       by means of the remove_insecure_properties method.
         *
         * @since 5.8.0
         * @since 5.9.0 Added the `color.duotone` and `typography.fontFamilies` presets,
         *              `use_default_names` preset key, and simplified the metadata structure.
         * @since 6.0.0 Replaced `override` with `prevent_override` and updated the
         *              `prevent_override` value for `color.duotone` to use `color.defaultDuotone`.
         * @since 6.2.0 Added 'shadow' presets.
         * @since 6.3.0 Replaced value_func for duotone with `null`. Custom properties are handled by class-wp-duotone.php.
         * @since 6.6.0 Added the `dimensions.aspectRatios` and `dimensions.defaultAspectRatios` presets.
         *              Updated the 'prevent_override' value for font size presets to use 'typography.defaultFontSizes'
         *              and spacing size presets to use `spacing.defaultSpacingSizes`.
         * @var array
         */
        const PRESETS_METADATA = array(array('path' => array('dimensions', 'aspectRatios'), 'prevent_override' => array('dimensions', 'defaultAspectRatios'), 'use_default_names' => \false, 'value_key' => 'ratio', 'css_vars' => '--wp--preset--aspect-ratio--$slug', 'classes' => array(), 'properties' => array('aspect-ratio')), array('path' => array('color', 'palette'), 'prevent_override' => array('color', 'defaultPalette'), 'use_default_names' => \false, 'value_key' => 'color', 'css_vars' => '--wp--preset--color--$slug', 'classes' => array('.has-$slug-color' => 'color', '.has-$slug-background-color' => 'background-color', '.has-$slug-border-color' => 'border-color'), 'properties' => array('color', 'background-color', 'border-color')), array('path' => array('color', 'gradients'), 'prevent_override' => array('color', 'defaultGradients'), 'use_default_names' => \false, 'value_key' => 'gradient', 'css_vars' => '--wp--preset--gradient--$slug', 'classes' => array('.has-$slug-gradient-background' => 'background'), 'properties' => array('background')), array(
            'path' => array('color', 'duotone'),
            'prevent_override' => array('color', 'defaultDuotone'),
            'use_default_names' => \false,
            'value_func' => \null,
            // CSS Custom Properties for duotone are handled by block supports in class-wp-duotone.php.
            'css_vars' => \null,
            'classes' => array(),
            'properties' => array('filter'),
        ), array('path' => array('typography', 'fontSizes'), 'prevent_override' => array('typography', 'defaultFontSizes'), 'use_default_names' => \true, 'value_func' => 'wp_get_typography_font_size_value', 'css_vars' => '--wp--preset--font-size--$slug', 'classes' => array('.has-$slug-font-size' => 'font-size'), 'properties' => array('font-size')), array('path' => array('typography', 'fontFamilies'), 'prevent_override' => \false, 'use_default_names' => \false, 'value_key' => 'fontFamily', 'css_vars' => '--wp--preset--font-family--$slug', 'classes' => array('.has-$slug-font-family' => 'font-family'), 'properties' => array('font-family')), array('path' => array('spacing', 'spacingSizes'), 'prevent_override' => array('spacing', 'defaultSpacingSizes'), 'use_default_names' => \true, 'value_key' => 'size', 'css_vars' => '--wp--preset--spacing--$slug', 'classes' => array(), 'properties' => array('padding', 'margin')), array('path' => array('shadow', 'presets'), 'prevent_override' => array('shadow', 'defaultPresets'), 'use_default_names' => \false, 'value_key' => 'shadow', 'css_vars' => '--wp--preset--shadow--$slug', 'classes' => array(), 'properties' => array('box-shadow')));
        /**
         * Metadata for style properties.
         *
         * Each element is a direct mapping from the CSS property name to the
         * path to the value in theme.json & block attributes.
         *
         * @since 5.8.0
         * @since 5.9.0 Added the `border-*`, `font-family`, `font-style`, `font-weight`,
         *              `letter-spacing`, `margin-*`, `padding-*`, `--wp--style--block-gap`,
         *              `text-decoration`, `text-transform`, and `filter` properties,
         *              simplified the metadata structure.
         * @since 6.1.0 Added the `border-*-color`, `border-*-width`, `border-*-style`,
         *              `--wp--style--root--padding-*`, and `box-shadow` properties,
         *              removed the `--wp--style--block-gap` property.
         * @since 6.2.0 Added `outline-*`, and `min-height` properties.
         * @since 6.3.0 Added `column-count` property.
         * @since 6.4.0 Added `writing-mode` property.
         * @since 6.5.0 Added `aspect-ratio` property.
         * @since 6.6.0 Added `background-[image|position|repeat|size]` properties.
         * @since 6.7.0 Added `background-attachment` property.
         *
         * @var array
         */
        const PROPERTIES_METADATA = array('aspect-ratio' => array('dimensions', 'aspectRatio'), 'background' => array('color', 'gradient'), 'background-color' => array('color', 'background'), 'background-image' => array('background', 'backgroundImage'), 'background-position' => array('background', 'backgroundPosition'), 'background-repeat' => array('background', 'backgroundRepeat'), 'background-size' => array('background', 'backgroundSize'), 'background-attachment' => array('background', 'backgroundAttachment'), 'border-radius' => array('border', 'radius'), 'border-top-left-radius' => array('border', 'radius', 'topLeft'), 'border-top-right-radius' => array('border', 'radius', 'topRight'), 'border-bottom-left-radius' => array('border', 'radius', 'bottomLeft'), 'border-bottom-right-radius' => array('border', 'radius', 'bottomRight'), 'border-color' => array('border', 'color'), 'border-width' => array('border', 'width'), 'border-style' => array('border', 'style'), 'border-top-color' => array('border', 'top', 'color'), 'border-top-width' => array('border', 'top', 'width'), 'border-top-style' => array('border', 'top', 'style'), 'border-right-color' => array('border', 'right', 'color'), 'border-right-width' => array('border', 'right', 'width'), 'border-right-style' => array('border', 'right', 'style'), 'border-bottom-color' => array('border', 'bottom', 'color'), 'border-bottom-width' => array('border', 'bottom', 'width'), 'border-bottom-style' => array('border', 'bottom', 'style'), 'border-left-color' => array('border', 'left', 'color'), 'border-left-width' => array('border', 'left', 'width'), 'border-left-style' => array('border', 'left', 'style'), 'color' => array('color', 'text'), 'text-align' => array('typography', 'textAlign'), 'column-count' => array('typography', 'textColumns'), 'font-family' => array('typography', 'fontFamily'), 'font-size' => array('typography', 'fontSize'), 'font-style' => array('typography', 'fontStyle'), 'font-weight' => array('typography', 'fontWeight'), 'letter-spacing' => array('typography', 'letterSpacing'), 'line-height' => array('typography', 'lineHeight'), 'margin' => array('spacing', 'margin'), 'margin-top' => array('spacing', 'margin', 'top'), 'margin-right' => array('spacing', 'margin', 'right'), 'margin-bottom' => array('spacing', 'margin', 'bottom'), 'margin-left' => array('spacing', 'margin', 'left'), 'min-height' => array('dimensions', 'minHeight'), 'outline-color' => array('outline', 'color'), 'outline-offset' => array('outline', 'offset'), 'outline-style' => array('outline', 'style'), 'outline-width' => array('outline', 'width'), 'padding' => array('spacing', 'padding'), 'padding-top' => array('spacing', 'padding', 'top'), 'padding-right' => array('spacing', 'padding', 'right'), 'padding-bottom' => array('spacing', 'padding', 'bottom'), 'padding-left' => array('spacing', 'padding', 'left'), '--wp--style--root--padding' => array('spacing', 'padding'), '--wp--style--root--padding-top' => array('spacing', 'padding', 'top'), '--wp--style--root--padding-right' => array('spacing', 'padding', 'right'), '--wp--style--root--padding-bottom' => array('spacing', 'padding', 'bottom'), '--wp--style--root--padding-left' => array('spacing', 'padding', 'left'), 'text-decoration' => array('typography', 'textDecoration'), 'text-transform' => array('typography', 'textTransform'), 'filter' => array('filter', 'duotone'), 'box-shadow' => array('shadow'), 'writing-mode' => array('typography', 'writingMode'));
        /**
         * Indirect metadata for style properties that are not directly output.
         *
         * Each element maps from a CSS property name to an array of
         * paths to the value in theme.json & block attributes.
         *
         * Indirect properties are not output directly by `compute_style_properties`,
         * but are used elsewhere in the processing of global styles. The indirect
         * property is used to validate whether a style value is allowed.
         *
         * @since 6.2.0
         * @since 6.6.0 Added background-image properties.
         *
         * @var array
         */
        const INDIRECT_PROPERTIES_METADATA = array('gap' => array(array('spacing', 'blockGap')), 'column-gap' => array(array('spacing', 'blockGap', 'left')), 'row-gap' => array(array('spacing', 'blockGap', 'top')), 'max-width' => array(array('layout', 'contentSize'), array('layout', 'wideSize')), 'background-image' => array(array('background', 'backgroundImage', 'url')));
        /**
         * Protected style properties.
         *
         * These style properties are only rendered if a setting enables it
         * via a value other than `null`.
         *
         * Each element maps the style property to the corresponding theme.json
         * setting key.
         *
         * @since 5.9.0
         */
        const PROTECTED_PROPERTIES = array('spacing.blockGap' => array('spacing', 'blockGap'));
        /**
         * The top-level keys a theme.json can have.
         *
         * @since 5.8.0 As `ALLOWED_TOP_LEVEL_KEYS`.
         * @since 5.9.0 Renamed from `ALLOWED_TOP_LEVEL_KEYS` to `VALID_TOP_LEVEL_KEYS`,
         *              added the `customTemplates` and `templateParts` values.
         * @since 6.3.0 Added the `description` value.
         * @since 6.6.0 Added `blockTypes` to support block style variation theme.json partials.
         * @var string[]
         */
        const VALID_TOP_LEVEL_KEYS = array('blockTypes', 'customTemplates', 'description', 'patterns', 'settings', 'slug', 'styles', 'templateParts', 'title', 'version');
        /**
         * The valid properties under the settings key.
         *
         * @since 5.8.0 As `ALLOWED_SETTINGS`.
         * @since 5.9.0 Renamed from `ALLOWED_SETTINGS` to `VALID_SETTINGS`,
         *              added new properties for `border`, `color`, `spacing`,
         *              and `typography`, and renamed others according to the new schema.
         * @since 6.0.0 Added `color.defaultDuotone`.
         * @since 6.1.0 Added `layout.definitions` and `useRootPaddingAwareAlignments`.
         * @since 6.2.0 Added `dimensions.minHeight`, 'shadow.presets', 'shadow.defaultPresets',
         *              `position.fixed` and `position.sticky`.
         * @since 6.3.0 Added support for `typography.textColumns`, removed `layout.definitions`.
         * @since 6.4.0 Added support for `layout.allowEditing`, `background.backgroundImage`,
         *              `typography.writingMode`, `lightbox.enabled` and `lightbox.allowEditing`.
         * @since 6.5.0 Added support for `layout.allowCustomContentAndWideSize`,
         *              `background.backgroundSize` and `dimensions.aspectRatio`.
         * @since 6.6.0 Added support for 'dimensions.aspectRatios', 'dimensions.defaultAspectRatios',
         *              'typography.defaultFontSizes', and 'spacing.defaultSpacingSizes'.
         * @var array
         */
        const VALID_SETTINGS = array('appearanceTools' => \null, 'useRootPaddingAwareAlignments' => \null, 'background' => array('backgroundImage' => \null, 'backgroundSize' => \null), 'border' => array('color' => \null, 'radius' => \null, 'style' => \null, 'width' => \null), 'color' => array('background' => \null, 'custom' => \null, 'customDuotone' => \null, 'customGradient' => \null, 'defaultDuotone' => \null, 'defaultGradients' => \null, 'defaultPalette' => \null, 'duotone' => \null, 'gradients' => \null, 'link' => \null, 'heading' => \null, 'button' => \null, 'caption' => \null, 'palette' => \null, 'text' => \null), 'custom' => \null, 'dimensions' => array('aspectRatio' => \null, 'aspectRatios' => \null, 'defaultAspectRatios' => \null, 'minHeight' => \null), 'layout' => array('contentSize' => \null, 'wideSize' => \null, 'allowEditing' => \null, 'allowCustomContentAndWideSize' => \null), 'lightbox' => array('enabled' => \null, 'allowEditing' => \null), 'position' => array('fixed' => \null, 'sticky' => \null), 'spacing' => array('customSpacingSize' => \null, 'defaultSpacingSizes' => \null, 'spacingSizes' => \null, 'spacingScale' => \null, 'blockGap' => \null, 'margin' => \null, 'padding' => \null, 'units' => \null), 'shadow' => array('presets' => \null, 'defaultPresets' => \null), 'typography' => array('fluid' => \null, 'customFontSize' => \null, 'defaultFontSizes' => \null, 'dropCap' => \null, 'fontFamilies' => \null, 'fontSizes' => \null, 'fontStyle' => \null, 'fontWeight' => \null, 'letterSpacing' => \null, 'lineHeight' => \null, 'textAlign' => \null, 'textColumns' => \null, 'textDecoration' => \null, 'textTransform' => \null, 'writingMode' => \null));
        /*
         * The valid properties for fontFamilies under settings key.
         *
         * @since 6.5.0
         *
         * @var array
         */
        const FONT_FAMILY_SCHEMA = array(array('fontFamily' => \null, 'name' => \null, 'slug' => \null, 'fontFace' => array(array('ascentOverride' => \null, 'descentOverride' => \null, 'fontDisplay' => \null, 'fontFamily' => \null, 'fontFeatureSettings' => \null, 'fontStyle' => \null, 'fontStretch' => \null, 'fontVariationSettings' => \null, 'fontWeight' => \null, 'lineGapOverride' => \null, 'sizeAdjust' => \null, 'src' => \null, 'unicodeRange' => \null))));
        /**
         * The valid properties under the styles key.
         *
         * @since 5.8.0 As `ALLOWED_STYLES`.
         * @since 5.9.0 Renamed from `ALLOWED_STYLES` to `VALID_STYLES`,
         *              added new properties for `border`, `filter`, `spacing`,
         *              and `typography`.
         * @since 6.1.0 Added new side properties for `border`,
         *              added new property `shadow`,
         *              updated `blockGap` to be allowed at any level.
         * @since 6.2.0 Added `outline`, and `minHeight` properties.
         * @since 6.3.0 Added support for `typography.textColumns`.
         * @since 6.5.0 Added support for `dimensions.aspectRatio`.
         * @since 6.6.0 Added `background` sub properties to top-level only.
         *
         * @var array
         */
        const VALID_STYLES = array('background' => array('backgroundImage' => \null, 'backgroundPosition' => \null, 'backgroundRepeat' => \null, 'backgroundSize' => \null, 'backgroundAttachment' => \null), 'border' => array('color' => \null, 'radius' => \null, 'style' => \null, 'width' => \null, 'top' => \null, 'right' => \null, 'bottom' => \null, 'left' => \null), 'color' => array('background' => \null, 'gradient' => \null, 'text' => \null), 'dimensions' => array('aspectRatio' => \null, 'minHeight' => \null), 'filter' => array('duotone' => \null), 'outline' => array('color' => \null, 'offset' => \null, 'style' => \null, 'width' => \null), 'shadow' => \null, 'spacing' => array('margin' => \null, 'padding' => \null, 'blockGap' => \null), 'typography' => array('fontFamily' => \null, 'fontSize' => \null, 'fontStyle' => \null, 'fontWeight' => \null, 'letterSpacing' => \null, 'lineHeight' => \null, 'textAlign' => \null, 'textColumns' => \null, 'textDecoration' => \null, 'textTransform' => \null, 'writingMode' => \null), 'css' => \null);
        /**
         * Defines which pseudo selectors are enabled for which elements.
         *
         * The order of the selectors should be: link, any-link, visited, hover, focus, active.
         * This is to ensure the user action (hover, focus and active) styles have a higher
         * specificity than the visited styles, which in turn have a higher specificity than
         * the unvisited styles.
         *
         * See https://core.trac.wordpress.org/ticket/56928.
         * Note: this will affect both top-level and block-level elements.
         *
         * @since 6.1.0
         * @since 6.2.0 Added support for ':link' and ':any-link'.
         */
        const VALID_ELEMENT_PSEUDO_SELECTORS = array('link' => array(':link', ':any-link', ':visited', ':hover', ':focus', ':active'), 'button' => array(':link', ':any-link', ':visited', ':hover', ':focus', ':active'));
        /**
         * The valid elements that can be found under styles.
         *
         * @since 5.8.0
         * @since 6.1.0 Added `heading`, `button`, and `caption` elements.
         * @var string[]
         */
        const ELEMENTS = array(
            'link' => 'a:where(:not(.wp-element-button))',
            // The `where` is needed to lower the specificity.
            'heading' => 'h1, h2, h3, h4, h5, h6',
            'h1' => 'h1',
            'h2' => 'h2',
            'h3' => 'h3',
            'h4' => 'h4',
            'h5' => 'h5',
            'h6' => 'h6',
            // We have the .wp-block-button__link class so that this will target older buttons that have been serialized.
            'button' => '.wp-element-button, .wp-block-button__link',
            // The block classes are necessary to target older content that won't use the new class names.
            'caption' => '.wp-element-caption, .wp-block-audio figcaption, .wp-block-embed figcaption, .wp-block-gallery figcaption, .wp-block-image figcaption, .wp-block-table figcaption, .wp-block-video figcaption',
            'cite' => 'cite',
        );
        const __EXPERIMENTAL_ELEMENT_CLASS_NAMES = array('button' => 'wp-element-button', 'caption' => 'wp-element-caption');
        /**
         * List of block support features that can have their related styles
         * generated under their own feature level selector rather than the block's.
         *
         * @since 6.1.0
         * @var string[]
         */
        const BLOCK_SUPPORT_FEATURE_LEVEL_SELECTORS = array('__experimentalBorder' => 'border', 'color' => 'color', 'spacing' => 'spacing', 'typography' => 'typography');
        /**
         * Return the input schema at the root and per origin.
         *
         * @since 6.5.0
         *
         * @param array $schema The base schema.
         * @return array The schema at the root and per origin.
         *
         * Example:
         * schema_in_root_and_per_origin(
         *   array(
         *    'fontFamily' => null,
         *    'slug' => null,
         *   )
         * )
         *
         * Returns:
         * array(
         *  'fontFamily' => null,
         *  'slug' => null,
         *  'default' => array(
         *    'fontFamily' => null,
         *    'slug' => null,
         *  ),
         *  'blocks' => array(
         *    'fontFamily' => null,
         *    'slug' => null,
         *  ),
         *  'theme' => array(
         *     'fontFamily' => null,
         *     'slug' => null,
         *  ),
         *  'custom' => array(
         *     'fontFamily' => null,
         *     'slug' => null,
         *  ),
         * )
         */
        protected static function schema_in_root_and_per_origin($schema)
        {
        }
        /**
         * Returns a class name by an element name.
         *
         * @since 6.1.0
         *
         * @param string $element The name of the element.
         * @return string The name of the class.
         */
        public static function get_element_class_name($element)
        {
        }
        /**
         * Options that settings.appearanceTools enables.
         *
         * @since 6.0.0
         * @since 6.2.0 Added `dimensions.minHeight` and `position.sticky`.
         * @since 6.4.0 Added `background.backgroundImage`.
         * @since 6.5.0 Added `background.backgroundSize` and `dimensions.aspectRatio`.
         * @var array
         */
        const APPEARANCE_TOOLS_OPT_INS = array(array('background', 'backgroundImage'), array('background', 'backgroundSize'), array('border', 'color'), array('border', 'radius'), array('border', 'style'), array('border', 'width'), array('color', 'link'), array('color', 'heading'), array('color', 'button'), array('color', 'caption'), array('dimensions', 'aspectRatio'), array('dimensions', 'minHeight'), array('position', 'sticky'), array('spacing', 'blockGap'), array('spacing', 'margin'), array('spacing', 'padding'), array('typography', 'lineHeight'));
        /**
         * The latest version of the schema in use.
         *
         * @since 5.8.0
         * @since 5.9.0 Changed value from 1 to 2.
         * @since 6.6.0 Changed value from 2 to 3.
         * @var int
         */
        const LATEST_SCHEMA = 3;
        /**
         * Constructor.
         *
         * @since 5.8.0
         * @since 6.6.0 Key spacingScale by origin, and Pre-generate the spacingSizes from spacingScale.
         *              Added unwrapping of shared block style variations into block type variations if registered.
         *
         * @param array  $theme_json A structure that follows the theme.json schema.
         * @param string $origin     Optional. What source of data this object represents.
         *                           One of 'blocks', 'default', 'theme', or 'custom'. Default 'theme'.
         * @phpstan-param 'blocks'|'default'|'theme'|'custom' $origin
         */
        public function __construct($theme_json = array('version' => self::LATEST_SCHEMA), $origin = 'theme')
        {
        }
        /**
         * Enables some opt-in settings if theme declared support.
         *
         * @since 5.9.0
         *
         * @param array $theme_json A theme.json structure to modify.
         * @return array The modified theme.json structure.
         */
        protected static function maybe_opt_in_into_settings($theme_json)
        {
        }
        /**
         * Enables some settings.
         *
         * @since 5.9.0
         *
         * @param array $context The context to which the settings belong.
         */
        protected static function do_opt_in_into_settings(&$context)
        {
        }
        /**
         * Sanitizes the input according to the schemas.
         *
         * @since 5.8.0
         * @since 5.9.0 Added the `$valid_block_names` and `$valid_element_name` parameters.
         * @since 6.3.0 Added the `$valid_variations` parameter.
         * @since 6.6.0 Updated schema to allow extended block style variations.
         *
         * @param array $input               Structure to sanitize.
         * @param array $valid_block_names   List of valid block names.
         * @param array $valid_element_names List of valid element names.
         * @param array $valid_variations    List of valid variations per block.
         * @return array The sanitized output.
         */
        protected static function sanitize($input, $valid_block_names, $valid_element_names, $valid_variations)
        {
        }
        /**
         * Appends a sub-selector to an existing one.
         *
         * Given the compounded $selector "h1, h2, h3"
         * and the $to_append selector ".some-class" the result will be
         * "h1.some-class, h2.some-class, h3.some-class".
         *
         * @since 5.8.0
         * @since 6.1.0 Added append position.
         * @since 6.3.0 Removed append position parameter.
         *
         * @param string $selector  Original selector.
         * @param string $to_append Selector to append.
         * @return string The new selector.
         */
        protected static function append_to_selector($selector, $to_append)
        {
        }
        /**
         * Prepends a sub-selector to an existing one.
         *
         * Given the compounded $selector "h1, h2, h3"
         * and the $to_prepend selector ".some-class " the result will be
         * ".some-class h1, .some-class  h2, .some-class  h3".
         *
         * @since 6.3.0
         *
         * @param string $selector   Original selector.
         * @param string $to_prepend Selector to prepend.
         * @return string The new selector.
         */
        protected static function prepend_to_selector($selector, $to_prepend)
        {
        }
        /**
         * Returns the metadata for each block.
         *
         * Example:
         *
         *     {
         *       'core/paragraph': {
         *         'selector': 'p',
         *         'elements': {
         *           'link' => 'link selector',
         *           'etc'  => 'element selector'
         *         }
         *       },
         *       'core/heading': {
         *         'selector': 'h1',
         *         'elements': {}
         *       },
         *       'core/image': {
         *         'selector': '.wp-block-image',
         *         'duotone': 'img',
         *         'elements': {}
         *       }
         *     }
         *
         * @since 5.8.0
         * @since 5.9.0 Added `duotone` key with CSS selector.
         * @since 6.1.0 Added `features` key with block support feature level selectors.
         * @since 6.3.0 Refactored and stabilized selectors API.
         * @since 6.6.0 Updated to include block style variations from the block styles registry.
         *
         * @return array Block metadata.
         */
        protected static function get_blocks_metadata()
        {
        }
        /**
         * Given a tree, removes the keys that are not present in the schema.
         *
         * It is recursive and modifies the input in-place.
         *
         * @since 5.8.0
         *
         * @param array $tree   Input to process.
         * @param array $schema Schema to adhere to.
         * @return array The modified $tree.
         */
        protected static function remove_keys_not_in_schema($tree, $schema)
        {
        }
        /**
         * Returns the existing settings for each block.
         *
         * Example:
         *
         *     {
         *       'root': {
         *         'color': {
         *           'custom': true
         *         }
         *       },
         *       'core/paragraph': {
         *         'spacing': {
         *           'customPadding': true
         *         }
         *       }
         *     }
         *
         * @since 5.8.0
         *
         * @return array Settings per block.
         */
        public function get_settings()
        {
        }
        /**
         * Returns the stylesheet that results of processing
         * the theme.json structure this object represents.
         *
         * @since 5.8.0
         * @since 5.9.0 Removed the `$type` parameter, added the `$types` and `$origins` parameters.
         * @since 6.3.0 Add fallback layout styles for Post Template when block gap support isn't available.
         * @since 6.6.0 Added boolean `skip_root_layout_styles` and `include_block_style_variations` options
         *              to control styles output as desired.
         *
         * @param string[] $types   Types of styles to load. Will load all by default. It accepts:
         *                          - `variables`: only the CSS Custom Properties for presets & custom ones.
         *                          - `styles`: only the styles section in theme.json.
         *                          - `presets`: only the classes for the presets.
         * @param string[] $origins A list of origins to include. By default it includes VALID_ORIGINS.
         * @param array    $options {
         *     Optional. An array of options for now used for internal purposes only (may change without notice).
         *
         *     @type string $scope                           Makes sure all style are scoped to a given selector
         *     @type string $root_selector                   Overwrites and forces a given selector to be used on the root node
         *     @type bool   $skip_root_layout_styles         Omits root layout styles from the generated stylesheet. Default false.
         *     @type bool   $include_block_style_variations  Includes styles for block style variations in the generated stylesheet. Default false.
         * }
         * @return string The resulting stylesheet.
         * @phpstan-param array{
         *   scope?: string,
         *   root_selector?: string,
         *   skip_root_layout_styles?: bool,
         *   include_block_style_variations?: bool,
         * } $options
         */
        public function get_stylesheet($types = array('variables', 'styles', 'presets'), $origins = \null, $options = array())
        {
        }
        /**
         * Processes the CSS, to apply nesting.
         *
         * @since 6.2.0
         * @since 6.6.0 Enforced 0-1-0 specificity for block custom CSS selectors.
         *
         * @param string $css      The CSS to process.
         * @param string $selector The selector to nest.
         * @return string The processed CSS.
         */
        protected function process_blocks_custom_css($css, $selector)
        {
        }
        /**
         * Returns the global styles custom CSS.
         *
         * @since 6.2.0
         * @deprecated 6.7.0 Use {@see 'get_stylesheet'} instead.
         *
         * @return string The global styles custom CSS.
         */
        public function get_custom_css()
        {
        }
        /**
         * Returns the page templates of the active theme.
         *
         * @since 5.9.0
         *
         * @return array
         */
        public function get_custom_templates()
        {
        }
        /**
         * Returns the template part data of active theme.
         *
         * @since 5.9.0
         *
         * @return array
         */
        public function get_template_parts()
        {
        }
        /**
         * Converts each style section into a list of rulesets
         * containing the block styles to be appended to the stylesheet.
         *
         * See glossary at https://developer.mozilla.org/en-US/docs/Web/CSS/Syntax
         *
         * For each section this creates a new ruleset such as:
         *
         *   block-selector {
         *     style-property-one: value;
         *   }
         *
         * @since 5.8.0 As `get_block_styles()`.
         * @since 5.9.0 Renamed from `get_block_styles()` to `get_block_classes()`
         *              and no longer returns preset classes.
         *              Removed the `$setting_nodes` parameter.
         * @since 6.1.0 Moved most internal logic to `get_styles_for_block()`.
         *
         * @param array $style_nodes Nodes with styles.
         * @return string The new stylesheet.
         */
        protected function get_block_classes($style_nodes)
        {
        }
        /**
         * Gets the CSS layout rules for a particular block from theme.json layout definitions.
         *
         * @since 6.1.0
         * @since 6.3.0 Reduced specificity for layout margin rules.
         * @since 6.5.1 Only output rules referencing content and wide sizes when values exist.
         * @since 6.5.3 Add types parameter to check if only base layout styles are needed.
         * @since 6.6.0 Updated layout style specificity to be compatible with overall 0-1-0 specificity in global styles.
         *
         * @param array $block_metadata Metadata about the block to get styles for.
         * @param array $types          Optional. Types of styles to output. If empty, all styles will be output.
         * @return string Layout styles for the block.
         */
        protected function get_layout_styles($block_metadata, $types = array())
        {
        }
        /**
         * Creates new rulesets as classes for each preset value such as:
         *
         *   .has-value-color {
         *     color: value;
         *   }
         *
         *   .has-value-background-color {
         *     background-color: value;
         *   }
         *
         *   .has-value-font-size {
         *     font-size: value;
         *   }
         *
         *   .has-value-gradient-background {
         *     background: value;
         *   }
         *
         *   p.has-value-gradient-background {
         *     background: value;
         *   }
         *
         * @since 5.9.0
         *
         * @param array    $setting_nodes Nodes with settings.
         * @param string[] $origins       List of origins to process presets from.
         * @return string The new stylesheet.
         */
        protected function get_preset_classes($setting_nodes, $origins)
        {
        }
        /**
         * Converts each styles section into a list of rulesets
         * to be appended to the stylesheet.
         * These rulesets contain all the css variables (custom variables and preset variables).
         *
         * See glossary at https://developer.mozilla.org/en-US/docs/Web/CSS/Syntax
         *
         * For each section this creates a new ruleset such as:
         *
         *     block-selector {
         *       --wp--preset--category--slug: value;
         *       --wp--custom--variable: value;
         *     }
         *
         * @since 5.8.0
         * @since 5.9.0 Added the `$origins` parameter.
         *
         * @param array    $nodes   Nodes with settings.
         * @param string[] $origins List of origins to process.
         * @return string The new stylesheet.
         */
        protected function get_css_variables($nodes, $origins)
        {
        }
        /**
         * Given a selector and a declaration list,
         * creates the corresponding ruleset.
         *
         * @since 5.8.0
         *
         * @param string $selector     CSS selector.
         * @param array  $declarations List of declarations.
         * @return string The resulting CSS ruleset.
         */
        protected static function to_ruleset($selector, $declarations)
        {
        }
        /**
         * Given a settings array, returns the generated rulesets
         * for the preset classes.
         *
         * @since 5.8.0
         * @since 5.9.0 Added the `$origins` parameter.
         * @since 6.6.0 Added check for root CSS properties selector.
         *
         * @param array    $settings Settings to process.
         * @param string   $selector Selector wrapping the classes.
         * @param string[] $origins  List of origins to process.
         * @return string The result of processing the presets.
         */
        protected static function compute_preset_classes($settings, $selector, $origins)
        {
        }
        /**
         * Function that scopes a selector with another one. This works a bit like
         * SCSS nesting except the `&` operator isn't supported.
         *
         * <code>
         * $scope = '.a, .b .c';
         * $selector = '> .x, .y';
         * $merged = scope_selector( $scope, $selector );
         * // $merged is '.a > .x, .a .y, .b .c > .x, .b .c .y'
         * </code>
         *
         * @since 5.9.0
         * @since 6.6.0 Added early return if missing scope or selector.
         *
         * @param string $scope    Selector to scope to.
         * @param string $selector Original selector.
         * @return string Scoped selector.
         */
        public static function scope_selector($scope, $selector)
        {
        }
        /**
         * Scopes the selectors for a given style node.
         *
         * This includes the primary selector, i.e. `$node['selector']`, as well as any custom
         * selectors for features and subfeatures, e.g. `$node['selectors']['border']` etc.
         *
         * @since 6.6.0
         *
         * @param string $scope Selector to scope to.
         * @param array  $node  Style node with selectors to scope.
         * @return array Node with updated selectors.
         */
        protected static function scope_style_node_selectors($scope, $node)
        {
        }
        /**
         * Gets preset values keyed by slugs based on settings and metadata.
         *
         * <code>
         * $settings = array(
         *     'typography' => array(
         *         'fontFamilies' => array(
         *             array(
         *                 'slug'       => 'sansSerif',
         *                 'fontFamily' => '"Helvetica Neue", sans-serif',
         *             ),
         *             array(
         *                 'slug'   => 'serif',
         *                 'colors' => 'Georgia, serif',
         *             )
         *         ),
         *     ),
         * );
         * $meta = array(
         *    'path'      => array( 'typography', 'fontFamilies' ),
         *    'value_key' => 'fontFamily',
         * );
         * $values_by_slug = get_settings_values_by_slug();
         * // $values_by_slug === array(
         * //   'sans-serif' => '"Helvetica Neue", sans-serif',
         * //   'serif'      => 'Georgia, serif',
         * // );
         * </code>
         *
         * @since 5.9.0
         * @since 6.6.0 Passing $settings to the callbacks defined in static::PRESETS_METADATA.
         *
         * @param array    $settings        Settings to process.
         * @param array    $preset_metadata One of the PRESETS_METADATA values.
         * @param string[] $origins         List of origins to process.
         * @return array Array of presets where each key is a slug and each value is the preset value.
         */
        protected static function get_settings_values_by_slug($settings, $preset_metadata, $origins)
        {
        }
        /**
         * Similar to get_settings_values_by_slug, but doesn't compute the value.
         *
         * @since 5.9.0
         *
         * @param array    $settings        Settings to process.
         * @param array    $preset_metadata One of the PRESETS_METADATA values.
         * @param string[] $origins         List of origins to process.
         * @return array Array of presets where the key and value are both the slug.
         */
        protected static function get_settings_slugs($settings, $preset_metadata, $origins = \null)
        {
        }
        /**
         * Transforms a slug into a CSS Custom Property.
         *
         * @since 5.9.0
         *
         * @param string $input String to replace.
         * @param string $slug  The slug value to use to generate the custom property.
         * @return string The CSS Custom Property. Something along the lines of `--wp--preset--color--black`.
         */
        protected static function replace_slug_in_string($input, $slug)
        {
        }
        /**
         * Given the block settings, extracts the CSS Custom Properties
         * for the presets and adds them to the $declarations array
         * following the format:
         *
         *     array(
         *       'name'  => 'property_name',
         *       'value' => 'property_value,
         *     )
         *
         * @since 5.8.0
         * @since 5.9.0 Added the `$origins` parameter.
         *
         * @param array    $settings Settings to process.
         * @param string[] $origins  List of origins to process.
         * @return array The modified $declarations.
         */
        protected static function compute_preset_vars($settings, $origins)
        {
        }
        /**
         * Given an array of settings, extracts the CSS Custom Properties
         * for the custom values and adds them to the $declarations
         * array following the format:
         *
         *     array(
         *       'name'  => 'property_name',
         *       'value' => 'property_value,
         *     )
         *
         * @since 5.8.0
         *
         * @param array $settings Settings to process.
         * @return array The modified $declarations.
         */
        protected static function compute_theme_vars($settings)
        {
        }
        /**
         * Given a tree, it creates a flattened one
         * by merging the keys and binding the leaf values
         * to the new keys.
         *
         * It also transforms camelCase names into kebab-case
         * and substitutes '/' by '-'.
         *
         * This is thought to be useful to generate
         * CSS Custom Properties from a tree,
         * although there's nothing in the implementation
         * of this function that requires that format.
         *
         * For example, assuming the given prefix is '--wp'
         * and the token is '--', for this input tree:
         *
         *     {
         *       'some/property': 'value',
         *       'nestedProperty': {
         *         'sub-property': 'value'
         *       }
         *     }
         *
         * it'll return this output:
         *
         *     {
         *       '--wp--some-property': 'value',
         *       '--wp--nested-property--sub-property': 'value'
         *     }
         *
         * @since 5.8.0
         *
         * @param array  $tree   Input tree to process.
         * @param string $prefix Optional. Prefix to prepend to each variable. Default empty string.
         * @param string $token  Optional. Token to use between levels. Default '--'.
         * @return array The flattened tree.
         */
        protected static function flatten_tree($tree, $prefix = '', $token = '--')
        {
        }
        /**
         * Given a styles array, it extracts the style properties
         * and adds them to the $declarations array following the format:
         *
         *     array(
         *       'name'  => 'property_name',
         *       'value' => 'property_value',
         *     )
         *
         * @since 5.8.0
         * @since 5.9.0 Added the `$settings` and `$properties` parameters.
         * @since 6.1.0 Added `$theme_json`, `$selector`, and `$use_root_padding` parameters.
         * @since 6.5.0 Output a `min-height: unset` rule when `aspect-ratio` is set.
         * @since 6.6.0 Pass current theme JSON settings to wp_get_typography_font_size_value(), and process background properties.
         * @since 6.7.0 `ref` resolution of background properties, and assigning custom default values.
         *
         * @param array   $styles Styles to process.
         * @param array   $settings Theme settings.
         * @param array   $properties Properties metadata.
         * @param array   $theme_json Theme JSON array.
         * @param string  $selector The style block selector.
         * @param boolean $use_root_padding Whether to add custom properties at root level.
         * @return array  Returns the modified $declarations.
         */
        protected static function compute_style_properties($styles, $settings = array(), $properties = \null, $theme_json = \null, $selector = \null, $use_root_padding = \null)
        {
        }
        /**
         * Returns the style property for the given path.
         *
         * It also converts references to a path to the value
         * stored at that location, e.g.
         * { "ref": "style.color.background" } => "#fff".
         *
         * @since 5.8.0
         * @since 5.9.0 Added support for values of array type, which are returned as is.
         * @since 6.1.0 Added the `$theme_json` parameter.
         * @since 6.3.0 It no longer converts the internal format "var:preset|color|secondary"
         *              to the standard form "--wp--preset--color--secondary".
         *              This is already done by the sanitize method,
         *              so every property will be in the standard form.
         * @since 6.7.0 Added support for background image refs.
         *
         * @param array $styles Styles subtree.
         * @param array $path   Which property to process.
         * @param array $theme_json Theme JSON array.
         * @return string|array Style property value.
         */
        protected static function get_property_value($styles, $path, $theme_json = \null)
        {
        }
        /**
         * Builds metadata for the setting nodes, which returns in the form of:
         *
         *     [
         *       [
         *         'path'     => ['path', 'to', 'some', 'node' ],
         *         'selector' => 'CSS selector for some node'
         *       ],
         *       [
         *         'path'     => [ 'path', 'to', 'other', 'node' ],
         *         'selector' => 'CSS selector for other node'
         *       ],
         *     ]
         *
         * @since 5.8.0
         *
         * @param array $theme_json The tree to extract setting nodes from.
         * @param array $selectors  List of selectors per block.
         * @return array An array of setting nodes metadata.
         */
        protected static function get_setting_nodes($theme_json, $selectors = array())
        {
        }
        /**
         * Builds metadata for the style nodes, which returns in the form of:
         *
         *     [
         *       [
         *         'path'     => [ 'path', 'to', 'some', 'node' ],
         *         'selector' => 'CSS selector for some node',
         *         'duotone'  => 'CSS selector for duotone for some node'
         *       ],
         *       [
         *         'path'     => ['path', 'to', 'other', 'node' ],
         *         'selector' => 'CSS selector for other node',
         *         'duotone'  => null
         *       ],
         *     ]
         *
         * @since 5.8.0
         * @since 6.6.0 Added options array for modifying generated nodes.
         *
         * @param array $theme_json The tree to extract style nodes from.
         * @param array $selectors  List of selectors per block.
         * @param array $options {
         *     Optional. An array of options for now used for internal purposes only (may change without notice).
         *
         *     @type bool $include_block_style_variations Includes style nodes for block style variations. Default false.
         * }
         * @return array An array of style nodes metadata.
         * @phpstan-param array{
         *   include_block_style_variations?: bool,
         * } $options
         */
        protected static function get_style_nodes($theme_json, $selectors = array(), $options = array())
        {
        }
        /**
         * A public helper to get the block nodes from a theme.json file.
         *
         * @since 6.1.0
         *
         * @return array The block nodes in theme.json.
         */
        public function get_styles_block_nodes()
        {
        }
        /**
         * Gets the CSS rules for a particular block from theme.json.
         *
         * @since 6.1.0
         * @since 6.6.0 Setting a min-height of HTML when root styles have a background gradient or image.
         *              Updated general global styles specificity to 0-1-0.
         *              Fixed custom CSS output in block style variations.
         *
         * @param array $block_metadata Metadata about the block to get styles for.
         *
         * @return string Styles for the block.
         */
        public function get_styles_for_block($block_metadata)
        {
        }
        /**
         * Outputs the CSS for layout rules on the root.
         *
         * @since 6.1.0
         * @since 6.6.0 Use `ROOT_CSS_PROPERTIES_SELECTOR` for CSS custom properties and improved consistency of root padding rules.
         *              Updated specificity of body margin reset and first/last child selectors.
         *
         * @param string $selector The root node selector.
         * @param array  $block_metadata The metadata for the root block.
         * @return string The additional root rules CSS.
         */
        public function get_root_layout_rules($selector, $block_metadata)
        {
        }
        /**
         * For metadata values that can either be booleans or paths to booleans, gets the value.
         *
         *     $data = array(
         *       'color' => array(
         *         'defaultPalette' => true
         *       )
         *     );
         *
         *     static::get_metadata_boolean( $data, false );
         *     // => false
         *
         *     static::get_metadata_boolean( $data, array( 'color', 'defaultPalette' ) );
         *     // => true
         *
         * @since 6.0.0
         *
         * @param array      $data          The data to inspect.
         * @param bool|array $path          Boolean or path to a boolean.
         * @param bool       $default_value Default value if the referenced path is missing.
         *                                  Default false.
         * @return bool Value of boolean metadata.
         */
        protected static function get_metadata_boolean($data, $path, $default_value = \false)
        {
        }
        /**
         * Merges new incoming data.
         *
         * @since 5.8.0
         * @since 5.9.0 Duotone preset also has origins.
         * @since 6.7.0 Replace background image objects during merge.
         *
         * @param WP_Theme_JSON $incoming Data to merge.
         */
        public function merge($incoming)
        {
        }
        /**
         * Converts all filter (duotone) presets into SVGs.
         *
         * @since 5.9.1
         *
         * @param array $origins List of origins to process.
         * @return string SVG filters.
         */
        public function get_svg_filters($origins)
        {
        }
        /**
         * Determines whether a presets should be overridden or not.
         *
         * @since 5.9.0
         * @deprecated 6.0.0 Use {@see 'get_metadata_boolean'} instead.
         *
         * @param array      $theme_json The theme.json like structure to inspect.
         * @param array      $path       Path to inspect.
         * @param bool|array $override   Data to compute whether to override the preset.
         * @return bool
         */
        protected static function should_override_preset($theme_json, $path, $override)
        {
        }
        /**
         * Returns the default slugs for all the presets in an associative array
         * whose keys are the preset paths and the leaves is the list of slugs.
         *
         * For example:
         *
         *     array(
         *       'color' => array(
         *         'palette'   => array( 'slug-1', 'slug-2' ),
         *         'gradients' => array( 'slug-3', 'slug-4' ),
         *       ),
         *     )
         *
         * @since 5.9.0
         *
         * @param array $data      A theme.json like structure.
         * @param array $node_path The path to inspect. It's 'settings' by default.
         * @return array
         */
        protected static function get_default_slugs($data, $node_path)
        {
        }
        /**
         * Gets a `default`'s preset name by a provided slug.
         *
         * @since 5.9.0
         *
         * @param string $slug The slug we want to find a match from default presets.
         * @param array  $base_path The path to inspect. It's 'settings' by default.
         * @return string|null
         */
        protected function get_name_from_defaults($slug, $base_path)
        {
        }
        /**
         * Removes the preset values whose slug is equal to any of given slugs.
         *
         * @since 5.9.0
         *
         * @param array $node  The node with the presets to validate.
         * @param array $slugs The slugs that should not be overridden.
         * @return array The new node.
         */
        protected static function filter_slugs($node, $slugs)
        {
        }
        /**
         * Removes insecure data from theme.json.
         *
         * @since 5.9.0
         * @since 6.3.2 Preserves global styles block variations when securing styles.
         * @since 6.6.0 Updated to allow variation element styles and $origin parameter.
         *
         * @param array  $theme_json Structure to sanitize.
         * @param string $origin    Optional. What source of data this object represents.
         *                          One of 'blocks', 'default', 'theme', or 'custom'. Default 'theme'.
         * @return array Sanitized structure.
         * @phpstan-param 'blocks'|'default'|'theme'|'custom' $origin
         */
        public static function remove_insecure_properties($theme_json, $origin = 'theme')
        {
        }
        /**
         * Processes a setting node and returns the same node
         * without the insecure settings.
         *
         * @since 5.9.0
         *
         * @param array $input Node to process.
         * @return array
         */
        protected static function remove_insecure_settings($input)
        {
        }
        /**
         * Processes a style node and returns the same node
         * without the insecure styles.
         *
         * @since 5.9.0
         *
         * @param array $input Node to process.
         * @return array
         */
        protected static function remove_insecure_styles($input)
        {
        }
        /**
         * Checks that a declaration provided by the user is safe.
         *
         * @since 5.9.0
         *
         * @param string $property_name  Property name in a CSS declaration, i.e. the `color` in `color: red`.
         * @param string $property_value Value in a CSS declaration, i.e. the `red` in `color: red`.
         * @return bool
         */
        protected static function is_safe_css_declaration($property_name, $property_value)
        {
        }
        /**
         * Returns the raw data.
         *
         * @since 5.8.0
         *
         * @return array Raw data.
         */
        public function get_raw_data()
        {
        }
        /**
         * Transforms the given editor settings according the
         * add_theme_support format to the theme.json format.
         *
         * @since 5.8.0
         *
         * @param array $settings Existing editor settings.
         * @return array Config that adheres to the theme.json schema.
         */
        public static function get_from_editor_settings($settings)
        {
        }
        /**
         * Returns the current theme's wanted patterns(slugs) to be
         * registered from Pattern Directory.
         *
         * @since 6.0.0
         *
         * @return string[]
         */
        public function get_patterns()
        {
        }
        /**
         * Returns a valid theme.json as provided by a theme.
         *
         * Unlike get_raw_data() this returns the presets flattened, as provided by a theme.
         * This also uses appearanceTools instead of their opt-ins if all of them are true.
         *
         * @since 6.0.0
         *
         * @return array
         */
        public function get_data()
        {
        }
        /**
         * Sets the spacingSizes array based on the spacingScale values from theme.json.
         *
         * @since 6.1.0
         * @deprecated 6.6.0 No longer used as the spacingSizes are automatically
         *                   generated in the constructor and merge methods instead
         *                   of manually after instantiation.
         *
         * @return null|void
         */
        public function set_spacing_sizes()
        {
        }
        /**
         * Returns the selectors metadata for a block.
         *
         * @since 6.3.0
         *
         * @param object $block_type    The block type.
         * @param string $root_selector The block's root selector.
         *
         * @return array The custom selectors set by the block.
         */
        protected static function get_block_selectors($block_type, $root_selector)
        {
        }
        /**
         * Generates all the element selectors for a block.
         *
         * @since 6.3.0
         *
         * @param string $root_selector The block's root CSS selector.
         * @return array The block's element selectors.
         */
        protected static function get_block_element_selectors($root_selector)
        {
        }
        /**
         * Generates style declarations for a node's features e.g., color, border,
         * typography etc. that have custom selectors in their related block's
         * metadata.
         *
         * @since 6.3.0
         *
         * @param object $metadata The related block metadata containing selectors.
         * @param object $node     A merged theme.json node for block or variation.
         *
         * @return array The style declarations for the node's features with custom
         * selectors.
         */
        protected function get_feature_declarations_for_node($metadata, &$node)
        {
        }
        /**
         * Resolves the values of CSS variables in the given styles.
         *
         * @since 6.3.0
         * @param WP_Theme_JSON $theme_json The theme json resolver.
         *
         * @return WP_Theme_JSON The $theme_json with resolved variables.
         */
        public static function resolve_variables($theme_json)
        {
        }
        /**
         * Generates a selector for a block style variation.
         *
         * @since 6.5.0
         *
         * @param string $variation_name Name of the block style variation.
         * @param string $block_selector CSS selector for the block.
         * @return string Block selector with block style variation selector added to it.
         */
        protected static function get_block_style_variation_selector($variation_name, $block_selector)
        {
        }
        /**
         * Collects valid block style variations keyed by block type.
         *
         * @since 6.6.0
         *
         * @return array Valid block style variations by block type.
         */
        protected static function get_valid_block_style_variations()
        {
        }
    }
    /**
     * WP_Theme Class
     *
     * @package WordPress
     * @subpackage Theme
     * @since 3.4.0
     * @phpstan-type ThemeKey 'Name'|'Version'|'Status'|'Title'|'Author'|'Author Name'|'Author URI'|'Description'|'Template'|'Stylesheet'|'Template Files'|'Stylesheet Files'|'Template Dir'|'Stylesheet Dir'|'Screenshot'|'Tags'|'Theme Root'|'Theme Root URI'|'Parent Theme'
     * @phpstan-property-read string $name
     * @phpstan-property-read string $title
     * @phpstan-property-read string $version
     * @phpstan-property-read string $parent_theme
     * @phpstan-property-read string $template_dir
     * @phpstan-property-read string $stylesheet_dir
     * @phpstan-property-read string $template
     * @phpstan-property-read string $stylesheet
     * @phpstan-property-read string $screenshot
     * @phpstan-property-read string $description
     * @phpstan-property-read string $author
     * @phpstan-property-read list<string> $tags
     * @phpstan-property-read string $theme_root
     * @phpstan-property-read string $theme_root_uri
     */
    #[\AllowDynamicProperties]
    final class WP_Theme implements \ArrayAccess
    {
        /**
         * Whether the theme has been marked as updateable.
         *
         * @since 4.4.0
         * @var bool
         *
         * @see WP_MS_Themes_List_Table
         */
        public $update = \false;
        /**
         * Constructor for WP_Theme.
         *
         * @since 3.4.0
         *
         * @global array $wp_theme_directories
         *
         * @param string        $theme_dir  Directory of the theme within the theme_root.
         * @param string        $theme_root Theme root.
         * @param WP_Theme|null $_child If this theme is a parent theme, the child may be passed for validation purposes.
         * @phpstan-return void
         */
        public function __construct($theme_dir, $theme_root, $_child = \null)
        {
        }
        /**
         * When converting the object to a string, the theme name is returned.
         *
         * @since 3.4.0
         *
         * @return string Theme name, ready for display (translated)
         */
        public function __toString()
        {
        }
        /**
         * __isset() magic method for properties formerly returned by current_theme_info()
         *
         * @since 3.4.0
         *
         * @param string $offset Property to check if set.
         * @return bool Whether the given property is set.
         */
        public function __isset($offset)
        {
        }
        /**
         * __get() magic method for properties formerly returned by current_theme_info()
         *
         * @since 3.4.0
         *
         * @param string $offset Property to get.
         * @return mixed Property value.
         */
        public function __get($offset)
        {
        }
        /**
         * Method to implement ArrayAccess for keys formerly returned by get_themes()
         *
         * @since 3.4.0
         *
         * @param mixed $offset
         * @param mixed $value
         */
        #[\ReturnTypeWillChange]
        public function offsetSet($offset, $value)
        {
        }
        /**
         * Method to implement ArrayAccess for keys formerly returned by get_themes()
         *
         * @since 3.4.0
         *
         * @param mixed $offset
         */
        #[\ReturnTypeWillChange]
        public function offsetUnset($offset)
        {
        }
        /**
         * Method to implement ArrayAccess for keys formerly returned by get_themes()
         *
         * @since 3.4.0
         *
         * @param mixed $offset
         * @return bool
         * @phpstan-return ($offset is ThemeKey ? true : false)
         */
        #[\ReturnTypeWillChange]
        public function offsetExists($offset)
        {
        }
        /**
         * Method to implement ArrayAccess for keys formerly returned by get_themes().
         *
         * Author, Author Name, Author URI, and Description did not previously return
         * translated data. We are doing so now as it is safe to do. However, as
         * Name and Title could have been used as the key for get_themes(), both remain
         * untranslated for back compatibility. This means that ['Name'] is not ideal,
         * and care should be taken to use `$theme::display( 'Name' )` to get a properly
         * translated header.
         *
         * @since 3.4.0
         *
         * @param mixed $offset
         * @return mixed
         * @phpstan-return ($offset is ThemeKey ? mixed : null)
         */
        #[\ReturnTypeWillChange]
        public function offsetGet($offset)
        {
        }
        /**
         * Returns errors property.
         *
         * @since 3.4.0
         *
         * @return WP_Error|false WP_Error if there are errors, or false.
         */
        public function errors()
        {
        }
        /**
         * Determines whether the theme exists.
         *
         * A theme with errors exists. A theme with the error of 'theme_not_found',
         * meaning that the theme's directory was not found, does not exist.
         *
         * @since 3.4.0
         *
         * @return bool Whether the theme exists.
         */
        public function exists()
        {
        }
        /**
         * Returns reference to the parent theme.
         *
         * @since 3.4.0
         *
         * @return WP_Theme|false Parent theme, or false if the active theme is not a child theme.
         */
        public function parent()
        {
        }
        /**
         * Perform reinitialization tasks.
         *
         * Prevents a callback from being injected during unserialization of an object.
         */
        public function __wakeup()
        {
        }
        /**
         * Clears the cache for the theme.
         *
         * @since 3.4.0
         */
        public function cache_delete()
        {
        }
        /**
         * Gets a raw, unformatted theme header.
         *
         * The header is sanitized, but is not translated, and is not marked up for display.
         * To get a theme header for display, use the display() method.
         *
         * Use the get_template() method, not the 'Template' header, for finding the template.
         * The 'Template' header is only good for what was written in the style.css, while
         * get_template() takes into account where WordPress actually located the theme and
         * whether it is actually valid.
         *
         * @since 3.4.0
         *
         * @param string $header Theme header. Name, Description, Author, Version, ThemeURI, AuthorURI, Status, Tags.
         * @return string|array|false String or array (for Tags header) on success, false on failure.
         * @phpstan-return ($header is 'Name'|'ThemeURI'|'Description'|'Author'|'AuthorURI'|'Version'|'Template'|'Status'|'Tags'|'TextDomain'|'DomainPath'|'RequiresWP'|'RequiresPHP'|'UpdateURI' ? ($header is 'Tags' ? string[] : string) : false)
         */
        public function get($header)
        {
        }
        /**
         * Gets a theme header, formatted and translated for display.
         *
         * @since 3.4.0
         *
         * @param string $header    Theme header. Name, Description, Author, Version, ThemeURI, AuthorURI, Status, Tags.
         * @param bool   $markup    Optional. Whether to mark up the header. Defaults to true.
         * @param bool   $translate Optional. Whether to translate the header. Defaults to true.
         * @return string|array|false Processed header. An array for Tags if `$markup` is false, string otherwise.
         *                            False on failure.
         */
        public function display($header, $markup = \true, $translate = \true)
        {
        }
        /**
         * Returns the directory name of the theme's "stylesheet" files, inside the theme root.
         *
         * In the case of a child theme, this is directory name of the child theme.
         * Otherwise, get_stylesheet() is the same as get_template().
         *
         * @since 3.4.0
         *
         * @return string Stylesheet
         */
        public function get_stylesheet()
        {
        }
        /**
         * Returns the directory name of the theme's "template" files, inside the theme root.
         *
         * In the case of a child theme, this is the directory name of the parent theme.
         * Otherwise, the get_template() is the same as get_stylesheet().
         *
         * @since 3.4.0
         *
         * @return string Template
         */
        public function get_template()
        {
        }
        /**
         * Returns the absolute path to the directory of a theme's "stylesheet" files.
         *
         * In the case of a child theme, this is the absolute path to the directory
         * of the child theme's files.
         *
         * @since 3.4.0
         *
         * @return string Absolute path of the stylesheet directory.
         */
        public function get_stylesheet_directory()
        {
        }
        /**
         * Returns the absolute path to the directory of a theme's "template" files.
         *
         * In the case of a child theme, this is the absolute path to the directory
         * of the parent theme's files.
         *
         * @since 3.4.0
         *
         * @return string Absolute path of the template directory.
         */
        public function get_template_directory()
        {
        }
        /**
         * Returns the URL to the directory of a theme's "stylesheet" files.
         *
         * In the case of a child theme, this is the URL to the directory of the
         * child theme's files.
         *
         * @since 3.4.0
         *
         * @return string URL to the stylesheet directory.
         */
        public function get_stylesheet_directory_uri()
        {
        }
        /**
         * Returns the URL to the directory of a theme's "template" files.
         *
         * In the case of a child theme, this is the URL to the directory of the
         * parent theme's files.
         *
         * @since 3.4.0
         *
         * @return string URL to the template directory.
         */
        public function get_template_directory_uri()
        {
        }
        /**
         * Returns the absolute path to the directory of the theme root.
         *
         * This is typically the absolute path to wp-content/themes.
         *
         * @since 3.4.0
         *
         * @return string Theme root.
         */
        public function get_theme_root()
        {
        }
        /**
         * Returns the URL to the directory of the theme root.
         *
         * This is typically the absolute URL to wp-content/themes. This forms the basis
         * for all other URLs returned by WP_Theme, so we pass it to the public function
         * get_theme_root_uri() and allow it to run the {@see 'theme_root_uri'} filter.
         *
         * @since 3.4.0
         *
         * @return string Theme root URI.
         */
        public function get_theme_root_uri()
        {
        }
        /**
         * Returns the main screenshot file for the theme.
         *
         * The main screenshot is called screenshot.png. gif and jpg extensions are also allowed.
         *
         * Screenshots for a theme must be in the stylesheet directory. (In the case of child
         * themes, parent theme screenshots are not inherited.)
         *
         * @since 3.4.0
         *
         * @param string $uri Type of URL to return, either 'relative' or an absolute URI. Defaults to absolute URI.
         * @return string|false Screenshot file. False if the theme does not have a screenshot.
         */
        public function get_screenshot($uri = 'uri')
        {
        }
        /**
         * Returns files in the theme's directory.
         *
         * @since 3.4.0
         *
         * @param string[]|string $type          Optional. Array of extensions to find, string of a single extension,
         *                                       or null for all extensions. Default null.
         * @param int             $depth         Optional. How deep to search for files. Defaults to a flat scan (0 depth).
         *                                       -1 depth is infinite.
         * @param bool            $search_parent Optional. Whether to return parent files. Default false.
         * @return string[] Array of files, keyed by the path to the file relative to the theme's directory, with the values
         *                  being absolute paths.
         */
        public function get_files($type = \null, $depth = 0, $search_parent = \false)
        {
        }
        /**
         * Returns the theme's post templates.
         *
         * @since 4.7.0
         * @since 5.8.0 Include block templates.
         *
         * @return array[] Array of page template arrays, keyed by post type and filename,
         *                 with the value of the translated header name.
         */
        public function get_post_templates()
        {
        }
        /**
         * Returns the theme's post templates for a given post type.
         *
         * @since 3.4.0
         * @since 4.7.0 Added the `$post_type` parameter.
         *
         * @param WP_Post|null $post      Optional. The post being edited, provided for context.
         * @param string       $post_type Optional. Post type to get the templates for. Default 'page'.
         *                                If a post is provided, its post type is used.
         * @return string[] Array of template header names keyed by the template file name.
         */
        public function get_page_templates($post = \null, $post_type = 'page')
        {
        }
        /**
         * Loads the theme's textdomain.
         *
         * Translation files are not inherited from the parent theme. TODO: If this fails for the
         * child theme, it should probably try to load the parent theme's translations.
         *
         * @since 3.4.0
         *
         * @return bool True if the textdomain was successfully loaded or has already been loaded.
         *  False if no textdomain was specified in the file headers, or if the domain could not be loaded.
         */
        public function load_textdomain()
        {
        }
        /**
         * Determines whether the theme is allowed (multisite only).
         *
         * @since 3.4.0
         *
         * @param string $check   Optional. Whether to check only the 'network'-wide settings, the 'site'
         *                        settings, or 'both'. Defaults to 'both'.
         * @param int    $blog_id Optional. Ignored if only network-wide settings are checked. Defaults to current site.
         * @return bool Whether the theme is allowed for the network. Returns true in single-site.
         */
        public function is_allowed($check = 'both', $blog_id = \null)
        {
        }
        /**
         * Returns whether this theme is a block-based theme or not.
         *
         * @since 5.9.0
         *
         * @return bool
         */
        public function is_block_theme()
        {
        }
        /**
         * Retrieves the path of a file in the theme.
         *
         * Searches in the stylesheet directory before the template directory so themes
         * which inherit from a parent theme can just override one file.
         *
         * @since 5.9.0
         *
         * @param string $file Optional. File to search for in the stylesheet directory.
         * @return string The path of the file.
         */
        public function get_file_path($file = '')
        {
        }
        /**
         * Determines the latest WordPress default theme that is installed.
         *
         * This hits the filesystem.
         *
         * @since 4.4.0
         *
         * @return WP_Theme|false Object, or false if no theme is installed, which would be bad.
         */
        public static function get_core_default_theme()
        {
        }
        /**
         * Returns array of stylesheet names of themes allowed on the site or network.
         *
         * @since 3.4.0
         *
         * @param int $blog_id Optional. ID of the site. Defaults to the current site.
         * @return string[] Array of stylesheet names.
         */
        public static function get_allowed($blog_id = \null)
        {
        }
        /**
         * Returns array of stylesheet names of themes allowed on the network.
         *
         * @since 3.4.0
         *
         * @return string[] Array of stylesheet names.
         */
        public static function get_allowed_on_network()
        {
        }
        /**
         * Returns array of stylesheet names of themes allowed on the site.
         *
         * @since 3.4.0
         *
         * @param int $blog_id Optional. ID of the site. Defaults to the current site.
         * @return string[] Array of stylesheet names.
         */
        public static function get_allowed_on_site($blog_id = \null)
        {
        }
        /**
         * Returns the folder names of the block template directories.
         *
         * @since 6.4.0
         *
         * @return string[] {
         *     Folder names used by block themes.
         *
         *     @type string $wp_template      Theme-relative directory name for block templates.
         *     @type string $wp_template_part Theme-relative directory name for block template parts.
         * }
         * @phpstan-return array{
         *   wp_template: string,
         *   wp_template_part: string,
         * }
         */
        public function get_block_template_folders()
        {
        }
        /**
         * Gets block pattern data for a specified theme.
         * Each pattern is defined as a PHP file and defines
         * its metadata using plugin-style headers. The minimum required definition is:
         *
         *     /**
         *      * Title: My Pattern
         *      * Slug: my-theme/my-pattern
         *      *
         *
         * The output of the PHP source corresponds to the content of the pattern, e.g.:
         *
         *     <main><p><?php echo "Hello"; ?></p></main>
         *
         * If applicable, this will collect from both parent and child theme.
         *
         * Other settable fields include:
         *
         *     - Description
         *     - Viewport Width
         *     - Inserter         (yes/no)
         *     - Categories       (comma-separated values)
         *     - Keywords         (comma-separated values)
         *     - Block Types      (comma-separated values)
         *     - Post Types       (comma-separated values)
         *     - Template Types   (comma-separated values)
         *
         * @since 6.4.0
         *
         * @return array Block pattern data.
         */
        public function get_block_patterns()
        {
        }
        /**
         * Clears block pattern cache.
         *
         * @since 6.4.0
         * @since 6.6.0 Uses transients to cache regardless of site environment.
         */
        public function delete_pattern_cache()
        {
        }
        /**
         * Enables a theme for all sites on the current network.
         *
         * @since 4.6.0
         *
         * @param string|string[] $stylesheets Stylesheet name or array of stylesheet names.
         * @phpstan-return void
         */
        public static function network_enable_theme($stylesheets)
        {
        }
        /**
         * Disables a theme for all sites on the current network.
         *
         * @since 4.6.0
         *
         * @param string|string[] $stylesheets Stylesheet name or array of stylesheet names.
         * @phpstan-return void
         */
        public static function network_disable_theme($stylesheets)
        {
        }
        /**
         * Sorts themes by name.
         *
         * @since 3.4.0
         *
         * @param WP_Theme[] $themes Array of theme objects to sort (passed by reference).
         */
        public static function sort_by_name(&$themes)
        {
        }
    }
    /**
     * WP_Token_Map class.
     *
     * Use this class in specific circumstances with a static set of lookup keys which map to
     * a static set of transformed values. For example, this class is used to map HTML named
     * character references to their equivalent UTF-8 values.
     *
     * This class works differently than code calling `in_array()` and other methods. It
     * internalizes lookup logic and provides helper interfaces to optimize lookup and
     * transformation. It provides a method for precomputing the lookup tables and storing
     * them as PHP source code.
     *
     * All tokens and substitutions must be shorter than 256 bytes.
     *
     * Example:
     *
     *     $smilies = WP_Token_Map::from_array( array(
     *         '8O' => '😯',
     *         ':(' => '🙁',
     *         ':)' => '🙂',
     *         ':?' => '😕',
     *      ) );
     *
     *      true  === $smilies->contains( ':)' );
     *      false === $smilies->contains( 'simile' );
     *
     *      '😕' === $smilies->read_token( 'Not sure :?.', 9, $length_of_smily_syntax );
     *      2    === $length_of_smily_syntax;
     *
     * ## Precomputing the Token Map.
     *
     * Creating the class involves some work sorting and organizing the tokens and their
     * replacement values. In order to skip this, it's possible for the class to export
     * its state and be used as actual PHP source code.
     *
     * Example:
     *
     *      // Export with four spaces as the indent, only for the sake of this docblock.
     *      // The default indent is a tab character.
     *      $indent = '    ';
     *      echo $smilies->precomputed_php_source_table( $indent );
     *
     *      // Output, to be pasted into a PHP source file:
     *      WP_Token_Map::from_precomputed_table(
     *          array(
     *              "storage_version" => "6.6.0",
     *              "key_length" => 2,
     *              "groups" => "",
     *              "long_words" => array(),
     *              "small_words" => "8O\x00:)\x00:(\x00:?\x00",
     *              "small_mappings" => array( "😯", "🙂", "🙁", "😕" )
     *          )
     *      );
     *
     * ## Large vs. small words.
     *
     * This class uses a short prefix called the "key" to optimize lookup of its tokens.
     * This means that some tokens may be shorter than or equal in length to that key.
     * Those words that are longer than the key are called "large" while those shorter
     * than or equal to the key length are called "small."
     *
     * This separation of large and small words is incidental to the way this class
     * optimizes lookup, and should be considered an internal implementation detail
     * of the class. It may still be important to be aware of it, however.
     *
     * ## Determining Key Length.
     *
     * The choice of the size of the key length should be based on the data being stored in
     * the token map. It should divide the data as evenly as possible, but should not create
     * so many groups that a large fraction of the groups only contain a single token.
     *
     * For the HTML5 named character references, a key length of 2 was found to provide a
     * sufficient spread and should be a good default for relatively large sets of tokens.
     *
     * However, for some data sets this might be too long. For example, a list of smilies
     * may be too small for a key length of 2. Perhaps 1 would be more appropriate. It's
     * best to experiment and determine empirically which values are appropriate.
     *
     * ## Generate Pre-Computed Source Code.
     *
     * Since the `WP_Token_Map` is designed for relatively static lookups, it can be
     * advantageous to precompute the values and instantiate a table that has already
     * sorted and grouped the tokens and built the lookup strings.
     *
     * This can be done with `WP_Token_Map::precomputed_php_source_table()`.
     *
     * Note that if there is a leading character that all tokens need, such as `&` for
     * HTML named character references, it can be beneficial to exclude this from the
     * token map. Instead, find occurrences of the leading character and then use the
     * token map to see if the following characters complete the token.
     *
     * Example:
     *
     *     $map = WP_Token_Map::from_array( array( 'simple_smile:' => '🙂', 'sob:' => '😭', 'soba:' => '🍜' ) );
     *     echo $map->precomputed_php_source_table();
     *     // Output
     *     WP_Token_Map::from_precomputed_table(
     *         array(
     *             "storage_version" => "6.6.0",
     *             "key_length" => 2,
     *             "groups" => "si\x00so\x00",
     *             "long_words" => array(
     *                 // simple_smile:[🙂].
     *                 "\x0bmple_smile:\x04🙂",
     *                 // soba:[🍜] sob:[😭].
     *                 "\x03ba:\x04🍜\x02b:\x04😭",
     *             ),
     *             "short_words" => "",
     *             "short_mappings" => array()
     *         }
     *     );
     *
     * This precomputed value can be stored directly in source code and will skip the
     * startup cost of generating the lookup strings. See `$html5_named_character_entities`.
     *
     * Note that any updates to the precomputed format should update the storage version
     * constant. It would also be best to provide an update function to take older known
     * versions and upgrade them in place when loading into `from_precomputed_table()`.
     *
     * ## Future Direction.
     *
     * It may be viable to dynamically increase the length limits such that there's no need to impose them.
     * The limit appears because of the packing structure, which indicates how many bytes each segment of
     * text in the lookup tables spans. If, however, care were taken to track the longest word length, then
     * the packing structure could change its representation to allow for that. Each additional byte storing
     * length, however, increases the memory overhead and lookup runtime.
     *
     * An alternative approach could be to borrow the UTF-8 variable-length encoding and store lengths of less
     * than 127 as a single byte with the high bit unset, storing longer lengths as the combination of
     * continuation bytes.
     *
     * Since it has not been shown during the development of this class that longer strings are required, this
     * update is deferred until such a need is clear.
     *
     * @since 6.6.0
     */
    class WP_Token_Map
    {
        /**
         * Denotes the version of the code which produces pre-computed source tables.
         *
         * This version will be used not only to verify pre-computed data, but also
         * to upgrade pre-computed data from older versions. Choosing a name that
         * corresponds to the WordPress release will help people identify where an
         * old copy of data came from.
         */
        const STORAGE_VERSION = '6.6.0-trunk';
        /**
         * Maximum length for each key and each transformed value in the table (in bytes).
         *
         * @since 6.6.0
         */
        const MAX_LENGTH = 256;
        /**
         * Create a token map using an associative array of key/value pairs as the input.
         *
         * Example:
         *
         *     $smilies = WP_Token_Map::from_array( array(
         *          '8O' => '😯',
         *          ':(' => '🙁',
         *          ':)' => '🙂',
         *          ':?' => '😕',
         *       ) );
         *
         * @since 6.6.0
         *
         * @param array $mappings   The keys transform into the values, both are strings.
         * @param int   $key_length Determines the group key length. Leave at the default value
         *                          of 2 unless there's an empirical reason to change it.
         *
         * @return WP_Token_Map|null Token map, unless unable to create it.
         */
        public static function from_array(array $mappings, int $key_length = 2) : ?\WP_Token_Map
        {
        }
        /**
         * Creates a token map from a pre-computed table.
         * This skips the initialization cost of generating the table.
         *
         * This function should only be used to load data created with
         * WP_Token_Map::precomputed_php_source_tag().
         *
         * @since 6.6.0
         *
         * @param array $state {
         *     Stores pre-computed state for directly loading into a Token Map.
         *
         *     @type string $storage_version Which version of the code produced this state.
         *     @type int    $key_length      Group key length.
         *     @type string $groups          Group lookup index.
         *     @type array  $large_words     Large word groups and packed strings.
         *     @type string $small_words     Small words packed string.
         *     @type array  $small_mappings  Small word mappings.
         * }
         *
         * @return WP_Token_Map Map with precomputed data loaded.
         * @phpstan-param array{
         *   storage_version?: string,
         *   key_length?: int,
         *   groups?: string,
         *   large_words?: array,
         *   small_words?: string,
         *   small_mappings?: array,
         * } $state
         */
        public static function from_precomputed_table($state) : ?\WP_Token_Map
        {
        }
        /**
         * Indicates if a given word is a lookup key in the map.
         *
         * Example:
         *
         *     true  === $smilies->contains( ':)' );
         *     false === $smilies->contains( 'simile' );
         *
         * @since 6.6.0
         *
         * @param string $word             Determine if this word is a lookup key in the map.
         * @param string $case_sensitivity Optional. Pass 'ascii-case-insensitive' to ignore ASCII case when matching. Default 'case-sensitive'.
         * @return bool Whether there's an entry for the given word in the map.
         */
        public function contains(string $word, string $case_sensitivity = 'case-sensitive') : bool
        {
        }
        /**
         * If the text starting at a given offset is a lookup key in the map,
         * return the corresponding transformation from the map, else `false`.
         *
         * This function returns the translated string, but accepts an optional
         * parameter `$matched_token_byte_length`, which communicates how many
         * bytes long the lookup key was, if it found one. This can be used to
         * advance a cursor in calling code if a lookup key was found.
         *
         * Example:
         *
         *     false === $smilies->read_token( 'Not sure :?.', 0, $token_byte_length );
         *     '😕'  === $smilies->read_token( 'Not sure :?.', 9, $token_byte_length );
         *     2     === $token_byte_length;
         *
         * Example:
         *
         *     while ( $at < strlen( $input ) ) {
         *         $next_at = strpos( $input, ':', $at );
         *         if ( false === $next_at ) {
         *             break;
         *         }
         *
         *         $smily = $smilies->read_token( $input, $next_at, $token_byte_length );
         *         if ( false === $next_at ) {
         *             ++$at;
         *             continue;
         *         }
         *
         *         $prefix  = substr( $input, $at, $next_at - $at );
         *         $at     += $token_byte_length;
         *         $output .= "{$prefix}{$smily}";
         *     }
         *
         * @since 6.6.0
         *
         * @param string   $text                       String in which to search for a lookup key.
         * @param int      $offset                     Optional. How many bytes into the string where the lookup key ought to start. Default 0.
         * @param int|null &$matched_token_byte_length Optional. Holds byte-length of found token matched, otherwise not set. Default null.
         * @param string   $case_sensitivity           Optional. Pass 'ascii-case-insensitive' to ignore ASCII case when matching. Default 'case-sensitive'.
         *
         * @return string|null Mapped value of lookup key if found, otherwise `null`.
         */
        public function read_token(string $text, int $offset = 0, &$matched_token_byte_length = \null, $case_sensitivity = 'case-sensitive') : ?string
        {
        }
        /**
         * Exports the token map into an associate array of key/value pairs.
         *
         * Example:
         *
         *     $smilies->to_array() === array(
         *         '8O' => '😯',
         *         ':(' => '🙁',
         *         ':)' => '🙂',
         *         ':?' => '😕',
         *     );
         *
         * @return array The lookup key/substitution values as an associate array.
         */
        public function to_array() : array
        {
        }
        /**
         * Export the token map for quick loading in PHP source code.
         *
         * This function has a specific purpose, to make loading of static token maps fast.
         * It's used to ensure that the HTML character reference lookups add a minimal cost
         * to initializing the PHP process.
         *
         * Example:
         *
         *     echo $smilies->precomputed_php_source_table();
         *
         *     // Output.
         *     WP_Token_Map::from_precomputed_table(
         *         array(
         *             "storage_version" => "6.6.0",
         *             "key_length" => 2,
         *             "groups" => "",
         *             "long_words" => array(),
         *             "small_words" => "8O\x00:)\x00:(\x00:?\x00",
         *             "small_mappings" => array( "😯", "🙂", "🙁", "😕" )
         *         )
         *     );
         *
         * @since 6.6.0
         *
         * @param string $indent Optional. Use this string for indentation, or rely on the default horizontal tab character. Default "\t".
         * @return string Value which can be pasted into a PHP source file for quick loading of table.
         */
        public function precomputed_php_source_table(string $indent = "\t") : string
        {
        }
    }
    /**
     * Meta-based user sessions token manager.
     *
     * @since 4.0.0
     *
     * @see WP_Session_Tokens
     */
    class WP_User_Meta_Session_Tokens extends \WP_Session_Tokens
    {
        /**
         * Retrieves all sessions of the user.
         *
         * @since 4.0.0
         *
         * @return array Sessions of the user.
         */
        protected function get_sessions()
        {
        }
        /**
         * Converts an expiration to an array of session information.
         *
         * @param mixed $session Session or expiration.
         * @return array Session.
         */
        protected function prepare_session($session)
        {
        }
        /**
         * Retrieves a session based on its verifier (token hash).
         *
         * @since 4.0.0
         *
         * @param string $verifier Verifier for the session to retrieve.
         * @return array|null The session, or null if it does not exist
         */
        protected function get_session($verifier)
        {
        }
        /**
         * Updates a session based on its verifier (token hash).
         *
         * @since 4.0.0
         *
         * @param string $verifier Verifier for the session to update.
         * @param array  $session  Optional. Session. Omitting this argument destroys the session.
         */
        protected function update_session($verifier, $session = \null)
        {
        }
        /**
         * Updates the user's sessions in the usermeta table.
         *
         * @since 4.0.0
         *
         * @param array $sessions Sessions.
         */
        protected function update_sessions($sessions)
        {
        }
        /**
         * Destroys all sessions for this user, except the single session with the given verifier.
         *
         * @since 4.0.0
         *
         * @param string $verifier Verifier of the session to keep.
         */
        protected function destroy_other_sessions($verifier)
        {
        }
        /**
         * Destroys all session tokens for the user.
         *
         * @since 4.0.0
         */
        protected function destroy_all_sessions()
        {
        }
        /**
         * Destroys all sessions for all users.
         *
         * @since 4.0.0
         */
        public static function drop_sessions()
        {
        }
    }
    /**
     * Core class used for querying users.
     *
     * @since 3.1.0
     *
     * @see WP_User_Query::prepare_query() for information on accepted arguments.
     */
    #[\AllowDynamicProperties]
    class WP_User_Query
    {
        /**
         * Query vars, after parsing
         *
         * @since 3.5.0
         * @var array
         */
        public $query_vars = array();
        /**
         * Metadata query container.
         *
         * @since 4.2.0
         * @var WP_Meta_Query
         */
        public $meta_query = \false;
        /**
         * The SQL query used to fetch matching users.
         *
         * @since 4.4.0
         * @var string
         */
        public $request;
        public $query_fields;
        public $query_from;
        public $query_where;
        public $query_orderby;
        public $query_limit;
        /**
         * Constructor.
         *
         * @since 3.1.0
         *
         * @param null|string|array $query Optional. The query variables.
         *                                 See WP_User_Query::prepare_query() for information on accepted arguments.
         * @phpstan-param array{
         *   blog_id?: int,
         *   role?: string|string[],
         *   role__in?: string[],
         *   role__not_in?: string[],
         *   meta_key?: string|string[],
         *   meta_value?: string|string[],
         *   meta_compare?: string,
         *   meta_compare_key?: string,
         *   meta_type?: string,
         *   meta_type_key?: string,
         *   meta_query?: array,
         *   capability?: string|string[],
         *   capability__in?: string[],
         *   capability__not_in?: string[],
         *   include?: int[],
         *   exclude?: int[],
         *   search?: string,
         *   search_columns?: string[],
         *   orderby?: string|array,
         *   order?: string,
         *   offset?: int,
         *   number?: int,
         *   paged?: int,
         *   count_total?: bool,
         *   fields?: string|string[],
         *   who?: string,
         *   has_published_posts?: bool|string[],
         *   nicename?: string,
         *   nicename__in?: string[],
         *   nicename__not_in?: string[],
         *   login?: string,
         *   login__in?: string[],
         *   login__not_in?: string[],
         *   cache_results?: bool,
         * } $query See WP_User_Query::prepare_query()
         */
        public function __construct($query = \null)
        {
        }
        /**
         * Fills in missing query variables with default values.
         *
         * @since 4.4.0
         *
         * @param string|array $args Query vars, as passed to `WP_User_Query`.
         * @return array Complete query variables with undefined ones filled in with defaults.
         */
        public static function fill_query_vars($args)
        {
        }
        /**
         * Prepares the query variables.
         *
         * @since 3.1.0
         * @since 4.1.0 Added the ability to order by the `include` value.
         * @since 4.2.0 Added 'meta_value_num' support for `$orderby` parameter. Added multi-dimensional array syntax
         *              for `$orderby` parameter.
         * @since 4.3.0 Added 'has_published_posts' parameter.
         * @since 4.4.0 Added 'paged', 'role__in', and 'role__not_in' parameters. The 'role' parameter was updated to
         *              permit an array or comma-separated list of values. The 'number' parameter was updated to support
         *              querying for all users with using -1.
         * @since 4.7.0 Added 'nicename', 'nicename__in', 'nicename__not_in', 'login', 'login__in',
         *              and 'login__not_in' parameters.
         * @since 5.1.0 Introduced the 'meta_compare_key' parameter.
         * @since 5.3.0 Introduced the 'meta_type_key' parameter.
         * @since 5.9.0 Added 'capability', 'capability__in', and 'capability__not_in' parameters.
         *              Deprecated the 'who' parameter.
         * @since 6.3.0 Added 'cache_results' parameter.
         *
         * @global wpdb     $wpdb     WordPress database abstraction object.
         * @global WP_Roles $wp_roles WordPress role management object.
         *
         * @param string|array $query {
         *     Optional. Array or string of query parameters.
         *
         *     @type int             $blog_id             The site ID. Default is the current site.
         *     @type string|string[] $role                An array or a comma-separated list of role names that users
         *                                                must match to be included in results. Note that this is
         *                                                an inclusive list: users must match *each* role. Default empty.
         *     @type string[]        $role__in            An array of role names. Matched users must have at least one
         *                                                of these roles. Default empty array.
         *     @type string[]        $role__not_in        An array of role names to exclude. Users matching one or more
         *                                                of these roles will not be included in results. Default empty array.
         *     @type string|string[] $meta_key            Meta key or keys to filter by.
         *     @type string|string[] $meta_value          Meta value or values to filter by.
         *     @type string          $meta_compare        MySQL operator used for comparing the meta value.
         *                                                See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_compare_key    MySQL operator used for comparing the meta key.
         *                                                See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_type           MySQL data type that the meta_value column will be CAST to for comparisons.
         *                                                See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type string          $meta_type_key       MySQL data type that the meta_key column will be CAST to for comparisons.
         *                                                See WP_Meta_Query::__construct() for accepted values and default value.
         *     @type array           $meta_query          An associative array of WP_Meta_Query arguments.
         *                                                See WP_Meta_Query::__construct() for accepted values.
         *     @type string|string[] $capability          An array or a comma-separated list of capability names that users
         *                                                must match to be included in results. Note that this is
         *                                                an inclusive list: users must match *each* capability.
         *                                                Does NOT work for capabilities not in the database or filtered
         *                                                via {@see 'map_meta_cap'}. Default empty.
         *     @type string[]        $capability__in      An array of capability names. Matched users must have at least one
         *                                                of these capabilities.
         *                                                Does NOT work for capabilities not in the database or filtered
         *                                                via {@see 'map_meta_cap'}. Default empty array.
         *     @type string[]        $capability__not_in  An array of capability names to exclude. Users matching one or more
         *                                                of these capabilities will not be included in results.
         *                                                Does NOT work for capabilities not in the database or filtered
         *                                                via {@see 'map_meta_cap'}. Default empty array.
         *     @type int[]           $include             An array of user IDs to include. Default empty array.
         *     @type int[]           $exclude             An array of user IDs to exclude. Default empty array.
         *     @type string          $search              Search keyword. Searches for possible string matches on columns.
         *                                                When `$search_columns` is left empty, it tries to determine which
         *                                                column to search in based on search string. Default empty.
         *     @type string[]        $search_columns      Array of column names to be searched. Accepts 'ID', 'user_login',
         *                                                'user_email', 'user_url', 'user_nicename', 'display_name'.
         *                                                Default empty array.
         *     @type string|array    $orderby             Field(s) to sort the retrieved users by. May be a single value,
         *                                                an array of values, or a multi-dimensional array with fields as
         *                                                keys and orders ('ASC' or 'DESC') as values. Accepted values are:
         *                                                - 'ID'
         *                                                - 'display_name' (or 'name')
         *                                                - 'include'
         *                                                - 'user_login' (or 'login')
         *                                                - 'login__in'
         *                                                - 'user_nicename' (or 'nicename')
         *                                                - 'nicename__in'
         *                                                - 'user_email (or 'email')
         *                                                - 'user_url' (or 'url')
         *                                                - 'user_registered' (or 'registered')
         *                                                - 'post_count'
         *                                                - 'meta_value'
         *                                                - 'meta_value_num'
         *                                                - The value of `$meta_key`
         *                                                - An array key of `$meta_query`
         *                                                To use 'meta_value' or 'meta_value_num', `$meta_key`
         *                                                must be also be defined. Default 'user_login'.
         *     @type string          $order               Designates ascending or descending order of users. Order values
         *                                                passed as part of an `$orderby` array take precedence over this
         *                                                parameter. Accepts 'ASC', 'DESC'. Default 'ASC'.
         *     @type int             $offset              Number of users to offset in retrieved results. Can be used in
         *                                                conjunction with pagination. Default 0.
         *     @type int             $number              Number of users to limit the query for. Can be used in
         *                                                conjunction with pagination. Value -1 (all) is supported, but
         *                                                should be used with caution on larger sites.
         *                                                Default -1 (all users).
         *     @type int             $paged               When used with number, defines the page of results to return.
         *                                                Default 1.
         *     @type bool            $count_total         Whether to count the total number of users found. If pagination
         *                                                is not needed, setting this to false can improve performance.
         *                                                Default true.
         *     @type string|string[] $fields              Which fields to return. Single or all fields (string), or array
         *                                                of fields. Accepts:
         *                                                - 'ID'
         *                                                - 'display_name'
         *                                                - 'user_login'
         *                                                - 'user_nicename'
         *                                                - 'user_email'
         *                                                - 'user_url'
         *                                                - 'user_registered'
         *                                                - 'user_pass'
         *                                                - 'user_activation_key'
         *                                                - 'user_status'
         *                                                - 'spam' (only available on multisite installs)
         *                                                - 'deleted' (only available on multisite installs)
         *                                                - 'all' for all fields and loads user meta.
         *                                                - 'all_with_meta' Deprecated. Use 'all'.
         *                                                Default 'all'.
         *     @type string          $who                 Deprecated, use `$capability` instead.
         *                                                Type of users to query. Accepts 'authors'.
         *                                                Default empty (all users).
         *     @type bool|string[]   $has_published_posts Pass an array of post types to filter results to users who have
         *                                                published posts in those post types. `true` is an alias for all
         *                                                public post types.
         *     @type string          $nicename            The user nicename. Default empty.
         *     @type string[]        $nicename__in        An array of nicenames to include. Users matching one of these
         *                                                nicenames will be included in results. Default empty array.
         *     @type string[]        $nicename__not_in    An array of nicenames to exclude. Users matching one of these
         *                                                nicenames will not be included in results. Default empty array.
         *     @type string          $login               The user login. Default empty.
         *     @type string[]        $login__in           An array of logins to include. Users matching one of these
         *                                                logins will be included in results. Default empty array.
         *     @type string[]        $login__not_in       An array of logins to exclude. Users matching one of these
         *                                                logins will not be included in results. Default empty array.
         *     @type bool            $cache_results       Whether to cache user information. Default true.
         * }
         * @phpstan-param array{
         *   blog_id?: int,
         *   role?: string|string[],
         *   role__in?: string[],
         *   role__not_in?: string[],
         *   meta_key?: string|string[],
         *   meta_value?: string|string[],
         *   meta_compare?: string,
         *   meta_compare_key?: string,
         *   meta_type?: string,
         *   meta_type_key?: string,
         *   meta_query?: array,
         *   capability?: string|string[],
         *   capability__in?: string[],
         *   capability__not_in?: string[],
         *   include?: int[],
         *   exclude?: int[],
         *   search?: string,
         *   search_columns?: string[],
         *   orderby?: string|array,
         *   order?: string,
         *   offset?: int,
         *   number?: int,
         *   paged?: int,
         *   count_total?: bool,
         *   fields?: string|string[],
         *   who?: string,
         *   has_published_posts?: bool|string[],
         *   nicename?: string,
         *   nicename__in?: string[],
         *   nicename__not_in?: string[],
         *   login?: string,
         *   login__in?: string[],
         *   login__not_in?: string[],
         *   cache_results?: bool,
         * } $query
         */
        public function prepare_query($query = array())
        {
        }
        /**
         * Executes the query, with the current variables.
         *
         * @since 3.1.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         * @phpstan-return void
         */
        public function query()
        {
        }
        /**
         * Retrieves query variable.
         *
         * @since 3.5.0
         *
         * @param string $query_var Query variable key.
         * @return mixed
         */
        public function get($query_var)
        {
        }
        /**
         * Sets query variable.
         *
         * @since 3.5.0
         *
         * @param string $query_var Query variable key.
         * @param mixed  $value     Query variable value.
         */
        public function set($query_var, $value)
        {
        }
        /**
         * Used internally to generate an SQL string for searching across multiple columns.
         *
         * @since 3.1.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string   $search  Search string.
         * @param string[] $columns Array of columns to search.
         * @param bool     $wild    Whether to allow wildcard searches. Default is false for Network Admin, true for single site.
         *                          Single site allows leading and trailing wildcards, Network Admin only trailing.
         * @return string
         */
        protected function get_search_sql($search, $columns, $wild = \false)
        {
        }
        /**
         * Returns the list of users.
         *
         * @since 3.1.0
         *
         * @return array Array of results.
         */
        public function get_results()
        {
        }
        /**
         * Returns the total number of users for the current query.
         *
         * @since 3.1.0
         *
         * @return int Number of total users.
         */
        public function get_total()
        {
        }
        /**
         * Parses and sanitizes 'orderby' keys passed to the user query.
         *
         * @since 4.2.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $orderby Alias for the field to order by.
         * @return string Value to used in the ORDER clause, if `$orderby` is valid.
         */
        protected function parse_orderby($orderby)
        {
        }
        /**
         * Generate cache key.
         *
         * @since 6.3.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param array  $args Query arguments.
         * @param string $sql  SQL statement.
         * @return string Cache key.
         */
        protected function generate_cache_key(array $args, $sql)
        {
        }
        /**
         * Parses an 'order' query variable and casts it to ASC or DESC as necessary.
         *
         * @since 4.2.0
         *
         * @param string $order The 'order' query variable.
         * @return string The sanitized 'order' query variable.
         */
        protected function parse_order($order)
        {
        }
        /**
         * Makes private properties readable for backward compatibility.
         *
         * @since 4.0.0
         * @since 6.4.0 Getting a dynamic property is deprecated.
         *
         * @param string $name Property to get.
         * @return mixed Property.
         */
        public function __get($name)
        {
        }
        /**
         * Makes private properties settable for backward compatibility.
         *
         * @since 4.0.0
         * @since 6.4.0 Setting a dynamic property is deprecated.
         *
         * @param string $name  Property to check if set.
         * @param mixed  $value Property value.
         * @phpstan-return void
         */
        public function __set($name, $value)
        {
        }
        /**
         * Makes private properties checkable for backward compatibility.
         *
         * @since 4.0.0
         * @since 6.4.0 Checking a dynamic property is deprecated.
         *
         * @param string $name Property to check if set.
         * @return bool Whether the property is set.
         */
        public function __isset($name)
        {
        }
        /**
         * Makes private properties un-settable for backward compatibility.
         *
         * @since 4.0.0
         * @since 6.4.0 Unsetting a dynamic property is deprecated.
         *
         * @param string $name Property to unset.
         * @phpstan-return void
         */
        public function __unset($name)
        {
        }
        /**
         * Makes private/protected methods readable for backward compatibility.
         *
         * @since 4.0.0
         *
         * @param string $name      Method to call.
         * @param array  $arguments Arguments to pass when calling.
         * @return mixed Return value of the callback, false otherwise.
         */
        public function __call($name, $arguments)
        {
        }
    }
    /**
     * WP_User_Request class.
     *
     * Represents user request data loaded from a WP_Post object.
     *
     * @since 4.9.6
     */
    #[\AllowDynamicProperties]
    final class WP_User_Request
    {
        /**
         * Request ID.
         *
         * @since 4.9.6
         * @var int
         */
        public $ID = 0;
        /**
         * User ID.
         *
         * @since 4.9.6
         * @var int
         */
        public $user_id = 0;
        /**
         * User email.
         *
         * @since 4.9.6
         * @var string
         */
        public $email = '';
        /**
         * Action name.
         *
         * @since 4.9.6
         * @var string
         */
        public $action_name = '';
        /**
         * Current status.
         *
         * @since 4.9.6
         * @var string
         */
        public $status = '';
        /**
         * Timestamp this request was created.
         *
         * @since 4.9.6
         * @var int|null
         */
        public $created_timestamp = \null;
        /**
         * Timestamp this request was last modified.
         *
         * @since 4.9.6
         * @var int|null
         */
        public $modified_timestamp = \null;
        /**
         * Timestamp this request was confirmed.
         *
         * @since 4.9.6
         * @var int|null
         */
        public $confirmed_timestamp = \null;
        /**
         * Timestamp this request was completed.
         *
         * @since 4.9.6
         * @var int|null
         */
        public $completed_timestamp = \null;
        /**
         * Misc data assigned to this request.
         *
         * @since 4.9.6
         * @var array
         */
        public $request_data = array();
        /**
         * Key used to confirm this request.
         *
         * @since 4.9.6
         * @var string
         */
        public $confirm_key = '';
        /**
         * Constructor.
         *
         * @since 4.9.6
         *
         * @param WP_Post|object $post Post object.
         */
        public function __construct($post)
        {
        }
    }
    /**
     * Core class used to implement the WP_User object.
     *
     * @since 2.0.0
     *
     * @property string $nickname
     * @property string $description
     * @property string $user_description
     * @property string $first_name
     * @property string $user_firstname
     * @property string $last_name
     * @property string $user_lastname
     * @property string $user_login
     * @property string $user_pass
     * @property string $user_nicename
     * @property string $user_email
     * @property string $user_url
     * @property string $user_registered
     * @property string $user_activation_key
     * @property string $user_status
     * @property int    $user_level
     * @property string $display_name
     * @property string $spam
     * @property string $deleted
     * @property string $locale
     * @property string $rich_editing
     * @property string $syntax_highlighting
     * @property string $use_ssl
     */
    #[\AllowDynamicProperties]
    class WP_User
    {
        /**
         * User data container.
         *
         * @since 2.0.0
         * @var stdClass
         */
        public $data;
        /**
         * The user's ID.
         *
         * @since 2.1.0
         * @var int
         */
        public $ID = 0;
        /**
         * Capabilities that the individual user has been granted outside of those inherited from their role.
         *
         * @since 2.0.0
         * @var bool[] Array of key/value pairs where keys represent a capability name
         *             and boolean values represent whether the user has that capability.
         */
        public $caps = array();
        /**
         * User metadata option name.
         *
         * @since 2.0.0
         * @var string
         */
        public $cap_key;
        /**
         * The roles the user is part of.
         *
         * @since 2.0.0
         * @var string[]
         */
        public $roles = array();
        /**
         * All capabilities the user has, including individual and role based.
         *
         * @since 2.0.0
         * @var bool[] Array of key/value pairs where keys represent a capability name
         *             and boolean values represent whether the user has that capability.
         */
        public $allcaps = array();
        /**
         * The filter context applied to user data fields.
         *
         * @since 2.9.0
         * @var string
         */
        public $filter = \null;
        /**
         * Constructor.
         *
         * Retrieves the userdata and passes it to WP_User::init().
         *
         * @since 2.0.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param int|string|stdClass|WP_User $id      User's ID, a WP_User object, or a user object from the DB.
         * @param string                      $name    Optional. User's username
         * @param int                         $site_id Optional Site ID, defaults to current site.
         * @phpstan-return void
         */
        public function __construct($id = 0, $name = '', $site_id = '')
        {
        }
        /**
         * Sets up object properties, including capabilities.
         *
         * @since 3.3.0
         *
         * @param object $data    User DB row object.
         * @param int    $site_id Optional. The site ID to initialize for.
         */
        public function init($data, $site_id = '')
        {
        }
        /**
         * Returns only the main user fields.
         *
         * @since 3.3.0
         * @since 4.4.0 Added 'ID' as an alias of 'id' for the `$field` parameter.
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string     $field The field to query against: Accepts 'id', 'ID', 'slug', 'email' or 'login'.
         * @param string|int $value The field value.
         * @return object|false Raw user object.
         * @phpstan-param 'id'|'ID'|'slug'|'email'|'login' $field
         */
        public static function get_data_by($field, $value)
        {
        }
        /**
         * Magic method for checking the existence of a certain custom field.
         *
         * @since 3.3.0
         *
         * @param string $key User meta key to check if set.
         * @return bool Whether the given user meta key is set.
         */
        public function __isset($key)
        {
        }
        /**
         * Magic method for accessing custom fields.
         *
         * @since 3.3.0
         *
         * @param string $key User meta key to retrieve.
         * @return mixed Value of the given user meta key (if set). If `$key` is 'id', the user ID.
         */
        public function __get($key)
        {
        }
        /**
         * Magic method for setting custom user fields.
         *
         * This method does not update custom fields in the database. It only stores
         * the value on the WP_User instance.
         *
         * @since 3.3.0
         *
         * @param string $key   User meta key.
         * @param mixed  $value User meta value.
         * @phpstan-return void
         */
        public function __set($key, $value)
        {
        }
        /**
         * Magic method for unsetting a certain custom field.
         *
         * @since 4.4.0
         *
         * @param string $key User meta key to unset.
         */
        public function __unset($key)
        {
        }
        /**
         * Determines whether the user exists in the database.
         *
         * @since 3.4.0
         *
         * @return bool True if user exists in the database, false if not.
         */
        public function exists()
        {
        }
        /**
         * Retrieves the value of a property or meta key.
         *
         * Retrieves from the users and usermeta table.
         *
         * @since 3.3.0
         *
         * @param string $key Property
         * @return mixed
         */
        public function get($key)
        {
        }
        /**
         * Determines whether a property or meta key is set.
         *
         * Consults the users and usermeta tables.
         *
         * @since 3.3.0
         *
         * @param string $key Property.
         * @return bool
         */
        public function has_prop($key)
        {
        }
        /**
         * Returns an array representation.
         *
         * @since 3.5.0
         *
         * @return array Array representation.
         */
        public function to_array()
        {
        }
        /**
         * Makes private/protected methods readable for backward compatibility.
         *
         * @since 4.3.0
         *
         * @param string $name      Method to call.
         * @param array  $arguments Arguments to pass when calling.
         * @return mixed|false Return value of the callback, false otherwise.
         */
        public function __call($name, $arguments)
        {
        }
        /**
         * Sets up capability object properties.
         *
         * Will set the value for the 'cap_key' property to current database table
         * prefix, followed by 'capabilities'. Will then check to see if the
         * property matching the 'cap_key' exists and is an array. If so, it will be
         * used.
         *
         * @since 2.1.0
         * @deprecated 4.9.0 Use WP_User::for_site()
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $cap_key Optional capability key
         */
        protected function _init_caps($cap_key = '')
        {
        }
        /**
         * Retrieves all of the capabilities of the user's roles, and merges them with
         * individual user capabilities.
         *
         * All of the capabilities of the user's roles are merged with the user's individual
         * capabilities. This means that the user can be denied specific capabilities that
         * their role might have, but the user is specifically denied.
         *
         * @since 2.0.0
         *
         * @return bool[] Array of key/value pairs where keys represent a capability name
         *                and boolean values represent whether the user has that capability.
         */
        public function get_role_caps()
        {
        }
        /**
         * Adds role to user.
         *
         * Updates the user's meta data option with capabilities and roles.
         *
         * @since 2.0.0
         *
         * @param string $role Role name.
         * @phpstan-return void
         */
        public function add_role($role)
        {
        }
        /**
         * Removes role from user.
         *
         * @since 2.0.0
         *
         * @param string $role Role name.
         * @phpstan-return void
         */
        public function remove_role($role)
        {
        }
        /**
         * Sets the role of the user.
         *
         * This will remove the previous roles of the user and assign the user the
         * new one. You can set the role to an empty string and it will remove all
         * of the roles from the user.
         *
         * @since 2.0.0
         *
         * @param string $role Role name.
         * @phpstan-return void
         */
        public function set_role($role)
        {
        }
        /**
         * Chooses the maximum level the user has.
         *
         * Will compare the level from the $item parameter against the $max
         * parameter. If the item is incorrect, then just the $max parameter value
         * will be returned.
         *
         * Used to get the max level based on the capabilities the user has. This
         * is also based on roles, so if the user is assigned the Administrator role
         * then the capability 'level_10' will exist and the user will get that
         * value.
         *
         * @since 2.0.0
         *
         * @param int    $max  Max level of user.
         * @param string $item Level capability name.
         * @return int Max Level.
         */
        public function level_reduction($max, $item)
        {
        }
        /**
         * Updates the maximum user level for the user.
         *
         * Updates the 'user_level' user metadata (includes prefix that is the
         * database table prefix) with the maximum user level. Gets the value from
         * the all of the capabilities that the user has.
         *
         * @since 2.0.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         */
        public function update_user_level_from_caps()
        {
        }
        /**
         * Adds capability and grant or deny access to capability.
         *
         * @since 2.0.0
         *
         * @param string $cap   Capability name.
         * @param bool   $grant Whether to grant capability to user.
         */
        public function add_cap($cap, $grant = \true)
        {
        }
        /**
         * Removes capability from user.
         *
         * @since 2.0.0
         *
         * @param string $cap Capability name.
         * @phpstan-return void
         */
        public function remove_cap($cap)
        {
        }
        /**
         * Removes all of the capabilities of the user.
         *
         * @since 2.1.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         */
        public function remove_all_caps()
        {
        }
        /**
         * Returns whether the user has the specified capability.
         *
         * This function also accepts an ID of an object to check against if the capability is a meta capability. Meta
         * capabilities such as `edit_post` and `edit_user` are capabilities used by the `map_meta_cap()` function to
         * map to primitive capabilities that a user or role has, such as `edit_posts` and `edit_others_posts`.
         *
         * Example usage:
         *
         *     $user->has_cap( 'edit_posts' );
         *     $user->has_cap( 'edit_post', $post->ID );
         *     $user->has_cap( 'edit_post_meta', $post->ID, $meta_key );
         *
         * While checking against a role in place of a capability is supported in part, this practice is discouraged as it
         * may produce unreliable results.
         *
         * @since 2.0.0
         * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
         *              by adding it to the function signature.
         *
         * @see map_meta_cap()
         *
         * @param string $cap     Capability name.
         * @param mixed  ...$args Optional further parameters, typically starting with an object ID.
         * @return bool Whether the user has the given capability, or, if an object ID is passed, whether the user has
         *              the given capability for that object.
         */
        public function has_cap($cap, ...$args)
        {
        }
        /**
         * Converts numeric level to level capability name.
         *
         * Prepends 'level_' to level number.
         *
         * @since 2.0.0
         *
         * @param int $level Level number, 1 to 10.
         * @return string
         */
        public function translate_level_to_cap($level)
        {
        }
        /**
         * Sets the site to operate on. Defaults to the current site.
         *
         * @since 3.0.0
         * @deprecated 4.9.0 Use WP_User::for_site()
         *
         * @param int $blog_id Optional. Site ID, defaults to current site.
         */
        public function for_blog($blog_id = '')
        {
        }
        /**
         * Sets the site to operate on. Defaults to the current site.
         *
         * @since 4.9.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param int $site_id Site ID to initialize user capabilities for. Default is the current site.
         */
        public function for_site($site_id = '')
        {
        }
        /**
         * Gets the ID of the site for which the user's capabilities are currently initialized.
         *
         * @since 4.9.0
         *
         * @return int Site ID.
         */
        public function get_site_id()
        {
        }
    }
    /**
     * Singleton that registers and instantiates WP_Widget classes.
     *
     * @since 2.8.0
     * @since 4.4.0 Moved to its own file from wp-includes/widgets.php
     */
    #[\AllowDynamicProperties]
    class WP_Widget_Factory
    {
        /**
         * Widgets array.
         *
         * @since 2.8.0
         * @var array
         * @phpstan-var array<string, \WP_Widget>
         */
        public $widgets = array();
        /**
         * PHP5 constructor.
         *
         * @since 4.3.0
         */
        public function __construct()
        {
        }
        /**
         * PHP4 constructor.
         *
         * @since 2.8.0
         * @deprecated 4.3.0 Use __construct() instead.
         *
         * @see WP_Widget_Factory::__construct()
         */
        public function WP_Widget_Factory()
        {
        }
        /**
         * Registers a widget subclass.
         *
         * @since 2.8.0
         * @since 4.6.0 Updated the `$widget` parameter to also accept a WP_Widget instance object
         *              instead of simply a `WP_Widget` subclass name.
         *
         * @param string|WP_Widget $widget Either the name of a `WP_Widget` subclass or an instance of a `WP_Widget` subclass.
         * @phpstan-param class-string<\WP_Widget>|\WP_Widget $widget
         */
        public function register($widget)
        {
        }
        /**
         * Un-registers a widget subclass.
         *
         * @since 2.8.0
         * @since 4.6.0 Updated the `$widget` parameter to also accept a WP_Widget instance object
         *              instead of simply a `WP_Widget` subclass name.
         *
         * @param string|WP_Widget $widget Either the name of a `WP_Widget` subclass or an instance of a `WP_Widget` subclass.
         * @phpstan-param class-string<\WP_Widget>|\WP_Widget $widget
         */
        public function unregister($widget)
        {
        }
        /**
         * Serves as a utility method for adding widgets to the registered widgets global.
         *
         * @since 2.8.0
         *
         * @global array $wp_registered_widgets
         */
        public function _register_widgets()
        {
        }
        /**
         * Returns the registered WP_Widget object for the given widget type.
         *
         * @since 5.8.0
         *
         * @param string $id_base Widget type ID.
         * @return WP_Widget|null
         */
        public function get_widget_object($id_base)
        {
        }
        /**
         * Returns the registered key for the given widget type.
         *
         * @since 5.8.0
         *
         * @param string $id_base Widget type ID.
         * @return string
         */
        public function get_widget_key($id_base)
        {
        }
    }
    /**
     * Core base class extended to register widgets.
     *
     * This class must be extended for each widget, and WP_Widget::widget() must be overridden.
     *
     * If adding widget options, WP_Widget::update() and WP_Widget::form() should also be overridden.
     *
     * @since 2.8.0
     * @since 4.4.0 Moved to its own file from wp-includes/widgets.php
     * @phpstan-template T of array<string, mixed>
     */
    #[\AllowDynamicProperties]
    class WP_Widget
    {
        /**
         * Root ID for all widgets of this type.
         *
         * @since 2.8.0
         * @var mixed|string
         */
        public $id_base;
        /**
         * Name for this widget type.
         *
         * @since 2.8.0
         * @var string
         */
        public $name;
        /**
         * Option name for this widget type.
         *
         * @since 2.8.0
         * @var string
         */
        public $option_name;
        /**
         * Alt option name for this widget type.
         *
         * @since 2.8.0
         * @var string
         */
        public $alt_option_name;
        /**
         * Option array passed to wp_register_sidebar_widget().
         *
         * @since 2.8.0
         * @var array
         */
        public $widget_options;
        /**
         * Option array passed to wp_register_widget_control().
         *
         * @since 2.8.0
         * @var array
         */
        public $control_options;
        /**
         * Unique ID number of the current instance.
         *
         * @since 2.8.0
         * @var bool|int
         */
        public $number = \false;
        /**
         * Unique ID string of the current instance (id_base-number).
         *
         * @since 2.8.0
         * @var bool|string
         */
        public $id = \false;
        /**
         * Whether the widget data has been updated.
         *
         * Set to true when the data is updated after a POST submit - ensures it does
         * not happen twice.
         *
         * @since 2.8.0
         * @var bool
         */
        public $updated = \false;
        /**
         * Echoes the widget content.
         *
         * Subclasses should override this function to generate their widget code.
         *
         * @since 2.8.0
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance The settings for the particular instance of the widget.
         * @phpstan-param T $instance
         * @phpstan-param array{name:string,id:string,description:string,class:string,before_widget:string,after_widget:string,before_title:string,after_title:string,before_sidebar:string,after_sidebar:string,show_in_rest:boolean,widget_id:string,widget_name:string} $args
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Updates a particular instance of a widget.
         *
         * This function should check that `$new_instance` is set correctly. The newly-calculated
         * value of `$instance` should be returned. If false is returned, the instance won't be
         * saved/updated.
         *
         * @since 2.8.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Settings to save or bool false to cancel saving.
         * @phpstan-param T $new_instance
         * @phpstan-param T $old_instance
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Outputs the settings update form.
         *
         * @since 2.8.0
         *
         * @param array $instance The settings for the particular instance of the widget.
         * @return string Default return is 'noform'.
         * @phpstan-param T $instance
         */
        public function form($instance)
        {
        }
        /**
         * PHP5 constructor.
         *
         * @since 2.8.0
         *
         * @param string $id_base         Base ID for the widget, lowercase and unique. If left empty,
         *                                a portion of the widget's PHP class name will be used. Has to be unique.
         * @param string $name            Name for the widget displayed on the configuration page.
         * @param array  $widget_options  Optional. Widget options. See wp_register_sidebar_widget() for
         *                                information on accepted arguments. Default empty array.
         * @param array  $control_options Optional. Widget control options. See wp_register_widget_control() for
         *                                information on accepted arguments. Default empty array.
         * @phpstan-param array{
         *   classname?: string,
         *   description?: string,
         *   show_instance_in_rest?: bool,
         * } $widget_options See wp_register_sidebar_widget()
         * @phpstan-param array{
         *   height?: int,
         *   width?: int,
         *   id_base?: int|string,
         * } $control_options See wp_register_widget_control()
         */
        public function __construct($id_base, $name, $widget_options = array(), $control_options = array())
        {
        }
        /**
         * PHP4 constructor.
         *
         * @since 2.8.0
         * @deprecated 4.3.0 Use __construct() instead.
         *
         * @see WP_Widget::__construct()
         *
         * @param string $id_base         Base ID for the widget, lowercase and unique. If left empty,
         *                                a portion of the widget's PHP class name will be used. Has to be unique.
         * @param string $name            Name for the widget displayed on the configuration page.
         * @param array  $widget_options  Optional. Widget options. See wp_register_sidebar_widget() for
         *                                information on accepted arguments. Default empty array.
         * @param array  $control_options Optional. Widget control options. See wp_register_widget_control() for
         *                                information on accepted arguments. Default empty array.
         * @phpstan-param array{
         *   classname?: string,
         *   description?: string,
         *   show_instance_in_rest?: bool,
         * } $widget_options See wp_register_sidebar_widget()
         * @phpstan-param array{
         *   height?: int,
         *   width?: int,
         *   id_base?: int|string,
         * } $control_options See wp_register_widget_control()
         */
        public function WP_Widget($id_base, $name, $widget_options = array(), $control_options = array())
        {
        }
        /**
         * Constructs name attributes for use in form() fields
         *
         * This function should be used in form() methods to create name attributes for fields
         * to be saved by update()
         *
         * @since 2.8.0
         * @since 4.4.0 Array format field names are now accepted.
         *
         * @param string $field_name Field name.
         * @return string Name attribute for `$field_name`.
         */
        public function get_field_name($field_name)
        {
        }
        /**
         * Constructs id attributes for use in WP_Widget::form() fields.
         *
         * This function should be used in form() methods to create id attributes
         * for fields to be saved by WP_Widget::update().
         *
         * @since 2.8.0
         * @since 4.4.0 Array format field IDs are now accepted.
         *
         * @param string $field_name Field name.
         * @return string ID attribute for `$field_name`.
         */
        public function get_field_id($field_name)
        {
        }
        /**
         * Register all widget instances of this widget class.
         *
         * @since 2.8.0
         */
        public function _register()
        {
        }
        /**
         * Sets the internal order number for the widget instance.
         *
         * @since 2.8.0
         *
         * @param int $number The unique order number of this widget instance compared to other
         *                    instances of the same class.
         */
        public function _set($number)
        {
        }
        /**
         * Retrieves the widget display callback.
         *
         * @since 2.8.0
         *
         * @return callable Display callback.
         */
        public function _get_display_callback()
        {
        }
        /**
         * Retrieves the widget update callback.
         *
         * @since 2.8.0
         *
         * @return callable Update callback.
         */
        public function _get_update_callback()
        {
        }
        /**
         * Retrieves the form callback.
         *
         * @since 2.8.0
         *
         * @return callable Form callback.
         */
        public function _get_form_callback()
        {
        }
        /**
         * Determines whether the current request is inside the Customizer preview.
         *
         * If true -- the current request is inside the Customizer preview, then
         * the object cache gets suspended and widgets should check this to decide
         * whether they should store anything persistently to the object cache,
         * to transients, or anywhere else.
         *
         * @since 3.9.0
         *
         * @global WP_Customize_Manager $wp_customize
         *
         * @return bool True if within the Customizer preview, false if not.
         */
        public function is_preview()
        {
        }
        /**
         * Generates the actual widget content (Do NOT override).
         *
         * Finds the instance and calls WP_Widget::widget().
         *
         * @since 2.8.0
         *
         * @param array     $args        Display arguments. See WP_Widget::widget() for information
         *                               on accepted arguments.
         * @param int|array $widget_args {
         *     Optional. Internal order number of the widget instance, or array of multi-widget arguments.
         *     Default 1.
         *
         *     @type int $number Number increment used for multiples of the same widget.
         * }
         * @phpstan-param int|array{
         *   number?: int,
         * } $widget_args
         * @phpstan-return void
         */
        public function display_callback($args, $widget_args = 1)
        {
        }
        /**
         * Handles changed settings (Do NOT override).
         *
         * @since 2.8.0
         *
         * @global array $wp_registered_widgets
         *
         * @param int $deprecated Not used.
         * @phpstan-return void
         */
        public function update_callback($deprecated = 1)
        {
        }
        /**
         * Generates the widget control form (Do NOT override).
         *
         * @since 2.8.0
         *
         * @param int|array $widget_args {
         *     Optional. Internal order number of the widget instance, or array of multi-widget arguments.
         *     Default 1.
         *
         *     @type int $number Number increment used for multiples of the same widget.
         * }
         * @return string|null
         * @phpstan-param int|array{
         *   number?: int,
         * } $widget_args
         */
        public function form_callback($widget_args = 1)
        {
        }
        /**
         * Registers an instance of the widget class.
         *
         * @since 2.8.0
         *
         * @param int $number Optional. The unique order number of this widget instance
         *                    compared to other instances of the same class. Default -1.
         */
        public function _register_one($number = -1)
        {
        }
        /**
         * Saves the settings for all instances of the widget class.
         *
         * @since 2.8.0
         *
         * @param array $settings Multi-dimensional array of widget instance settings.
         */
        public function save_settings($settings)
        {
        }
        /**
         * Retrieves the settings for all instances of the widget class.
         *
         * @since 2.8.0
         *
         * @return array Multi-dimensional array of widget instance settings.
         */
        public function get_settings()
        {
        }
    }
    /**
     * WordPress XMLRPC server implementation.
     *
     * Implements compatibility for Blogger API, MetaWeblog API, MovableType, and
     * pingback. Additional WordPress API for managing comments, pages, posts,
     * options, etc.
     *
     * As of WordPress 3.5.0, XML-RPC is enabled by default. It can be disabled
     * via the {@see 'xmlrpc_enabled'} filter found in wp_xmlrpc_server::set_is_enabled().
     *
     * @since 1.5.0
     *
     * @see IXR_Server
     */
    #[\AllowDynamicProperties]
    class wp_xmlrpc_server extends \IXR_Server
    {
        /**
         * Methods.
         *
         * @var array
         */
        public $methods;
        /**
         * Blog options.
         *
         * @var array
         */
        public $blog_options;
        /**
         * IXR_Error instance.
         *
         * @var IXR_Error
         */
        public $error;
        /**
         * Flags that the user authentication has failed in this instance of wp_xmlrpc_server.
         *
         * @var bool
         */
        protected $auth_failed = \false;
        /**
         * Registers all of the XMLRPC methods that XMLRPC server understands.
         *
         * Sets up server and method property. Passes XMLRPC methods through the
         * {@see 'xmlrpc_methods'} filter to allow plugins to extend or replace
         * XML-RPC methods.
         *
         * @since 1.5.0
         */
        public function __construct()
        {
        }
        /**
         * Makes private/protected methods readable for backward compatibility.
         *
         * @since 4.0.0
         *
         * @param string $name      Method to call.
         * @param array  $arguments Arguments to pass when calling.
         * @return array|IXR_Error|false Return value of the callback, false otherwise.
         */
        public function __call($name, $arguments)
        {
        }
        /**
         * Serves the XML-RPC request.
         *
         * @since 2.9.0
         */
        public function serve_request()
        {
        }
        /**
         * Tests XMLRPC API by saying, "Hello!" to client.
         *
         * @since 1.5.0
         *
         * @return string Hello string response.
         */
        public function sayHello()
        {
        }
        /**
         * Tests XMLRPC API by adding two numbers for client.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int $0 A number to add.
         *     @type int $1 A second number to add.
         * }
         * @return int Sum of the two given numbers.
         * @phpstan-param array{
         *   0: int,
         *   1: int,
         * } $args
         */
        public function addTwoNumbers($args)
        {
        }
        /**
         * Logs user in.
         *
         * @since 2.8.0
         *
         * @param string $username User's username.
         * @param string $password User's password.
         * @return WP_User|false WP_User object if authentication passed, false otherwise.
         */
        public function login($username, $password)
        {
        }
        /**
         * Checks user's credentials. Deprecated.
         *
         * @since 1.5.0
         * @deprecated 2.8.0 Use wp_xmlrpc_server::login()
         * @see wp_xmlrpc_server::login()
         *
         * @param string $username User's username.
         * @param string $password User's password.
         * @return bool Whether authentication passed.
         */
        public function login_pass_ok($username, $password)
        {
        }
        /**
         * Escapes string or array of strings for database.
         *
         * @since 1.5.2
         *
         * @param string|array $data Escape single string or array of strings.
         * @return string|void Returns with string is passed, alters by-reference
         *                     when array is passed.
         */
        public function escape(&$data)
        {
        }
        /**
         * Sends error response to client.
         *
         * Sends an XML error response to the client. If the endpoint is enabled
         * an HTTP 200 response is always sent per the XML-RPC specification.
         *
         * @since 5.7.3
         *
         * @param IXR_Error|string $error   Error code or an error object.
         * @param false            $message Error message. Optional.
         */
        public function error($error, $message = \false)
        {
        }
        /**
         * Retrieves custom fields for post.
         *
         * @since 2.5.0
         *
         * @param int $post_id Post ID.
         * @return array Custom fields, if exist.
         */
        public function get_custom_fields($post_id)
        {
        }
        /**
         * Sets custom fields for post.
         *
         * @since 2.5.0
         *
         * @param int   $post_id Post ID.
         * @param array $fields  Custom fields.
         */
        public function set_custom_fields($post_id, $fields)
        {
        }
        /**
         * Retrieves custom fields for a term.
         *
         * @since 4.9.0
         *
         * @param int $term_id Term ID.
         * @return array Array of custom fields, if they exist.
         */
        public function get_term_custom_fields($term_id)
        {
        }
        /**
         * Sets custom fields for a term.
         *
         * @since 4.9.0
         *
         * @param int   $term_id Term ID.
         * @param array $fields  Custom fields.
         */
        public function set_term_custom_fields($term_id, $fields)
        {
        }
        /**
         * Sets up blog options property.
         *
         * Passes property through {@see 'xmlrpc_blog_options'} filter.
         *
         * @since 2.6.0
         */
        public function initialise_blog_option_info()
        {
        }
        /**
         * Retrieves the blogs of the user.
         *
         * @since 2.6.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type string $0 Username.
         *     @type string $1 Password.
         * }
         * @return array|IXR_Error Array contains:
         *  - 'isAdmin'
         *  - 'isPrimary' - whether the blog is the user's primary blog
         *  - 'url'
         *  - 'blogid'
         *  - 'blogName'
         *  - 'xmlrpc' - url of xmlrpc endpoint
         * @phpstan-param array{
         *   0: string,
         *   1: string,
         * } $args
         */
        public function wp_getUsersBlogs($args)
        {
        }
        /**
         * Checks if the method received at least the minimum number of arguments.
         *
         * @since 3.4.0
         *
         * @param array $args  An array of arguments to check.
         * @param int   $count Minimum number of arguments.
         * @return bool True if `$args` contains at least `$count` arguments, false otherwise.
         */
        protected function minimum_args($args, $count)
        {
        }
        /**
         * Prepares taxonomy data for return in an XML-RPC object.
         *
         * @param WP_Taxonomy $taxonomy The unprepared taxonomy data.
         * @param array       $fields   The subset of taxonomy fields to return.
         * @return array The prepared taxonomy data.
         */
        protected function _prepare_taxonomy($taxonomy, $fields)
        {
        }
        /**
         * Prepares term data for return in an XML-RPC object.
         *
         * @param array|object $term The unprepared term data.
         * @return array The prepared term data.
         */
        protected function _prepare_term($term)
        {
        }
        /**
         * Converts a WordPress date string to an IXR_Date object.
         *
         * @param string $date Date string to convert.
         * @return IXR_Date IXR_Date object.
         */
        protected function _convert_date($date)
        {
        }
        /**
         * Converts a WordPress GMT date string to an IXR_Date object.
         *
         * @param string $date_gmt WordPress GMT date string.
         * @param string $date     Date string.
         * @return IXR_Date IXR_Date object.
         */
        protected function _convert_date_gmt($date_gmt, $date)
        {
        }
        /**
         * Prepares post data for return in an XML-RPC object.
         *
         * @param array $post   The unprepared post data.
         * @param array $fields The subset of post type fields to return.
         * @return array The prepared post data.
         */
        protected function _prepare_post($post, $fields)
        {
        }
        /**
         * Prepares post data for return in an XML-RPC object.
         *
         * @since 3.4.0
         * @since 4.6.0 Converted the `$post_type` parameter to accept a WP_Post_Type object.
         *
         * @param WP_Post_Type $post_type Post type object.
         * @param array        $fields    The subset of post fields to return.
         * @return array The prepared post type data.
         */
        protected function _prepare_post_type($post_type, $fields)
        {
        }
        /**
         * Prepares media item data for return in an XML-RPC object.
         *
         * @param WP_Post $media_item     The unprepared media item data.
         * @param string  $thumbnail_size The image size to use for the thumbnail URL.
         * @return array The prepared media item data.
         */
        protected function _prepare_media_item($media_item, $thumbnail_size = 'thumbnail')
        {
        }
        /**
         * Prepares page data for return in an XML-RPC object.
         *
         * @param WP_Post $page The unprepared page data.
         * @return array The prepared page data.
         */
        protected function _prepare_page($page)
        {
        }
        /**
         * Prepares comment data for return in an XML-RPC object.
         *
         * @param WP_Comment $comment The unprepared comment data.
         * @return array The prepared comment data.
         */
        protected function _prepare_comment($comment)
        {
        }
        /**
         * Prepares user data for return in an XML-RPC object.
         *
         * @param WP_User $user   The unprepared user object.
         * @param array   $fields The subset of user fields to return.
         * @return array The prepared user data.
         */
        protected function _prepare_user($user, $fields)
        {
        }
        /**
         * Creates a new post for any registered post type.
         *
         * @since 3.4.0
         *
         * @link https://en.wikipedia.org/wiki/RSS_enclosure for information on RSS enclosures.
         *
         * @param array $args {
         *     Method arguments. Note: top-level arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 {
         *         Content struct for adding a new post. See wp_insert_post() for information on
         *         additional post fields
         *
         *         @type string $post_type      Post type. Default 'post'.
         *         @type string $post_status    Post status. Default 'draft'
         *         @type string $post_title     Post title.
         *         @type int    $post_author    Post author ID.
         *         @type string $post_excerpt   Post excerpt.
         *         @type string $post_content   Post content.
         *         @type string $post_date_gmt  Post date in GMT.
         *         @type string $post_date      Post date.
         *         @type string $post_password  Post password (20-character limit).
         *         @type string $comment_status Post comment enabled status. Accepts 'open' or 'closed'.
         *         @type string $ping_status    Post ping status. Accepts 'open' or 'closed'.
         *         @type bool   $sticky         Whether the post should be sticky. Automatically false if
         *                                      `$post_status` is 'private'.
         *         @type int    $post_thumbnail ID of an image to use as the post thumbnail/featured image.
         *         @type array  $custom_fields  Array of meta key/value pairs to add to the post.
         *         @type array  $terms          Associative array with taxonomy names as keys and arrays
         *                                      of term IDs as values.
         *         @type array  $terms_names    Associative array with taxonomy names as keys and arrays
         *                                      of term names as values.
         *         @type array  $enclosure      {
         *             Array of feed enclosure data to add to post meta.
         *
         *             @type string $url    URL for the feed enclosure.
         *             @type int    $length Size in bytes of the enclosure.
         *             @type string $type   Mime-type for the enclosure.
         *         }
         *     }
         * }
         * @return int|IXR_Error Post ID on success, IXR_Error instance otherwise.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array{
         *     post_type?: string,
         *     post_status?: string,
         *     post_title: string,
         *     post_author: int,
         *     post_excerpt: string,
         *     post_content: string,
         *     post_date_gmt: string,
         *     post_date: string,
         *     post_password: string,
         *     comment_status: string,
         *     ping_status: string,
         *     sticky: bool,
         *     post_thumbnail: int,
         *     custom_fields: array,
         *     terms: array,
         *     terms_names: array,
         *     enclosure: array{
         *       url: string,
         *       length: int,
         *       type: string,
         *     },
         *   },
         * } $args
         */
        public function wp_newPost($args)
        {
        }
        /**
         * Helper method for wp_newPost() and wp_editPost(), containing shared logic.
         *
         * @since 3.4.0
         *
         * @see wp_insert_post()
         *
         * @param WP_User         $user           The post author if post_author isn't set in $content_struct.
         * @param array|IXR_Error $content_struct Post data to insert.
         * @return IXR_Error|string
         */
        protected function _insert_post($user, $content_struct)
        {
        }
        /**
         * Edits a post for any registered post type.
         *
         * The $content_struct parameter only needs to contain fields that
         * should be changed. All other fields will retain their existing values.
         *
         * @since 3.4.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Post ID.
         *     @type array  $4 Extra content arguments.
         * }
         * @return true|IXR_Error True on success, IXR_Error on failure.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         *   4: array,
         * } $args
         */
        public function wp_editPost($args)
        {
        }
        /**
         * Deletes a post for any registered post type.
         *
         * @since 3.4.0
         *
         * @see wp_delete_post()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Post ID.
         * }
         * @return true|IXR_Error True on success, IXR_Error instance on failure.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         * } $args
         */
        public function wp_deletePost($args)
        {
        }
        /**
         * Retrieves a post.
         *
         * @since 3.4.0
         *
         * The optional $fields parameter specifies what fields will be included
         * in the response array. This should be a list of field names. 'post_id' will
         * always be included in the response regardless of the value of $fields.
         *
         * Instead of, or in addition to, individual field names, conceptual group
         * names can be used to specify multiple fields. The available conceptual
         * groups are 'post' (all basic fields), 'taxonomies', 'custom_fields',
         * and 'enclosure'.
         *
         * @see get_post()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Post ID.
         *     @type array  $4 Optional. The subset of post type fields to return.
         * }
         * @return array|IXR_Error Array contains (based on $fields parameter):
         *  - 'post_id'
         *  - 'post_title'
         *  - 'post_date'
         *  - 'post_date_gmt'
         *  - 'post_modified'
         *  - 'post_modified_gmt'
         *  - 'post_status'
         *  - 'post_type'
         *  - 'post_name'
         *  - 'post_author'
         *  - 'post_password'
         *  - 'post_excerpt'
         *  - 'post_content'
         *  - 'link'
         *  - 'comment_status'
         *  - 'ping_status'
         *  - 'sticky'
         *  - 'custom_fields'
         *  - 'terms'
         *  - 'categories'
         *  - 'tags'
         *  - 'enclosure'
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         *   4: array,
         * } $args
         */
        public function wp_getPost($args)
        {
        }
        /**
         * Retrieves posts.
         *
         * @since 3.4.0
         *
         * @see wp_get_recent_posts()
         * @see wp_getPost() for more on `$fields`
         * @see get_posts() for more on `$filter` values
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Optional. Modifies the query used to retrieve posts. Accepts 'post_type',
         *                     'post_status', 'number', 'offset', 'orderby', 's', and 'order'.
         *                     Default empty array.
         *     @type array  $4 Optional. The subset of post type fields to return in the response array.
         * }
         * @return array|IXR_Error Array containing a collection of posts.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         *   4: array,
         * } $args
         */
        public function wp_getPosts($args)
        {
        }
        /**
         * Creates a new term.
         *
         * @since 3.4.0
         *
         * @see wp_insert_term()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Content struct for adding a new term. The struct must contain
         *                     the term 'name' and 'taxonomy'. Optional accepted values include
         *                     'parent', 'description', and 'slug'.
         * }
         * @return int|IXR_Error The term ID on success, or an IXR_Error object on failure.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         * } $args
         */
        public function wp_newTerm($args)
        {
        }
        /**
         * Edits a term.
         *
         * @since 3.4.0
         *
         * @see wp_update_term()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Term ID.
         *     @type array  $4 Content struct for editing a term. The struct must contain the
         *                     term 'taxonomy'. Optional accepted values include 'name', 'parent',
         *                     'description', and 'slug'.
         * }
         * @return true|IXR_Error True on success, IXR_Error instance on failure.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         *   4: array,
         * } $args
         */
        public function wp_editTerm($args)
        {
        }
        /**
         * Deletes a term.
         *
         * @since 3.4.0
         *
         * @see wp_delete_term()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type string $3 Taxonomy name.
         *     @type int    $4 Term ID.
         * }
         * @return true|IXR_Error True on success, IXR_Error instance on failure.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: string,
         *   4: int,
         * } $args
         */
        public function wp_deleteTerm($args)
        {
        }
        /**
         * Retrieves a term.
         *
         * @since 3.4.0
         *
         * @see get_term()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type string $3 Taxonomy name.
         *     @type int    $4 Term ID.
         * }
         * @return array|IXR_Error IXR_Error on failure, array on success, containing:
         *  - 'term_id'
         *  - 'name'
         *  - 'slug'
         *  - 'term_group'
         *  - 'term_taxonomy_id'
         *  - 'taxonomy'
         *  - 'description'
         *  - 'parent'
         *  - 'count'
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: string,
         *   4: int,
         * } $args
         */
        public function wp_getTerm($args)
        {
        }
        /**
         * Retrieves all terms for a taxonomy.
         *
         * @since 3.4.0
         *
         * The optional $filter parameter modifies the query used to retrieve terms.
         * Accepted keys are 'number', 'offset', 'orderby', 'order', 'hide_empty', and 'search'.
         *
         * @see get_terms()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type string $3 Taxonomy name.
         *     @type array  $4 Optional. Modifies the query used to retrieve posts. Accepts 'number',
         *                     'offset', 'orderby', 'order', 'hide_empty', and 'search'. Default empty array.
         * }
         * @return array|IXR_Error An associative array of terms data on success, IXR_Error instance otherwise.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: string,
         *   4: array,
         * } $args
         */
        public function wp_getTerms($args)
        {
        }
        /**
         * Retrieves a taxonomy.
         *
         * @since 3.4.0
         *
         * @see get_taxonomy()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type string $3 Taxonomy name.
         *     @type array  $4 Optional. Array of taxonomy fields to limit to in the return.
         *                     Accepts 'labels', 'cap', 'menu', and 'object_type'.
         *                     Default empty array.
         * }
         * @return array|IXR_Error An array of taxonomy data on success, IXR_Error instance otherwise.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: string,
         *   4: array,
         * } $args
         */
        public function wp_getTaxonomy($args)
        {
        }
        /**
         * Retrieves all taxonomies.
         *
         * @since 3.4.0
         *
         * @see get_taxonomies()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Optional. An array of arguments for retrieving taxonomies.
         *     @type array  $4 Optional. The subset of taxonomy fields to return.
         * }
         * @return array|IXR_Error An associative array of taxonomy data with returned fields determined
         *                         by `$fields`, or an IXR_Error instance on failure.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         *   4: array,
         * } $args
         */
        public function wp_getTaxonomies($args)
        {
        }
        /**
         * Retrieves a user.
         *
         * The optional $fields parameter specifies what fields will be included
         * in the response array. This should be a list of field names. 'user_id' will
         * always be included in the response regardless of the value of $fields.
         *
         * Instead of, or in addition to, individual field names, conceptual group
         * names can be used to specify multiple fields. The available conceptual
         * groups are 'basic' and 'all'.
         *
         * @uses get_userdata()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 User ID.
         *     @type array  $4 Optional. Array of fields to return.
         * }
         * @return array|IXR_Error Array contains (based on $fields parameter):
         *  - 'user_id'
         *  - 'username'
         *  - 'first_name'
         *  - 'last_name'
         *  - 'registered'
         *  - 'bio'
         *  - 'email'
         *  - 'nickname'
         *  - 'nicename'
         *  - 'url'
         *  - 'display_name'
         *  - 'roles'
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         *   4: array,
         * } $args
         */
        public function wp_getUser($args)
        {
        }
        /**
         * Retrieves users.
         *
         * The optional $filter parameter modifies the query used to retrieve users.
         * Accepted keys are 'number' (default: 50), 'offset' (default: 0), 'role',
         * 'who', 'orderby', and 'order'.
         *
         * The optional $fields parameter specifies what fields will be included
         * in the response array.
         *
         * @uses get_users()
         * @see wp_getUser() for more on $fields and return values
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Optional. Arguments for the user query.
         *     @type array  $4 Optional. Fields to return.
         * }
         * @return array|IXR_Error users data
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         *   4: array,
         * } $args
         */
        public function wp_getUsers($args)
        {
        }
        /**
         * Retrieves information about the requesting user.
         *
         * @uses get_userdata()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username
         *     @type string $2 Password
         *     @type array  $3 Optional. Fields to return.
         * }
         * @return array|IXR_Error (@see wp_getUser)
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         * } $args
         */
        public function wp_getProfile($args)
        {
        }
        /**
         * Edits user's profile.
         *
         * @uses wp_update_user()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Content struct. It can optionally contain:
         *      - 'first_name'
         *      - 'last_name'
         *      - 'website'
         *      - 'display_name'
         *      - 'nickname'
         *      - 'nicename'
         *      - 'bio'
         * }
         * @return true|IXR_Error True, on success.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         * } $args
         */
        public function wp_editProfile($args)
        {
        }
        /**
         * Retrieves a page.
         *
         * @since 2.2.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type int    $1 Page ID.
         *     @type string $2 Username.
         *     @type string $3 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: int,
         *   2: string,
         *   3: string,
         * } $args
         */
        public function wp_getPage($args)
        {
        }
        /**
         * Retrieves Pages.
         *
         * @since 2.2.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Optional. Number of pages. Default 10.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         * } $args
         */
        public function wp_getPages($args)
        {
        }
        /**
         * Creates a new page.
         *
         * @since 2.2.0
         *
         * @see wp_xmlrpc_server::mw_newPost()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Content struct.
         * }
         * @return int|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         * } $args
         */
        public function wp_newPage($args)
        {
        }
        /**
         * Deletes a page.
         *
         * @since 2.2.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Page ID.
         * }
         * @return true|IXR_Error True, if success.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         * } $args
         */
        public function wp_deletePage($args)
        {
        }
        /**
         * Edits a page.
         *
         * @since 2.2.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type int    $1 Page ID.
         *     @type string $2 Username.
         *     @type string $3 Password.
         *     @type string $4 Content.
         *     @type int    $5 Publish flag. 0 for draft, 1 for publish.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: int,
         *   2: string,
         *   3: string,
         *   4: string,
         *   5: int,
         * } $args
         */
        public function wp_editPage($args)
        {
        }
        /**
         * Retrieves page list.
         *
         * @since 2.2.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function wp_getPageList($args)
        {
        }
        /**
         * Retrieves authors list.
         *
         * @since 2.2.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function wp_getAuthors($args)
        {
        }
        /**
         * Gets the list of all tags.
         *
         * @since 2.7.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function wp_getTags($args)
        {
        }
        /**
         * Creates a new category.
         *
         * @since 2.2.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Category.
         * }
         * @return int|IXR_Error Category ID.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         * } $args
         */
        public function wp_newCategory($args)
        {
        }
        /**
         * Deletes a category.
         *
         * @since 2.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Category ID.
         * }
         * @return bool|IXR_Error See wp_delete_term() for return info.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         * } $args
         */
        public function wp_deleteCategory($args)
        {
        }
        /**
         * Retrieves category list.
         *
         * @since 2.2.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Category
         *     @type int    $4 Max number of results.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         *   4: int,
         * } $args
         */
        public function wp_suggestCategories($args)
        {
        }
        /**
         * Retrieves a comment.
         *
         * @since 2.7.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Comment ID.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         * } $args
         */
        public function wp_getComment($args)
        {
        }
        /**
         * Retrieves comments.
         *
         * Besides the common blog_id (unused), username, and password arguments,
         * it takes a filter array as the last argument.
         *
         * Accepted 'filter' keys are 'status', 'post_id', 'offset', and 'number'.
         *
         * The defaults are as follows:
         * - 'status'  - Default is ''. Filter by status (e.g., 'approve', 'hold')
         * - 'post_id' - Default is ''. The post where the comment is posted.
         *               Empty string shows all comments.
         * - 'number'  - Default is 10. Total number of media items to retrieve.
         * - 'offset'  - Default is 0. See WP_Query::query() for more.
         *
         * @since 2.7.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Optional. Query arguments.
         * }
         * @return array|IXR_Error Array containing a collection of comments.
         *                         See wp_xmlrpc_server::wp_getComment() for a description
         *                         of each item contents.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         * } $args
         */
        public function wp_getComments($args)
        {
        }
        /**
         * Deletes a comment.
         *
         * By default, the comment will be moved to the Trash instead of deleted.
         * See wp_delete_comment() for more information on this behavior.
         *
         * @since 2.7.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Comment ID.
         * }
         * @return bool|IXR_Error See wp_delete_comment().
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         * } $args
         */
        public function wp_deleteComment($args)
        {
        }
        /**
         * Edits a comment.
         *
         * Besides the common blog_id (unused), username, and password arguments,
         * it takes a comment_id integer and a content_struct array as the last argument.
         *
         * The allowed keys in the content_struct array are:
         *  - 'author'
         *  - 'author_url'
         *  - 'author_email'
         *  - 'content'
         *  - 'date_created_gmt'
         *  - 'status'. Common statuses are 'approve', 'hold', 'spam'. See get_comment_statuses() for more details.
         *
         * @since 2.7.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Comment ID.
         *     @type array  $4 Content structure.
         * }
         * @return true|IXR_Error True, on success.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         *   4: array,
         * } $args
         */
        public function wp_editComment($args)
        {
        }
        /**
         * Creates a new comment.
         *
         * @since 2.7.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int        $0 Blog ID (unused).
         *     @type string     $1 Username.
         *     @type string     $2 Password.
         *     @type string|int $3 Post ID or URL.
         *     @type array      $4 Content structure.
         * }
         * @return int|IXR_Error See wp_new_comment().
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: string|int,
         *   4: array,
         * } $args
         */
        public function wp_newComment($args)
        {
        }
        /**
         * Retrieves all of the comment status.
         *
         * @since 2.7.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function wp_getCommentStatusList($args)
        {
        }
        /**
         * Retrieves comment counts.
         *
         * @since 2.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Post ID.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         * } $args
         */
        public function wp_getCommentCount($args)
        {
        }
        /**
         * Retrieves post statuses.
         *
         * @since 2.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function wp_getPostStatusList($args)
        {
        }
        /**
         * Retrieves page statuses.
         *
         * @since 2.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function wp_getPageStatusList($args)
        {
        }
        /**
         * Retrieves page templates.
         *
         * @since 2.6.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function wp_getPageTemplates($args)
        {
        }
        /**
         * Retrieves blog options.
         *
         * @since 2.6.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Optional. Options.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         * } $args
         */
        public function wp_getOptions($args)
        {
        }
        /**
         * Retrieves blog options value from list.
         *
         * @since 2.6.0
         *
         * @param array $options Options to retrieve.
         * @return array
         */
        public function _getOptions($options)
        {
        }
        /**
         * Updates blog options.
         *
         * @since 2.6.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Options.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         * } $args
         */
        public function wp_setOptions($args)
        {
        }
        /**
         * Retrieves a media item by ID.
         *
         * @since 3.1.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Attachment ID.
         * }
         * @return array|IXR_Error Associative array contains:
         *  - 'date_created_gmt'
         *  - 'parent'
         *  - 'link'
         *  - 'thumbnail'
         *  - 'title'
         *  - 'caption'
         *  - 'description'
         *  - 'metadata'
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         * } $args
         */
        public function wp_getMediaItem($args)
        {
        }
        /**
         * Retrieves a collection of media library items (or attachments).
         *
         * Besides the common blog_id (unused), username, and password arguments,
         * it takes a filter array as the last argument.
         *
         * Accepted 'filter' keys are 'parent_id', 'mime_type', 'offset', and 'number'.
         *
         * The defaults are as follows:
         * - 'number'    - Default is 5. Total number of media items to retrieve.
         * - 'offset'    - Default is 0. See WP_Query::query() for more.
         * - 'parent_id' - Default is ''. The post where the media item is attached.
         *                 Empty string shows all media items. 0 shows unattached media items.
         * - 'mime_type' - Default is ''. Filter by mime type (e.g., 'image/jpeg', 'application/pdf')
         *
         * @since 3.1.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Optional. Query arguments.
         * }
         * @return array|IXR_Error Array containing a collection of media items.
         *                         See wp_xmlrpc_server::wp_getMediaItem() for a description
         *                         of each item contents.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         * } $args
         */
        public function wp_getMediaLibrary($args)
        {
        }
        /**
         * Retrieves a list of post formats used by the site.
         *
         * @since 3.1.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error List of post formats, otherwise IXR_Error object.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function wp_getPostFormats($args)
        {
        }
        /**
         * Retrieves a post type.
         *
         * @since 3.4.0
         *
         * @see get_post_type_object()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type string $3 Post type name.
         *     @type array  $4 Optional. Fields to fetch.
         * }
         * @return array|IXR_Error Array contains:
         *  - 'labels'
         *  - 'description'
         *  - 'capability_type'
         *  - 'cap'
         *  - 'map_meta_cap'
         *  - 'hierarchical'
         *  - 'menu_position'
         *  - 'taxonomies'
         *  - 'supports'
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: string,
         *   4: array,
         * } $args
         */
        public function wp_getPostType($args)
        {
        }
        /**
         * Retrieves post types.
         *
         * @since 3.4.0
         *
         * @see get_post_types()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Optional. Query arguments.
         *     @type array  $4 Optional. Fields to fetch.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         *   4: array,
         * } $args
         */
        public function wp_getPostTypes($args)
        {
        }
        /**
         * Retrieves revisions for a specific post.
         *
         * @since 3.5.0
         *
         * The optional $fields parameter specifies what fields will be included
         * in the response array.
         *
         * @uses wp_get_post_revisions()
         * @see wp_getPost() for more on $fields
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Post ID.
         *     @type array  $4 Optional. Fields to fetch.
         * }
         * @return array|IXR_Error Array containing a collection of posts.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         *   4: array,
         * } $args
         */
        public function wp_getRevisions($args)
        {
        }
        /**
         * Restores a post revision.
         *
         * @since 3.5.0
         *
         * @uses wp_restore_post_revision()
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Revision ID.
         * }
         * @return bool|IXR_Error false if there was an error restoring, true if success.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         * } $args
         */
        public function wp_restoreRevision($args)
        {
        }
        /**
         * Retrieves blogs that user owns.
         *
         * Will make more sense once we support multiple blogs.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function blogger_getUsersBlogs($args)
        {
        }
        /**
         * Private function for retrieving a users blogs for multisite setups.
         *
         * @since 3.0.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        protected function _multisite_getUsersBlogs($args)
        {
        }
        /**
         * Retrieves user's data.
         *
         * Gives your client some info about you, so you don't have to.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function blogger_getUserInfo($args)
        {
        }
        /**
         * Retrieves a post.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type int    $1 Post ID.
         *     @type string $2 Username.
         *     @type string $3 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: int,
         *   2: string,
         *   3: string,
         * } $args
         */
        public function blogger_getPost($args)
        {
        }
        /**
         * Retrieves the list of recent posts.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type string $0 App key (unused).
         *     @type int    $1 Blog ID (unused).
         *     @type string $2 Username.
         *     @type string $3 Password.
         *     @type int    $4 Optional. Number of posts.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: string,
         *   1: int,
         *   2: string,
         *   3: string,
         *   4: int,
         * } $args
         */
        public function blogger_getRecentPosts($args)
        {
        }
        /**
         * Deprecated.
         *
         * @since 1.5.0
         * @deprecated 3.5.0
         *
         * @param array $args Unused.
         * @return IXR_Error Error object.
         */
        public function blogger_getTemplate($args)
        {
        }
        /**
         * Deprecated.
         *
         * @since 1.5.0
         * @deprecated 3.5.0
         *
         * @param array $args Unused.
         * @return IXR_Error Error object.
         */
        public function blogger_setTemplate($args)
        {
        }
        /**
         * Creates a new post.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type string $0 App key (unused).
         *     @type int    $1 Blog ID (unused).
         *     @type string $2 Username.
         *     @type string $3 Password.
         *     @type string $4 Content.
         *     @type int    $5 Publish flag. 0 for draft, 1 for publish.
         * }
         * @return int|IXR_Error
         * @phpstan-param array{
         *   0: string,
         *   1: int,
         *   2: string,
         *   3: string,
         *   4: string,
         *   5: int,
         * } $args
         */
        public function blogger_newPost($args)
        {
        }
        /**
         * Edits a post.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type int    $1 Post ID.
         *     @type string $2 Username.
         *     @type string $3 Password.
         *     @type string $4 Content
         *     @type int    $5 Publish flag. 0 for draft, 1 for publish.
         * }
         * @return true|IXR_Error true when done.
         * @phpstan-param array{
         *   0: int,
         *   1: int,
         *   2: string,
         *   3: string,
         *   4: string,
         *   5: int,
         * } $args
         */
        public function blogger_editPost($args)
        {
        }
        /**
         * Deletes a post.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type int    $1 Post ID.
         *     @type string $2 Username.
         *     @type string $3 Password.
         * }
         * @return true|IXR_Error True when post is deleted.
         * @phpstan-param array{
         *   0: int,
         *   1: int,
         *   2: string,
         *   3: string,
         * } $args
         */
        public function blogger_deletePost($args)
        {
        }
        /**
         * Creates a new post.
         *
         * The 'content_struct' argument must contain:
         *  - title
         *  - description
         *  - mt_excerpt
         *  - mt_text_more
         *  - mt_keywords
         *  - mt_tb_ping_urls
         *  - categories
         *
         * Also, it can optionally contain:
         *  - wp_slug
         *  - wp_password
         *  - wp_page_parent_id
         *  - wp_page_order
         *  - wp_author_id
         *  - post_status | page_status - can be 'draft', 'private', 'publish', or 'pending'
         *  - mt_allow_comments - can be 'open' or 'closed'
         *  - mt_allow_pings - can be 'open' or 'closed'
         *  - date_created_gmt
         *  - dateCreated
         *  - wp_post_thumbnail
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Content structure.
         *     @type int    $4 Optional. Publish flag. 0 for draft, 1 for publish. Default 0.
         * }
         * @return int|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         *   4: int,
         * } $args
         */
        public function mw_newPost($args)
        {
        }
        /**
         * Adds an enclosure to a post if it's new.
         *
         * @since 2.8.0
         *
         * @param int   $post_id   Post ID.
         * @param array $enclosure Enclosure data.
         */
        public function add_enclosure_if_new($post_id, $enclosure)
        {
        }
        /**
         * Attaches an upload to a post.
         *
         * @since 2.1.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param int    $post_id      Post ID.
         * @param string $post_content Post Content for attachment.
         */
        public function attach_uploads($post_id, $post_content)
        {
        }
        /**
         * Edits a post.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Post ID.
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Content structure.
         *     @type int    $4 Optional. Publish flag. 0 for draft, 1 for publish. Default 0.
         * }
         * @return true|IXR_Error True on success.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         *   4: int,
         * } $args
         */
        public function mw_editPost($args)
        {
        }
        /**
         * Retrieves a post.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Post ID.
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function mw_getPost($args)
        {
        }
        /**
         * Retrieves list of recent posts.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Optional. Number of posts.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         * } $args
         */
        public function mw_getRecentPosts($args)
        {
        }
        /**
         * Retrieves the list of categories on a given blog.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function mw_getCategories($args)
        {
        }
        /**
         * Uploads a file, following your settings.
         *
         * Adapted from a patch by Johann Richard.
         *
         * @link http://mycvs.org/archives/2004/06/30/file-upload-to-wordpress-in-ecto/
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Data.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         * } $args
         */
        public function mw_newMediaObject($args)
        {
        }
        /**
         * Retrieves the post titles of recent posts.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type int    $3 Optional. Number of posts.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: int,
         * } $args
         */
        public function mt_getRecentPostTitles($args)
        {
        }
        /**
         * Retrieves the list of all categories on a blog.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Blog ID (unused).
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function mt_getCategoryList($args)
        {
        }
        /**
         * Retrieves post categories.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Post ID.
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return array|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function mt_getPostCategories($args)
        {
        }
        /**
         * Sets categories for a post.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Post ID.
         *     @type string $1 Username.
         *     @type string $2 Password.
         *     @type array  $3 Categories.
         * }
         * @return true|IXR_Error True on success.
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         *   3: array,
         * } $args
         */
        public function mt_setPostCategories($args)
        {
        }
        /**
         * Retrieves an array of methods supported by this server.
         *
         * @since 1.5.0
         *
         * @return array
         */
        public function mt_supportedMethods()
        {
        }
        /**
         * Retrieves an empty array because we don't support per-post text filters.
         *
         * @since 1.5.0
         */
        public function mt_supportedTextFilters()
        {
        }
        /**
         * Retrieves trackbacks sent to a given post.
         *
         * @since 1.5.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param int $post_id
         * @return array|IXR_Error
         */
        public function mt_getTrackbackPings($post_id)
        {
        }
        /**
         * Sets a post's publish status to 'publish'.
         *
         * @since 1.5.0
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type int    $0 Post ID.
         *     @type string $1 Username.
         *     @type string $2 Password.
         * }
         * @return int|IXR_Error
         * @phpstan-param array{
         *   0: int,
         *   1: string,
         *   2: string,
         * } $args
         */
        public function mt_publishPost($args)
        {
        }
        /**
         * Retrieves a pingback and registers it.
         *
         * @since 1.5.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param array $args {
         *     Method arguments. Note: arguments must be ordered as documented.
         *
         *     @type string $0 URL of page linked from.
         *     @type string $1 URL of page linked to.
         * }
         * @return string|IXR_Error
         * @phpstan-param array{
         *   0: string,
         *   1: string,
         * } $args
         */
        public function pingback_ping($args)
        {
        }
        /**
         * Retrieves an array of URLs that pingbacked the given URL.
         *
         * Specs on http://www.aquarionics.com/misc/archives/blogite/0198.html
         *
         * @since 1.5.0
         *
         * @global wpdb $wpdb WordPress database abstraction object.
         *
         * @param string $url
         * @return array|IXR_Error
         */
        public function pingback_extensions_getPingbacks($url)
        {
        }
        /**
         * Sends a pingback error based on the given error code and message.
         *
         * @since 3.6.0
         *
         * @param int    $code    Error code.
         * @param string $message Error message.
         * @return IXR_Error Error object.
         */
        protected function pingback_error($code, $message)
        {
        }
    }
    /**
     * WordPress environment setup class.
     *
     * @package WordPress
     * @since 2.0.0
     */
    #[\AllowDynamicProperties]
    class WP
    {
        /**
         * Public query variables.
         *
         * Long list of public query variables.
         *
         * @since 2.0.0
         * @var string[]
         */
        public $public_query_vars = array('m', 'p', 'posts', 'w', 'cat', 'withcomments', 'withoutcomments', 's', 'search', 'exact', 'sentence', 'calendar', 'page', 'paged', 'more', 'tb', 'pb', 'author', 'order', 'orderby', 'year', 'monthnum', 'day', 'hour', 'minute', 'second', 'name', 'category_name', 'tag', 'feed', 'author_name', 'pagename', 'page_id', 'error', 'attachment', 'attachment_id', 'subpost', 'subpost_id', 'preview', 'robots', 'favicon', 'taxonomy', 'term', 'cpage', 'post_type', 'embed');
        /**
         * Private query variables.
         *
         * Long list of private query variables.
         *
         * @since 2.0.0
         * @var string[]
         */
        public $private_query_vars = array('offset', 'posts_per_page', 'posts_per_archive_page', 'showposts', 'nopaging', 'post_type', 'post_status', 'category__in', 'category__not_in', 'category__and', 'tag__in', 'tag__not_in', 'tag__and', 'tag_slug__in', 'tag_slug__and', 'tag_id', 'post_mime_type', 'perm', 'comments_per_page', 'post__in', 'post__not_in', 'post_parent', 'post_parent__in', 'post_parent__not_in', 'title', 'fields');
        /**
         * Extra query variables set by the user.
         *
         * @since 2.1.0
         * @var array
         */
        public $extra_query_vars = array();
        /**
         * Query variables for setting up the WordPress Query Loop.
         *
         * @since 2.0.0
         * @var array
         */
        public $query_vars = array();
        /**
         * String parsed to set the query variables.
         *
         * @since 2.0.0
         * @var string
         */
        public $query_string = '';
        /**
         * The request path, e.g. 2015/05/06.
         *
         * @since 2.0.0
         * @var string
         */
        public $request = '';
        /**
         * Rewrite rule the request matched.
         *
         * @since 2.0.0
         * @var string
         */
        public $matched_rule = '';
        /**
         * Rewrite query the request matched.
         *
         * @since 2.0.0
         * @var string
         */
        public $matched_query = '';
        /**
         * Whether already did the permalink.
         *
         * @since 2.0.0
         * @var bool
         */
        public $did_permalink = \false;
        /**
         * Adds a query variable to the list of public query variables.
         *
         * @since 2.1.0
         *
         * @param string $qv Query variable name.
         */
        public function add_query_var($qv)
        {
        }
        /**
         * Removes a query variable from a list of public query variables.
         *
         * @since 4.5.0
         *
         * @param string $name Query variable name.
         */
        public function remove_query_var($name)
        {
        }
        /**
         * Sets the value of a query variable.
         *
         * @since 2.3.0
         *
         * @param string $key   Query variable name.
         * @param mixed  $value Query variable value.
         */
        public function set_query_var($key, $value)
        {
        }
        /**
         * Parses the request to find the correct WordPress query.
         *
         * Sets up the query variables based on the request. There are also many
         * filters and actions that can be used to further manipulate the result.
         *
         * @since 2.0.0
         * @since 6.0.0 A return value was added.
         *
         * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
         *
         * @param array|string $extra_query_vars Set the extra query variables.
         * @return bool Whether the request was parsed.
         */
        public function parse_request($extra_query_vars = '')
        {
        }
        /**
         * Sends additional HTTP headers for caching, content type, etc.
         *
         * Sets the Content-Type header. Sets the 'error' status (if passed) and optionally exits.
         * If showing a feed, it will also send Last-Modified, ETag, and 304 status if needed.
         *
         * @since 2.0.0
         * @since 4.4.0 `X-Pingback` header is added conditionally for single posts that allow pings.
         * @since 6.1.0 Runs after posts have been queried.
         *
         * @global WP_Query $wp_query WordPress Query object.
         */
        public function send_headers()
        {
        }
        /**
         * Sets the query string property based off of the query variable property.
         *
         * The {@see 'query_string'} filter is deprecated, but still works. Plugins should
         * use the {@see 'request'} filter instead.
         *
         * @since 2.0.0
         */
        public function build_query_string()
        {
        }
        /**
         * Set up the WordPress Globals.
         *
         * The query_vars property will be extracted to the GLOBALS. So care should
         * be taken when naming global variables that might interfere with the
         * WordPress environment.
         *
         * @since 2.0.0
         *
         * @global WP_Query     $wp_query     WordPress Query object.
         * @global string       $query_string Query string for the loop.
         * @global array        $posts        The found posts.
         * @global WP_Post|null $post         The current post, if available.
         * @global string       $request      The SQL statement for the request.
         * @global int          $more         Only set, if single page or post.
         * @global int          $single       If single page or post. Only set, if single page or post.
         * @global WP_User      $authordata   Only set, if author archive.
         */
        public function register_globals()
        {
        }
        /**
         * Set up the current user.
         *
         * @since 2.0.0
         */
        public function init()
        {
        }
        /**
         * Set up the Loop based on the query variables.
         *
         * @since 2.0.0
         *
         * @global WP_Query $wp_the_query WordPress Query object.
         */
        public function query_posts()
        {
        }
        /**
         * Set the Headers for 404, if nothing is found for requested URL.
         *
         * Issue a 404 if a request doesn't match any posts and doesn't match any object
         * (e.g. an existing-but-empty category, tag, author) and a 404 was not already issued,
         * and if the request was not a search or the homepage.
         *
         * Otherwise, issue a 200.
         *
         * This sets headers after posts have been queried. handle_404() really means "handle status".
         * By inspecting the result of querying posts, seemingly successful requests can be switched to
         * a 404 so that canonical redirection logic can kick in.
         *
         * @since 2.0.0
         *
         * @global WP_Query $wp_query WordPress Query object.
         * @phpstan-return void
         */
        public function handle_404()
        {
        }
        /**
         * Sets up all of the variables required by the WordPress environment.
         *
         * The action {@see 'wp'} has one parameter that references the WP object. It
         * allows for accessing the properties and methods to further manipulate the
         * object.
         *
         * @since 2.0.0
         *
         * @param string|array $query_args Passed to parse_request().
         */
        public function main($query_args = '')
        {
        }
    }
    /**
     * WordPress database access abstraction class.
     *
     * This class is used to interact with a database without needing to use raw SQL statements.
     * By default, WordPress uses this class to instantiate the global $wpdb object, providing
     * access to the WordPress database.
     *
     * It is possible to replace this class with your own by setting the $wpdb global variable
     * in wp-content/db.php file to your class. The wpdb class will still be included, so you can
     * extend it or simply use your own.
     *
     * @link https://developer.wordpress.org/reference/classes/wpdb/
     *
     * @since 0.71
     */
    #[\AllowDynamicProperties]
    class wpdb
    {
        /**
         * Whether to show SQL/DB errors.
         *
         * Default is to show errors if both WP_DEBUG and WP_DEBUG_DISPLAY evaluate to true.
         *
         * @since 0.71
         *
         * @var bool
         */
        public $show_errors = \false;
        /**
         * Whether to suppress errors during the DB bootstrapping. Default false.
         *
         * @since 2.5.0
         *
         * @var bool
         */
        public $suppress_errors = \false;
        /**
         * The error encountered during the last query.
         *
         * @since 2.5.0
         *
         * @var string
         */
        public $last_error = '';
        /**
         * The number of queries made.
         *
         * @since 1.2.0
         *
         * @var int
         */
        public $num_queries = 0;
        /**
         * Count of rows returned by the last query.
         *
         * @since 0.71
         *
         * @var int
         */
        public $num_rows = 0;
        /**
         * Count of rows affected by the last query.
         *
         * @since 0.71
         *
         * @var int
         */
        public $rows_affected = 0;
        /**
         * The ID generated for an AUTO_INCREMENT column by the last query (usually INSERT).
         *
         * @since 0.71
         *
         * @var int
         */
        public $insert_id = 0;
        /**
         * The last query made.
         *
         * @since 0.71
         *
         * @var string
         */
        public $last_query;
        /**
         * Results of the last query.
         *
         * @since 0.71
         *
         * @var stdClass[]|null
         */
        public $last_result;
        /**
         * Database query result.
         *
         * Possible values:
         *
         * - `mysqli_result` instance for successful SELECT, SHOW, DESCRIBE, or EXPLAIN queries
         * - `true` for other query types that were successful
         * - `null` if a query is yet to be made or if the result has since been flushed
         * - `false` if the query returned an error
         *
         * @since 0.71
         *
         * @var mysqli_result|bool|null
         */
        protected $result;
        /**
         * Cached column info, for confidence checking data before inserting.
         *
         * @since 4.2.0
         *
         * @var array
         */
        protected $col_meta = array();
        /**
         * Calculated character sets keyed by table name.
         *
         * @since 4.2.0
         *
         * @var string[]
         */
        protected $table_charset = array();
        /**
         * Whether text fields in the current query need to be confidence checked.
         *
         * @since 4.2.0
         *
         * @var bool
         */
        protected $check_current_query = \true;
        /**
         * Saved info on the table column.
         *
         * @since 0.71
         *
         * @var array
         */
        protected $col_info;
        /**
         * Log of queries that were executed, for debugging purposes.
         *
         * @since 1.5.0
         * @since 2.5.0 The third element in each query log was added to record the calling functions.
         * @since 5.1.0 The fourth element in each query log was added to record the start time.
         * @since 5.3.0 The fifth element in each query log was added to record custom data.
         *
         * @var array[] {
         *     Array of arrays containing information about queries that were executed.
         *
         *     @type array ...$0 {
         *         Data for each query.
         *
         *         @type string $0 The query's SQL.
         *         @type float  $1 Total time spent on the query, in seconds.
         *         @type string $2 Comma-separated list of the calling functions.
         *         @type float  $3 Unix timestamp of the time at the start of the query.
         *         @type array  $4 Custom query data.
         *     }
         * }
         * @phpstan-var array<int|string, array{
         *   0: string,
         *   1: float,
         *   2: string,
         *   3: float,
         *   4: array,
         * }>
         */
        public $queries;
        /**
         * The number of times to retry reconnecting before dying. Default 5.
         *
         * @since 3.9.0
         *
         * @see wpdb::check_connection()
         * @var int
         */
        protected $reconnect_retries = 5;
        /**
         * WordPress table prefix.
         *
         * You can set this to have multiple WordPress installations in a single database.
         * The second reason is for possible security precautions.
         *
         * @since 2.5.0
         *
         * @var string
         */
        public $prefix = '';
        /**
         * WordPress base table prefix.
         *
         * @since 3.0.0
         *
         * @var string
         */
        public $base_prefix;
        /**
         * Whether the database queries are ready to start executing.
         *
         * @since 2.3.2
         *
         * @var bool
         */
        public $ready = \false;
        /**
         * Blog ID.
         *
         * @since 3.0.0
         *
         * @var int
         */
        public $blogid = 0;
        /**
         * Site ID.
         *
         * @since 3.0.0
         *
         * @var int
         */
        public $siteid = 0;
        /**
         * List of WordPress per-site tables.
         *
         * @since 2.5.0
         *
         * @see wpdb::tables()
         * @var string[]
         */
        public $tables = array('posts', 'comments', 'links', 'options', 'postmeta', 'terms', 'term_taxonomy', 'term_relationships', 'termmeta', 'commentmeta');
        /**
         * List of deprecated WordPress tables.
         *
         * 'categories', 'post2cat', and 'link2cat' were deprecated in 2.3.0, db version 5539.
         *
         * @since 2.9.0
         *
         * @see wpdb::tables()
         * @var string[]
         */
        public $old_tables = array('categories', 'post2cat', 'link2cat');
        /**
         * List of WordPress global tables.
         *
         * @since 3.0.0
         *
         * @see wpdb::tables()
         * @var string[]
         */
        public $global_tables = array('users', 'usermeta');
        /**
         * List of Multisite global tables.
         *
         * @since 3.0.0
         *
         * @see wpdb::tables()
         * @var string[]
         */
        public $ms_global_tables = array('blogs', 'blogmeta', 'signups', 'site', 'sitemeta', 'registration_log');
        /**
         * List of deprecated WordPress Multisite global tables.
         *
         * @since 6.1.0
         *
         * @see wpdb::tables()
         * @var string[]
         */
        public $old_ms_global_tables = array('sitecategories');
        /**
         * WordPress Comments table.
         *
         * @since 1.5.0
         *
         * @var string
         */
        public $comments;
        /**
         * WordPress Comment Metadata table.
         *
         * @since 2.9.0
         *
         * @var string
         */
        public $commentmeta;
        /**
         * WordPress Links table.
         *
         * @since 1.5.0
         *
         * @var string
         */
        public $links;
        /**
         * WordPress Options table.
         *
         * @since 1.5.0
         *
         * @var string
         */
        public $options;
        /**
         * WordPress Post Metadata table.
         *
         * @since 1.5.0
         *
         * @var string
         */
        public $postmeta;
        /**
         * WordPress Posts table.
         *
         * @since 1.5.0
         *
         * @var string
         */
        public $posts;
        /**
         * WordPress Terms table.
         *
         * @since 2.3.0
         *
         * @var string
         */
        public $terms;
        /**
         * WordPress Term Relationships table.
         *
         * @since 2.3.0
         *
         * @var string
         */
        public $term_relationships;
        /**
         * WordPress Term Taxonomy table.
         *
         * @since 2.3.0
         *
         * @var string
         */
        public $term_taxonomy;
        /**
         * WordPress Term Meta table.
         *
         * @since 4.4.0
         *
         * @var string
         */
        public $termmeta;
        /**
         * WordPress User Metadata table.
         *
         * @since 2.3.0
         *
         * @var string
         */
        public $usermeta;
        /**
         * WordPress Users table.
         *
         * @since 1.5.0
         *
         * @var string
         */
        public $users;
        /**
         * Multisite Blogs table.
         *
         * @since 3.0.0
         *
         * @var string
         */
        public $blogs;
        /**
         * Multisite Blog Metadata table.
         *
         * @since 5.1.0
         *
         * @var string
         */
        public $blogmeta;
        /**
         * Multisite Registration Log table.
         *
         * @since 3.0.0
         *
         * @var string
         */
        public $registration_log;
        /**
         * Multisite Signups table.
         *
         * @since 3.0.0
         *
         * @var string
         */
        public $signups;
        /**
         * Multisite Sites table.
         *
         * @since 3.0.0
         *
         * @var string
         */
        public $site;
        /**
         * Multisite Sitewide Terms table.
         *
         * @since 3.0.0
         *
         * @var string
         */
        public $sitecategories;
        /**
         * Multisite Site Metadata table.
         *
         * @since 3.0.0
         *
         * @var string
         */
        public $sitemeta;
        /**
         * Format specifiers for DB columns.
         *
         * Columns not listed here default to %s. Initialized during WP load.
         * Keys are column names, values are format types: 'ID' => '%d'.
         *
         * @since 2.8.0
         *
         * @see wpdb::prepare()
         * @see wpdb::insert()
         * @see wpdb::update()
         * @see wpdb::delete()
         * @see wp_set_wpdb_vars()
         * @var array
         */
        public $field_types = array();
        /**
         * Database table columns charset.
         *
         * @since 2.2.0
         *
         * @var string
         */
        public $charset;
        /**
         * Database table columns collate.
         *
         * @since 2.2.0
         *
         * @var string
         */
        public $collate;
        /**
         * Database Username.
         *
         * @since 2.9.0
         *
         * @var string
         */
        protected $dbuser;
        /**
         * Database Password.
         *
         * @since 3.1.0
         *
         * @var string
         */
        protected $dbpassword;
        /**
         * Database Name.
         *
         * @since 3.1.0
         *
         * @var string
         */
        protected $dbname;
        /**
         * Database Host.
         *
         * @since 3.1.0
         *
         * @var string
         */
        protected $dbhost;
        /**
         * Database handle.
         *
         * Possible values:
         *
         * - `mysqli` instance during normal operation
         * - `null` if the connection is yet to be made or has been closed
         * - `false` if the connection has failed
         *
         * @since 0.71
         *
         * @var mysqli|false|null
         */
        protected $dbh;
        /**
         * A textual description of the last query/get_row/get_var call.
         *
         * @since 3.0.0
         *
         * @var string
         */
        public $func_call;
        /**
         * Whether MySQL is used as the database engine.
         *
         * Set in wpdb::db_connect() to true, by default. This is used when checking
         * against the required MySQL version for WordPress. Normally, a replacement
         * database drop-in (db.php) will skip these checks, but setting this to true
         * will force the checks to occur.
         *
         * @since 3.3.0
         *
         * @var bool
         */
        public $is_mysql = \null;
        /**
         * A list of incompatible SQL modes.
         *
         * @since 3.9.0
         *
         * @var string[]
         */
        protected $incompatible_modes = array('NO_ZERO_DATE', 'ONLY_FULL_GROUP_BY', 'STRICT_TRANS_TABLES', 'STRICT_ALL_TABLES', 'TRADITIONAL', 'ANSI');
        /**
         * Time when the last query was performed.
         *
         * Only set when `SAVEQUERIES` is defined and truthy.
         *
         * @since 1.5.0
         *
         * @var float
         */
        public $time_start = \null;
        /**
         * The last SQL error that was encountered.
         *
         * @since 2.5.0
         *
         * @var WP_Error|string
         */
        public $error = \null;
        /**
         * Connects to the database server and selects a database.
         *
         * Does the actual setting up
         * of the class properties and connection to the database.
         *
         * @since 2.0.8
         *
         * @link https://core.trac.wordpress.org/ticket/3354
         *
         * @param string $dbuser     Database user.
         * @param string $dbpassword Database password.
         * @param string $dbname     Database name.
         * @param string $dbhost     Database host.
         * @phpstan-return void
         */
        public function __construct($dbuser, $dbpassword, $dbname, $dbhost)
        {
        }
        /**
         * Makes private properties readable for backward compatibility.
         *
         * @since 3.5.0
         *
         * @param string $name The private member to get, and optionally process.
         * @return mixed The private member.
         */
        public function __get($name)
        {
        }
        /**
         * Makes private properties settable for backward compatibility.
         *
         * @since 3.5.0
         *
         * @param string $name  The private member to set.
         * @param mixed  $value The value to set.
         * @phpstan-return void
         */
        public function __set($name, $value)
        {
        }
        /**
         * Makes private properties check-able for backward compatibility.
         *
         * @since 3.5.0
         *
         * @param string $name The private member to check.
         * @return bool If the member is set or not.
         */
        public function __isset($name)
        {
        }
        /**
         * Makes private properties un-settable for backward compatibility.
         *
         * @since 3.5.0
         *
         * @param string $name  The private member to unset
         */
        public function __unset($name)
        {
        }
        /**
         * Sets $this->charset and $this->collate.
         *
         * @since 3.1.0
         */
        public function init_charset()
        {
        }
        /**
         * Determines the best charset and collation to use given a charset and collation.
         *
         * For example, when able, utf8mb4 should be used instead of utf8.
         *
         * @since 4.6.0
         *
         * @param string $charset The character set to check.
         * @param string $collate The collation to check.
         * @return array {
         *     The most appropriate character set and collation to use.
         *
         *     @type string $charset Character set.
         *     @type string $collate Collation.
         * }
         * @phpstan-return array{
         *   charset: string,
         *   collate: string,
         * }
         */
        public function determine_charset($charset, $collate)
        {
        }
        /**
         * Sets the connection's character set.
         *
         * @since 3.1.0
         *
         * @param mysqli $dbh     The connection returned by `mysqli_connect()`.
         * @param string $charset Optional. The character set. Default null.
         * @param string $collate Optional. The collation. Default null.
         */
        public function set_charset($dbh, $charset = \null, $collate = \null)
        {
        }
        /**
         * Changes the current SQL mode, and ensures its WordPress compatibility.
         *
         * If no modes are passed, it will ensure the current MySQL server modes are compatible.
         *
         * @since 3.9.0
         *
         * @param array $modes Optional. A list of SQL modes to set. Default empty array.
         * @phpstan-return void
         */
        public function set_sql_mode($modes = array())
        {
        }
        /**
         * Sets the table prefix for the WordPress tables.
         *
         * @since 2.5.0
         *
         * @param string $prefix          Alphanumeric name for the new prefix.
         * @param bool   $set_table_names Optional. Whether the table names, e.g. wpdb::$posts,
         *                                should be updated or not. Default true.
         * @return string|WP_Error Old prefix or WP_Error on error.
         */
        public function set_prefix($prefix, $set_table_names = \true)
        {
        }
        /**
         * Sets blog ID.
         *
         * @since 3.0.0
         *
         * @param int $blog_id
         * @param int $network_id Optional. Network ID. Default 0.
         * @return int Previous blog ID.
         */
        public function set_blog_id($blog_id, $network_id = 0)
        {
        }
        /**
         * Gets blog prefix.
         *
         * @since 3.0.0
         *
         * @param int $blog_id Optional. Blog ID to retrieve the table prefix for.
         *                     Defaults to the current blog ID.
         * @return string Blog prefix.
         */
        public function get_blog_prefix($blog_id = \null)
        {
        }
        /**
         * Returns an array of WordPress tables.
         *
         * Also allows for the `CUSTOM_USER_TABLE` and `CUSTOM_USER_META_TABLE` to override the WordPress users
         * and usermeta tables that would otherwise be determined by the prefix.
         *
         * The `$scope` argument can take one of the following:
         *
         * - 'all' - returns 'all' and 'global' tables. No old tables are returned.
         * - 'blog' - returns the blog-level tables for the queried blog.
         * - 'global' - returns the global tables for the installation, returning multisite tables only on multisite.
         * - 'ms_global' - returns the multisite global tables, regardless if current installation is multisite.
         * - 'old' - returns tables which are deprecated.
         *
         * @since 3.0.0
         * @since 6.1.0 `old` now includes deprecated multisite global tables only on multisite.
         *
         * @uses wpdb::$tables
         * @uses wpdb::$old_tables
         * @uses wpdb::$global_tables
         * @uses wpdb::$ms_global_tables
         * @uses wpdb::$old_ms_global_tables
         *
         * @param string $scope   Optional. Possible values include 'all', 'global', 'ms_global', 'blog',
         *                        or 'old' tables. Default 'all'.
         * @param bool   $prefix  Optional. Whether to include table prefixes. If blog prefix is requested,
         *                        then the custom users and usermeta tables will be mapped. Default true.
         * @param int    $blog_id Optional. The blog_id to prefix. Used only when prefix is requested.
         *                        Defaults to `wpdb::$blogid`.
         * @return string[] Table names. When a prefix is requested, the key is the unprefixed table name.
         */
        public function tables($scope = 'all', $prefix = \true, $blog_id = 0)
        {
        }
        /**
         * Selects a database using the current or provided database connection.
         *
         * The database name will be changed based on the current database connection.
         * On failure, the execution will bail and display a DB error.
         *
         * @since 0.71
         *
         * @param string $db  Database name.
         * @param mysqli $dbh Optional. Database connection.
         *                    Defaults to the current database handle.
         */
        public function select($db, $dbh = \null)
        {
        }
        /**
         * Do not use, deprecated.
         *
         * Use esc_sql() or wpdb::prepare() instead.
         *
         * @since 2.8.0
         * @deprecated 3.6.0 Use wpdb::prepare()
         * @see wpdb::prepare()
         * @see esc_sql()
         *
         * @param string $data
         * @return string
         */
        public function _weak_escape($data)
        {
        }
        /**
         * Real escape using mysqli_real_escape_string().
         *
         * @since 2.8.0
         *
         * @see mysqli_real_escape_string()
         *
         * @param string $data String to escape.
         * @return string Escaped string.
         */
        public function _real_escape($data)
        {
        }
        /**
         * Escapes data. Works on arrays.
         *
         * @since 2.8.0
         *
         * @uses wpdb::_real_escape()
         *
         * @param string|array $data Data to escape.
         * @return string|array Escaped data, in the same type as supplied.
         */
        public function _escape($data)
        {
        }
        /**
         * Do not use, deprecated.
         *
         * Use esc_sql() or wpdb::prepare() instead.
         *
         * @since 0.71
         * @deprecated 3.6.0 Use wpdb::prepare()
         * @see wpdb::prepare()
         * @see esc_sql()
         *
         * @param string|array $data Data to escape.
         * @return string|array Escaped data, in the same type as supplied.
         */
        public function escape($data)
        {
        }
        /**
         * Escapes content by reference for insertion into the database, for security.
         *
         * @uses wpdb::_real_escape()
         *
         * @since 2.3.0
         *
         * @param string $data String to escape.
         */
        public function escape_by_ref(&$data)
        {
        }
        /**
         * Quotes an identifier for a MySQL database, e.g. table/field names.
         *
         * @since 6.2.0
         *
         * @param string $identifier Identifier to escape.
         * @return string Escaped identifier.
         */
        public function quote_identifier($identifier)
        {
        }
        /**
         * Prepares a SQL query for safe execution.
         *
         * Uses `sprintf()`-like syntax. The following placeholders can be used in the query string:
         *
         * - `%d` (integer)
         * - `%f` (float)
         * - `%s` (string)
         * - `%i` (identifier, e.g. table/field names)
         *
         * All placeholders MUST be left unquoted in the query string. A corresponding argument
         * MUST be passed for each placeholder.
         *
         * Note: There is one exception to the above: for compatibility with old behavior,
         * numbered or formatted string placeholders (eg, `%1$s`, `%5s`) will not have quotes
         * added by this function, so should be passed with appropriate quotes around them.
         *
         * Literal percentage signs (`%`) in the query string must be written as `%%`. Percentage wildcards
         * (for example, to use in LIKE syntax) must be passed via a substitution argument containing
         * the complete LIKE string, these cannot be inserted directly in the query string.
         * Also see wpdb::esc_like().
         *
         * Arguments may be passed as individual arguments to the method, or as a single array
         * containing all arguments. A combination of the two is not supported.
         *
         * Examples:
         *
         *     $wpdb->prepare(
         *         "SELECT * FROM `table` WHERE `column` = %s AND `field` = %d OR `other_field` LIKE %s",
         *         array( 'foo', 1337, '%bar' )
         *     );
         *
         *     $wpdb->prepare(
         *         "SELECT DATE_FORMAT(`field`, '%%c') FROM `table` WHERE `column` = %s",
         *         'foo'
         *     );
         *
         * @since 2.3.0
         * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
         *              by updating the function signature. The second parameter was changed
         *              from `$args` to `...$args`.
         * @since 6.2.0 Added `%i` for identifiers, e.g. table or field names.
         *              Check support via `wpdb::has_cap( 'identifier_placeholders' )`.
         *              This preserves compatibility with `sprintf()`, as the C version uses
         *              `%d` and `$i` as a signed integer, whereas PHP only supports `%d`.
         *
         * @link https://www.php.net/sprintf Description of syntax.
         *
         * @param string      $query   Query statement with `sprintf()`-like placeholders.
         * @param array|mixed $args    The array of variables to substitute into the query's placeholders
         *                             if being called with an array of arguments, or the first variable
         *                             to substitute into the query's placeholders if being called with
         *                             individual arguments.
         * @param mixed       ...$args Further variables to substitute into the query's placeholders
         *                             if being called with individual arguments.
         * @return string|void Sanitized query string, if there is a query to prepare.
         * @phpstan-param literal-string $query
         */
        public function prepare($query, ...$args)
        {
        }
        /**
         * First half of escaping for `LIKE` special characters `%` and `_` before preparing for SQL.
         *
         * Use this only before wpdb::prepare() or esc_sql(). Reversing the order is very bad for security.
         *
         * Example Prepared Statement:
         *
         *     $wild = '%';
         *     $find = 'only 43% of planets';
         *     $like = $wild . $wpdb->esc_like( $find ) . $wild;
         *     $sql  = $wpdb->prepare( "SELECT * FROM $wpdb->posts WHERE post_content LIKE %s", $like );
         *
         * Example Escape Chain:
         *
         *     $sql  = esc_sql( $wpdb->esc_like( $input ) );
         *
         * @since 4.0.0
         *
         * @param string $text The raw text to be escaped. The input typed by the user
         *                     should have no extra or deleted slashes.
         * @return string Text in the form of a LIKE phrase. The output is not SQL safe.
         *                Call wpdb::prepare() or wpdb::_real_escape() next.
         */
        public function esc_like($text)
        {
        }
        /**
         * Prints SQL/DB error.
         *
         * @since 0.71
         *
         * @global array $EZSQL_ERROR Stores error information of query and error string.
         *
         * @param string $str The error to display.
         * @return void|false Void if the showing of errors is enabled, false if disabled.
         */
        public function print_error($str = '')
        {
        }
        /**
         * Enables showing of database errors.
         *
         * This function should be used only to enable showing of errors.
         * wpdb::hide_errors() should be used instead for hiding errors.
         *
         * @since 0.71
         *
         * @see wpdb::hide_errors()
         *
         * @param bool $show Optional. Whether to show errors. Default true.
         * @return bool Whether showing of errors was previously active.
         */
        public function show_errors($show = \true)
        {
        }
        /**
         * Disables showing of database errors.
         *
         * By default database errors are not shown.
         *
         * @since 0.71
         *
         * @see wpdb::show_errors()
         *
         * @return bool Whether showing of errors was previously active.
         */
        public function hide_errors()
        {
        }
        /**
         * Enables or disables suppressing of database errors.
         *
         * By default database errors are suppressed.
         *
         * @since 2.5.0
         *
         * @see wpdb::hide_errors()
         *
         * @param bool $suppress Optional. Whether to suppress errors. Default true.
         * @return bool Whether suppressing of errors was previously active.
         */
        public function suppress_errors($suppress = \true)
        {
        }
        /**
         * Kills cached query results.
         *
         * @since 0.71
         * @phpstan-return void
         */
        public function flush()
        {
        }
        /**
         * Connects to and selects database.
         *
         * If `$allow_bail` is false, the lack of database connection will need to be handled manually.
         *
         * @since 3.0.0
         * @since 3.9.0 $allow_bail parameter added.
         *
         * @param bool $allow_bail Optional. Allows the function to bail. Default true.
         * @return bool True with a successful connection, false on failure.
         */
        public function db_connect($allow_bail = \true)
        {
        }
        /**
         * Parses the DB_HOST setting to interpret it for mysqli_real_connect().
         *
         * mysqli_real_connect() doesn't support the host param including a port or socket
         * like mysql_connect() does. This duplicates how mysql_connect() detects a port
         * and/or socket file.
         *
         * @since 4.9.0
         *
         * @param string $host The DB_HOST setting to parse.
         * @return array|false {
         *     Array containing the host, the port, the socket and
         *     whether it is an IPv6 address, in that order.
         *     False if the host couldn't be parsed.
         *
         *     @type string      $0 Host name.
         *     @type string|null $1 Port.
         *     @type string|null $2 Socket.
         *     @type bool        $3 Whether it is an IPv6 address.
         * }
         * @phpstan-return false|array{
         *   0: string,
         *   1: string|null,
         *   2: string|null,
         *   3: bool,
         * }
         */
        public function parse_db_host($host)
        {
        }
        /**
         * Checks that the connection to the database is still up. If not, try to reconnect.
         *
         * If this function is unable to reconnect, it will forcibly die, or if called
         * after the {@see 'template_redirect'} hook has been fired, return false instead.
         *
         * If `$allow_bail` is false, the lack of database connection will need to be handled manually.
         *
         * @since 3.9.0
         *
         * @param bool $allow_bail Optional. Allows the function to bail. Default true.
         * @return bool|void True if the connection is up.
         */
        public function check_connection($allow_bail = \true)
        {
        }
        /**
         * Performs a database query, using current database connection.
         *
         * More information can be found on the documentation page.
         *
         * @since 0.71
         *
         * @link https://developer.wordpress.org/reference/classes/wpdb/
         *
         * @param string $query Database query.
         * @return int|bool Boolean true for CREATE, ALTER, TRUNCATE and DROP queries. Number of rows
         *                  affected/selected for all other queries. Boolean false on error.
         */
        public function query($query)
        {
        }
        /**
         * Logs query data.
         *
         * @since 5.3.0
         *
         * @param string $query           The query's SQL.
         * @param float  $query_time      Total time spent on the query, in seconds.
         * @param string $query_callstack Comma-separated list of the calling functions.
         * @param float  $query_start     Unix timestamp of the time at the start of the query.
         * @param array  $query_data      Custom query data.
         */
        public function log_query($query, $query_time, $query_callstack, $query_start, $query_data)
        {
        }
        /**
         * Generates and returns a placeholder escape string for use in queries returned by ::prepare().
         *
         * @since 4.8.3
         *
         * @return string String to escape placeholders.
         */
        public function placeholder_escape()
        {
        }
        /**
         * Adds a placeholder escape string, to escape anything that resembles a printf() placeholder.
         *
         * @since 4.8.3
         *
         * @param string $query The query to escape.
         * @return string The query with the placeholder escape string inserted where necessary.
         */
        public function add_placeholder_escape($query)
        {
        }
        /**
         * Removes the placeholder escape strings from a query.
         *
         * @since 4.8.3
         *
         * @param string $query The query from which the placeholder will be removed.
         * @return string The query with the placeholder removed.
         */
        public function remove_placeholder_escape($query)
        {
        }
        /**
         * Inserts a row into the table.
         *
         * Examples:
         *
         *     $wpdb->insert(
         *         'table',
         *         array(
         *             'column1' => 'foo',
         *             'column2' => 'bar',
         *         )
         *     );
         *     $wpdb->insert(
         *         'table',
         *         array(
         *             'column1' => 'foo',
         *             'column2' => 1337,
         *         ),
         *         array(
         *             '%s',
         *             '%d',
         *         )
         *     );
         *
         * @since 2.5.0
         *
         * @see wpdb::prepare()
         * @see wpdb::$field_types
         * @see wp_set_wpdb_vars()
         *
         * @param string          $table  Table name.
         * @param array           $data   Data to insert (in column => value pairs).
         *                                Both `$data` columns and `$data` values should be "raw" (neither should be SQL escaped).
         *                                Sending a null value will cause the column to be set to NULL - the corresponding
         *                                format is ignored in this case.
         * @param string[]|string $format Optional. An array of formats to be mapped to each of the value in `$data`.
         *                                If string, that format will be used for all of the values in `$data`.
         *                                A format is one of '%d', '%f', '%s' (integer, float, string).
         *                                If omitted, all values in `$data` will be treated as strings unless otherwise
         *                                specified in wpdb::$field_types. Default null.
         * @return int|false The number of rows inserted, or false on error.
         */
        public function insert($table, $data, $format = \null)
        {
        }
        /**
         * Replaces a row in the table or inserts it if it does not exist, based on a PRIMARY KEY or a UNIQUE index.
         *
         * A REPLACE works exactly like an INSERT, except that if an old row in the table has the same value as a new row
         * for a PRIMARY KEY or a UNIQUE index, the old row is deleted before the new row is inserted.
         *
         * Examples:
         *
         *     $wpdb->replace(
         *         'table',
         *         array(
         *             'ID'      => 123,
         *             'column1' => 'foo',
         *             'column2' => 'bar',
         *         )
         *     );
         *     $wpdb->replace(
         *         'table',
         *         array(
         *             'ID'      => 456,
         *             'column1' => 'foo',
         *             'column2' => 1337,
         *         ),
         *         array(
         *             '%d',
         *             '%s',
         *             '%d',
         *         )
         *     );
         *
         * @since 3.0.0
         *
         * @see wpdb::prepare()
         * @see wpdb::$field_types
         * @see wp_set_wpdb_vars()
         *
         * @param string          $table  Table name.
         * @param array           $data   Data to insert (in column => value pairs).
         *                                Both `$data` columns and `$data` values should be "raw" (neither should be SQL escaped).
         *                                A primary key or unique index is required to perform a replace operation.
         *                                Sending a null value will cause the column to be set to NULL - the corresponding
         *                                format is ignored in this case.
         * @param string[]|string $format Optional. An array of formats to be mapped to each of the value in `$data`.
         *                                If string, that format will be used for all of the values in `$data`.
         *                                A format is one of '%d', '%f', '%s' (integer, float, string).
         *                                If omitted, all values in `$data` will be treated as strings unless otherwise
         *                                specified in wpdb::$field_types. Default null.
         * @return int|false The number of rows affected, or false on error.
         */
        public function replace($table, $data, $format = \null)
        {
        }
        /**
         * Helper function for insert and replace.
         *
         * Runs an insert or replace query based on `$type` argument.
         *
         * @since 3.0.0
         *
         * @see wpdb::prepare()
         * @see wpdb::$field_types
         * @see wp_set_wpdb_vars()
         *
         * @param string          $table  Table name.
         * @param array           $data   Data to insert (in column => value pairs).
         *                                Both `$data` columns and `$data` values should be "raw" (neither should be SQL escaped).
         *                                Sending a null value will cause the column to be set to NULL - the corresponding
         *                                format is ignored in this case.
         * @param string[]|string $format Optional. An array of formats to be mapped to each of the value in `$data`.
         *                                If string, that format will be used for all of the values in `$data`.
         *                                A format is one of '%d', '%f', '%s' (integer, float, string).
         *                                If omitted, all values in `$data` will be treated as strings unless otherwise
         *                                specified in wpdb::$field_types. Default null.
         * @param string          $type   Optional. Type of operation. Either 'INSERT' or 'REPLACE'.
         *                                Default 'INSERT'.
         * @return int|false The number of rows affected, or false on error.
         * @phpstan-param 'INSERT'|'REPLACE' $type
         */
        public function _insert_replace_helper($table, $data, $format = \null, $type = 'INSERT')
        {
        }
        /**
         * Updates a row in the table.
         *
         * Examples:
         *
         *     $wpdb->update(
         *         'table',
         *         array(
         *             'column1' => 'foo',
         *             'column2' => 'bar',
         *         ),
         *         array(
         *             'ID' => 1,
         *         )
         *     );
         *     $wpdb->update(
         *         'table',
         *         array(
         *             'column1' => 'foo',
         *             'column2' => 1337,
         *         ),
         *         array(
         *             'ID' => 1,
         *         ),
         *         array(
         *             '%s',
         *             '%d',
         *         ),
         *         array(
         *             '%d',
         *         )
         *     );
         *
         * @since 2.5.0
         *
         * @see wpdb::prepare()
         * @see wpdb::$field_types
         * @see wp_set_wpdb_vars()
         *
         * @param string       $table           Table name.
         * @param array        $data            Data to update (in column => value pairs).
         *                                      Both $data columns and $data values should be "raw" (neither should be SQL escaped).
         *                                      Sending a null value will cause the column to be set to NULL - the corresponding
         *                                      format is ignored in this case.
         * @param array        $where           A named array of WHERE clauses (in column => value pairs).
         *                                      Multiple clauses will be joined with ANDs.
         *                                      Both $where columns and $where values should be "raw".
         *                                      Sending a null value will create an IS NULL comparison - the corresponding
         *                                      format will be ignored in this case.
         * @param string[]|string $format       Optional. An array of formats to be mapped to each of the values in $data.
         *                                      If string, that format will be used for all of the values in $data.
         *                                      A format is one of '%d', '%f', '%s' (integer, float, string).
         *                                      If omitted, all values in $data will be treated as strings unless otherwise
         *                                      specified in wpdb::$field_types. Default null.
         * @param string[]|string $where_format Optional. An array of formats to be mapped to each of the values in $where.
         *                                      If string, that format will be used for all of the items in $where.
         *                                      A format is one of '%d', '%f', '%s' (integer, float, string).
         *                                      If omitted, all values in $where will be treated as strings unless otherwise
         *                                      specified in wpdb::$field_types. Default null.
         * @return int|false The number of rows updated, or false on error.
         */
        public function update($table, $data, $where, $format = \null, $where_format = \null)
        {
        }
        /**
         * Deletes a row in the table.
         *
         * Examples:
         *
         *     $wpdb->delete(
         *         'table',
         *         array(
         *             'ID' => 1,
         *         )
         *     );
         *     $wpdb->delete(
         *         'table',
         *         array(
         *             'ID' => 1,
         *         ),
         *         array(
         *             '%d',
         *         )
         *     );
         *
         * @since 3.4.0
         *
         * @see wpdb::prepare()
         * @see wpdb::$field_types
         * @see wp_set_wpdb_vars()
         *
         * @param string          $table        Table name.
         * @param array           $where        A named array of WHERE clauses (in column => value pairs).
         *                                      Multiple clauses will be joined with ANDs.
         *                                      Both $where columns and $where values should be "raw".
         *                                      Sending a null value will create an IS NULL comparison - the corresponding
         *                                      format will be ignored in this case.
         * @param string[]|string $where_format Optional. An array of formats to be mapped to each of the values in $where.
         *                                      If string, that format will be used for all of the items in $where.
         *                                      A format is one of '%d', '%f', '%s' (integer, float, string).
         *                                      If omitted, all values in $data will be treated as strings unless otherwise
         *                                      specified in wpdb::$field_types. Default null.
         * @return int|false The number of rows deleted, or false on error.
         */
        public function delete($table, $where, $where_format = \null)
        {
        }
        /**
         * Processes arrays of field/value pairs and field formats.
         *
         * This is a helper method for wpdb's CRUD methods, which take field/value pairs
         * for inserts, updates, and where clauses. This method first pairs each value
         * with a format. Then it determines the charset of that field, using that
         * to determine if any invalid text would be stripped. If text is stripped,
         * then field processing is rejected and the query fails.
         *
         * @since 4.2.0
         *
         * @param string          $table  Table name.
         * @param array           $data   Array of values keyed by their field names.
         * @param string[]|string $format Formats or format to be mapped to the values in the data.
         * @return array|false An array of fields that contain paired value and formats.
         *                     False for invalid values.
         */
        protected function process_fields($table, $data, $format)
        {
        }
        /**
         * Prepares arrays of value/format pairs as passed to wpdb CRUD methods.
         *
         * @since 4.2.0
         *
         * @param array           $data   Array of values keyed by their field names.
         * @param string[]|string $format Formats or format to be mapped to the values in the data.
         * @return array {
         *     Array of values and formats keyed by their field names.
         *
         *     @type mixed  $value  The value to be formatted.
         *     @type string $format The format to be mapped to the value.
         * }
         * @phpstan-return array{
         *   value: mixed,
         *   format: string,
         * }
         */
        protected function process_field_formats($data, $format)
        {
        }
        /**
         * Adds field charsets to field/value/format arrays generated by wpdb::process_field_formats().
         *
         * @since 4.2.0
         *
         * @param array $data {
         *     Array of values and formats keyed by their field names,
         *     as it comes from the wpdb::process_field_formats() method.
         *
         *     @type array ...$0 {
         *         Value and format for this field.
         *
         *         @type mixed  $value  The value to be formatted.
         *         @type string $format The format to be mapped to the value.
         *     }
         * }
         * @param string $table Table name.
         * @return array|false {
         *     The same array of data with additional 'charset' keys, or false if
         *     the charset for the table cannot be found.
         *
         *     @type array ...$0 {
         *         Value, format, and charset for this field.
         *
         *         @type mixed        $value   The value to be formatted.
         *         @type string       $format  The format to be mapped to the value.
         *         @type string|false $charset The charset to be used for the value.
         *     }
         * }
         * @phpstan-param array<int|string, array{
         *   value: mixed,
         *   format: string,
         * }> $data
         * @phpstan-return false|array<int|string, array{
         *   value: mixed,
         *   format: string,
         *   charset: string|false,
         * }>
         */
        protected function process_field_charsets($data, $table)
        {
        }
        /**
         * For string fields, records the maximum string length that field can safely save.
         *
         * @since 4.2.1
         *
         * @param array $data {
         *     Array of values, formats, and charsets keyed by their field names,
         *     as it comes from the wpdb::process_field_charsets() method.
         *
         *     @type array ...$0 {
         *         Value, format, and charset for this field.
         *
         *         @type mixed        $value   The value to be formatted.
         *         @type string       $format  The format to be mapped to the value.
         *         @type string|false $charset The charset to be used for the value.
         *     }
         * }
         * @param string $table Table name.
         * @return array|false {
         *     The same array of data with additional 'length' keys, or false if
         *     information for the table cannot be found.
         *
         *     @type array ...$0 {
         *         Value, format, charset, and length for this field.
         *
         *         @type mixed        $value   The value to be formatted.
         *         @type string       $format  The format to be mapped to the value.
         *         @type string|false $charset The charset to be used for the value.
         *         @type array|false  $length  {
         *             Information about the maximum length of the value.
         *             False if the column has no length.
         *
         *             @type string $type   One of 'byte' or 'char'.
         *             @type int    $length The column length.
         *         }
         *     }
         * }
         * @phpstan-param array<int|string, array{
         *   value: mixed,
         *   format: string,
         *   charset: string|false,
         * }> $data
         * @phpstan-return false|array<int|string, array{
         *   value: mixed,
         *   format: string,
         *   charset: string|false,
         *   length: false|array{
         *     type: string,
         *     length: int,
         *   },
         * }>
         */
        protected function process_field_lengths($data, $table)
        {
        }
        /**
         * Retrieves one value from the database.
         *
         * Executes a SQL query and returns the value from the SQL result.
         * If the SQL result contains more than one column and/or more than one row,
         * the value in the column and row specified is returned. If $query is null,
         * the value in the specified column and row from the previous SQL result is returned.
         *
         * @since 0.71
         *
         * @param string|null $query Optional. SQL query. Defaults to null, use the result from the previous query.
         * @param int         $x     Optional. Column of value to return. Indexed from 0. Default 0.
         * @param int         $y     Optional. Row of value to return. Indexed from 0. Default 0.
         * @return string|null Database query result (as string), or null on failure.
         */
        public function get_var($query = \null, $x = 0, $y = 0)
        {
        }
        /**
         * Retrieves one row from the database.
         *
         * Executes a SQL query and returns the row from the SQL result.
         *
         * @since 0.71
         *
         * @param string|null $query  SQL query.
         * @param string      $output Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
         *                            correspond to an stdClass object, an associative array, or a numeric array,
         *                            respectively. Default OBJECT.
         * @param int         $y      Optional. Row to return. Indexed from 0. Default 0.
         * @return array|object|null|void Database query result in format specified by $output or null on failure.
         * @phpstan-param 'OBJECT'|'ARRAY_A'|'ARRAY_N' $output
         * @phpstan-param int<0, max> $y
         * @phpstan-return null|void|($output is 'ARRAY_A' ? array<array-key, mixed> : ($output is 'ARRAY_N' ? list<mixed> : \stdClass))
         */
        public function get_row($query = \null, $output = \OBJECT, $y = 0)
        {
        }
        /**
         * Retrieves one column from the database.
         *
         * Executes a SQL query and returns the column from the SQL result.
         * If the SQL result contains more than one column, the column specified is returned.
         * If $query is null, the specified column from the previous SQL result is returned.
         *
         * @since 0.71
         *
         * @param string|null $query Optional. SQL query. Defaults to previous query.
         * @param int         $x     Optional. Column to return. Indexed from 0. Default 0.
         * @return array Database query result. Array indexed from 0 by SQL result row number.
         */
        public function get_col($query = \null, $x = 0)
        {
        }
        /**
         * Retrieves an entire SQL result set from the database (i.e., many rows).
         *
         * Executes a SQL query and returns the entire SQL result.
         *
         * @since 0.71
         *
         * @param string $query  SQL query.
         * @param string $output Optional. Any of ARRAY_A | ARRAY_N | OBJECT | OBJECT_K constants.
         *                       With one of the first three, return an array of rows indexed
         *                       from 0 by SQL result row number. Each row is an associative array
         *                       (column => value, ...), a numerically indexed array (0 => value, ...),
         *                       or an object ( ->column = value ), respectively. With OBJECT_K,
         *                       return an associative array of row objects keyed by the value
         *                       of each row's first column's value. Duplicate keys are discarded.
         *                       Default OBJECT.
         * @return array|object|null Database query results.
         * @phpstan-param 'OBJECT'|'OBJECT_K'|'ARRAY_A'|'ARRAY_N' $output
         * @phpstan-return null|($output is 'ARRAY_A' ? list<array<array-key, mixed>> : ($output is 'ARRAY_N' ? list<array<int, mixed>> : ($output is 'OBJECT_K' ? array<array-key, \stdClass> : list<\stdClass>)))
         */
        public function get_results($query = \null, $output = \OBJECT)
        {
        }
        /**
         * Retrieves the character set for the given table.
         *
         * @since 4.2.0
         *
         * @param string $table Table name.
         * @return string|WP_Error Table character set, WP_Error object if it couldn't be found.
         */
        protected function get_table_charset($table)
        {
        }
        /**
         * Retrieves the character set for the given column.
         *
         * @since 4.2.0
         *
         * @param string $table  Table name.
         * @param string $column Column name.
         * @return string|false|WP_Error Column character set as a string. False if the column has
         *                               no character set. WP_Error object if there was an error.
         */
        public function get_col_charset($table, $column)
        {
        }
        /**
         * Retrieves the maximum string length allowed in a given column.
         *
         * The length may either be specified as a byte length or a character length.
         *
         * @since 4.2.1
         *
         * @param string $table  Table name.
         * @param string $column Column name.
         * @return array|false|WP_Error {
         *     Array of column length information, false if the column has no length (for
         *     example, numeric column), WP_Error object if there was an error.
         *
         *     @type string $type   One of 'byte' or 'char'.
         *     @type int    $length The column length.
         * }
         * @phpstan-return false|\WP_Error|array{
         *   type: string,
         *   length: int,
         * }
         */
        public function get_col_length($table, $column)
        {
        }
        /**
         * Checks if a string is ASCII.
         *
         * The negative regex is faster for non-ASCII strings, as it allows
         * the search to finish as soon as it encounters a non-ASCII character.
         *
         * @since 4.2.0
         *
         * @param string $input_string String to check.
         * @return bool True if ASCII, false if not.
         */
        protected function check_ascii($input_string)
        {
        }
        /**
         * Checks if the query is accessing a collation considered safe on the current version of MySQL.
         *
         * @since 4.2.0
         *
         * @param string $query The query to check.
         * @return bool True if the collation is safe, false if it isn't.
         */
        protected function check_safe_collation($query)
        {
        }
        /**
         * Strips any invalid characters based on value/charset pairs.
         *
         * @since 4.2.0
         *
         * @param array $data Array of value arrays. Each value array has the keys 'value', 'charset', and 'length'.
         *                    An optional 'ascii' key can be set to false to avoid redundant ASCII checks.
         * @return array|WP_Error The $data parameter, with invalid characters removed from each value.
         *                        This works as a passthrough: any additional keys such as 'field' are
         *                        retained in each value array. If we cannot remove invalid characters,
         *                        a WP_Error object is returned.
         */
        protected function strip_invalid_text($data)
        {
        }
        /**
         * Strips any invalid characters from the query.
         *
         * @since 4.2.0
         *
         * @param string $query Query to convert.
         * @return string|WP_Error The converted query, or a WP_Error object if the conversion fails.
         */
        protected function strip_invalid_text_from_query($query)
        {
        }
        /**
         * Strips any invalid characters from the string for a given table and column.
         *
         * @since 4.2.0
         *
         * @param string $table  Table name.
         * @param string $column Column name.
         * @param string $value  The text to check.
         * @return string|WP_Error The converted string, or a WP_Error object if the conversion fails.
         */
        public function strip_invalid_text_for_column($table, $column, $value)
        {
        }
        /**
         * Finds the first table name referenced in a query.
         *
         * @since 4.2.0
         *
         * @param string $query The query to search.
         * @return string|false The table name found, or false if a table couldn't be found.
         */
        protected function get_table_from_query($query)
        {
        }
        /**
         * Loads the column metadata from the last query.
         *
         * @since 3.5.0
         * @phpstan-return void
         */
        protected function load_col_info()
        {
        }
        /**
         * Retrieves column metadata from the last query.
         *
         * @since 0.71
         *
         * @param string $info_type  Optional. Possible values include 'name', 'table', 'def', 'max_length',
         *                           'not_null', 'primary_key', 'multiple_key', 'unique_key', 'numeric',
         *                           'blob', 'type', 'unsigned', 'zerofill'. Default 'name'.
         * @param int    $col_offset Optional. 0: col name. 1: which table the col's in. 2: col's max length.
         *                           3: if the col is numeric. 4: col's type. Default -1.
         * @return mixed Column results.
         */
        public function get_col_info($info_type = 'name', $col_offset = -1)
        {
        }
        /**
         * Starts the timer, for debugging purposes.
         *
         * @since 1.5.0
         *
         * @return true
         */
        public function timer_start()
        {
        }
        /**
         * Stops the debugging timer.
         *
         * @since 1.5.0
         *
         * @return float Total time spent on the query, in seconds.
         */
        public function timer_stop()
        {
        }
        /**
         * Wraps errors in a nice header and footer and dies.
         *
         * Will not die if wpdb::$show_errors is false.
         *
         * @since 1.5.0
         *
         * @param string $message    The error message.
         * @param string $error_code Optional. A computer-readable string to identify the error.
         *                           Default '500'.
         * @return void|false Void if the showing of errors is enabled, false if disabled.
         */
        public function bail($message, $error_code = '500')
        {
        }
        /**
         * Closes the current database connection.
         *
         * @since 4.5.0
         *
         * @return bool True if the connection was successfully closed,
         *              false if it wasn't, or if the connection doesn't exist.
         */
        public function close()
        {
        }
        /**
         * Determines whether MySQL database is at least the required minimum version.
         *
         * @since 2.5.0
         *
         * @global string $required_mysql_version The required MySQL version string.
         * @return void|WP_Error
         */
        public function check_database_version()
        {
        }
        /**
         * Determines whether the database supports collation.
         *
         * Called when WordPress is generating the table scheme.
         *
         * Use `wpdb::has_cap( 'collation' )`.
         *
         * @since 2.5.0
         * @deprecated 3.5.0 Use wpdb::has_cap()
         *
         * @return bool True if collation is supported, false if not.
         */
        public function supports_collation()
        {
        }
        /**
         * Retrieves the database character collate.
         *
         * @since 3.5.0
         *
         * @return string The database character collate.
         */
        public function get_charset_collate()
        {
        }
        /**
         * Determines whether the database or WPDB supports a particular feature.
         *
         * Capability sniffs for the database server and current version of WPDB.
         *
         * Database sniffs are based on the version of MySQL the site is using.
         *
         * WPDB sniffs are added as new features are introduced to allow theme and plugin
         * developers to determine feature support. This is to account for drop-ins which may
         * introduce feature support at a different time to WordPress.
         *
         * @since 2.7.0
         * @since 4.1.0 Added support for the 'utf8mb4' feature.
         * @since 4.6.0 Added support for the 'utf8mb4_520' feature.
         * @since 6.2.0 Added support for the 'identifier_placeholders' feature.
         * @since 6.6.0 The `utf8mb4` feature now always returns true.
         *
         * @see wpdb::db_version()
         *
         * @param string $db_cap The feature to check for. Accepts 'collation', 'group_concat',
         *                       'subqueries', 'set_charset', 'utf8mb4', 'utf8mb4_520',
         *                       or 'identifier_placeholders'.
         * @return bool True when the database feature is supported, false otherwise.
         * @phpstan-param 'collation'|'group_concat'|'subqueries'|'set_charset'|'utf8mb4'|'utf8mb4_520'|'identifier_placeholders' $db_cap
         */
        public function has_cap($db_cap)
        {
        }
        /**
         * Retrieves a comma-separated list of the names of the functions that called wpdb.
         *
         * @since 2.5.0
         *
         * @return string Comma-separated list of the calling functions.
         */
        public function get_caller()
        {
        }
        /**
         * Retrieves the database server version.
         *
         * @since 2.7.0
         *
         * @return string|null Version number on success, null on failure.
         */
        public function db_version()
        {
        }
        /**
         * Returns the version of the MySQL server.
         *
         * @since 5.5.0
         *
         * @return string Server version as a string.
         */
        public function db_server_info()
        {
        }
    }
    /**
     * Customize Media Control class.
     *
     * @since 4.2.0
     *
     * @see WP_Customize_Control
     */
    class WP_Customize_Media_Control extends \WP_Customize_Control
    {
        /**
         * Control type.
         *
         * @since 4.2.0
         * @var string
         */
        public $type = 'media';
        /**
         * Media control mime type.
         *
         * @since 4.2.0
         * @var string
         */
        public $mime_type = '';
        /**
         * Button labels.
         *
         * @since 4.2.0
         * @var array
         */
        public $button_labels = array();
        /**
         * Constructor.
         *
         * @since 4.1.0
         * @since 4.2.0 Moved from WP_Customize_Upload_Control.
         *
         * @see WP_Customize_Control::__construct()
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      Control ID.
         * @param array                $args    Optional. Arguments to override class property defaults.
         *                                      See WP_Customize_Control::__construct() for information
         *                                      on accepted arguments. Default empty array.
         * @phpstan-param array{
         *   instance_number?: int,
         *   manager?: WP_Customize_Manager,
         *   id?: string,
         *   settings?: array,
         *   setting?: string,
         *   capability?: string,
         *   priority?: int,
         *   section?: string,
         *   label?: string,
         *   description?: string,
         *   choices?: array,
         *   input_attrs?: array,
         *   allow_addition?: bool,
         *   json?: array,
         *   type?: string,
         *   active_callback?: callable,
         * } $args See WP_Customize_Control::__construct()
         */
        public function __construct($manager, $id, $args = array())
        {
        }
        /**
         * Enqueue control related scripts/styles.
         *
         * @since 3.4.0
         * @since 4.2.0 Moved from WP_Customize_Upload_Control.
         */
        public function enqueue()
        {
        }
        /**
         * Refresh the parameters passed to the JavaScript via JSON.
         *
         * @since 3.4.0
         * @since 4.2.0 Moved from WP_Customize_Upload_Control.
         *
         * @see WP_Customize_Control::to_json()
         */
        public function to_json()
        {
        }
        /**
         * Don't render any content for this control from PHP.
         *
         * @since 3.4.0
         * @since 4.2.0 Moved from WP_Customize_Upload_Control.
         *
         * @see WP_Customize_Media_Control::content_template()
         */
        public function render_content()
        {
        }
        /**
         * Render a JS template for the content of the media control.
         *
         * @since 4.1.0
         * @since 4.2.0 Moved from WP_Customize_Upload_Control.
         */
        public function content_template()
        {
        }
        /**
         * Get default button labels.
         *
         * Provides an array of the default button labels based on the mime type of the current control.
         *
         * @since 4.9.0
         *
         * @return string[] An associative array of default button labels keyed by the button name.
         */
        public function get_default_button_labels()
        {
        }
    }
    /**
     * Customize Upload Control Class.
     *
     * @since 3.4.0
     *
     * @see WP_Customize_Media_Control
     */
    class WP_Customize_Upload_Control extends \WP_Customize_Media_Control
    {
        /**
         * Control type.
         *
         * @since 3.4.0
         * @var string
         */
        public $type = 'upload';
        /**
         * Media control mime type.
         *
         * @since 4.1.0
         * @var string
         */
        public $mime_type = '';
        /**
         * Button labels.
         *
         * @since 4.1.0
         * @var array
         */
        public $button_labels = array();
        public $removed = '';
        public $context;
        public $extensions = array();
        /**
         * Refresh the parameters passed to the JavaScript via JSON.
         *
         * @since 3.4.0
         *
         * @uses WP_Customize_Media_Control::to_json()
         */
        public function to_json()
        {
        }
    }
    /**
     * Customize Image Control class.
     *
     * @since 3.4.0
     *
     * @see WP_Customize_Upload_Control
     */
    class WP_Customize_Image_Control extends \WP_Customize_Upload_Control
    {
        /**
         * Control type.
         *
         * @since 3.4.0
         * @var string
         */
        public $type = 'image';
        /**
         * Media control mime type.
         *
         * @since 4.1.0
         * @var string
         */
        public $mime_type = 'image';
        /**
         * @since 3.4.2
         * @deprecated 4.1.0
         */
        public function prepare_control()
        {
        }
        /**
         * @since 3.4.0
         * @deprecated 4.1.0
         *
         * @param string $id
         * @param string $label
         * @param mixed  $callback
         */
        public function add_tab($id, $label, $callback)
        {
        }
        /**
         * @since 3.4.0
         * @deprecated 4.1.0
         *
         * @param string $id
         */
        public function remove_tab($id)
        {
        }
        /**
         * @since 3.4.0
         * @deprecated 4.1.0
         *
         * @param string $url
         * @param string $thumbnail_url
         */
        public function print_tab_image($url, $thumbnail_url = \null)
        {
        }
    }
    /**
     * Customize Background Image Control class.
     *
     * @since 3.4.0
     *
     * @see WP_Customize_Image_Control
     */
    class WP_Customize_Background_Image_Control extends \WP_Customize_Image_Control
    {
        /**
         * Customize control type.
         *
         * @since 4.1.0
         * @var string
         */
        public $type = 'background';
        /**
         * Constructor.
         *
         * @since 3.4.0
         * @uses WP_Customize_Image_Control::__construct()
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         */
        public function __construct($manager)
        {
        }
        /**
         * Enqueue control related scripts/styles.
         *
         * @since 4.1.0
         */
        public function enqueue()
        {
        }
    }
    /**
     * Customizer Background Image Setting class.
     *
     * @since 3.4.0
     *
     * @see WP_Customize_Setting
     */
    final class WP_Customize_Background_Image_Setting extends \WP_Customize_Setting
    {
        /**
         * Unique string identifier for the setting.
         *
         * @since 3.4.0
         * @var string
         */
        public $id = 'background_image_thumb';
        /**
         * @since 3.4.0
         *
         * @param mixed $value The value to update. Not used.
         */
        public function update($value)
        {
        }
    }
    /**
     * Customize Background Position Control class.
     *
     * @since 4.7.0
     *
     * @see WP_Customize_Control
     */
    class WP_Customize_Background_Position_Control extends \WP_Customize_Control
    {
        /**
         * Type.
         *
         * @since 4.7.0
         * @var string
         */
        public $type = 'background_position';
        /**
         * Don't render the control content from PHP, as it's rendered via JS on load.
         *
         * @since 4.7.0
         */
        public function render_content()
        {
        }
        /**
         * Render a JS template for the content of the position control.
         *
         * @since 4.7.0
         */
        public function content_template()
        {
        }
    }
    /**
     * Customize Code Editor Control class.
     *
     * @since 4.9.0
     *
     * @see WP_Customize_Control
     */
    class WP_Customize_Code_Editor_Control extends \WP_Customize_Control
    {
        /**
         * Customize control type.
         *
         * @since 4.9.0
         * @var string
         */
        public $type = 'code_editor';
        /**
         * Type of code that is being edited.
         *
         * @since 4.9.0
         * @var string
         */
        public $code_type = '';
        /**
         * Code editor settings.
         *
         * @see wp_enqueue_code_editor()
         * @since 4.9.0
         * @var array|false
         */
        public $editor_settings = array();
        /**
         * Enqueue control related scripts/styles.
         *
         * @since 4.9.0
         */
        public function enqueue()
        {
        }
        /**
         * Refresh the parameters passed to the JavaScript via JSON.
         *
         * @since 4.9.0
         *
         * @see WP_Customize_Control::json()
         *
         * @return array Array of parameters passed to the JavaScript.
         */
        public function json()
        {
        }
        /**
         * Don't render the control content from PHP, as it's rendered via JS on load.
         *
         * @since 4.9.0
         */
        public function render_content()
        {
        }
        /**
         * Render a JS template for control display.
         *
         * @since 4.9.0
         */
        public function content_template()
        {
        }
    }
    /**
     * Customize Color Control class.
     *
     * @since 3.4.0
     *
     * @see WP_Customize_Control
     */
    class WP_Customize_Color_Control extends \WP_Customize_Control
    {
        /**
         * Type.
         *
         * @var string
         */
        public $type = 'color';
        /**
         * Statuses.
         *
         * @var array
         */
        public $statuses;
        /**
         * Mode.
         *
         * @since 4.7.0
         * @var string
         */
        public $mode = 'full';
        /**
         * Constructor.
         *
         * @since 3.4.0
         *
         * @see WP_Customize_Control::__construct()
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      Control ID.
         * @param array                $args    Optional. Arguments to override class property defaults.
         *                                      See WP_Customize_Control::__construct() for information
         *                                      on accepted arguments. Default empty array.
         * @phpstan-param array{
         *   instance_number?: int,
         *   manager?: WP_Customize_Manager,
         *   id?: string,
         *   settings?: array,
         *   setting?: string,
         *   capability?: string,
         *   priority?: int,
         *   section?: string,
         *   label?: string,
         *   description?: string,
         *   choices?: array,
         *   input_attrs?: array,
         *   allow_addition?: bool,
         *   json?: array,
         *   type?: string,
         *   active_callback?: callable,
         * } $args See WP_Customize_Control::__construct()
         */
        public function __construct($manager, $id, $args = array())
        {
        }
        /**
         * Enqueue scripts/styles for the color picker.
         *
         * @since 3.4.0
         */
        public function enqueue()
        {
        }
        /**
         * Refresh the parameters passed to the JavaScript via JSON.
         *
         * @since 3.4.0
         * @uses WP_Customize_Control::to_json()
         */
        public function to_json()
        {
        }
        /**
         * Don't render the control content from PHP, as it's rendered via JS on load.
         *
         * @since 3.4.0
         */
        public function render_content()
        {
        }
        /**
         * Render a JS template for the content of the color picker control.
         *
         * @since 4.1.0
         */
        public function content_template()
        {
        }
    }
    /**
     * Customize Cropped Image Control class.
     *
     * @since 4.3.0
     *
     * @see WP_Customize_Image_Control
     */
    class WP_Customize_Cropped_Image_Control extends \WP_Customize_Image_Control
    {
        /**
         * Control type.
         *
         * @since 4.3.0
         * @var string
         */
        public $type = 'cropped_image';
        /**
         * Suggested width for cropped image.
         *
         * @since 4.3.0
         * @var int
         */
        public $width = 150;
        /**
         * Suggested height for cropped image.
         *
         * @since 4.3.0
         * @var int
         */
        public $height = 150;
        /**
         * Whether the width is flexible.
         *
         * @since 4.3.0
         * @var bool
         */
        public $flex_width = \false;
        /**
         * Whether the height is flexible.
         *
         * @since 4.3.0
         * @var bool
         */
        public $flex_height = \false;
        /**
         * Enqueue control related scripts/styles.
         *
         * @since 4.3.0
         */
        public function enqueue()
        {
        }
        /**
         * Refresh the parameters passed to the JavaScript via JSON.
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Control::to_json()
         */
        public function to_json()
        {
        }
    }
    /**
     * Custom Setting to handle WP Custom CSS.
     *
     * @since 4.7.0
     *
     * @see WP_Customize_Setting
     */
    final class WP_Customize_Custom_CSS_Setting extends \WP_Customize_Setting
    {
        /**
         * The setting type.
         *
         * @since 4.7.0
         * @var string
         */
        public $type = 'custom_css';
        /**
         * Setting Transport
         *
         * @since 4.7.0
         * @var string
         */
        public $transport = 'postMessage';
        /**
         * Capability required to edit this setting.
         *
         * @since 4.7.0
         * @var string
         */
        public $capability = 'edit_css';
        /**
         * Stylesheet
         *
         * @since 4.7.0
         * @var string
         */
        public $stylesheet = '';
        /**
         * WP_Customize_Custom_CSS_Setting constructor.
         *
         * @since 4.7.0
         *
         * @throws Exception If the setting ID does not match the pattern `custom_css[$stylesheet]`.
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      A specific ID of the setting.
         *                                      Can be a theme mod or option name.
         * @param array                $args    Setting arguments.
         */
        public function __construct($manager, $id, $args = array())
        {
        }
        /**
         * Add filter to preview post value.
         *
         * @since 4.7.9
         *
         * @return bool False when preview short-circuits due no change needing to be previewed.
         */
        public function preview()
        {
        }
        /**
         * Filters `wp_get_custom_css` for applying the customized value.
         *
         * This is used in the preview when `wp_get_custom_css()` is called for rendering the styles.
         *
         * @since 4.7.0
         *
         * @see wp_get_custom_css()
         *
         * @param string $css        Original CSS.
         * @param string $stylesheet Current stylesheet.
         * @return string CSS.
         */
        public function filter_previewed_wp_get_custom_css($css, $stylesheet)
        {
        }
        /**
         * Fetch the value of the setting. Will return the previewed value when `preview()` is called.
         *
         * @since 4.7.0
         *
         * @see WP_Customize_Setting::value()
         *
         * @return string
         */
        public function value()
        {
        }
        /**
         * Validate a received value for being valid CSS.
         *
         * Checks for imbalanced braces, brackets, and comments.
         * Notifications are rendered when the customizer state is saved.
         *
         * @since 4.7.0
         * @since 4.9.0 Checking for balanced characters has been moved client-side via linting in code editor.
         * @since 5.9.0 Renamed `$css` to `$value` for PHP 8 named parameter support.
         *
         * @param string $value CSS to validate.
         * @return true|WP_Error True if the input was validated, otherwise WP_Error.
         */
        public function validate($value)
        {
        }
        /**
         * Store the CSS setting value in the custom_css custom post type for the stylesheet.
         *
         * @since 4.7.0
         * @since 5.9.0 Renamed `$css` to `$value` for PHP 8 named parameter support.
         *
         * @param string $value CSS to update.
         * @return int|false The post ID or false if the value could not be saved.
         */
        public function update($value)
        {
        }
    }
    /**
     * Customize Date Time Control class.
     *
     * @since 4.9.0
     *
     * @see WP_Customize_Control
     */
    class WP_Customize_Date_Time_Control extends \WP_Customize_Control
    {
        /**
         * Customize control type.
         *
         * @since 4.9.0
         * @var string
         */
        public $type = 'date_time';
        /**
         * Minimum Year.
         *
         * @since 4.9.0
         * @var int
         */
        public $min_year = 1000;
        /**
         * Maximum Year.
         *
         * @since 4.9.0
         * @var int
         */
        public $max_year = 9999;
        /**
         * Allow past date, if set to false user can only select future date.
         *
         * @since 4.9.0
         * @var bool
         */
        public $allow_past_date = \true;
        /**
         * Whether hours, minutes, and meridian should be shown.
         *
         * @since 4.9.0
         * @var bool
         */
        public $include_time = \true;
        /**
         * If set to false the control will appear in 24 hour format,
         * the value will still be saved in Y-m-d H:i:s format.
         *
         * @since 4.9.0
         * @var bool
         */
        public $twelve_hour_format = \true;
        /**
         * Don't render the control's content - it's rendered with a JS template.
         *
         * @since 4.9.0
         */
        public function render_content()
        {
        }
        /**
         * Export data to JS.
         *
         * @since 4.9.0
         * @return array
         */
        public function json()
        {
        }
        /**
         * Renders a JS template for the content of date time control.
         *
         * @since 4.9.0
         */
        public function content_template()
        {
        }
        /**
         * Generate options for the month Select.
         *
         * Based on touch_time().
         *
         * @since 4.9.0
         *
         * @see touch_time()
         *
         * @global WP_Locale $wp_locale WordPress date and time locale object.
         *
         * @return array
         */
        public function get_month_choices()
        {
        }
        /**
         * Get timezone info.
         *
         * @since 4.9.0
         *
         * @return array {
         *     Timezone info. All properties are optional.
         *
         *     @type string $abbr        Timezone abbreviation. Examples: PST or CEST.
         *     @type string $description Human-readable timezone description as HTML.
         * }
         * @phpstan-return array{
         *   abbr: string,
         *   description: string,
         * }
         */
        public function get_timezone_info()
        {
        }
        /**
         * Format GMT Offset.
         *
         * @since 4.9.0
         *
         * @see wp_timezone_choice()
         *
         * @param float $offset Offset in hours.
         * @return string Formatted offset.
         */
        public function format_gmt_offset($offset)
        {
        }
    }
    /**
     * A setting that is used to filter a value, but will not save the results.
     *
     * Results should be properly handled using another setting or callback.
     *
     * @since 3.4.0
     *
     * @see WP_Customize_Setting
     */
    class WP_Customize_Filter_Setting extends \WP_Customize_Setting
    {
        /**
         * Saves the value of the setting, using the related API.
         *
         * @since 3.4.0
         *
         * @param mixed $value The value to update.
         */
        public function update($value)
        {
        }
    }
    /**
     * Customize Header Image Control class.
     *
     * @since 3.4.0
     *
     * @see WP_Customize_Image_Control
     */
    class WP_Customize_Header_Image_Control extends \WP_Customize_Image_Control
    {
        /**
         * Customize control type.
         *
         * @since 4.2.0
         * @var string
         */
        public $type = 'header';
        /**
         * Uploaded header images.
         *
         * @since 3.9.0
         * @var string
         */
        public $uploaded_headers;
        /**
         * Default header images.
         *
         * @since 3.9.0
         * @var string
         */
        public $default_headers;
        /**
         * Constructor.
         *
         * @since 3.4.0
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         */
        public function __construct($manager)
        {
        }
        /**
         */
        public function enqueue()
        {
        }
        /**
         * @global Custom_Image_Header $custom_image_header
         * @phpstan-return void
         */
        public function prepare_control()
        {
        }
        /**
         */
        public function print_header_image_template()
        {
        }
        /**
         * @return string|void
         */
        public function get_current_image_src()
        {
        }
        /**
         */
        public function render_content()
        {
        }
    }
    /**
     * A setting that is used to filter a value, but will not save the results.
     *
     * Results should be properly handled using another setting or callback.
     *
     * @since 3.4.0
     *
     * @see WP_Customize_Setting
     */
    final class WP_Customize_Header_Image_Setting extends \WP_Customize_Setting
    {
        /**
         * Unique string identifier for the setting.
         *
         * @since 3.4.0
         * @var string
         */
        public $id = 'header_image_data';
        /**
         * @since 3.4.0
         *
         * @global Custom_Image_Header $custom_image_header
         *
         * @param mixed $value The value to update.
         */
        public function update($value)
        {
        }
    }
    /**
     * Customize control to represent the auto_add field for a given menu.
     *
     * @since 4.3.0
     *
     * @see WP_Customize_Control
     */
    class WP_Customize_Nav_Menu_Auto_Add_Control extends \WP_Customize_Control
    {
        /**
         * Type of control, used by JS.
         *
         * @since 4.3.0
         * @var string
         */
        public $type = 'nav_menu_auto_add';
        /**
         * No-op since we're using JS template.
         *
         * @since 4.3.0
         */
        protected function render_content()
        {
        }
        /**
         * Render the Underscore template for this control.
         *
         * @since 4.3.0
         */
        protected function content_template()
        {
        }
    }
    /**
     * Customize Nav Menu Control Class.
     *
     * @since 4.3.0
     *
     * @see WP_Customize_Control
     */
    class WP_Customize_Nav_Menu_Control extends \WP_Customize_Control
    {
        /**
         * Control type.
         *
         * @since 4.3.0
         * @var string
         */
        public $type = 'nav_menu';
        /**
         * Don't render the control's content - it uses a JS template instead.
         *
         * @since 4.3.0
         */
        public function render_content()
        {
        }
        /**
         * JS/Underscore template for the control UI.
         *
         * @since 4.3.0
         */
        public function content_template()
        {
        }
        /**
         * Return parameters for this control.
         *
         * @since 4.3.0
         *
         * @return array Exported parameters.
         */
        public function json()
        {
        }
    }
    /**
     * Customize control to represent the name field for a given menu.
     *
     * @since 4.3.0
     *
     * @see WP_Customize_Control
     */
    class WP_Customize_Nav_Menu_Item_Control extends \WP_Customize_Control
    {
        /**
         * Control type.
         *
         * @since 4.3.0
         * @var string
         */
        public $type = 'nav_menu_item';
        /**
         * The nav menu item setting.
         *
         * @since 4.3.0
         * @var WP_Customize_Nav_Menu_Item_Setting
         */
        public $setting;
        /**
         * Constructor.
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Control::__construct()
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      The control ID.
         * @param array                $args    Optional. Arguments to override class property defaults.
         *                                      See WP_Customize_Control::__construct() for information
         *                                      on accepted arguments. Default empty array.
         * @phpstan-param array{
         *   instance_number?: int,
         *   manager?: WP_Customize_Manager,
         *   id?: string,
         *   settings?: array,
         *   setting?: string,
         *   capability?: string,
         *   priority?: int,
         *   section?: string,
         *   label?: string,
         *   description?: string,
         *   choices?: array,
         *   input_attrs?: array,
         *   allow_addition?: bool,
         *   json?: array,
         *   type?: string,
         *   active_callback?: callable,
         * } $args See WP_Customize_Control::__construct()
         */
        public function __construct($manager, $id, $args = array())
        {
        }
        /**
         * Don't render the control's content - it's rendered with a JS template.
         *
         * @since 4.3.0
         */
        public function render_content()
        {
        }
        /**
         * JS/Underscore template for the control UI.
         *
         * @since 4.3.0
         */
        public function content_template()
        {
        }
        /**
         * Return parameters for this control.
         *
         * @since 4.3.0
         *
         * @return array Exported parameters.
         */
        public function json()
        {
        }
    }
    /**
     * Customize Setting to represent a nav_menu.
     *
     * Subclass of WP_Customize_Setting to represent a nav_menu taxonomy term, and
     * the IDs for the nav_menu_items associated with the nav menu.
     *
     * @since 4.3.0
     *
     * @see WP_Customize_Setting
     */
    class WP_Customize_Nav_Menu_Item_Setting extends \WP_Customize_Setting
    {
        const ID_PATTERN = '/^nav_menu_item\\[(?P<id>-?\\d+)\\]$/';
        const POST_TYPE = 'nav_menu_item';
        const TYPE = 'nav_menu_item';
        /**
         * Setting type.
         *
         * @since 4.3.0
         * @var string
         */
        public $type = self::TYPE;
        /**
         * Default setting value.
         *
         * @since 4.3.0
         * @var array
         *
         * @see wp_setup_nav_menu_item()
         */
        public $default = array(
            // The $menu_item_data for wp_update_nav_menu_item().
            'object_id' => 0,
            'object' => '',
            // Taxonomy name.
            'menu_item_parent' => 0,
            // A.K.A. menu-item-parent-id; note that post_parent is different, and not included.
            'position' => 0,
            // A.K.A. menu_order.
            'type' => 'custom',
            // Note that type_label is not included here.
            'title' => '',
            'url' => '',
            'target' => '',
            'attr_title' => '',
            'description' => '',
            'classes' => '',
            'xfn' => '',
            'status' => 'publish',
            'original_title' => '',
            'nav_menu_term_id' => 0,
            // This will be supplied as the $menu_id arg for wp_update_nav_menu_item().
            '_invalid' => \false,
        );
        /**
         * Default transport.
         *
         * @since 4.3.0
         * @since 4.5.0 Default changed to 'refresh'
         * @var string
         */
        public $transport = 'refresh';
        /**
         * The post ID represented by this setting instance. This is the db_id.
         *
         * A negative value represents a placeholder ID for a new menu not yet saved.
         *
         * @since 4.3.0
         * @var int
         */
        public $post_id;
        /**
         * Storage of pre-setup menu item to prevent wasted calls to wp_setup_nav_menu_item().
         *
         * @since 4.3.0
         * @var array|null
         */
        protected $value;
        /**
         * Previous (placeholder) post ID used before creating a new menu item.
         *
         * This value will be exported to JS via the customize_save_response filter
         * so that JavaScript can update the settings to refer to the newly-assigned
         * post ID. This value is always negative to indicate it does not refer to
         * a real post.
         *
         * @since 4.3.0
         * @var int
         *
         * @see WP_Customize_Nav_Menu_Item_Setting::update()
         * @see WP_Customize_Nav_Menu_Item_Setting::amend_customize_save_response()
         */
        public $previous_post_id;
        /**
         * When previewing or updating a menu item, this stores the previous nav_menu_term_id
         * which ensures that we can apply the proper filters.
         *
         * @since 4.3.0
         * @var int
         */
        public $original_nav_menu_term_id;
        /**
         * Whether or not update() was called.
         *
         * @since 4.3.0
         * @var bool
         */
        protected $is_updated = \false;
        /**
         * Status for calling the update method, used in customize_save_response filter.
         *
         * See {@see 'customize_save_response'}.
         *
         * When status is inserted, the placeholder post ID is stored in $previous_post_id.
         * When status is error, the error is stored in $update_error.
         *
         * @since 4.3.0
         * @var string updated|inserted|deleted|error
         *
         * @see WP_Customize_Nav_Menu_Item_Setting::update()
         * @see WP_Customize_Nav_Menu_Item_Setting::amend_customize_save_response()
         */
        public $update_status;
        /**
         * Any error object returned by wp_update_nav_menu_item() when setting is updated.
         *
         * @since 4.3.0
         * @var WP_Error
         *
         * @see WP_Customize_Nav_Menu_Item_Setting::update()
         * @see WP_Customize_Nav_Menu_Item_Setting::amend_customize_save_response()
         */
        public $update_error;
        /**
         * Constructor.
         *
         * Any supplied $args override class property defaults.
         *
         * @since 4.3.0
         *
         * @throws Exception If $id is not valid for this setting type.
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      A specific ID of the setting.
         *                                      Can be a theme mod or option name.
         * @param array                $args    Optional. Setting arguments.
         */
        public function __construct(\WP_Customize_Manager $manager, $id, array $args = array())
        {
        }
        /**
         * Clear the cached value when this nav menu item is updated.
         *
         * @since 4.3.0
         *
         * @param int $menu_id       The term ID for the menu.
         * @param int $menu_item_id  The post ID for the menu item.
         */
        public function flush_cached_value($menu_id, $menu_item_id)
        {
        }
        /**
         * Get the instance data for a given nav_menu_item setting.
         *
         * @since 4.3.0
         *
         * @see wp_setup_nav_menu_item()
         *
         * @return array|false Instance data array, or false if the item is marked for deletion.
         */
        public function value()
        {
        }
        /**
         * Get original title.
         *
         * @since 4.7.0
         *
         * @param object $item Nav menu item.
         * @return string The original title.
         */
        protected function get_original_title($item)
        {
        }
        /**
         * Get type label.
         *
         * @since 4.7.0
         *
         * @param object $item Nav menu item.
         * @return string The type label.
         */
        protected function get_type_label($item)
        {
        }
        /**
         * Ensure that the value is fully populated with the necessary properties.
         *
         * Translates some properties added by wp_setup_nav_menu_item() and removes others.
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Nav_Menu_Item_Setting::value()
         * @phpstan-return void
         */
        protected function populate_value()
        {
        }
        /**
         * Handle previewing the setting.
         *
         * @since 4.3.0
         * @since 4.4.0 Added boolean return value.
         *
         * @see WP_Customize_Manager::post_value()
         *
         * @return bool False if method short-circuited due to no-op.
         */
        public function preview()
        {
        }
        /**
         * Filters the wp_get_nav_menu_items() result to supply the previewed menu items.
         *
         * @since 4.3.0
         *
         * @see wp_get_nav_menu_items()
         *
         * @param WP_Post[] $items An array of menu item post objects.
         * @param WP_Term   $menu  The menu object.
         * @param array     $args  An array of arguments used to retrieve menu item objects.
         * @return WP_Post[] Array of menu item objects.
         */
        public function filter_wp_get_nav_menu_items($items, $menu, $args)
        {
        }
        /**
         * Re-apply the tail logic also applied on $items by wp_get_nav_menu_items().
         *
         * @since 4.3.0
         *
         * @see wp_get_nav_menu_items()
         *
         * @param WP_Post[] $items An array of menu item post objects.
         * @param WP_Term   $menu  The menu object.
         * @param array     $args  An array of arguments used to retrieve menu item objects.
         * @return WP_Post[] Array of menu item objects.
         */
        public static function sort_wp_get_nav_menu_items($items, $menu, $args)
        {
        }
        /**
         * Get the value emulated into a WP_Post and set up as a nav_menu_item.
         *
         * @since 4.3.0
         *
         * @return WP_Post With wp_setup_nav_menu_item() applied.
         */
        public function value_as_wp_post_nav_menu_item()
        {
        }
        /**
         * Sanitize an input.
         *
         * Note that parent::sanitize() erroneously does wp_unslash() on $value, but
         * we remove that in this override.
         *
         * @since 4.3.0
         * @since 5.9.0 Renamed `$menu_item_value` to `$value` for PHP 8 named parameter support.
         *
         * @param array $value The menu item value to sanitize.
         * @return array|false|null|WP_Error Null or WP_Error if an input isn't valid. False if it is marked for deletion.
         *                                   Otherwise the sanitized value.
         */
        public function sanitize($value)
        {
        }
        /**
         * Creates/updates the nav_menu_item post for this setting.
         *
         * Any created menu items will have their assigned post IDs exported to the client
         * via the {@see 'customize_save_response'} filter. Likewise, any errors will be
         * exported to the client via the customize_save_response() filter.
         *
         * To delete a menu, the client can send false as the value.
         *
         * @since 4.3.0
         *
         * @see wp_update_nav_menu_item()
         *
         * @param array|false $value The menu item array to update. If false, then the menu item will be deleted
         *                           entirely. See WP_Customize_Nav_Menu_Item_Setting::$default for what the value
         *                           should consist of.
         * @return null|void
         * @phpstan-return void
         */
        protected function update($value)
        {
        }
        /**
         * Export data for the JS client.
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Nav_Menu_Item_Setting::update()
         *
         * @param array $data Additional information passed back to the 'saved' event on `wp.customize`.
         * @return array Save response data.
         */
        public function amend_customize_save_response($data)
        {
        }
    }
    /**
     * Customize Menu Location Control Class.
     *
     * This custom control is only needed for JS.
     *
     * @since 4.3.0
     *
     * @see WP_Customize_Control
     */
    class WP_Customize_Nav_Menu_Location_Control extends \WP_Customize_Control
    {
        /**
         * Control type.
         *
         * @since 4.3.0
         * @var string
         */
        public $type = 'nav_menu_location';
        /**
         * Location ID.
         *
         * @since 4.3.0
         * @var string
         */
        public $location_id = '';
        /**
         * Refresh the parameters passed to JavaScript via JSON.
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Control::to_json()
         */
        public function to_json()
        {
        }
        /**
         * Render content just like a normal select control.
         *
         * @since 4.3.0
         * @since 4.9.0 Added a button to create menus.
         * @phpstan-return void
         */
        public function render_content()
        {
        }
    }
    /**
     * Customize Nav Menu Locations Control Class.
     *
     * @since 4.9.0
     *
     * @see WP_Customize_Control
     */
    class WP_Customize_Nav_Menu_Locations_Control extends \WP_Customize_Control
    {
        /**
         * Control type.
         *
         * @since 4.9.0
         * @var string
         */
        public $type = 'nav_menu_locations';
        /**
         * Don't render the control's content - it uses a JS template instead.
         *
         * @since 4.9.0
         */
        public function render_content()
        {
        }
        /**
         * JS/Underscore template for the control UI.
         *
         * @since 4.9.0
         */
        public function content_template()
        {
        }
    }
    /**
     * Customize control to represent the name field for a given menu.
     *
     * @since 4.3.0
     *
     * @see WP_Customize_Control
     */
    class WP_Customize_Nav_Menu_Name_Control extends \WP_Customize_Control
    {
        /**
         * Type of control, used by JS.
         *
         * @since 4.3.0
         * @var string
         */
        public $type = 'nav_menu_name';
        /**
         * No-op since we're using JS template.
         *
         * @since 4.3.0
         */
        protected function render_content()
        {
        }
        /**
         * Render the Underscore template for this control.
         *
         * @since 4.3.0
         */
        protected function content_template()
        {
        }
    }
    /**
     * Customize Menu Section Class
     *
     * Custom section only needed in JS.
     *
     * @since 4.3.0
     *
     * @see WP_Customize_Section
     */
    class WP_Customize_Nav_Menu_Section extends \WP_Customize_Section
    {
        /**
         * Control type.
         *
         * @since 4.3.0
         * @var string
         */
        public $type = 'nav_menu';
        /**
         * Get section parameters for JS.
         *
         * @since 4.3.0
         * @return array Exported parameters.
         */
        public function json()
        {
        }
    }
    /**
     * Customize Setting to represent a nav_menu.
     *
     * Subclass of WP_Customize_Setting to represent a nav_menu taxonomy term, and
     * the IDs for the nav_menu_items associated with the nav menu.
     *
     * @since 4.3.0
     *
     * @see wp_get_nav_menu_object()
     * @see WP_Customize_Setting
     */
    class WP_Customize_Nav_Menu_Setting extends \WP_Customize_Setting
    {
        const ID_PATTERN = '/^nav_menu\\[(?P<id>-?\\d+)\\]$/';
        const TAXONOMY = 'nav_menu';
        const TYPE = 'nav_menu';
        /**
         * Setting type.
         *
         * @since 4.3.0
         * @var string
         */
        public $type = self::TYPE;
        /**
         * Default setting value.
         *
         * @since 4.3.0
         * @var array
         *
         * @see wp_get_nav_menu_object()
         */
        public $default = array('name' => '', 'description' => '', 'parent' => 0, 'auto_add' => \false);
        /**
         * Default transport.
         *
         * @since 4.3.0
         * @var string
         */
        public $transport = 'postMessage';
        /**
         * The term ID represented by this setting instance.
         *
         * A negative value represents a placeholder ID for a new menu not yet saved.
         *
         * @since 4.3.0
         * @var int
         */
        public $term_id;
        /**
         * Previous (placeholder) term ID used before creating a new menu.
         *
         * This value will be exported to JS via the {@see 'customize_save_response'} filter
         * so that JavaScript can update the settings to refer to the newly-assigned
         * term ID. This value is always negative to indicate it does not refer to
         * a real term.
         *
         * @since 4.3.0
         * @var int
         *
         * @see WP_Customize_Nav_Menu_Setting::update()
         * @see WP_Customize_Nav_Menu_Setting::amend_customize_save_response()
         */
        public $previous_term_id;
        /**
         * Whether or not update() was called.
         *
         * @since 4.3.0
         * @var bool
         */
        protected $is_updated = \false;
        /**
         * Status for calling the update method, used in customize_save_response filter.
         *
         * See {@see 'customize_save_response'}.
         *
         * When status is inserted, the placeholder term ID is stored in `$previous_term_id`.
         * When status is error, the error is stored in `$update_error`.
         *
         * @since 4.3.0
         * @var string updated|inserted|deleted|error
         *
         * @see WP_Customize_Nav_Menu_Setting::update()
         * @see WP_Customize_Nav_Menu_Setting::amend_customize_save_response()
         */
        public $update_status;
        /**
         * Any error object returned by wp_update_nav_menu_object() when setting is updated.
         *
         * @since 4.3.0
         * @var WP_Error
         *
         * @see WP_Customize_Nav_Menu_Setting::update()
         * @see WP_Customize_Nav_Menu_Setting::amend_customize_save_response()
         */
        public $update_error;
        /**
         * Constructor.
         *
         * Any supplied $args override class property defaults.
         *
         * @since 4.3.0
         *
         * @throws Exception If $id is not valid for this setting type.
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      A specific ID of the setting.
         *                                      Can be a theme mod or option name.
         * @param array                $args    Optional. Setting arguments.
         */
        public function __construct(\WP_Customize_Manager $manager, $id, array $args = array())
        {
        }
        /**
         * Get the instance data for a given widget setting.
         *
         * @since 4.3.0
         *
         * @see wp_get_nav_menu_object()
         *
         * @return array Instance data.
         */
        public function value()
        {
        }
        /**
         * Handle previewing the setting.
         *
         * @since 4.3.0
         * @since 4.4.0 Added boolean return value
         *
         * @see WP_Customize_Manager::post_value()
         *
         * @return bool False if method short-circuited due to no-op.
         */
        public function preview()
        {
        }
        /**
         * Filters the wp_get_nav_menus() result to ensure the inserted menu object is included, and the deleted one is removed.
         *
         * @since 4.3.0
         *
         * @see wp_get_nav_menus()
         *
         * @param WP_Term[] $menus An array of menu objects.
         * @param array     $args  An array of arguments used to retrieve menu objects.
         * @return WP_Term[] Array of menu objects.
         */
        public function filter_wp_get_nav_menus($menus, $args)
        {
        }
        /**
         * Temporary non-closure passing of orderby value to function.
         *
         * @since 4.3.0
         * @var string
         *
         * @see WP_Customize_Nav_Menu_Setting::filter_wp_get_nav_menus()
         * @see WP_Customize_Nav_Menu_Setting::_sort_menus_by_orderby()
         */
        protected $_current_menus_sort_orderby;
        /**
         * Sort menu objects by the class-supplied orderby property.
         *
         * This is a workaround for a lack of closures.
         *
         * @since 4.3.0
         * @deprecated 4.7.0 Use wp_list_sort()
         *
         * @param object $menu1
         * @param object $menu2
         * @return int
         *
         * @see WP_Customize_Nav_Menu_Setting::filter_wp_get_nav_menus()
         */
        protected function _sort_menus_by_orderby($menu1, $menu2)
        {
        }
        /**
         * Filters the wp_get_nav_menu_object() result to supply the previewed menu object.
         *
         * Requesting a nav_menu object by anything but ID is not supported.
         *
         * @since 4.3.0
         *
         * @see wp_get_nav_menu_object()
         *
         * @param object|null $menu_obj Object returned by wp_get_nav_menu_object().
         * @param string      $menu_id  ID of the nav_menu term. Requests by slug or name will be ignored.
         * @return object|null
         */
        public function filter_wp_get_nav_menu_object($menu_obj, $menu_id)
        {
        }
        /**
         * Filters the nav_menu_options option to include this menu's auto_add preference.
         *
         * @since 4.3.0
         *
         * @param array $nav_menu_options Nav menu options including auto_add.
         * @return array (Maybe) modified nav menu options.
         */
        public function filter_nav_menu_options($nav_menu_options)
        {
        }
        /**
         * Sanitize an input.
         *
         * Note that parent::sanitize() erroneously does wp_unslash() on $value, but
         * we remove that in this override.
         *
         * @since 4.3.0
         *
         * @param array $value The menu value to sanitize.
         * @return array|false|null Null if an input isn't valid. False if it is marked for deletion.
         *                          Otherwise the sanitized value.
         */
        public function sanitize($value)
        {
        }
        /**
         * Storage for data to be sent back to client in customize_save_response filter.
         *
         * See {@see 'customize_save_response'}.
         *
         * @since 4.3.0
         * @var array
         *
         * @see WP_Customize_Nav_Menu_Setting::amend_customize_save_response()
         */
        protected $_widget_nav_menu_updates = array();
        /**
         * Create/update the nav_menu term for this setting.
         *
         * Any created menus will have their assigned term IDs exported to the client
         * via the {@see 'customize_save_response'} filter. Likewise, any errors will be exported
         * to the client via the customize_save_response() filter.
         *
         * To delete a menu, the client can send false as the value.
         *
         * @since 4.3.0
         *
         * @see wp_update_nav_menu_object()
         *
         * @param array|false $value {
         *     The value to update. Note that slug cannot be updated via wp_update_nav_menu_object().
         *     If false, then the menu will be deleted entirely.
         *
         *     @type string $name        The name of the menu to save.
         *     @type string $description The term description. Default empty string.
         *     @type int    $parent      The id of the parent term. Default 0.
         *     @type bool   $auto_add    Whether pages will auto_add to this menu. Default false.
         * }
         * @return null|void
         * @phpstan-param false|array{
         *   name?: string,
         *   description?: string,
         *   parent?: int,
         *   auto_add?: bool,
         * } $value
         * @phpstan-return void
         */
        protected function update($value)
        {
        }
        /**
         * Updates a nav_menu_options array.
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Nav_Menu_Setting::filter_nav_menu_options()
         * @see WP_Customize_Nav_Menu_Setting::update()
         *
         * @param array $nav_menu_options Array as returned by get_option( 'nav_menu_options' ).
         * @param int   $menu_id          The term ID for the given menu.
         * @param bool  $auto_add         Whether to auto-add or not.
         * @return array (Maybe) modified nav_menu_options array.
         */
        protected function filter_nav_menu_options_value($nav_menu_options, $menu_id, $auto_add)
        {
        }
        /**
         * Export data for the JS client.
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Nav_Menu_Setting::update()
         *
         * @param array $data Additional information passed back to the 'saved' event on `wp.customize`.
         * @return array Export data.
         */
        public function amend_customize_save_response($data)
        {
        }
    }
    /**
     * Customize Nav Menus Panel Class
     *
     * Needed to add screen options.
     *
     * @since 4.3.0
     *
     * @see WP_Customize_Panel
     */
    class WP_Customize_Nav_Menus_Panel extends \WP_Customize_Panel
    {
        /**
         * Control type.
         *
         * @since 4.3.0
         * @var string
         */
        public $type = 'nav_menus';
        /**
         * Render screen options for Menus.
         *
         * @since 4.3.0
         */
        public function render_screen_options()
        {
        }
        /**
         * Returns the advanced options for the nav menus page.
         *
         * Link title attribute added as it's a relatively advanced concept for new users.
         *
         * @since 4.3.0
         * @deprecated 4.5.0 Deprecated in favor of wp_nav_menu_manage_columns().
         */
        public function wp_nav_menu_manage_columns()
        {
        }
        /**
         * An Underscore (JS) template for this panel's content (but not its container).
         *
         * Class variables for this panel class are available in the `data` JS object;
         * export custom variables by overriding WP_Customize_Panel::json().
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Panel::print_template()
         */
        protected function content_template()
        {
        }
    }
    /**
     * Customize control class for new menus.
     *
     * @since 4.3.0
     * @deprecated 4.9.0 This class is no longer used as of the menu creation UX introduced in #40104.
     *
     * @see WP_Customize_Control
     */
    class WP_Customize_New_Menu_Control extends \WP_Customize_Control
    {
        /**
         * Control type.
         *
         * @since 4.3.0
         * @var string
         */
        public $type = 'new_menu';
        /**
         * Constructor.
         *
         * @since 4.9.0
         * @deprecated 4.9.0
         *
         * @see WP_Customize_Control::__construct()
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      The control ID.
         * @param array                $args    Optional. Arguments to override class property defaults.
         *                                      See WP_Customize_Control::__construct() for information
         *                                      on accepted arguments. Default empty array.
         * @phpstan-param array{
         *   instance_number?: int,
         *   manager?: WP_Customize_Manager,
         *   id?: string,
         *   settings?: array,
         *   setting?: string,
         *   capability?: string,
         *   priority?: int,
         *   section?: string,
         *   label?: string,
         *   description?: string,
         *   choices?: array,
         *   input_attrs?: array,
         *   allow_addition?: bool,
         *   json?: array,
         *   type?: string,
         *   active_callback?: callable,
         * } $args See WP_Customize_Control::__construct()
         */
        public function __construct(\WP_Customize_Manager $manager, $id, array $args = array())
        {
        }
        /**
         * Render the control's content.
         *
         * @since 4.3.0
         * @deprecated 4.9.0
         */
        public function render_content()
        {
        }
    }
    /**
     * Customize Menu Section Class
     *
     * @since 4.3.0
     * @deprecated 4.9.0 This class is no longer used as of the menu creation UX introduced in #40104.
     *
     * @see WP_Customize_Section
     */
    class WP_Customize_New_Menu_Section extends \WP_Customize_Section
    {
        /**
         * Control type.
         *
         * @since 4.3.0
         * @var string
         */
        public $type = 'new_menu';
        /**
         * Constructor.
         *
         * Any supplied $args override class property defaults.
         *
         * @since 4.9.0
         * @deprecated 4.9.0
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      A specific ID of the section.
         * @param array                $args    Section arguments.
         */
        public function __construct(\WP_Customize_Manager $manager, $id, array $args = array())
        {
        }
        /**
         * Render the section, and the controls that have been added to it.
         *
         * @since 4.3.0
         * @deprecated 4.9.0
         */
        protected function render()
        {
        }
    }
    /**
     * Core Customizer class for implementing selective refresh partials.
     *
     * Representation of a rendered region in the previewed page that gets
     * selectively refreshed when an associated setting is changed.
     * This class is analogous of WP_Customize_Control.
     *
     * @since 4.5.0
     */
    #[\AllowDynamicProperties]
    class WP_Customize_Partial
    {
        /**
         * Component.
         *
         * @since 4.5.0
         * @var WP_Customize_Selective_Refresh
         */
        public $component;
        /**
         * Unique identifier for the partial.
         *
         * If the partial is used to display a single setting, this would generally
         * be the same as the associated setting's ID.
         *
         * @since 4.5.0
         * @var string
         */
        public $id;
        /**
         * Parsed ID.
         *
         * @since 4.5.0
         * @var array {
         *     @type string $base ID base.
         *     @type array  $keys Keys for multidimensional.
         * }
         * @phpstan-var array{
         *   base: string,
         *   keys: array,
         * }
         */
        protected $id_data = array();
        /**
         * Type of this partial.
         *
         * @since 4.5.0
         * @var string
         */
        public $type = 'default';
        /**
         * The jQuery selector to find the container element for the partial.
         *
         * @since 4.5.0
         * @var string
         */
        public $selector;
        /**
         * IDs for settings tied to the partial.
         *
         * @since 4.5.0
         * @var string[]
         */
        public $settings;
        /**
         * The ID for the setting that this partial is primarily responsible for rendering.
         *
         * If not supplied, it will default to the ID of the first setting.
         *
         * @since 4.5.0
         * @var string
         */
        public $primary_setting;
        /**
         * Capability required to edit this partial.
         *
         * Normally this is empty and the capability is derived from the capabilities
         * of the associated `$settings`.
         *
         * @since 4.5.0
         * @var string
         */
        public $capability;
        /**
         * Render callback.
         *
         * @since 4.5.0
         *
         * @see WP_Customize_Partial::render()
         * @var callable Callback is called with one argument, the instance of
         *               WP_Customize_Partial. The callback can either echo the
         *               partial or return the partial as a string, or return false if error.
         */
        public $render_callback;
        /**
         * Whether the container element is included in the partial, or if only the contents are rendered.
         *
         * @since 4.5.0
         * @var bool
         */
        public $container_inclusive = \false;
        /**
         * Whether to refresh the entire preview in case a partial cannot be refreshed.
         *
         * A partial render is considered a failure if the render_callback returns false.
         *
         * @since 4.5.0
         * @var bool
         */
        public $fallback_refresh = \true;
        /**
         * Constructor.
         *
         * Supplied `$args` override class property defaults.
         *
         * If `$args['settings']` is not defined, use the $id as the setting ID.
         *
         * @since 4.5.0
         *
         * @param WP_Customize_Selective_Refresh $component Customize Partial Refresh plugin instance.
         * @param string                         $id        Control ID.
         * @param array                          $args {
         *     Optional. Array of properties for the new Partials object. Default empty array.
         *
         *     @type string   $type                  Type of the partial to be created.
         *     @type string   $selector              The jQuery selector to find the container element for the partial, that is,
         *                                           a partial's placement.
         *     @type string[] $settings              IDs for settings tied to the partial. If undefined, `$id` will be used.
         *     @type string   $primary_setting       The ID for the setting that this partial is primarily responsible for
         *                                           rendering. If not supplied, it will default to the ID of the first setting.
         *     @type string   $capability            Capability required to edit this partial.
         *                                           Normally this is empty and the capability is derived from the capabilities
         *                                           of the associated `$settings`.
         *     @type callable $render_callback       Render callback.
         *                                           Callback is called with one argument, the instance of WP_Customize_Partial.
         *                                           The callback can either echo the partial or return the partial as a string,
         *                                           or return false if error.
         *     @type bool     $container_inclusive   Whether the container element is included in the partial, or if only
         *                                           the contents are rendered.
         *     @type bool     $fallback_refresh      Whether to refresh the entire preview in case a partial cannot be refreshed.
         *                                           A partial render is considered a failure if the render_callback returns
         *                                           false.
         * }
         * @phpstan-param array{
         *   type?: string,
         *   selector?: string,
         *   settings?: string[],
         *   primary_setting?: string,
         *   capability?: string,
         *   render_callback?: callable,
         *   container_inclusive?: bool,
         *   fallback_refresh?: bool,
         * } $args
         */
        public function __construct(\WP_Customize_Selective_Refresh $component, $id, $args = array())
        {
        }
        /**
         * Retrieves parsed ID data for multidimensional setting.
         *
         * @since 4.5.0
         *
         * @return array {
         *     ID data for multidimensional partial.
         *
         *     @type string $base ID base.
         *     @type array  $keys Keys for multidimensional array.
         * }
         * @phpstan-return array{
         *   base: string,
         *   keys: array,
         * }
         */
        public final function id_data()
        {
        }
        /**
         * Renders the template partial involving the associated settings.
         *
         * @since 4.5.0
         *
         * @param array $container_context Optional. Array of context data associated with the target container (placement).
         *                                 Default empty array.
         * @return string|array|false The rendered partial as a string, raw data array (for client-side JS template),
         *                            or false if no render applied.
         */
        public final function render($container_context = array())
        {
        }
        /**
         * Default callback used when invoking WP_Customize_Control::render().
         *
         * Note that this method may echo the partial *or* return the partial as
         * a string or array, but not both. Output buffering is performed when this
         * is called. Subclasses can override this with their specific logic, or they
         * may provide an 'render_callback' argument to the constructor.
         *
         * This method may return an HTML string for straight DOM injection, or it
         * may return an array for supporting Partial JS subclasses to render by
         * applying to client-side templating.
         *
         * @since 4.5.0
         *
         * @param WP_Customize_Partial $partial Partial.
         * @param array                $context Context.
         * @return string|array|false
         */
        public function render_callback(\WP_Customize_Partial $partial, $context = array())
        {
        }
        /**
         * Retrieves the data to export to the client via JSON.
         *
         * @since 4.5.0
         *
         * @return array Array of parameters passed to the JavaScript.
         */
        public function json()
        {
        }
        /**
         * Checks if the user can refresh this partial.
         *
         * Returns false if the user cannot manipulate one of the associated settings,
         * or if one of the associated settings does not exist.
         *
         * @since 4.5.0
         *
         * @return bool False if user can't edit one of the related settings,
         *                    or if one of the associated settings does not exist.
         */
        public final function check_capabilities()
        {
        }
    }
    /**
     * Core Customizer class for implementing selective refresh.
     *
     * @since 4.5.0
     */
    #[\AllowDynamicProperties]
    final class WP_Customize_Selective_Refresh
    {
        /**
         * Query var used in requests to render partials.
         *
         * @since 4.5.0
         */
        const RENDER_QUERY_VAR = 'wp_customize_render_partials';
        /**
         * Customize manager.
         *
         * @since 4.5.0
         * @var WP_Customize_Manager
         */
        public $manager;
        /**
         * Plugin bootstrap for Partial Refresh functionality.
         *
         * @since 4.5.0
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         */
        public function __construct(\WP_Customize_Manager $manager)
        {
        }
        /**
         * Retrieves the registered partials.
         *
         * @since 4.5.0
         *
         * @return array Partials.
         */
        public function partials()
        {
        }
        /**
         * Adds a partial.
         *
         * @since 4.5.0
         *
         * @see WP_Customize_Partial::__construct()
         *
         * @param WP_Customize_Partial|string $id   Customize Partial object, or Partial ID.
         * @param array                       $args Optional. Array of properties for the new Partials object.
         *                                          See WP_Customize_Partial::__construct() for information
         *                                          on accepted arguments. Default empty array.
         * @return WP_Customize_Partial The instance of the partial that was added.
         * @phpstan-param array{
         *   type?: string,
         *   selector?: string,
         *   settings?: string[],
         *   primary_setting?: string,
         *   capability?: string,
         *   render_callback?: callable,
         *   container_inclusive?: bool,
         *   fallback_refresh?: bool,
         * } $args See WP_Customize_Partial::__construct()
         */
        public function add_partial($id, $args = array())
        {
        }
        /**
         * Retrieves a partial.
         *
         * @since 4.5.0
         *
         * @param string $id Customize Partial ID.
         * @return WP_Customize_Partial|null The partial, if set. Otherwise null.
         */
        public function get_partial($id)
        {
        }
        /**
         * Removes a partial.
         *
         * @since 4.5.0
         *
         * @param string $id Customize Partial ID.
         */
        public function remove_partial($id)
        {
        }
        /**
         * Initializes the Customizer preview.
         *
         * @since 4.5.0
         */
        public function init_preview()
        {
        }
        /**
         * Enqueues preview scripts.
         *
         * @since 4.5.0
         */
        public function enqueue_preview_scripts()
        {
        }
        /**
         * Exports data in preview after it has finished rendering so that partials can be added at runtime.
         *
         * @since 4.5.0
         */
        public function export_preview_data()
        {
        }
        /**
         * Registers dynamically-created partials.
         *
         * @since 4.5.0
         *
         * @see WP_Customize_Manager::add_dynamic_settings()
         *
         * @param string[] $partial_ids Array of the partial IDs to add.
         * @return WP_Customize_Partial[] Array of added WP_Customize_Partial instances.
         */
        public function add_dynamic_partials($partial_ids)
        {
        }
        /**
         * Checks whether the request is for rendering partials.
         *
         * Note that this will not consider whether the request is authorized or valid,
         * just that essentially the route is a match.
         *
         * @since 4.5.0
         *
         * @return bool Whether the request is for rendering partials.
         */
        public function is_render_partials_request()
        {
        }
        /**
         * Handles PHP errors triggered during rendering the partials.
         *
         * These errors will be relayed back to the client in the Ajax response.
         *
         * @since 4.5.0
         *
         * @param int    $errno   Error number.
         * @param string $errstr  Error string.
         * @param string $errfile Error file.
         * @param int    $errline Error line.
         * @return true Always true.
         */
        public function handle_error($errno, $errstr, $errfile = \null, $errline = \null)
        {
        }
        /**
         * Handles the Ajax request to return the rendered partials for the requested placements.
         *
         * @since 4.5.0
         * @phpstan-return void
         */
        public function handle_render_partials_request()
        {
        }
    }
    /**
     * Customizer section representing widget area (sidebar).
     *
     * @since 4.1.0
     *
     * @see WP_Customize_Section
     */
    class WP_Customize_Sidebar_Section extends \WP_Customize_Section
    {
        /**
         * Type of this section.
         *
         * @since 4.1.0
         * @var string
         */
        public $type = 'sidebar';
        /**
         * Unique identifier.
         *
         * @since 4.1.0
         * @var string
         */
        public $sidebar_id;
        /**
         * Gather the parameters passed to client JavaScript via JSON.
         *
         * @since 4.1.0
         *
         * @return array The array to be exported to the client as JSON.
         */
        public function json()
        {
        }
        /**
         * Whether the current sidebar is rendered on the page.
         *
         * @since 4.1.0
         *
         * @return bool Whether sidebar is rendered.
         */
        public function active_callback()
        {
        }
    }
    /**
     * Customize Site Icon control class.
     *
     * Used only for custom functionality in JavaScript.
     *
     * @since 4.3.0
     *
     * @see WP_Customize_Cropped_Image_Control
     */
    class WP_Customize_Site_Icon_Control extends \WP_Customize_Cropped_Image_Control
    {
        /**
         * Control type.
         *
         * @since 4.3.0
         * @var string
         */
        public $type = 'site_icon';
        /**
         * Constructor.
         *
         * @since 4.3.0
         *
         * @see WP_Customize_Control::__construct()
         *
         * @param WP_Customize_Manager $manager Customizer bootstrap instance.
         * @param string               $id      Control ID.
         * @param array                $args    Optional. Arguments to override class property defaults.
         *                                      See WP_Customize_Control::__construct() for information
         *                                      on accepted arguments. Default empty array.
         * @phpstan-param array{
         *   instance_number?: int,
         *   manager?: WP_Customize_Manager,
         *   id?: string,
         *   settings?: array,
         *   setting?: string,
         *   capability?: string,
         *   priority?: int,
         *   section?: string,
         *   label?: string,
         *   description?: string,
         *   choices?: array,
         *   input_attrs?: array,
         *   allow_addition?: bool,
         *   json?: array,
         *   type?: string,
         *   active_callback?: callable,
         * } $args See WP_Customize_Control::__construct()
         */
        public function __construct($manager, $id, $args = array())
        {
        }
        /**
         * Renders a JS template for the content of the site icon control.
         *
         * @since 4.5.0
         */
        public function content_template()
        {
        }
    }
    /**
     * Customize Theme Control class.
     *
     * @since 4.2.0
     *
     * @see WP_Customize_Control
     */
    class WP_Customize_Theme_Control extends \WP_Customize_Control
    {
        /**
         * Customize control type.
         *
         * @since 4.2.0
         * @var string
         */
        public $type = 'theme';
        /**
         * Theme object.
         *
         * @since 4.2.0
         * @var WP_Theme
         */
        public $theme;
        /**
         * Refresh the parameters passed to the JavaScript via JSON.
         *
         * @since 4.2.0
         *
         * @see WP_Customize_Control::to_json()
         */
        public function to_json()
        {
        }
        /**
         * Don't render the control content from PHP, as it's rendered via JS on load.
         *
         * @since 4.2.0
         */
        public function render_content()
        {
        }
        /**
         * Render a JS template for theme display.
         *
         * @since 4.2.0
         */
        public function content_template()
        {
        }
    }
    /**
     * Customize Themes Panel Class
     *
     * @since 4.9.0
     *
     * @see WP_Customize_Panel
     */
    class WP_Customize_Themes_Panel extends \WP_Customize_Panel
    {
        /**
         * Panel type.
         *
         * @since 4.9.0
         * @var string
         */
        public $type = 'themes';
        /**
         * An Underscore (JS) template for rendering this panel's container.
         *
         * The themes panel renders a custom panel heading with the active theme and a switch themes button.
         *
         * @see WP_Customize_Panel::print_template()
         *
         * @since 4.9.0
         */
        protected function render_template()
        {
        }
        /**
         * An Underscore (JS) template for this panel's content (but not its container).
         *
         * Class variables for this panel class are available in the `data` JS object;
         * export custom variables by overriding WP_Customize_Panel::json().
         *
         * @since 4.9.0
         *
         * @see WP_Customize_Panel::print_template()
         */
        protected function content_template()
        {
        }
    }
    /**
     * Customize Themes Section class.
     *
     * A UI container for theme controls, which are displayed within sections.
     *
     * @since 4.2.0
     *
     * @see WP_Customize_Section
     */
    class WP_Customize_Themes_Section extends \WP_Customize_Section
    {
        /**
         * Section type.
         *
         * @since 4.2.0
         * @var string
         */
        public $type = 'themes';
        /**
         * Theme section action.
         *
         * Defines the type of themes to load (installed, wporg, etc.).
         *
         * @since 4.9.0
         * @var string
         */
        public $action = '';
        /**
         * Theme section filter type.
         *
         * Determines whether filters are applied to loaded (local) themes or by initiating a new remote query (remote).
         * When filtering is local, the initial themes query is not paginated by default.
         *
         * @since 4.9.0
         * @var string
         */
        public $filter_type = 'local';
        /**
         * Gets section parameters for JS.
         *
         * @since 4.9.0
         * @return array Exported parameters.
         */
        public function json()
        {
        }
        /**
         * Renders a themes section as a JS template.
         *
         * The template is only rendered by PHP once, so all actions are prepared at once on the server side.
         *
         * @since 4.9.0
         */
        protected function render_template()
        {
        }
        /**
         * Renders the filter bar portion of a themes section as a JS template.
         *
         * The template is only rendered by PHP once, so all actions are prepared at once on the server side.
         * The filter bar container is rendered by {@see render_template()}.
         *
         * @since 4.9.0
         */
        protected function filter_bar_content_template()
        {
        }
        /**
         * Renders the filter drawer portion of a themes section as a JS template.
         *
         * The filter bar container is rendered by {@see render_template()}.
         *
         * @since 4.9.0
         */
        protected function filter_drawer_content_template()
        {
        }
    }
    /**
     * Core class used to implement the widgets block editor control in the
     * customizer.
     *
     * @since 5.8.0
     *
     * @see WP_Customize_Control
     */
    class WP_Sidebar_Block_Editor_Control extends \WP_Customize_Control
    {
        /**
         * The control type.
         *
         * @since 5.8.0
         *
         * @var string
         */
        public $type = 'sidebar_block_editor';
        /**
         * Render the widgets block editor container.
         *
         * @since 5.8.0
         */
        public function render_content()
        {
        }
    }
    /**
     * Widget Area Customize Control class.
     *
     * @since 3.9.0
     *
     * @see WP_Customize_Control
     */
    class WP_Widget_Area_Customize_Control extends \WP_Customize_Control
    {
        /**
         * Customize control type.
         *
         * @since 3.9.0
         * @var string
         */
        public $type = 'sidebar_widgets';
        /**
         * Sidebar ID.
         *
         * @since 3.9.0
         * @var int|string
         */
        public $sidebar_id;
        /**
         * Refreshes the parameters passed to the JavaScript via JSON.
         *
         * @since 3.9.0
         */
        public function to_json()
        {
        }
        /**
         * Renders the control's content.
         *
         * @since 3.9.0
         */
        public function render_content()
        {
        }
    }
    /**
     * Widget Form Customize Control class.
     *
     * @since 3.9.0
     *
     * @see WP_Customize_Control
     */
    class WP_Widget_Form_Customize_Control extends \WP_Customize_Control
    {
        /**
         * Customize control type.
         *
         * @since 3.9.0
         * @var string
         */
        public $type = 'widget_form';
        /**
         * Widget ID.
         *
         * @since 3.9.0
         * @var string
         */
        public $widget_id;
        /**
         * Widget ID base.
         *
         * @since 3.9.0
         * @var string
         */
        public $widget_id_base;
        /**
         * Sidebar ID.
         *
         * @since 3.9.0
         * @var string
         */
        public $sidebar_id;
        /**
         * Widget status.
         *
         * @since 3.9.0
         * @var bool True if new, false otherwise. Default false.
         */
        public $is_new = \false;
        /**
         * Widget width.
         *
         * @since 3.9.0
         * @var int
         */
        public $width;
        /**
         * Widget height.
         *
         * @since 3.9.0
         * @var int
         */
        public $height;
        /**
         * Widget mode.
         *
         * @since 3.9.0
         * @var bool True if wide, false otherwise. Default false.
         */
        public $is_wide = \false;
        /**
         * Gather control params for exporting to JavaScript.
         *
         * @since 3.9.0
         *
         * @global array $wp_registered_widgets
         */
        public function to_json()
        {
        }
        /**
         * Override render_content to be no-op since content is exported via to_json for deferred embedding.
         *
         * @since 3.9.0
         */
        public function render_content()
        {
        }
        /**
         * Whether the current widget is rendered on the page.
         *
         * @since 4.0.0
         *
         * @return bool Whether the widget is rendered.
         */
        public function active_callback()
        {
        }
    }
    /**
     * Font Collection class.
     *
     * @since 6.5.0
     *
     * @see wp_register_font_collection()
     */
    final class WP_Font_Collection
    {
        /**
         * The unique slug for the font collection.
         *
         * @since 6.5.0
         * @var string
         */
        public $slug;
        /**
         * WP_Font_Collection constructor.
         *
         * @since 6.5.0
         *
         * @param string $slug Font collection slug. May only contain alphanumeric characters, dashes,
         *                     and underscores. See sanitize_title().
         * @param array  $args Font collection data. See wp_register_font_collection() for information on accepted arguments.
         * @phpstan-param array{
         *   name?: string,
         *   description?: string,
         *   font_families?: array|string,
         *   categories?: array,
         * } $args See wp_register_font_collection()
         */
        public function __construct(string $slug, array $args)
        {
        }
        /**
         * Retrieves the font collection data.
         *
         * @since 6.5.0
         *
         * @return array|WP_Error An array containing the font collection data, or a WP_Error on failure.
         */
        public function get_data()
        {
        }
    }
    /**
     * The Font Face Resolver abstracts the processing of different data sources
     * (such as theme.json) for processing within the Font Face.
     *
     * This class is for internal core usage and is not supposed to be used by
     * extenders (plugins and/or themes).
     *
     * @access private
     */
    class WP_Font_Face_Resolver
    {
        /**
         * Gets fonts defined in theme.json.
         *
         * @since 6.4.0
         *
         * @return array Returns the font-families, each with their font-face variations.
         */
        public static function get_fonts_from_theme_json()
        {
        }
        /**
         * Gets fonts defined in style variations.
         *
         * @since 6.7.0
         *
         * @return array Returns an array of font-families.
         */
        public static function get_fonts_from_style_variations()
        {
        }
    }
    /**
     * Font Face generates and prints `@font-face` styles for given fonts.
     *
     * @since 6.4.0
     */
    class WP_Font_Face
    {
        /**
         * Creates and initializes an instance of WP_Font_Face.
         *
         * @since 6.4.0
         */
        public function __construct()
        {
        }
        /**
         * Generates and prints the `@font-face` styles for the given fonts.
         *
         * @since 6.4.0
         *
         * @param array[][] $fonts Optional. The font-families and their font variations.
         *                         See {@see wp_print_font_faces()} for the supported fields.
         *                         Default empty array.
         * @phpstan-param array[]<int|string, array{
         * ?: array<array-key, array{
         *     font-family: string,
         *     src: string|string[],
         *     font-style?: string,
         *     font-weight?: string,
         *     font-display?: string,
         *     ascent-override?: string,
         *     descent-override?: string,
         *     font-stretch?: string,
         *     font-variant?: string,
         *     font-feature-settings?: string,
         *     font-variation-settings?: string,
         *     line-gap-override?: string,
         *     size-adjust?: string,
         *     unicode-range?: string,
         * }>,
         * }> $fonts See wp_print_font_faces()
         * @phpstan-return void
         */
        public function generate_and_print(array $fonts)
        {
        }
    }
    /**
     * Font Library class.
     *
     * @since 6.5.0
     */
    class WP_Font_Library
    {
        /**
         * Register a new font collection.
         *
         * @since 6.5.0
         *
         * @param string $slug Font collection slug. May only contain alphanumeric characters, dashes,
         *                     and underscores. See sanitize_title().
         * @param array  $args Font collection data. See wp_register_font_collection() for information on accepted arguments.
         * @return WP_Font_Collection|WP_Error A font collection if it was registered successfully,
         *                                     or WP_Error object on failure.
         * @phpstan-param array{
         *   name?: string,
         *   description?: string,
         *   font_families?: array|string,
         *   categories?: array,
         * } $args See wp_register_font_collection()
         */
        public function register_font_collection(string $slug, array $args)
        {
        }
        /**
         * Unregisters a previously registered font collection.
         *
         * @since 6.5.0
         *
         * @param string $slug Font collection slug.
         * @return bool True if the font collection was unregistered successfully and false otherwise.
         */
        public function unregister_font_collection(string $slug)
        {
        }
        /**
         * Gets all the font collections available.
         *
         * @since 6.5.0
         *
         * @return array List of font collections.
         */
        public function get_font_collections()
        {
        }
        /**
         * Gets a font collection.
         *
         * @since 6.5.0
         *
         * @param string $slug Font collection slug.
         * @return WP_Font_Collection|null Font collection object, or null if the font collection doesn't exist.
         */
        public function get_font_collection(string $slug)
        {
        }
        /**
         * Utility method to retrieve the main instance of the class.
         *
         * The instance will be created if it does not exist yet.
         *
         * @since 6.5.0
         *
         * @return WP_Font_Library The main instance.
         */
        public static function get_instance()
        {
        }
    }
    /**
     * A class of utilities for working with the Font Library.
     *
     * These utilities may change or be removed in the future and are intended for internal use only.
     *
     * @since 6.5.0
     * @access private
     */
    class WP_Font_Utils
    {
        /**
         * Sanitizes and formats font family names.
         *
         * - Applies `sanitize_text_field`.
         * - Adds surrounding quotes to names containing any characters that are not alphabetic or dashes.
         *
         * It follows the recommendations from the CSS Fonts Module Level 4.
         * @link https://www.w3.org/TR/css-fonts-4/#font-family-prop
         *
         * @since 6.5.0
         * @access private
         *
         * @see sanitize_text_field()
         *
         * @param string $font_family Font family name(s), comma-separated.
         * @return string Sanitized and formatted font family name(s).
         */
        public static function sanitize_font_family($font_family)
        {
        }
        /**
         * Generates a slug from font face properties, e.g. `open sans;normal;400;100%;U+0-10FFFF`
         *
         * Used for comparison with other font faces in the same family, to prevent duplicates
         * that would both match according the CSS font matching spec. Uses only simple case-insensitive
         * matching for fontFamily and unicodeRange, so does not handle overlapping font-family lists or
         * unicode ranges.
         *
         * @since 6.5.0
         * @access private
         *
         * @link https://drafts.csswg.org/css-fonts/#font-style-matching
         *
         * @param array $settings {
         *     Font face settings.
         *
         *     @type string $fontFamily   Font family name.
         *     @type string $fontStyle    Optional font style, defaults to 'normal'.
         *     @type string $fontWeight   Optional font weight, defaults to 400.
         *     @type string $fontStretch  Optional font stretch, defaults to '100%'.
         *     @type string $unicodeRange Optional unicode range, defaults to 'U+0-10FFFF'.
         * }
         * @return string Font face slug.
         * @phpstan-param array{
         *   fontFamily?: string,
         *   fontStyle?: string,
         *   fontWeight?: string,
         *   fontStretch?: string,
         *   unicodeRange?: string,
         * } $settings
         */
        public static function get_font_face_slug($settings)
        {
        }
        /**
         * Sanitizes a tree of data using a schema.
         *
         * The schema structure should mirror the data tree. Each value provided in the
         * schema should be a callable that will be applied to sanitize the corresponding
         * value in the data tree. Keys that are in the data tree, but not present in the
         * schema, will be removed in the sanitized data. Nested arrays are traversed recursively.
         *
         * @since 6.5.0
         *
         * @access private
         *
         * @param array $tree   The data to sanitize.
         * @param array $schema The schema used for sanitization.
         * @return array The sanitized data.
         */
        public static function sanitize_from_schema($tree, $schema)
        {
        }
        /**
         * Returns the expected mime-type values for font files, depending on PHP version.
         *
         * This is needed because font mime types vary by PHP version, so checking the PHP version
         * is necessary until a list of valid mime-types for each file extension can be provided to
         * the 'upload_mimes' filter.
         *
         * @since 6.5.0
         *
         * @access private
         *
         * @return string[] A collection of mime types keyed by file extension.
         */
        public static function get_allowed_font_mime_types()
        {
        }
    }
    /**
     * Core class used by the HTML processor during HTML parsing
     * for managing the stack of active formatting elements.
     *
     * This class is designed for internal use by the HTML processor.
     *
     * > Initially, the list of active formatting elements is empty.
     * > It is used to handle mis-nested formatting element tags.
     * >
     * > The list contains elements in the formatting category, and markers.
     * > The markers are inserted when entering applet, object, marquee,
     * > template, td, th, and caption elements, and are used to prevent
     * > formatting from "leaking" into applet, object, marquee, template,
     * > td, th, and caption elements.
     * >
     * > In addition, each element in the list of active formatting elements
     * > is associated with the token for which it was created, so that
     * > further elements can be created for that token if necessary.
     *
     * @since 6.4.0
     *
     * @access private
     *
     * @see https://html.spec.whatwg.org/#list-of-active-formatting-elements
     * @see WP_HTML_Processor
     */
    class WP_HTML_Active_Formatting_Elements
    {
        /**
         * Reports if a specific node is in the stack of active formatting elements.
         *
         * @since 6.4.0
         *
         * @param WP_HTML_Token $token Look for this node in the stack.
         * @return bool Whether the referenced node is in the stack of active formatting elements.
         */
        public function contains_node(\WP_HTML_Token $token)
        {
        }
        /**
         * Returns how many nodes are currently in the stack of active formatting elements.
         *
         * @since 6.4.0
         *
         * @return int How many node are in the stack of active formatting elements.
         */
        public function count()
        {
        }
        /**
         * Returns the node at the end of the stack of active formatting elements,
         * if one exists. If the stack is empty, returns null.
         *
         * @since 6.4.0
         *
         * @return WP_HTML_Token|null Last node in the stack of active formatting elements, if one exists, otherwise null.
         */
        public function current_node()
        {
        }
        /**
         * Inserts a "marker" at the end of the list of active formatting elements.
         *
         * > The markers are inserted when entering applet, object, marquee,
         * > template, td, th, and caption elements, and are used to prevent
         * > formatting from "leaking" into applet, object, marquee, template,
         * > td, th, and caption elements.
         *
         * @see https://html.spec.whatwg.org/#concept-parser-marker
         *
         * @since 6.7.0
         */
        public function insert_marker() : void
        {
        }
        /**
         * Pushes a node onto the stack of active formatting elements.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#push-onto-the-list-of-active-formatting-elements
         *
         * @param WP_HTML_Token $token Push this node onto the stack.
         */
        public function push(\WP_HTML_Token $token)
        {
        }
        /**
         * Removes a node from the stack of active formatting elements.
         *
         * @since 6.4.0
         *
         * @param WP_HTML_Token $token Remove this node from the stack, if it's there already.
         * @return bool Whether the node was found and removed from the stack of active formatting elements.
         */
        public function remove_node(\WP_HTML_Token $token)
        {
        }
        /**
         * Steps through the stack of active formatting elements, starting with the
         * top element (added first) and walking downwards to the one added last.
         *
         * This generator function is designed to be used inside a "foreach" loop.
         *
         * Example:
         *
         *     $html = '<em><strong><a>We are here';
         *     foreach ( $stack->walk_down() as $node ) {
         *         echo "{$node->node_name} -> ";
         *     }
         *     > EM -> STRONG -> A ->
         *
         * To start with the most-recently added element and walk towards the top,
         * see WP_HTML_Active_Formatting_Elements::walk_up().
         *
         * @since 6.4.0
         */
        public function walk_down()
        {
        }
        /**
         * Steps through the stack of active formatting elements, starting with the
         * bottom element (added last) and walking upwards to the one added first.
         *
         * This generator function is designed to be used inside a "foreach" loop.
         *
         * Example:
         *
         *     $html = '<em><strong><a>We are here';
         *     foreach ( $stack->walk_up() as $node ) {
         *         echo "{$node->node_name} -> ";
         *     }
         *     > A -> STRONG -> EM ->
         *
         * To start with the first added element and walk towards the bottom,
         * see WP_HTML_Active_Formatting_Elements::walk_down().
         *
         * @since 6.4.0
         */
        public function walk_up()
        {
        }
        /**
         * Clears the list of active formatting elements up to the last marker.
         *
         * > When the steps below require the UA to clear the list of active formatting elements up to
         * > the last marker, the UA must perform the following steps:
         * >
         * > 1. Let entry be the last (most recently added) entry in the list of active
         * >    formatting elements.
         * > 2. Remove entry from the list of active formatting elements.
         * > 3. If entry was a marker, then stop the algorithm at this point.
         * >    The list has been cleared up to the last marker.
         * > 4. Go to step 1.
         *
         * @see https://html.spec.whatwg.org/multipage/parsing.html#clear-the-list-of-active-formatting-elements-up-to-the-last-marker
         *
         * @since 6.7.0
         */
        public function clear_up_to_last_marker() : void
        {
        }
    }
    /**
     * Core class used by the HTML tag processor as a data structure for the attribute token,
     * allowing to drastically improve performance.
     *
     * This class is for internal usage of the WP_HTML_Tag_Processor class.
     *
     * @access private
     * @since 6.2.0
     * @since 6.5.0 Replaced `end` with `length` to more closely match `substr()`.
     *
     * @see WP_HTML_Tag_Processor
     */
    class WP_HTML_Attribute_Token
    {
        /**
         * Attribute name.
         *
         * @since 6.2.0
         *
         * @var string
         */
        public $name;
        /**
         * Attribute value.
         *
         * @since 6.2.0
         *
         * @var int
         */
        public $value_starts_at;
        /**
         * How many bytes the value occupies in the input HTML.
         *
         * @since 6.2.0
         *
         * @var int
         */
        public $value_length;
        /**
         * The string offset where the attribute name starts.
         *
         * @since 6.2.0
         *
         * @var int
         */
        public $start;
        /**
         * Byte length of text spanning the attribute inside a tag.
         *
         * This span starts at the first character of the attribute name
         * and it ends after one of three cases:
         *
         *  - at the end of the attribute name for boolean attributes.
         *  - at the end of the value for unquoted attributes.
         *  - at the final single or double quote for quoted attributes.
         *
         * Example:
         *
         *     <div class="post">
         *          ------------ length is 12, including quotes
         *
         *     <input type="checked" checked id="selector">
         *                           ------- length is 6
         *
         *     <a rel=noopener>
         *        ------------ length is 11
         *
         * @since 6.5.0 Replaced `end` with `length` to more closely match `substr()`.
         *
         * @var int
         */
        public $length;
        /**
         * Whether the attribute is a boolean attribute with value `true`.
         *
         * @since 6.2.0
         *
         * @var bool
         */
        public $is_true;
        /**
         * Constructor.
         *
         * @since 6.2.0
         * @since 6.5.0 Replaced `end` with `length` to more closely match `substr()`.
         *
         * @param string $name         Attribute name.
         * @param int    $value_start  Attribute value.
         * @param int    $value_length Number of bytes attribute value spans.
         * @param int    $start        The string offset where the attribute name starts.
         * @param int    $length       Byte length of the entire attribute name or name and value pair expression.
         * @param bool   $is_true      Whether the attribute is a boolean attribute with true value.
         */
        public function __construct($name, $value_start, $value_length, $start, $length, $is_true)
        {
        }
    }
    /**
     * HTML API: WP_HTML_Decoder class
     *
     * Decodes spans of raw text found inside HTML content.
     *
     * @package WordPress
     * @subpackage HTML-API
     * @since 6.6.0
     */
    class WP_HTML_Decoder
    {
        /**
         * Indicates if an attribute value starts with a given raw string value.
         *
         * Use this method to determine if an attribute value starts with a given string, regardless
         * of how it might be encoded in HTML. For instance, `http:` could be represented as `http:`
         * or as `http&colon;` or as `&#x68;ttp:` or as `h&#116;tp&colon;`, or in many other ways.
         *
         * Example:
         *
         *     $value = 'http&colon;//wordpress.org/';
         *     true   === WP_HTML_Decoder::attribute_starts_with( $value, 'http:', 'ascii-case-insensitive' );
         *     false  === WP_HTML_Decoder::attribute_starts_with( $value, 'https:', 'ascii-case-insensitive' );
         *
         * @since 6.6.0
         *
         * @param string $haystack         String containing the raw non-decoded attribute value.
         * @param string $search_text      Does the attribute value start with this plain string.
         * @param string $case_sensitivity Optional. Pass 'ascii-case-insensitive' to ignore ASCII case when matching.
         *                                 Default 'case-sensitive'.
         * @return bool Whether the attribute value starts with the given string.
         */
        public static function attribute_starts_with($haystack, $search_text, $case_sensitivity = 'case-sensitive') : bool
        {
        }
        /**
         * Returns a string containing the decoded value of a given HTML text node.
         *
         * Text nodes appear in HTML DATA sections, which are the text segments inside
         * and around tags, excepting SCRIPT and STYLE elements (and some others),
         * whose inner text is not decoded. Use this function to read the decoded
         * value of such a text span in an HTML document.
         *
         * Example:
         *
         *     '“😄”' === WP_HTML_Decode::decode_text_node( '&#x93;&#x1f604;&#x94' );
         *
         * @since 6.6.0
         *
         * @param string $text Text containing raw and non-decoded text node to decode.
         * @return string Decoded UTF-8 value of given text node.
         */
        public static function decode_text_node($text) : string
        {
        }
        /**
         * Returns a string containing the decoded value of a given HTML attribute.
         *
         * Text found inside an HTML attribute has different parsing rules than for
         * text found inside other markup, or DATA segments. Use this function to
         * read the decoded value of an HTML string inside a quoted attribute.
         *
         * Example:
         *
         *     '“😄”' === WP_HTML_Decode::decode_attribute( '&#x93;&#x1f604;&#x94' );
         *
         * @since 6.6.0
         *
         * @param string $text Text containing raw and non-decoded attribute value to decode.
         * @return string Decoded UTF-8 value of given attribute value.
         */
        public static function decode_attribute($text) : string
        {
        }
        /**
         * Decodes a span of HTML text, depending on the context in which it's found.
         *
         * This is a low-level method; prefer calling WP_HTML_Decoder::decode_attribute() or
         * WP_HTML_Decoder::decode_text_node() instead. It's provided for cases where this
         * may be difficult to do from calling code.
         *
         * Example:
         *
         *     '©' = WP_HTML_Decoder::decode( 'data', '&copy;' );
         *
         * @since 6.6.0
         *
         * @access private
         *
         * @param string $context `attribute` for decoding attribute values, `data` otherwise.
         * @param string $text    Text document containing span of text to decode.
         * @return string Decoded UTF-8 string.
         */
        public static function decode($context, $text) : string
        {
        }
        /**
         * Attempt to read a character reference at the given location in a given string,
         * depending on the context in which it's found.
         *
         * If a character reference is found, this function will return the translated value
         * that the reference maps to. It will then set `$match_byte_length` the
         * number of bytes of input it read while consuming the character reference. This
         * gives calling code the opportunity to advance its cursor when traversing a string
         * and decoding.
         *
         * Example:
         *
         *     null === WP_HTML_Decoder::read_character_reference( 'attribute', 'Ships&hellip;', 0 );
         *     '…'  === WP_HTML_Decoder::read_character_reference( 'attribute', 'Ships&hellip;', 5, $token_length );
         *     8    === $token_length; // `&hellip;`
         *
         *     null === WP_HTML_Decoder::read_character_reference( 'attribute', '&notin', 0 );
         *     '∉'  === WP_HTML_Decoder::read_character_reference( 'attribute', '&notin;', 0, $token_length );
         *     7    === $token_length; // `&notin;`
         *
         *     '¬'  === WP_HTML_Decoder::read_character_reference( 'data', '&notin', 0, $token_length );
         *     4    === $token_length; // `&not`
         *     '∉'  === WP_HTML_Decoder::read_character_reference( 'data', '&notin;', 0, $token_length );
         *     7    === $token_length; // `&notin;`
         *
         * @since 6.6.0
         *
         * @global WP_Token_Map $html5_named_character_references Mappings for HTML5 named character references.
         *
         * @param string $context            `attribute` for decoding attribute values, `data` otherwise.
         * @param string $text               Text document containing span of text to decode.
         * @param int    $at                 Optional. Byte offset into text where span begins, defaults to the beginning (0).
         * @param int    &$match_byte_length Optional. Set to byte-length of character reference if provided and if a match
         *                                   is found, otherwise not set. Default null.
         * @return string|false Decoded character reference in UTF-8 if found, otherwise `false`.
         */
        public static function read_character_reference($context, $text, $at = 0, &$match_byte_length = \null)
        {
        }
        /**
         * Encode a code point number into the UTF-8 encoding.
         *
         * This encoder implements the UTF-8 encoding algorithm for converting
         * a code point into a byte sequence. If it receives an invalid code
         * point it will return the Unicode Replacement Character U+FFFD `�`.
         *
         * Example:
         *
         *     '🅰' === WP_HTML_Decoder::code_point_to_utf8_bytes( 0x1f170 );
         *
         *     // Half of a surrogate pair is an invalid code point.
         *     '�' === WP_HTML_Decoder::code_point_to_utf8_bytes( 0xd83c );
         *
         * @since 6.6.0
         *
         * @see https://www.rfc-editor.org/rfc/rfc3629 For the UTF-8 standard.
         *
         * @param int $code_point Which code point to convert.
         * @return string Converted code point, or `�` if invalid.
         */
        public static function code_point_to_utf8_bytes($code_point) : string
        {
        }
    }
    /**
     * Core class used by the HTML API to represent a DOCTYPE declaration.
     *
     * This class parses DOCTYPE tokens for the full parser in the HTML Processor.
     * Most code interacting with HTML won't need to parse DOCTYPE declarations;
     * the HTML Processor is one exception. Consult the HTML Processor for proper
     * parsing of an HTML document.
     *
     * A DOCTYPE declaration may indicate its document compatibility mode, which impacts
     * the structure of the following HTML as well as the behavior of CSS class selectors.
     * There are three possible modes:
     *
     *  - "no-quirks" and "limited-quirks" modes (also called "standards mode").
     *  - "quirks" mode.
     *
     * These modes mostly determine whether CSS class name selectors match values in the
     * HTML `class` attribute in an ASCII-case-insensitive way (quirks mode), or whether
     * they match only when byte-for-byte identical (no-quirks mode).
     *
     * All HTML documents should start with the standard HTML5 DOCTYPE: `<!DOCTYPE html>`.
     *
     * > DOCTYPEs are required for legacy reasons. When omitted, browsers tend to use a different
     * > rendering mode that is incompatible with some specifications. Including the DOCTYPE in a
     * > document ensures that the browser makes a best-effort attempt at following the
     * > relevant specifications.
     *
     * @see https://html.spec.whatwg.org/#the-doctype
     *
     * DOCTYPE declarations comprise four properties: a name, public identifier, system identifier,
     * and an indication of which document compatability mode they would imply if an HTML parser
     * hadn't already determined it from other information.
     *
     * @see https://html.spec.whatwg.org/#the-initial-insertion-mode
     *
     * Historically, the DOCTYPE declaration was used in SGML documents to instruct a parser how
     * to interpret the various tags and entities within a document. Its role in HTML diverged
     * from how it was used in SGML and no meaning should be back-read into HTML based on how it
     * is used in SGML, XML, or XHTML documents.
     *
     * @see https://www.iso.org/standard/16387.html
     *
     * @since 6.7.0
     *
     * @see WP_HTML_Processor
     */
    class WP_HTML_Doctype_Info
    {
        /**
         * Name of the DOCTYPE: should be "html" for HTML documents.
         *
         * This value should be considered "read only" and not modified.
         *
         * Historically the DOCTYPE name indicates name of the document's root element.
         *
         *     <!DOCTYPE html>
         *               ╰──┴── name is "html".
         *
         * @see https://html.spec.whatwg.org/#tokenization
         *
         * @since 6.7.0
         *
         * @var string|null
         */
        public $name = \null;
        /**
         * Public identifier of the DOCTYPE.
         *
         * This value should be considered "read only" and not modified.
         *
         * The public identifier is optional and should not appear in HTML documents.
         * A `null` value indicates that no public identifier was present in the DOCTYPE.
         *
         * Historically the presence of the public identifier indicated that a document
         * was meant to be shared between computer systems and the value indicated to a
         * knowledgeable parser how to find the relevant document type definition (DTD).
         *
         *     <!DOCTYPE html PUBLIC "public id goes here in quotes">
         *               │  │         ╰─── public identifier ─────╯
         *               ╰──┴── name is "html".
         *
         * @see https://html.spec.whatwg.org/#tokenization
         *
         * @since 6.7.0
         *
         * @var string|null
         */
        public $public_identifier = \null;
        /**
         * System identifier of the DOCTYPE.
         *
         * This value should be considered "read only" and not modified.
         *
         * The system identifier is optional and should not appear in HTML documents.
         * A `null` value indicates that no system identifier was present in the DOCTYPE.
         *
         * Historically the system identifier specified where a relevant document type
         * declaration for the given document is stored and may be retrieved.
         *
         *     <!DOCTYPE html SYSTEM "system id goes here in quotes">
         *               │  │         ╰──── system identifier ────╯
         *               ╰──┴── name is "html".
         *
         * If a public identifier were provided it would indicate to a knowledgeable
         * parser how to interpret the system identifier.
         *
         *     <!DOCTYPE html PUBLIC "public id goes here in quotes" "system id goes here in quotes">
         *               │  │         ╰─── public identifier ─────╯   ╰──── system identifier ────╯
         *               ╰──┴── name is "html".
         *
         * @see https://html.spec.whatwg.org/#tokenization
         *
         * @since 6.7.0
         *
         * @var string|null
         */
        public $system_identifier = \null;
        /**
         * Which document compatability mode this DOCTYPE declaration indicates.
         *
         * This value should be considered "read only" and not modified.
         *
         * When an HTML parser has not already set the document compatability mode,
         * (e.g. "quirks" or "no-quirks" mode), it will infer if from the properties
         * of the appropriate DOCTYPE declaration, if one exists. The DOCTYPE can
         * indicate one of three possible document compatability modes:
         *
         *  - "no-quirks" and "limited-quirks" modes (also called "standards" mode).
         *  - "quirks" mode (also called `CSS1Compat` mode).
         *
         * An appropriate DOCTYPE is one encountered in the "initial" insertion mode,
         * before the HTML element has been opened and before finding any other
         * DOCTYPE declaration tokens.
         *
         * @see https://html.spec.whatwg.org/#the-initial-insertion-mode
         *
         * @since 6.7.0
         *
         * @var string One of "no-quirks", "limited-quirks", or "quirks".
         */
        public $indicated_compatability_mode;
        /**
         * Creates a WP_HTML_Doctype_Info instance by parsing a raw DOCTYPE declaration token.
         *
         * Use this method to parse a DOCTYPE declaration token and get access to its properties
         * via the returned WP_HTML_Doctype_Info class instance. The provided input must parse
         * properly as a DOCTYPE declaration, though it must not represent a valid DOCTYPE.
         *
         * Example:
         *
         *     // Normative HTML DOCTYPE declaration.
         *     $doctype = WP_HTML_Doctype_Info::from_doctype_token( '<!DOCTYPE html>' );
         *     'no-quirks' === $doctype->indicated_compatability_mode;
         *
         *     // A nonsensical DOCTYPE is still valid, and will indicate "quirks" mode.
         *     $doctype = WP_HTML_Doctype_Info::from_doctype_token( '<!doctypeJSON SILLY "nonsense\'>' );
         *     'quirks' === $doctype->indicated_compatability_mode;
         *
         *     // Textual quirks present in raw HTML are handled appropriately.
         *     $doctype = WP_HTML_Doctype_Info::from_doctype_token( "<!DOCTYPE\nhtml\n>" );
         *     'no-quirks' === $doctype->indicated_compatability_mode;
         *
         *     // Anything other than a proper DOCTYPE declaration token fails to parse.
         *     null === WP_HTML_Doctype_Info::from_doctype_token( ' <!DOCTYPE>' );
         *     null === WP_HTML_Doctype_Info::from_doctype_token( '<!DOCTYPE ><p>' );
         *     null === WP_HTML_Doctype_Info::from_doctype_token( '<!TYPEDOC>' );
         *     null === WP_HTML_Doctype_Info::from_doctype_token( 'html' );
         *     null === WP_HTML_Doctype_Info::from_doctype_token( '<?xml version="1.0" encoding="UTF-8" ?>' );
         *
         * @since 6.7.0
         *
         * @param string $doctype_html The complete raw DOCTYPE HTML string, e.g. `<!DOCTYPE html>`.
         *
         * @return WP_HTML_Doctype_Info|null A WP_HTML_Doctype_Info instance will be returned if the
         *                                   provided DOCTYPE HTML is a valid DOCTYPE. Otherwise, null.
         */
        public static function from_doctype_token(string $doctype_html) : ?self
        {
        }
    }
    /**
     * Core class used by the HTML processor during HTML parsing
     * for managing the stack of open elements.
     *
     * This class is designed for internal use by the HTML processor.
     *
     * > Initially, the stack of open elements is empty. The stack grows
     * > downwards; the topmost node on the stack is the first one added
     * > to the stack, and the bottommost node of the stack is the most
     * > recently added node in the stack (notwithstanding when the stack
     * > is manipulated in a random access fashion as part of the handling
     * > for misnested tags).
     *
     * @since 6.4.0
     *
     * @access private
     *
     * @see https://html.spec.whatwg.org/#stack-of-open-elements
     * @see WP_HTML_Processor
     */
    class WP_HTML_Open_Elements
    {
        /**
         * Holds the stack of open element references.
         *
         * @since 6.4.0
         *
         * @var WP_HTML_Token[]
         */
        public $stack = array();
        /**
         * Sets a pop handler that will be called when an item is popped off the stack of
         * open elements.
         *
         * The function will be called with the pushed item as its argument.
         *
         * @since 6.6.0
         *
         * @param Closure $handler The handler function.
         */
        public function set_pop_handler(\Closure $handler) : void
        {
        }
        /**
         * Sets a push handler that will be called when an item is pushed onto the stack of
         * open elements.
         *
         * The function will be called with the pushed item as its argument.
         *
         * @since 6.6.0
         *
         * @param Closure $handler The handler function.
         */
        public function set_push_handler(\Closure $handler) : void
        {
        }
        /**
         * Returns the name of the node at the nth position on the stack
         * of open elements, or `null` if no such position exists.
         *
         * Note that this uses a 1-based index, which represents the
         * "nth item" on the stack, counting from the top, where the
         * top-most element is the 1st, the second is the 2nd, etc...
         *
         * @since 6.7.0
         *
         * @param int $nth Retrieve the nth item on the stack, with 1 being
         *                 the top element, 2 being the second, etc...
         * @return WP_HTML_Token|null Name of the node on the stack at the given location,
         *                            or `null` if the location isn't on the stack.
         */
        public function at(int $nth) : ?\WP_HTML_Token
        {
        }
        /**
         * Reports if a node of a given name is in the stack of open elements.
         *
         * @since 6.7.0
         *
         * @param string $node_name Name of node for which to check.
         * @return bool Whether a node of the given name is in the stack of open elements.
         */
        public function contains(string $node_name) : bool
        {
        }
        /**
         * Reports if a specific node is in the stack of open elements.
         *
         * @since 6.4.0
         *
         * @param WP_HTML_Token $token Look for this node in the stack.
         * @return bool Whether the referenced node is in the stack of open elements.
         */
        public function contains_node(\WP_HTML_Token $token) : bool
        {
        }
        /**
         * Returns how many nodes are currently in the stack of open elements.
         *
         * @since 6.4.0
         *
         * @return int How many node are in the stack of open elements.
         */
        public function count() : int
        {
        }
        /**
         * Returns the node at the end of the stack of open elements,
         * if one exists. If the stack is empty, returns null.
         *
         * @since 6.4.0
         *
         * @return WP_HTML_Token|null Last node in the stack of open elements, if one exists, otherwise null.
         */
        public function current_node() : ?\WP_HTML_Token
        {
        }
        /**
         * Indicates if the current node is of a given type or name.
         *
         * It's possible to pass either a node type or a node name to this function.
         * In the case there is no current element it will always return `false`.
         *
         * Example:
         *
         *     // Is the current node a text node?
         *     $stack->current_node_is( '#text' );
         *
         *     // Is the current node a DIV element?
         *     $stack->current_node_is( 'DIV' );
         *
         *     // Is the current node any element/tag?
         *     $stack->current_node_is( '#tag' );
         *
         * @see WP_HTML_Tag_Processor::get_token_type
         * @see WP_HTML_Tag_Processor::get_token_name
         *
         * @since 6.7.0
         *
         * @access private
         *
         * @param string $identity Check if the current node has this name or type (depending on what is provided).
         * @return bool Whether there is a current element that matches the given identity, whether a token name or type.
         */
        public function current_node_is(string $identity) : bool
        {
        }
        /**
         * Returns whether an element is in a specific scope.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#has-an-element-in-the-specific-scope
         *
         * @param string   $tag_name         Name of tag check.
         * @param string[] $termination_list List of elements that terminate the search.
         * @return bool Whether the element was found in a specific scope.
         */
        public function has_element_in_specific_scope(string $tag_name, $termination_list) : bool
        {
        }
        /**
         * Returns whether a particular element is in scope.
         *
         * > The stack of open elements is said to have a particular element in
         * > scope when it has that element in the specific scope consisting of
         * > the following element types:
         * >
         * >   - applet
         * >   - caption
         * >   - html
         * >   - table
         * >   - td
         * >   - th
         * >   - marquee
         * >   - object
         * >   - template
         * >   - MathML mi
         * >   - MathML mo
         * >   - MathML mn
         * >   - MathML ms
         * >   - MathML mtext
         * >   - MathML annotation-xml
         * >   - SVG foreignObject
         * >   - SVG desc
         * >   - SVG title
         *
         * @since 6.4.0
         * @since 6.7.0 Full support.
         *
         * @see https://html.spec.whatwg.org/#has-an-element-in-scope
         *
         * @param string $tag_name Name of tag to check.
         * @return bool Whether given element is in scope.
         */
        public function has_element_in_scope(string $tag_name) : bool
        {
        }
        /**
         * Returns whether a particular element is in list item scope.
         *
         * > The stack of open elements is said to have a particular element
         * > in list item scope when it has that element in the specific scope
         * > consisting of the following element types:
         * >
         * >   - All the element types listed above for the has an element in scope algorithm.
         * >   - ol in the HTML namespace
         * >   - ul in the HTML namespace
         *
         * @since 6.4.0
         * @since 6.5.0 Implemented: no longer throws on every invocation.
         * @since 6.7.0 Supports all required HTML elements.
         *
         * @see https://html.spec.whatwg.org/#has-an-element-in-list-item-scope
         *
         * @param string $tag_name Name of tag to check.
         * @return bool Whether given element is in scope.
         */
        public function has_element_in_list_item_scope(string $tag_name) : bool
        {
        }
        /**
         * Returns whether a particular element is in button scope.
         *
         * > The stack of open elements is said to have a particular element
         * > in button scope when it has that element in the specific scope
         * > consisting of the following element types:
         * >
         * >   - All the element types listed above for the has an element in scope algorithm.
         * >   - button in the HTML namespace
         *
         * @since 6.4.0
         * @since 6.7.0 Supports all required HTML elements.
         *
         * @see https://html.spec.whatwg.org/#has-an-element-in-button-scope
         *
         * @param string $tag_name Name of tag to check.
         * @return bool Whether given element is in scope.
         */
        public function has_element_in_button_scope(string $tag_name) : bool
        {
        }
        /**
         * Returns whether a particular element is in table scope.
         *
         * > The stack of open elements is said to have a particular element
         * > in table scope when it has that element in the specific scope
         * > consisting of the following element types:
         * >
         * >   - html in the HTML namespace
         * >   - table in the HTML namespace
         * >   - template in the HTML namespace
         *
         * @since 6.4.0
         * @since 6.7.0 Full implementation.
         *
         * @see https://html.spec.whatwg.org/#has-an-element-in-table-scope
         *
         * @param string $tag_name Name of tag to check.
         * @return bool Whether given element is in scope.
         */
        public function has_element_in_table_scope(string $tag_name) : bool
        {
        }
        /**
         * Returns whether a particular element is in select scope.
         *
         * This test differs from the others like it, in that its rules are inverted.
         * Instead of arriving at a match when one of any tag in a termination group
         * is reached, this one terminates if any other tag is reached.
         *
         * > The stack of open elements is said to have a particular element in select scope when it has
         * > that element in the specific scope consisting of all element types except the following:
         * >   - optgroup in the HTML namespace
         * >   - option in the HTML namespace
         *
         * @since 6.4.0 Stub implementation (throws).
         * @since 6.7.0 Full implementation.
         *
         * @see https://html.spec.whatwg.org/#has-an-element-in-select-scope
         *
         * @param string $tag_name Name of tag to check.
         * @return bool Whether the given element is in SELECT scope.
         */
        public function has_element_in_select_scope(string $tag_name) : bool
        {
        }
        /**
         * Returns whether a P is in BUTTON scope.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#has-an-element-in-button-scope
         *
         * @return bool Whether a P is in BUTTON scope.
         */
        public function has_p_in_button_scope() : bool
        {
        }
        /**
         * Pops a node off of the stack of open elements.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#stack-of-open-elements
         *
         * @return bool Whether a node was popped off of the stack.
         */
        public function pop() : bool
        {
        }
        /**
         * Pops nodes off of the stack of open elements until an HTML tag with the given name has been popped.
         *
         * @since 6.4.0
         *
         * @see WP_HTML_Open_Elements::pop
         *
         * @param string $html_tag_name Name of tag that needs to be popped off of the stack of open elements.
         * @return bool Whether a tag of the given name was found and popped off of the stack of open elements.
         */
        public function pop_until(string $html_tag_name) : bool
        {
        }
        /**
         * Pushes a node onto the stack of open elements.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#stack-of-open-elements
         *
         * @param WP_HTML_Token $stack_item Item to add onto stack.
         */
        public function push(\WP_HTML_Token $stack_item) : void
        {
        }
        /**
         * Removes a specific node from the stack of open elements.
         *
         * @since 6.4.0
         *
         * @param WP_HTML_Token $token The node to remove from the stack of open elements.
         * @return bool Whether the node was found and removed from the stack of open elements.
         */
        public function remove_node(\WP_HTML_Token $token) : bool
        {
        }
        /**
         * Steps through the stack of open elements, starting with the top element
         * (added first) and walking downwards to the one added last.
         *
         * This generator function is designed to be used inside a "foreach" loop.
         *
         * Example:
         *
         *     $html = '<em><strong><a>We are here';
         *     foreach ( $stack->walk_down() as $node ) {
         *         echo "{$node->node_name} -> ";
         *     }
         *     > EM -> STRONG -> A ->
         *
         * To start with the most-recently added element and walk towards the top,
         * see WP_HTML_Open_Elements::walk_up().
         *
         * @since 6.4.0
         */
        public function walk_down()
        {
        }
        /**
         * Steps through the stack of open elements, starting with the bottom element
         * (added last) and walking upwards to the one added first.
         *
         * This generator function is designed to be used inside a "foreach" loop.
         *
         * Example:
         *
         *     $html = '<em><strong><a>We are here';
         *     foreach ( $stack->walk_up() as $node ) {
         *         echo "{$node->node_name} -> ";
         *     }
         *     > A -> STRONG -> EM ->
         *
         * To start with the first added element and walk towards the bottom,
         * see WP_HTML_Open_Elements::walk_down().
         *
         * @since 6.4.0
         * @since 6.5.0 Accepts $above_this_node to start traversal above a given node, if it exists.
         *
         * @param WP_HTML_Token|null $above_this_node Optional. Start traversing above this node,
         *                                            if provided and if the node exists.
         */
        public function walk_up(?\WP_HTML_Token $above_this_node = \null)
        {
        }
        /**
         * Updates internal flags after adding an element.
         *
         * Certain conditions (such as "has_p_in_button_scope") are maintained here as
         * flags that are only modified when adding and removing elements. This allows
         * the HTML Processor to quickly check for these conditions instead of iterating
         * over the open stack elements upon each new tag it encounters. These flags,
         * however, need to be maintained as items are added and removed from the stack.
         *
         * @since 6.4.0
         *
         * @param WP_HTML_Token $item Element that was added to the stack of open elements.
         */
        public function after_element_push(\WP_HTML_Token $item) : void
        {
        }
        /**
         * Updates internal flags after removing an element.
         *
         * Certain conditions (such as "has_p_in_button_scope") are maintained here as
         * flags that are only modified when adding and removing elements. This allows
         * the HTML Processor to quickly check for these conditions instead of iterating
         * over the open stack elements upon each new tag it encounters. These flags,
         * however, need to be maintained as items are added and removed from the stack.
         *
         * @since 6.4.0
         *
         * @param WP_HTML_Token $item Element that was removed from the stack of open elements.
         */
        public function after_element_pop(\WP_HTML_Token $item) : void
        {
        }
        /**
         * Clear the stack back to a table context.
         *
         * > When the steps above require the UA to clear the stack back to a table context, it means
         * > that the UA must, while the current node is not a table, template, or html element, pop
         * > elements from the stack of open elements.
         *
         * @see https://html.spec.whatwg.org/multipage/parsing.html#clear-the-stack-back-to-a-table-context
         *
         * @since 6.7.0
         */
        public function clear_to_table_context() : void
        {
        }
        /**
         * Clear the stack back to a table body context.
         *
         * > When the steps above require the UA to clear the stack back to a table body context, it
         * > means that the UA must, while the current node is not a tbody, tfoot, thead, template, or
         * > html element, pop elements from the stack of open elements.
         *
         * @see https://html.spec.whatwg.org/multipage/parsing.html#clear-the-stack-back-to-a-table-body-context
         *
         * @since 6.7.0
         */
        public function clear_to_table_body_context() : void
        {
        }
        /**
         * Clear the stack back to a table row context.
         *
         * > When the steps above require the UA to clear the stack back to a table row context, it
         * > means that the UA must, while the current node is not a tr, template, or html element, pop
         * > elements from the stack of open elements.
         *
         * @see https://html.spec.whatwg.org/multipage/parsing.html#clear-the-stack-back-to-a-table-row-context
         *
         * @since 6.7.0
         */
        public function clear_to_table_row_context() : void
        {
        }
        /**
         * Wakeup magic method.
         *
         * @since 6.6.0
         */
        public function __wakeup()
        {
        }
    }
    /**
     * Core class used by the HTML processor during HTML parsing
     * for managing the internal parsing state.
     *
     * This class is designed for internal use by the HTML processor.
     *
     * @since 6.4.0
     *
     * @access private
     *
     * @see WP_HTML_Processor
     */
    class WP_HTML_Processor_State
    {
        /*
         * Insertion mode constants.
         *
         * These constants exist and are named to make it easier to
         * discover and recognize the supported insertion modes in
         * the parser.
         *
         * Out of all the possible insertion modes, only those
         * supported by the parser are listed here. As support
         * is added to the parser for more modes, add them here
         * following the same naming and value pattern.
         *
         * @see https://html.spec.whatwg.org/#the-insertion-mode
         */
        /**
         * Initial insertion mode for full HTML parser.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#the-initial-insertion-mode
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_INITIAL = 'insertion-mode-initial';
        /**
         * Before HTML insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#the-before-html-insertion-mode
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_BEFORE_HTML = 'insertion-mode-before-html';
        /**
         * Before head insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-beforehead
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_BEFORE_HEAD = 'insertion-mode-before-head';
        /**
         * In head insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-inhead
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_HEAD = 'insertion-mode-in-head';
        /**
         * In head noscript insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-inheadnoscript
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_HEAD_NOSCRIPT = 'insertion-mode-in-head-noscript';
        /**
         * After head insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-afterhead
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_AFTER_HEAD = 'insertion-mode-after-head';
        /**
         * In body insertion mode for full HTML parser.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-inbody
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_BODY = 'insertion-mode-in-body';
        /**
         * In table insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-intable
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_TABLE = 'insertion-mode-in-table';
        /**
         * In table text insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-intabletext
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_TABLE_TEXT = 'insertion-mode-in-table-text';
        /**
         * In caption insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-incaption
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_CAPTION = 'insertion-mode-in-caption';
        /**
         * In column group insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-incolumngroup
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_COLUMN_GROUP = 'insertion-mode-in-column-group';
        /**
         * In table body insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-intablebody
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_TABLE_BODY = 'insertion-mode-in-table-body';
        /**
         * In row insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-inrow
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_ROW = 'insertion-mode-in-row';
        /**
         * In cell insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-incell
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_CELL = 'insertion-mode-in-cell';
        /**
         * In select insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-inselect
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_SELECT = 'insertion-mode-in-select';
        /**
         * In select in table insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-inselectintable
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_SELECT_IN_TABLE = 'insertion-mode-in-select-in-table';
        /**
         * In template insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-intemplate
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_TEMPLATE = 'insertion-mode-in-template';
        /**
         * After body insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-afterbody
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_AFTER_BODY = 'insertion-mode-after-body';
        /**
         * In frameset insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-inframeset
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_IN_FRAMESET = 'insertion-mode-in-frameset';
        /**
         * After frameset insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#parsing-main-afterframeset
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_AFTER_FRAMESET = 'insertion-mode-after-frameset';
        /**
         * After after body insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#the-after-after-body-insertion-mode
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_AFTER_AFTER_BODY = 'insertion-mode-after-after-body';
        /**
         * After after frameset insertion mode for full HTML parser.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#the-after-after-frameset-insertion-mode
         * @see WP_HTML_Processor_State::$insertion_mode
         *
         * @var string
         */
        const INSERTION_MODE_AFTER_AFTER_FRAMESET = 'insertion-mode-after-after-frameset';
        /**
         * The stack of template insertion modes.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/#the-insertion-mode:stack-of-template-insertion-modes
         *
         * @var array<string>
         */
        public $stack_of_template_insertion_modes = array();
        /**
         * Tracks open elements while scanning HTML.
         *
         * This property is initialized in the constructor and never null.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#stack-of-open-elements
         *
         * @var WP_HTML_Open_Elements
         */
        public $stack_of_open_elements;
        /**
         * Tracks open formatting elements, used to handle mis-nested formatting element tags.
         *
         * This property is initialized in the constructor and never null.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#list-of-active-formatting-elements
         *
         * @var WP_HTML_Active_Formatting_Elements
         */
        public $active_formatting_elements;
        /**
         * Refers to the currently-matched tag, if any.
         *
         * @since 6.4.0
         *
         * @var WP_HTML_Token|null
         */
        public $current_token = \null;
        /**
         * Tree construction insertion mode.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#insertion-mode
         *
         * @var string
         */
        public $insertion_mode = self::INSERTION_MODE_INITIAL;
        /**
         * Context node initializing fragment parser, if created as a fragment parser.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#concept-frag-parse-context
         *
         * @var [string, array]|null
         */
        public $context_node = \null;
        /**
         * The recognized encoding of the input byte stream.
         *
         * > The stream of code points that comprises the input to the tokenization
         * > stage will be initially seen by the user agent as a stream of bytes
         * > (typically coming over the network or from the local file system).
         * > The bytes encode the actual characters according to a particular character
         * > encoding, which the user agent uses to decode the bytes into characters.
         *
         * @since 6.7.0
         *
         * @var string|null
         */
        public $encoding = \null;
        /**
         * The parser's confidence in the input encoding.
         *
         * > When the HTML parser is decoding an input byte stream, it uses a character
         * > encoding and a confidence. The confidence is either tentative, certain, or
         * > irrelevant. The encoding used, and whether the confidence in that encoding
         * > is tentative or certain, is used during the parsing to determine whether to
         * > change the encoding. If no encoding is necessary, e.g. because the parser is
         * > operating on a Unicode stream and doesn't have to use a character encoding
         * > at all, then the confidence is irrelevant.
         *
         * @since 6.7.0
         *
         * @var string
         */
        public $encoding_confidence = 'tentative';
        /**
         * HEAD element pointer.
         *
         * @since 6.7.0
         *
         * @see https://html.spec.whatwg.org/multipage/parsing.html#head-element-pointer
         *
         * @var WP_HTML_Token|null
         */
        public $head_element = \null;
        /**
         * FORM element pointer.
         *
         * > points to the last form element that was opened and whose end tag has
         * > not yet been seen. It is used to make form controls associate with
         * > forms in the face of dramatically bad markup, for historical reasons.
         * > It is ignored inside template elements.
         *
         * @todo This may be invalidated by a seek operation.
         *
         * @see https://html.spec.whatwg.org/#form-element-pointer
         *
         * @since 6.7.0
         *
         * @var WP_HTML_Token|null
         */
        public $form_element = \null;
        /**
         * The frameset-ok flag indicates if a `FRAMESET` element is allowed in the current state.
         *
         * > The frameset-ok flag is set to "ok" when the parser is created. It is set to "not ok" after certain tokens are seen.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#frameset-ok-flag
         *
         * @var bool
         */
        public $frameset_ok = \true;
        /**
         * Constructor - creates a new and empty state value.
         *
         * @since 6.4.0
         *
         * @see WP_HTML_Processor
         */
        public function __construct()
        {
        }
    }
    /**
     * Core class used to modify attributes in an HTML document for tags matching a query.
     *
     * ## Usage
     *
     * Use of this class requires three steps:
     *
     *  1. Create a new class instance with your input HTML document.
     *  2. Find the tag(s) you are looking for.
     *  3. Request changes to the attributes in those tag(s).
     *
     * Example:
     *
     *     $tags = new WP_HTML_Tag_Processor( $html );
     *     if ( $tags->next_tag( 'option' ) ) {
     *         $tags->set_attribute( 'selected', true );
     *     }
     *
     * ### Finding tags
     *
     * The `next_tag()` function moves the internal cursor through
     * your input HTML document until it finds a tag meeting any of
     * the supplied restrictions in the optional query argument. If
     * no argument is provided then it will find the next HTML tag,
     * regardless of what kind it is.
     *
     * If you want to _find whatever the next tag is_:
     *
     *     $tags->next_tag();
     *
     * | Goal                                                      | Query                                                                           |
     * |-----------------------------------------------------------|---------------------------------------------------------------------------------|
     * | Find any tag.                                             | `$tags->next_tag();`                                                            |
     * | Find next image tag.                                      | `$tags->next_tag( array( 'tag_name' => 'img' ) );`                              |
     * | Find next image tag (without passing the array).          | `$tags->next_tag( 'img' );`                                                     |
     * | Find next tag containing the `fullwidth` CSS class.       | `$tags->next_tag( array( 'class_name' => 'fullwidth' ) );`                      |
     * | Find next image tag containing the `fullwidth` CSS class. | `$tags->next_tag( array( 'tag_name' => 'img', 'class_name' => 'fullwidth' ) );` |
     *
     * If a tag was found meeting your criteria then `next_tag()`
     * will return `true` and you can proceed to modify it. If it
     * returns `false`, however, it failed to find the tag and
     * moved the cursor to the end of the file.
     *
     * Once the cursor reaches the end of the file the processor
     * is done and if you want to reach an earlier tag you will
     * need to recreate the processor and start over, as it's
     * unable to back up or move in reverse.
     *
     * See the section on bookmarks for an exception to this
     * no-backing-up rule.
     *
     * #### Custom queries
     *
     * Sometimes it's necessary to further inspect an HTML tag than
     * the query syntax here permits. In these cases one may further
     * inspect the search results using the read-only functions
     * provided by the processor or external state or variables.
     *
     * Example:
     *
     *     // Paint up to the first five DIV or SPAN tags marked with the "jazzy" style.
     *     $remaining_count = 5;
     *     while ( $remaining_count > 0 && $tags->next_tag() ) {
     *         if (
     *              ( 'DIV' === $tags->get_tag() || 'SPAN' === $tags->get_tag() ) &&
     *              'jazzy' === $tags->get_attribute( 'data-style' )
     *         ) {
     *             $tags->add_class( 'theme-style-everest-jazz' );
     *             $remaining_count--;
     *         }
     *     }
     *
     * `get_attribute()` will return `null` if the attribute wasn't present
     * on the tag when it was called. It may return `""` (the empty string)
     * in cases where the attribute was present but its value was empty.
     * For boolean attributes, those whose name is present but no value is
     * given, it will return `true` (the only way to set `false` for an
     * attribute is to remove it).
     *
     * #### When matching fails
     *
     * When `next_tag()` returns `false` it could mean different things:
     *
     *  - The requested tag wasn't found in the input document.
     *  - The input document ended in the middle of an HTML syntax element.
     *
     * When a document ends in the middle of a syntax element it will pause
     * the processor. This is to make it possible in the future to extend the
     * input document and proceed - an important requirement for chunked
     * streaming parsing of a document.
     *
     * Example:
     *
     *     $processor = new WP_HTML_Tag_Processor( 'This <div is="a" partial="token' );
     *     false === $processor->next_tag();
     *
     * If a special element (see next section) is encountered but no closing tag
     * is found it will count as an incomplete tag. The parser will pause as if
     * the opening tag were incomplete.
     *
     * Example:
     *
     *     $processor = new WP_HTML_Tag_Processor( '<style>// there could be more styling to come' );
     *     false === $processor->next_tag();
     *
     *     $processor = new WP_HTML_Tag_Processor( '<style>// this is everything</style><div>' );
     *     true === $processor->next_tag( 'DIV' );
     *
     * #### Special self-contained elements
     *
     * Some HTML elements are handled in a special way; their start and end tags
     * act like a void tag. These are special because their contents can't contain
     * HTML markup. Everything inside these elements is handled in a special way
     * and content that _appears_ like HTML tags inside of them isn't. There can
     * be no nesting in these elements.
     *
     * In the following list, "raw text" means that all of the content in the HTML
     * until the matching closing tag is treated verbatim without any replacements
     * and without any parsing.
     *
     *  - IFRAME allows no content but requires a closing tag.
     *  - NOEMBED (deprecated) content is raw text.
     *  - NOFRAMES (deprecated) content is raw text.
     *  - SCRIPT content is plaintext apart from legacy rules allowing `</script>` inside an HTML comment.
     *  - STYLE content is raw text.
     *  - TITLE content is plain text but character references are decoded.
     *  - TEXTAREA content is plain text but character references are decoded.
     *  - XMP (deprecated) content is raw text.
     *
     * ### Modifying HTML attributes for a found tag
     *
     * Once you've found the start of an opening tag you can modify
     * any number of the attributes on that tag. You can set a new
     * value for an attribute, remove the entire attribute, or do
     * nothing and move on to the next opening tag.
     *
     * Example:
     *
     *     if ( $tags->next_tag( array( 'class_name' => 'wp-group-block' ) ) ) {
     *         $tags->set_attribute( 'title', 'This groups the contained content.' );
     *         $tags->remove_attribute( 'data-test-id' );
     *     }
     *
     * If `set_attribute()` is called for an existing attribute it will
     * overwrite the existing value. Similarly, calling `remove_attribute()`
     * for a non-existing attribute has no effect on the document. Both
     * of these methods are safe to call without knowing if a given attribute
     * exists beforehand.
     *
     * ### Modifying CSS classes for a found tag
     *
     * The tag processor treats the `class` attribute as a special case.
     * Because it's a common operation to add or remove CSS classes, this
     * interface adds helper methods to make that easier.
     *
     * As with attribute values, adding or removing CSS classes is a safe
     * operation that doesn't require checking if the attribute or class
     * exists before making changes. If removing the only class then the
     * entire `class` attribute will be removed.
     *
     * Example:
     *
     *     // from `<span>Yippee!</span>`
     *     //   to `<span class="is-active">Yippee!</span>`
     *     $tags->add_class( 'is-active' );
     *
     *     // from `<span class="excited">Yippee!</span>`
     *     //   to `<span class="excited is-active">Yippee!</span>`
     *     $tags->add_class( 'is-active' );
     *
     *     // from `<span class="is-active heavy-accent">Yippee!</span>`
     *     //   to `<span class="is-active heavy-accent">Yippee!</span>`
     *     $tags->add_class( 'is-active' );
     *
     *     // from `<input type="text" class="is-active rugby not-disabled" length="24">`
     *     //   to `<input type="text" class="is-active not-disabled" length="24">
     *     $tags->remove_class( 'rugby' );
     *
     *     // from `<input type="text" class="rugby" length="24">`
     *     //   to `<input type="text" length="24">
     *     $tags->remove_class( 'rugby' );
     *
     *     // from `<input type="text" length="24">`
     *     //   to `<input type="text" length="24">
     *     $tags->remove_class( 'rugby' );
     *
     * When class changes are enqueued but a direct change to `class` is made via
     * `set_attribute` then the changes to `set_attribute` (or `remove_attribute`)
     * will take precedence over those made through `add_class` and `remove_class`.
     *
     * ### Bookmarks
     *
     * While scanning through the input HTMl document it's possible to set
     * a named bookmark when a particular tag is found. Later on, after
     * continuing to scan other tags, it's possible to `seek` to one of
     * the set bookmarks and then proceed again from that point forward.
     *
     * Because bookmarks create processing overhead one should avoid
     * creating too many of them. As a rule, create only bookmarks
     * of known string literal names; avoid creating "mark_{$index}"
     * and so on. It's fine from a performance standpoint to create a
     * bookmark and update it frequently, such as within a loop.
     *
     *     $total_todos = 0;
     *     while ( $p->next_tag( array( 'tag_name' => 'UL', 'class_name' => 'todo' ) ) ) {
     *         $p->set_bookmark( 'list-start' );
     *         while ( $p->next_tag( array( 'tag_closers' => 'visit' ) ) ) {
     *             if ( 'UL' === $p->get_tag() && $p->is_tag_closer() ) {
     *                 $p->set_bookmark( 'list-end' );
     *                 $p->seek( 'list-start' );
     *                 $p->set_attribute( 'data-contained-todos', (string) $total_todos );
     *                 $total_todos = 0;
     *                 $p->seek( 'list-end' );
     *                 break;
     *             }
     *
     *             if ( 'LI' === $p->get_tag() && ! $p->is_tag_closer() ) {
     *                 $total_todos++;
     *             }
     *         }
     *     }
     *
     * ## Tokens and finer-grained processing.
     *
     * It's possible to scan through every lexical token in the
     * HTML document using the `next_token()` function. This
     * alternative form takes no argument and provides no built-in
     * query syntax.
     *
     * Example:
     *
     *      $title = '(untitled)';
     *      $text  = '';
     *      while ( $processor->next_token() ) {
     *          switch ( $processor->get_token_name() ) {
     *              case '#text':
     *                  $text .= $processor->get_modifiable_text();
     *                  break;
     *
     *              case 'BR':
     *                  $text .= "\n";
     *                  break;
     *
     *              case 'TITLE':
     *                  $title = $processor->get_modifiable_text();
     *                  break;
     *          }
     *      }
     *      return trim( "# {$title}\n\n{$text}" );
     *
     * ### Tokens and _modifiable text_.
     *
     * #### Special "atomic" HTML elements.
     *
     * Not all HTML elements are able to contain other elements inside of them.
     * For instance, the contents inside a TITLE element are plaintext (except
     * that character references like &amp; will be decoded). This means that
     * if the string `<img>` appears inside a TITLE element, then it's not an
     * image tag, but rather it's text describing an image tag. Likewise, the
     * contents of a SCRIPT or STYLE element are handled entirely separately in
     * a browser than the contents of other elements because they represent a
     * different language than HTML.
     *
     * For these elements the Tag Processor treats the entire sequence as one,
     * from the opening tag, including its contents, through its closing tag.
     * This means that the it's not possible to match the closing tag for a
     * SCRIPT element unless it's unexpected; the Tag Processor already matched
     * it when it found the opening tag.
     *
     * The inner contents of these elements are that element's _modifiable text_.
     *
     * The special elements are:
     *  - `SCRIPT` whose contents are treated as raw plaintext but supports a legacy
     *    style of including JavaScript inside of HTML comments to avoid accidentally
     *    closing the SCRIPT from inside a JavaScript string. E.g. `console.log( '</script>' )`.
     *  - `TITLE` and `TEXTAREA` whose contents are treated as plaintext and then any
     *    character references are decoded. E.g. `1 &lt; 2 < 3` becomes `1 < 2 < 3`.
     *  - `IFRAME`, `NOSCRIPT`, `NOEMBED`, `NOFRAME`, `STYLE` whose contents are treated as
     *    raw plaintext and left as-is. E.g. `1 &lt; 2 < 3` remains `1 &lt; 2 < 3`.
     *
     * #### Other tokens with modifiable text.
     *
     * There are also non-elements which are void/self-closing in nature and contain
     * modifiable text that is part of that individual syntax token itself.
     *
     *  - `#text` nodes, whose entire token _is_ the modifiable text.
     *  - HTML comments and tokens that become comments due to some syntax error. The
     *    text for these tokens is the portion of the comment inside of the syntax.
     *    E.g. for `<!-- comment -->` the text is `" comment "` (note the spaces are included).
     *  - `CDATA` sections, whose text is the content inside of the section itself. E.g. for
     *    `<![CDATA[some content]]>` the text is `"some content"` (with restrictions [1]).
     *  - "Funky comments," which are a special case of invalid closing tags whose name is
     *    invalid. The text for these nodes is the text that a browser would transform into
     *    an HTML comment when parsing. E.g. for `</%post_author>` the text is `%post_author`.
     *  - `DOCTYPE` declarations like `<DOCTYPE html>` which have no closing tag.
     *  - XML Processing instruction nodes like `<?wp __( "Like" ); ?>` (with restrictions [2]).
     *  - The empty end tag `</>` which is ignored in the browser and DOM.
     *
     * [1]: There are no CDATA sections in HTML. When encountering `<![CDATA[`, everything
     *      until the next `>` becomes a bogus HTML comment, meaning there can be no CDATA
     *      section in an HTML document containing `>`. The Tag Processor will first find
     *      all valid and bogus HTML comments, and then if the comment _would_ have been a
     *      CDATA section _were they to exist_, it will indicate this as the type of comment.
     *
     * [2]: XML allows a broader range of characters in a processing instruction's target name
     *      and disallows "xml" as a name, since it's special. The Tag Processor only recognizes
     *      target names with an ASCII-representable subset of characters. It also exhibits the
     *      same constraint as with CDATA sections, in that `>` cannot exist within the token
     *      since Processing Instructions do no exist within HTML and their syntax transforms
     *      into a bogus comment in the DOM.
     *
     * ## Design and limitations
     *
     * The Tag Processor is designed to linearly scan HTML documents and tokenize
     * HTML tags and their attributes. It's designed to do this as efficiently as
     * possible without compromising parsing integrity. Therefore it will be
     * slower than some methods of modifying HTML, such as those incorporating
     * over-simplified PCRE patterns, but will not introduce the defects and
     * failures that those methods bring in, which lead to broken page renders
     * and often to security vulnerabilities. On the other hand, it will be faster
     * than full-blown HTML parsers such as DOMDocument and use considerably
     * less memory. It requires a negligible memory overhead, enough to consider
     * it a zero-overhead system.
     *
     * The performance characteristics are maintained by avoiding tree construction
     * and semantic cleanups which are specified in HTML5. Because of this, for
     * example, it's not possible for the Tag Processor to associate any given
     * opening tag with its corresponding closing tag, or to return the inner markup
     * inside an element. Systems may be built on top of the Tag Processor to do
     * this, but the Tag Processor is and should be constrained so it can remain an
     * efficient, low-level, and reliable HTML scanner.
     *
     * The Tag Processor's design incorporates a "garbage-in-garbage-out" philosophy.
     * HTML5 specifies that certain invalid content be transformed into different forms
     * for display, such as removing null bytes from an input document and replacing
     * invalid characters with the Unicode replacement character `U+FFFD` (visually "�").
     * Where errors or transformations exist within the HTML5 specification, the Tag Processor
     * leaves those invalid inputs untouched, passing them through to the final browser
     * to handle. While this implies that certain operations will be non-spec-compliant,
     * such as reading the value of an attribute with invalid content, it also preserves a
     * simplicity and efficiency for handling those error cases.
     *
     * Most operations within the Tag Processor are designed to minimize the difference
     * between an input and output document for any given change. For example, the
     * `add_class` and `remove_class` methods preserve whitespace and the class ordering
     * within the `class` attribute; and when encountering tags with duplicated attributes,
     * the Tag Processor will leave those invalid duplicate attributes where they are but
     * update the proper attribute which the browser will read for parsing its value. An
     * exception to this rule is that all attribute updates store their values as
     * double-quoted strings, meaning that attributes on input with single-quoted or
     * unquoted values will appear in the output with double-quotes.
     *
     * ### Scripting Flag
     *
     * The Tag Processor parses HTML with the "scripting flag" disabled. This means
     * that it doesn't run any scripts while parsing the page. In a browser with
     * JavaScript enabled, for example, the script can change the parse of the
     * document as it loads. On the server, however, evaluating JavaScript is not
     * only impractical, but also unwanted.
     *
     * Practically this means that the Tag Processor will descend into NOSCRIPT
     * elements and process its child tags. Were the scripting flag enabled, such
     * as in a typical browser, the contents of NOSCRIPT are skipped entirely.
     *
     * This allows the HTML API to process the content that will be presented in
     * a browser when scripting is disabled, but it offers a different view of a
     * page than most browser sessions will experience. E.g. the tags inside the
     * NOSCRIPT disappear.
     *
     * ### Text Encoding
     *
     * The Tag Processor assumes that the input HTML document is encoded with a
     * text encoding compatible with 7-bit ASCII's '<', '>', '&', ';', '/', '=',
     * "'", '"', 'a' - 'z', 'A' - 'Z', and the whitespace characters ' ', tab,
     * carriage-return, newline, and form-feed.
     *
     * In practice, this includes almost every single-byte encoding as well as
     * UTF-8. Notably, however, it does not include UTF-16. If providing input
     * that's incompatible, then convert the encoding beforehand.
     *
     * @since 6.2.0
     * @since 6.2.1 Fix: Support for various invalid comments; attribute updates are case-insensitive.
     * @since 6.3.2 Fix: Skip HTML-like content inside rawtext elements such as STYLE.
     * @since 6.5.0 Pauses processor when input ends in an incomplete syntax token.
     *              Introduces "special" elements which act like void elements, e.g. TITLE, STYLE.
     *              Allows scanning through all tokens and processing modifiable text, where applicable.
     */
    class WP_HTML_Tag_Processor
    {
        /**
         * The maximum number of bookmarks allowed to exist at
         * any given time.
         *
         * @since 6.2.0
         * @var int
         *
         * @see WP_HTML_Tag_Processor::set_bookmark()
         */
        const MAX_BOOKMARKS = 10;
        /**
         * Maximum number of times seek() can be called.
         * Prevents accidental infinite loops.
         *
         * @since 6.2.0
         * @var int
         *
         * @see WP_HTML_Tag_Processor::seek()
         */
        const MAX_SEEK_OPS = 1000;
        /**
         * The HTML document to parse.
         *
         * @since 6.2.0
         * @var string
         */
        protected $html;
        /**
         * Specifies mode of operation of the parser at any given time.
         *
         * | State           | Meaning                                                              |
         * | ----------------|----------------------------------------------------------------------|
         * | *Ready*         | The parser is ready to run.                                          |
         * | *Complete*      | There is nothing left to parse.                                      |
         * | *Incomplete*    | The HTML ended in the middle of a token; nothing more can be parsed. |
         * | *Matched tag*   | Found an HTML tag; it's possible to modify its attributes.           |
         * | *Text node*     | Found a #text node; this is plaintext and modifiable.                |
         * | *CDATA node*    | Found a CDATA section; this is modifiable.                           |
         * | *Comment*       | Found a comment or bogus comment; this is modifiable.                |
         * | *Presumptuous*  | Found an empty tag closer: `</>`.                                    |
         * | *Funky comment* | Found a tag closer with an invalid tag name; this is modifiable.     |
         *
         * @since 6.5.0
         *
         * @see WP_HTML_Tag_Processor::STATE_READY
         * @see WP_HTML_Tag_Processor::STATE_COMPLETE
         * @see WP_HTML_Tag_Processor::STATE_INCOMPLETE_INPUT
         * @see WP_HTML_Tag_Processor::STATE_MATCHED_TAG
         * @see WP_HTML_Tag_Processor::STATE_TEXT_NODE
         * @see WP_HTML_Tag_Processor::STATE_CDATA_NODE
         * @see WP_HTML_Tag_Processor::STATE_COMMENT
         * @see WP_HTML_Tag_Processor::STATE_DOCTYPE
         * @see WP_HTML_Tag_Processor::STATE_PRESUMPTUOUS_TAG
         * @see WP_HTML_Tag_Processor::STATE_FUNKY_COMMENT
         *
         * @var string
         */
        protected $parser_state = self::STATE_READY;
        /**
         * Indicates if the document is in quirks mode or no-quirks mode.
         *
         *  Impact on HTML parsing:
         *
         *   - In `NO_QUIRKS_MODE` (also known as "standard mode"):
         *       - CSS class and ID selectors match byte-for-byte (case-sensitively).
         *       - A TABLE start tag `<table>` implicitly closes any open `P` element.
         *
         *   - In `QUIRKS_MODE`:
         *       - CSS class and ID selectors match match in an ASCII case-insensitive manner.
         *       - A TABLE start tag `<table>` opens a `TABLE` element as a child of a `P`
         *         element if one is open.
         *
         * Quirks and no-quirks mode are thus mostly about styling, but have an impact when
         * tables are found inside paragraph elements.
         *
         * @see self::QUIRKS_MODE
         * @see self::NO_QUIRKS_MODE
         *
         * @since 6.7.0
         *
         * @var string
         */
        protected $compat_mode = self::NO_QUIRKS_MODE;
        /**
         * What kind of syntax token became an HTML comment.
         *
         * Since there are many ways in which HTML syntax can create an HTML comment,
         * this indicates which of those caused it. This allows the Tag Processor to
         * represent more from the original input document than would appear in the DOM.
         *
         * @since 6.5.0
         *
         * @var string|null
         */
        protected $comment_type = \null;
        /**
         * What kind of text the matched text node represents, if it was subdivided.
         *
         * @see self::TEXT_IS_NULL_SEQUENCE
         * @see self::TEXT_IS_WHITESPACE
         * @see self::TEXT_IS_GENERIC
         * @see self::subdivide_text_appropriately
         *
         * @since 6.7.0
         *
         * @var string
         */
        protected $text_node_classification = self::TEXT_IS_GENERIC;
        /**
         * Tracks a semantic location in the original HTML which
         * shifts with updates as they are applied to the document.
         *
         * @since 6.2.0
         * @var WP_HTML_Span[]
         */
        protected $bookmarks = array();
        const ADD_CLASS = \true;
        const REMOVE_CLASS = \false;
        const SKIP_CLASS = \null;
        /**
         * Lexical replacements to apply to input HTML document.
         *
         * "Lexical" in this class refers to the part of this class which
         * operates on pure text _as text_ and not as HTML. There's a line
         * between the public interface, with HTML-semantic methods like
         * `set_attribute` and `add_class`, and an internal state that tracks
         * text offsets in the input document.
         *
         * When higher-level HTML methods are called, those have to transform their
         * operations (such as setting an attribute's value) into text diffing
         * operations (such as replacing the sub-string from indices A to B with
         * some given new string). These text-diffing operations are the lexical
         * updates.
         *
         * As new higher-level methods are added they need to collapse their
         * operations into these lower-level lexical updates since that's the
         * Tag Processor's internal language of change. Any code which creates
         * these lexical updates must ensure that they do not cross HTML syntax
         * boundaries, however, so these should never be exposed outside of this
         * class or any classes which intentionally expand its functionality.
         *
         * These are enqueued while editing the document instead of being immediately
         * applied to avoid processing overhead, string allocations, and string
         * copies when applying many updates to a single document.
         *
         * Example:
         *
         *     // Replace an attribute stored with a new value, indices
         *     // sourced from the lazily-parsed HTML recognizer.
         *     $start  = $attributes['src']->start;
         *     $length = $attributes['src']->length;
         *     $modifications[] = new WP_HTML_Text_Replacement( $start, $length, $new_value );
         *
         *     // Correspondingly, something like this will appear in this array.
         *     $lexical_updates = array(
         *         WP_HTML_Text_Replacement( 14, 28, 'https://my-site.my-domain/wp-content/uploads/2014/08/kittens.jpg' )
         *     );
         *
         * @since 6.2.0
         * @var WP_HTML_Text_Replacement[]
         */
        protected $lexical_updates = array();
        /**
         * Tracks and limits `seek()` calls to prevent accidental infinite loops.
         *
         * @since 6.2.0
         * @var int
         *
         * @see WP_HTML_Tag_Processor::seek()
         */
        protected $seek_count = 0;
        /**
         * Constructor.
         *
         * @since 6.2.0
         *
         * @param string $html HTML to process.
         */
        public function __construct($html)
        {
        }
        /**
         * Switches parsing mode into a new namespace, such as when
         * encountering an SVG tag and entering foreign content.
         *
         * @since 6.7.0
         *
         * @param string $new_namespace One of 'html', 'svg', or 'math' indicating into what
         *                              namespace the next tokens will be processed.
         * @return bool Whether the namespace was valid and changed.
         * @phpstan-param 'html'|'svg'|'math' $new_namespace
         */
        public function change_parsing_namespace(string $new_namespace) : bool
        {
        }
        /**
         * Finds the next tag matching the $query.
         *
         * @since 6.2.0
         * @since 6.5.0 No longer processes incomplete tokens at end of document; pauses the processor at start of token.
         *
         * @param array|string|null $query {
         *     Optional. Which tag name to find, having which class, etc. Default is to find any tag.
         *
         *     @type string|null $tag_name     Which tag to find, or `null` for "any tag."
         *     @type int|null    $match_offset Find the Nth tag matching all search criteria.
         *                                     1 for "first" tag, 3 for "third," etc.
         *                                     Defaults to first tag.
         *     @type string|null $class_name   Tag must contain this whole class name to match.
         *     @type string|null $tag_closers  "visit" or "skip": whether to stop on tag closers, e.g. </div>.
         * }
         * @return bool Whether a tag was matched.
         * @phpstan-param null|array{
         *   tag_name?: string|null,
         *   match_offset?: int|null,
         *   class_name?: string|null,
         *   tag_closers?: string|null,
         * } $query
         */
        public function next_tag($query = \null) : bool
        {
        }
        /**
         * Finds the next token in the HTML document.
         *
         * An HTML document can be viewed as a stream of tokens,
         * where tokens are things like HTML tags, HTML comments,
         * text nodes, etc. This method finds the next token in
         * the HTML document and returns whether it found one.
         *
         * If it starts parsing a token and reaches the end of the
         * document then it will seek to the start of the last
         * token and pause, returning `false` to indicate that it
         * failed to find a complete token.
         *
         * Possible token types, based on the HTML specification:
         *
         *  - an HTML tag, whether opening, closing, or void.
         *  - a text node - the plaintext inside tags.
         *  - an HTML comment.
         *  - a DOCTYPE declaration.
         *  - a processing instruction, e.g. `<?xml version="1.0" ?>`.
         *
         * The Tag Processor currently only supports the tag token.
         *
         * @since 6.5.0
         * @since 6.7.0 Recognizes CDATA sections within foreign content.
         *
         * @return bool Whether a token was parsed.
         */
        public function next_token() : bool
        {
        }
        /**
         * Whether the processor paused because the input HTML document ended
         * in the middle of a syntax element, such as in the middle of a tag.
         *
         * Example:
         *
         *     $processor = new WP_HTML_Tag_Processor( '<input type="text" value="Th' );
         *     false      === $processor->get_next_tag();
         *     true       === $processor->paused_at_incomplete_token();
         *
         * @since 6.5.0
         *
         * @return bool Whether the parse paused at the start of an incomplete token.
         */
        public function paused_at_incomplete_token() : bool
        {
        }
        /**
         * Generator for a foreach loop to step through each class name for the matched tag.
         *
         * This generator function is designed to be used inside a "foreach" loop.
         *
         * Example:
         *
         *     $p = new WP_HTML_Tag_Processor( "<div class='free &lt;egg&lt;\tlang-en'>" );
         *     $p->next_tag();
         *     foreach ( $p->class_list() as $class_name ) {
         *         echo "{$class_name} ";
         *     }
         *     // Outputs: "free <egg> lang-en "
         *
         * @since 6.4.0
         * @phpstan-return void
         */
        public function class_list()
        {
        }
        /**
         * Returns if a matched tag contains the given ASCII case-insensitive class name.
         *
         * @since 6.4.0
         *
         * @param string $wanted_class Look for this CSS class name, ASCII case-insensitive.
         * @return bool|null Whether the matched tag contains the given class name, or null if not matched.
         */
        public function has_class($wanted_class) : ?bool
        {
        }
        /**
         * Sets a bookmark in the HTML document.
         *
         * Bookmarks represent specific places or tokens in the HTML
         * document, such as a tag opener or closer. When applying
         * edits to a document, such as setting an attribute, the
         * text offsets of that token may shift; the bookmark is
         * kept updated with those shifts and remains stable unless
         * the entire span of text in which the token sits is removed.
         *
         * Release bookmarks when they are no longer needed.
         *
         * Example:
         *
         *     <main><h2>Surprising fact you may not know!</h2></main>
         *           ^  ^
         *            \-|-- this `H2` opener bookmark tracks the token
         *
         *     <main class="clickbait"><h2>Surprising fact you may no…
         *                             ^  ^
         *                              \-|-- it shifts with edits
         *
         * Bookmarks provide the ability to seek to a previously-scanned
         * place in the HTML document. This avoids the need to re-scan
         * the entire document.
         *
         * Example:
         *
         *     <ul><li>One</li><li>Two</li><li>Three</li></ul>
         *                                 ^^^^
         *                                 want to note this last item
         *
         *     $p = new WP_HTML_Tag_Processor( $html );
         *     $in_list = false;
         *     while ( $p->next_tag( array( 'tag_closers' => $in_list ? 'visit' : 'skip' ) ) ) {
         *         if ( 'UL' === $p->get_tag() ) {
         *             if ( $p->is_tag_closer() ) {
         *                 $in_list = false;
         *                 $p->set_bookmark( 'resume' );
         *                 if ( $p->seek( 'last-li' ) ) {
         *                     $p->add_class( 'last-li' );
         *                 }
         *                 $p->seek( 'resume' );
         *                 $p->release_bookmark( 'last-li' );
         *                 $p->release_bookmark( 'resume' );
         *             } else {
         *                 $in_list = true;
         *             }
         *         }
         *
         *         if ( 'LI' === $p->get_tag() ) {
         *             $p->set_bookmark( 'last-li' );
         *         }
         *     }
         *
         * Bookmarks intentionally hide the internal string offsets
         * to which they refer. They are maintained internally as
         * updates are applied to the HTML document and therefore
         * retain their "position" - the location to which they
         * originally pointed. The inability to use bookmarks with
         * functions like `substr` is therefore intentional to guard
         * against accidentally breaking the HTML.
         *
         * Because bookmarks allocate memory and require processing
         * for every applied update, they are limited and require
         * a name. They should not be created with programmatically-made
         * names, such as "li_{$index}" with some loop. As a general
         * rule they should only be created with string-literal names
         * like "start-of-section" or "last-paragraph".
         *
         * Bookmarks are a powerful tool to enable complicated behavior.
         * Consider double-checking that you need this tool if you are
         * reaching for it, as inappropriate use could lead to broken
         * HTML structure or unwanted processing overhead.
         *
         * @since 6.2.0
         *
         * @param string $name Identifies this particular bookmark.
         * @return bool Whether the bookmark was successfully created.
         */
        public function set_bookmark($name) : bool
        {
        }
        /**
         * Removes a bookmark that is no longer needed.
         *
         * Releasing a bookmark frees up the small
         * performance overhead it requires.
         *
         * @param string $name Name of the bookmark to remove.
         * @return bool Whether the bookmark already existed before removal.
         */
        public function release_bookmark($name) : bool
        {
        }
        /**
         * Checks whether a bookmark with the given name exists.
         *
         * @since 6.3.0
         *
         * @param string $bookmark_name Name to identify a bookmark that potentially exists.
         * @return bool Whether that bookmark exists.
         */
        public function has_bookmark($bookmark_name) : bool
        {
        }
        /**
         * Move the internal cursor in the Tag Processor to a given bookmark's location.
         *
         * In order to prevent accidental infinite loops, there's a
         * maximum limit on the number of times seek() can be called.
         *
         * @since 6.2.0
         *
         * @param string $bookmark_name Jump to the place in the document identified by this bookmark name.
         * @return bool Whether the internal cursor was successfully moved to the bookmark's location.
         */
        public function seek($bookmark_name) : bool
        {
        }
        /**
         * Returns the value of a requested attribute from a matched tag opener if that attribute exists.
         *
         * Example:
         *
         *     $p = new WP_HTML_Tag_Processor( '<div enabled class="test" data-test-id="14">Test</div>' );
         *     $p->next_tag( array( 'class_name' => 'test' ) ) === true;
         *     $p->get_attribute( 'data-test-id' ) === '14';
         *     $p->get_attribute( 'enabled' ) === true;
         *     $p->get_attribute( 'aria-label' ) === null;
         *
         *     $p->next_tag() === false;
         *     $p->get_attribute( 'class' ) === null;
         *
         * @since 6.2.0
         *
         * @param string $name Name of attribute whose value is requested.
         * @return string|true|null Value of attribute or `null` if not available. Boolean attributes return `true`.
         */
        public function get_attribute($name)
        {
        }
        /**
         * Gets lowercase names of all attributes matching a given prefix in the current tag.
         *
         * Note that matching is case-insensitive. This is in accordance with the spec:
         *
         * > There must never be two or more attributes on
         * > the same start tag whose names are an ASCII
         * > case-insensitive match for each other.
         *     - HTML 5 spec
         *
         * Example:
         *
         *     $p = new WP_HTML_Tag_Processor( '<div data-ENABLED class="test" DATA-test-id="14">Test</div>' );
         *     $p->next_tag( array( 'class_name' => 'test' ) ) === true;
         *     $p->get_attribute_names_with_prefix( 'data-' ) === array( 'data-enabled', 'data-test-id' );
         *
         *     $p->next_tag() === false;
         *     $p->get_attribute_names_with_prefix( 'data-' ) === null;
         *
         * @since 6.2.0
         *
         * @see https://html.spec.whatwg.org/multipage/syntax.html#attributes-2:ascii-case-insensitive
         *
         * @param string $prefix Prefix of requested attribute names.
         * @return array|null List of attribute names, or `null` when no tag opener is matched.
         */
        public function get_attribute_names_with_prefix($prefix) : ?array
        {
        }
        /**
         * Returns the namespace of the matched token.
         *
         * @since 6.7.0
         *
         * @return string One of 'html', 'math', or 'svg'.
         * @phpstan-return 'html'|'math'|'svg'
         */
        public function get_namespace() : string
        {
        }
        /**
         * Returns the uppercase name of the matched tag.
         *
         * Example:
         *
         *     $p = new WP_HTML_Tag_Processor( '<div class="test">Test</div>' );
         *     $p->next_tag() === true;
         *     $p->get_tag() === 'DIV';
         *
         *     $p->next_tag() === false;
         *     $p->get_tag() === null;
         *
         * @since 6.2.0
         *
         * @return string|null Name of currently matched tag in input HTML, or `null` if none found.
         */
        public function get_tag() : ?string
        {
        }
        /**
         * Returns the adjusted tag name for a given token, taking into
         * account the current parsing context, whether HTML, SVG, or MathML.
         *
         * @since 6.7.0
         *
         * @return string|null Name of current tag name.
         */
        public function get_qualified_tag_name() : ?string
        {
        }
        /**
         * Returns the adjusted attribute name for a given attribute, taking into
         * account the current parsing context, whether HTML, SVG, or MathML.
         *
         * @since 6.7.0
         *
         * @param string $attribute_name Which attribute to adjust.
         *
         * @return string|null
         */
        public function get_qualified_attribute_name($attribute_name) : ?string
        {
        }
        /**
         * Indicates if the currently matched tag contains the self-closing flag.
         *
         * No HTML elements ought to have the self-closing flag and for those, the self-closing
         * flag will be ignored. For void elements this is benign because they "self close"
         * automatically. For non-void HTML elements though problems will appear if someone
         * intends to use a self-closing element in place of that element with an empty body.
         * For HTML foreign elements and custom elements the self-closing flag determines if
         * they self-close or not.
         *
         * This function does not determine if a tag is self-closing,
         * but only if the self-closing flag is present in the syntax.
         *
         * @since 6.3.0
         *
         * @return bool Whether the currently matched tag contains the self-closing flag.
         */
        public function has_self_closing_flag() : bool
        {
        }
        /**
         * Indicates if the current tag token is a tag closer.
         *
         * Example:
         *
         *     $p = new WP_HTML_Tag_Processor( '<div></div>' );
         *     $p->next_tag( array( 'tag_name' => 'div', 'tag_closers' => 'visit' ) );
         *     $p->is_tag_closer() === false;
         *
         *     $p->next_tag( array( 'tag_name' => 'div', 'tag_closers' => 'visit' ) );
         *     $p->is_tag_closer() === true;
         *
         * @since 6.2.0
         * @since 6.7.0 Reports all BR tags as opening tags.
         *
         * @return bool Whether the current tag is a tag closer.
         */
        public function is_tag_closer() : bool
        {
        }
        /**
         * Indicates the kind of matched token, if any.
         *
         * This differs from `get_token_name()` in that it always
         * returns a static string indicating the type, whereas
         * `get_token_name()` may return values derived from the
         * token itself, such as a tag name or processing
         * instruction tag.
         *
         * Possible values:
         *  - `#tag` when matched on a tag.
         *  - `#text` when matched on a text node.
         *  - `#cdata-section` when matched on a CDATA node.
         *  - `#comment` when matched on a comment.
         *  - `#doctype` when matched on a DOCTYPE declaration.
         *  - `#presumptuous-tag` when matched on an empty tag closer.
         *  - `#funky-comment` when matched on a funky comment.
         *
         * @since 6.5.0
         *
         * @return string|null What kind of token is matched, or null.
         */
        public function get_token_type() : ?string
        {
        }
        /**
         * Returns the node name represented by the token.
         *
         * This matches the DOM API value `nodeName`. Some values
         * are static, such as `#text` for a text node, while others
         * are dynamically generated from the token itself.
         *
         * Dynamic names:
         *  - Uppercase tag name for tag matches.
         *  - `html` for DOCTYPE declarations.
         *
         * Note that if the Tag Processor is not matched on a token
         * then this function will return `null`, either because it
         * hasn't yet found a token or because it reached the end
         * of the document without matching a token.
         *
         * @since 6.5.0
         *
         * @return string|null Name of the matched token.
         */
        public function get_token_name() : ?string
        {
        }
        /**
         * Indicates what kind of comment produced the comment node.
         *
         * Because there are different kinds of HTML syntax which produce
         * comments, the Tag Processor tracks and exposes this as a type
         * for the comment. Nominally only regular HTML comments exist as
         * they are commonly known, but a number of unrelated syntax errors
         * also produce comments.
         *
         * @see self::COMMENT_AS_ABRUPTLY_CLOSED_COMMENT
         * @see self::COMMENT_AS_CDATA_LOOKALIKE
         * @see self::COMMENT_AS_INVALID_HTML
         * @see self::COMMENT_AS_HTML_COMMENT
         * @see self::COMMENT_AS_PI_NODE_LOOKALIKE
         *
         * @since 6.5.0
         *
         * @return string|null
         */
        public function get_comment_type() : ?string
        {
        }
        /**
         * Returns the text of a matched comment or null if not on a comment type node.
         *
         * This method returns the entire text content of a comment node as it
         * would appear in the browser.
         *
         * This differs from {@see ::get_modifiable_text()} in that certain comment
         * types in the HTML API cannot allow their entire comment text content to
         * be modified. Namely, "bogus comments" of the form `<?not allowed in html>`
         * will create a comment whose text content starts with `?`. Note that if
         * that character were modified, it would be possible to change the node
         * type.
         *
         * @since 6.7.0
         *
         * @return string|null The comment text as it would appear in the browser or null
         *                     if not on a comment type node.
         */
        public function get_full_comment_text() : ?string
        {
        }
        /**
         * Subdivides a matched text node, splitting NULL byte sequences and decoded whitespace as
         * distinct nodes prefixes.
         *
         * Note that once anything that's neither a NULL byte nor decoded whitespace is
         * encountered, then the remainder of the text node is left intact as generic text.
         *
         *  - The HTML Processor uses this to apply distinct rules for different kinds of text.
         *  - Inter-element whitespace can be detected and skipped with this method.
         *
         * Text nodes aren't eagerly subdivided because there's no need to split them unless
         * decisions are being made on NULL byte sequences or whitespace-only text.
         *
         * Example:
         *
         *     $processor = new WP_HTML_Tag_Processor( "\x00Apples & Oranges" );
         *     true  === $processor->next_token();                   // Text is "Apples & Oranges".
         *     true  === $processor->subdivide_text_appropriately(); // Text is "".
         *     true  === $processor->next_token();                   // Text is "Apples & Oranges".
         *     false === $processor->subdivide_text_appropriately();
         *
         *     $processor = new WP_HTML_Tag_Processor( "&#x13; \r\n\tMore" );
         *     true  === $processor->next_token();                   // Text is "␤ ␤␉More".
         *     true  === $processor->subdivide_text_appropriately(); // Text is "␤ ␤␉".
         *     true  === $processor->next_token();                   // Text is "More".
         *     false === $processor->subdivide_text_appropriately();
         *
         * @since 6.7.0
         *
         * @return bool Whether the text node was subdivided.
         */
        public function subdivide_text_appropriately() : bool
        {
        }
        /**
         * Returns the modifiable text for a matched token, or an empty string.
         *
         * Modifiable text is text content that may be read and changed without
         * changing the HTML structure of the document around it. This includes
         * the contents of `#text` nodes in the HTML as well as the inner
         * contents of HTML comments, Processing Instructions, and others, even
         * though these nodes aren't part of a parsed DOM tree. They also contain
         * the contents of SCRIPT and STYLE tags, of TEXTAREA tags, and of any
         * other section in an HTML document which cannot contain HTML markup (DATA).
         *
         * If a token has no modifiable text then an empty string is returned to
         * avoid needless crashing or type errors. An empty string does not mean
         * that a token has modifiable text, and a token with modifiable text may
         * have an empty string (e.g. a comment with no contents).
         *
         * Limitations:
         *
         *  - This function will not strip the leading newline appropriately
         *    after seeking into a LISTING or PRE element. To ensure that the
         *    newline is treated properly, seek to the LISTING or PRE opening
         *    tag instead of to the first text node inside the element.
         *
         * @since 6.5.0
         * @since 6.7.0 Replaces NULL bytes (U+0000) and newlines appropriately.
         *
         * @return string
         */
        public function get_modifiable_text() : string
        {
        }
        /**
         * Sets the modifiable text for the matched token, if matched.
         *
         * Modifiable text is text content that may be read and changed without
         * changing the HTML structure of the document around it. This includes
         * the contents of `#text` nodes in the HTML as well as the inner
         * contents of HTML comments, Processing Instructions, and others, even
         * though these nodes aren't part of a parsed DOM tree. They also contain
         * the contents of SCRIPT and STYLE tags, of TEXTAREA tags, and of any
         * other section in an HTML document which cannot contain HTML markup (DATA).
         *
         * Not all modifiable text may be set by this method, and not all content
         * may be set as modifiable text. In the case that this fails it will return
         * `false` indicating as much. For instance, it will not allow inserting the
         * string `</script` into a SCRIPT element, because the rules for escaping
         * that safely are complicated. Similarly, it will not allow setting content
         * into a comment which would prematurely terminate the comment.
         *
         * Example:
         *
         *     // Add a preface to all STYLE contents.
         *     while ( $processor->next_tag( 'STYLE' ) ) {
         *         $style = $processor->get_modifiable_text();
         *         $processor->set_modifiable_text( "// Made with love on the World Wide Web\n{$style}" );
         *     }
         *
         *     // Replace smiley text with Emoji smilies.
         *     while ( $processor->next_token() ) {
         *         if ( '#text' !== $processor->get_token_name() ) {
         *             continue;
         *         }
         *
         *         $chunk = $processor->get_modifiable_text();
         *         if ( ! str_contains( $chunk, ':)' ) ) {
         *             continue;
         *         }
         *
         *         $processor->set_modifiable_text( str_replace( ':)', '🙂', $chunk ) );
         *     }
         *
         * @since 6.7.0
         *
         * @param string $plaintext_content New text content to represent in the matched token.
         *
         * @return bool Whether the text was able to update.
         */
        public function set_modifiable_text(string $plaintext_content) : bool
        {
        }
        /**
         * Updates or creates a new attribute on the currently matched tag with the passed value.
         *
         * For boolean attributes special handling is provided:
         *  - When `true` is passed as the value, then only the attribute name is added to the tag.
         *  - When `false` is passed, the attribute gets removed if it existed before.
         *
         * For string attributes, the value is escaped using the `esc_attr` function.
         *
         * @since 6.2.0
         * @since 6.2.1 Fix: Only create a single update for multiple calls with case-variant attribute names.
         *
         * @param string      $name  The attribute name to target.
         * @param string|bool $value The new attribute value.
         * @return bool Whether an attribute value was set.
         */
        public function set_attribute($name, $value) : bool
        {
        }
        /**
         * Remove an attribute from the currently-matched tag.
         *
         * @since 6.2.0
         *
         * @param string $name The attribute name to remove.
         * @return bool Whether an attribute was removed.
         */
        public function remove_attribute($name) : bool
        {
        }
        /**
         * Adds a new class name to the currently matched tag.
         *
         * @since 6.2.0
         *
         * @param string $class_name The class name to add.
         * @return bool Whether the class was set to be added.
         */
        public function add_class($class_name) : bool
        {
        }
        /**
         * Removes a class name from the currently matched tag.
         *
         * @since 6.2.0
         *
         * @param string $class_name The class name to remove.
         * @return bool Whether the class was set to be removed.
         */
        public function remove_class($class_name) : bool
        {
        }
        /**
         * Returns the string representation of the HTML Tag Processor.
         *
         * @since 6.2.0
         *
         * @see WP_HTML_Tag_Processor::get_updated_html()
         *
         * @return string The processed HTML.
         */
        public function __toString() : string
        {
        }
        /**
         * Returns the string representation of the HTML Tag Processor.
         *
         * @since 6.2.0
         * @since 6.2.1 Shifts the internal cursor corresponding to the applied updates.
         * @since 6.4.0 No longer calls subclass method `next_tag()` after updating HTML.
         *
         * @return string The processed HTML.
         */
        public function get_updated_html() : string
        {
        }
        /**
         * Gets DOCTYPE declaration info from a DOCTYPE token.
         *
         * DOCTYPE tokens may appear in many places in an HTML document. In most places, they are
         * simply ignored. The main parsing functions find the basic shape of DOCTYPE tokens but
         * do not perform detailed parsing.
         *
         * This method can be called to perform a full parse of the DOCTYPE token and retrieve
         * its information.
         *
         * @return WP_HTML_Doctype_Info|null The DOCTYPE declaration information or `null` if not
         *                                   currently at a DOCTYPE node.
         */
        public function get_doctype_info() : ?\WP_HTML_Doctype_Info
        {
        }
        /**
         * Parser Ready State.
         *
         * Indicates that the parser is ready to run and waiting for a state transition.
         * It may not have started yet, or it may have just finished parsing a token and
         * is ready to find the next one.
         *
         * @since 6.5.0
         *
         * @access private
         */
        const STATE_READY = 'STATE_READY';
        /**
         * Parser Complete State.
         *
         * Indicates that the parser has reached the end of the document and there is
         * nothing left to scan. It finished parsing the last token completely.
         *
         * @since 6.5.0
         *
         * @access private
         */
        const STATE_COMPLETE = 'STATE_COMPLETE';
        /**
         * Parser Incomplete Input State.
         *
         * Indicates that the parser has reached the end of the document before finishing
         * a token. It started parsing a token but there is a possibility that the input
         * HTML document was truncated in the middle of a token.
         *
         * The parser is reset at the start of the incomplete token and has paused. There
         * is nothing more than can be scanned unless provided a more complete document.
         *
         * @since 6.5.0
         *
         * @access private
         */
        const STATE_INCOMPLETE_INPUT = 'STATE_INCOMPLETE_INPUT';
        /**
         * Parser Matched Tag State.
         *
         * Indicates that the parser has found an HTML tag and it's possible to get
         * the tag name and read or modify its attributes (if it's not a closing tag).
         *
         * @since 6.5.0
         *
         * @access private
         */
        const STATE_MATCHED_TAG = 'STATE_MATCHED_TAG';
        /**
         * Parser Text Node State.
         *
         * Indicates that the parser has found a text node and it's possible
         * to read and modify that text.
         *
         * @since 6.5.0
         *
         * @access private
         */
        const STATE_TEXT_NODE = 'STATE_TEXT_NODE';
        /**
         * Parser CDATA Node State.
         *
         * Indicates that the parser has found a CDATA node and it's possible
         * to read and modify its modifiable text. Note that in HTML there are
         * no CDATA nodes outside of foreign content (SVG and MathML). Outside
         * of foreign content, they are treated as HTML comments.
         *
         * @since 6.5.0
         *
         * @access private
         */
        const STATE_CDATA_NODE = 'STATE_CDATA_NODE';
        /**
         * Indicates that the parser has found an HTML comment and it's
         * possible to read and modify its modifiable text.
         *
         * @since 6.5.0
         *
         * @access private
         */
        const STATE_COMMENT = 'STATE_COMMENT';
        /**
         * Indicates that the parser has found a DOCTYPE node and it's
         * possible to read its DOCTYPE information via `get_doctype_info()`.
         *
         * @since 6.5.0
         *
         * @access private
         */
        const STATE_DOCTYPE = 'STATE_DOCTYPE';
        /**
         * Indicates that the parser has found an empty tag closer `</>`.
         *
         * Note that in HTML there are no empty tag closers, and they
         * are ignored. Nonetheless, the Tag Processor still
         * recognizes them as they appear in the HTML stream.
         *
         * These were historically discussed as a "presumptuous tag
         * closer," which would close the nearest open tag, but were
         * dismissed in favor of explicitly-closing tags.
         *
         * @since 6.5.0
         *
         * @access private
         */
        const STATE_PRESUMPTUOUS_TAG = 'STATE_PRESUMPTUOUS_TAG';
        /**
         * Indicates that the parser has found a "funky comment"
         * and it's possible to read and modify its modifiable text.
         *
         * Example:
         *
         *     </%url>
         *     </{"wp-bit":"query/post-author"}>
         *     </2>
         *
         * Funky comments are tag closers with invalid tag names. Note
         * that in HTML these are turn into bogus comments. Nonetheless,
         * the Tag Processor recognizes them in a stream of HTML and
         * exposes them for inspection and modification.
         *
         * @since 6.5.0
         *
         * @access private
         */
        const STATE_FUNKY_COMMENT = 'STATE_WP_FUNKY';
        /**
         * Indicates that a comment was created when encountering abruptly-closed HTML comment.
         *
         * Example:
         *
         *     <!-->
         *     <!--->
         *
         * @since 6.5.0
         */
        const COMMENT_AS_ABRUPTLY_CLOSED_COMMENT = 'COMMENT_AS_ABRUPTLY_CLOSED_COMMENT';
        /**
         * Indicates that a comment would be parsed as a CDATA node,
         * were HTML to allow CDATA nodes outside of foreign content.
         *
         * Example:
         *
         *     <![CDATA[This is a CDATA node.]]>
         *
         * This is an HTML comment, but it looks like a CDATA node.
         *
         * @since 6.5.0
         */
        const COMMENT_AS_CDATA_LOOKALIKE = 'COMMENT_AS_CDATA_LOOKALIKE';
        /**
         * Indicates that a comment was created when encountering
         * normative HTML comment syntax.
         *
         * Example:
         *
         *     <!-- this is a comment -->
         *
         * @since 6.5.0
         */
        const COMMENT_AS_HTML_COMMENT = 'COMMENT_AS_HTML_COMMENT';
        /**
         * Indicates that a comment would be parsed as a Processing
         * Instruction node, were they to exist within HTML.
         *
         * Example:
         *
         *     <?wp __( 'Like' ) ?>
         *
         * This is an HTML comment, but it looks like a CDATA node.
         *
         * @since 6.5.0
         */
        const COMMENT_AS_PI_NODE_LOOKALIKE = 'COMMENT_AS_PI_NODE_LOOKALIKE';
        /**
         * Indicates that a comment was created when encountering invalid
         * HTML input, a so-called "bogus comment."
         *
         * Example:
         *
         *     <?nothing special>
         *     <!{nothing special}>
         *
         * @since 6.5.0
         */
        const COMMENT_AS_INVALID_HTML = 'COMMENT_AS_INVALID_HTML';
        /**
         * No-quirks mode document compatability mode.
         *
         * > In no-quirks mode, the behavior is (hopefully) the desired behavior
         * > described by the modern HTML and CSS specifications.
         *
         * @see self::$compat_mode
         * @see https://developer.mozilla.org/en-US/docs/Web/HTML/Quirks_Mode_and_Standards_Mode
         *
         * @since 6.7.0
         *
         * @var string
         */
        const NO_QUIRKS_MODE = 'no-quirks-mode';
        /**
         * Quirks mode document compatability mode.
         *
         * > In quirks mode, layout emulates behavior in Navigator 4 and Internet
         * > Explorer 5. This is essential in order to support websites that were
         * > built before the widespread adoption of web standards.
         *
         * @see self::$compat_mode
         * @see https://developer.mozilla.org/en-US/docs/Web/HTML/Quirks_Mode_and_Standards_Mode
         *
         * @since 6.7.0
         *
         * @var string
         */
        const QUIRKS_MODE = 'quirks-mode';
        /**
         * Indicates that a span of text may contain any combination of significant
         * kinds of characters: NULL bytes, whitespace, and others.
         *
         * @see self::$text_node_classification
         * @see self::subdivide_text_appropriately
         *
         * @since 6.7.0
         */
        const TEXT_IS_GENERIC = 'TEXT_IS_GENERIC';
        /**
         * Indicates that a span of text comprises a sequence only of NULL bytes.
         *
         * @see self::$text_node_classification
         * @see self::subdivide_text_appropriately
         *
         * @since 6.7.0
         */
        const TEXT_IS_NULL_SEQUENCE = 'TEXT_IS_NULL_SEQUENCE';
        /**
         * Indicates that a span of decoded text comprises only whitespace.
         *
         * @see self::$text_node_classification
         * @see self::subdivide_text_appropriately
         *
         * @since 6.7.0
         */
        const TEXT_IS_WHITESPACE = 'TEXT_IS_WHITESPACE';
    }
    /**
     * Core class used to safely parse and modify an HTML document.
     *
     * The HTML Processor class properly parses and modifies HTML5 documents.
     *
     * It supports a subset of the HTML5 specification, and when it encounters
     * unsupported markup, it aborts early to avoid unintentionally breaking
     * the document. The HTML Processor should never break an HTML document.
     *
     * While the `WP_HTML_Tag_Processor` is a valuable tool for modifying
     * attributes on individual HTML tags, the HTML Processor is more capable
     * and useful for the following operations:
     *
     *  - Querying based on nested HTML structure.
     *
     * Eventually the HTML Processor will also support:
     *  - Wrapping a tag in surrounding HTML.
     *  - Unwrapping a tag by removing its parent.
     *  - Inserting and removing nodes.
     *  - Reading and changing inner content.
     *  - Navigating up or around HTML structure.
     *
     * ## Usage
     *
     * Use of this class requires three steps:
     *
     *   1. Call a static creator method with your input HTML document.
     *   2. Find the location in the document you are looking for.
     *   3. Request changes to the document at that location.
     *
     * Example:
     *
     *     $processor = WP_HTML_Processor::create_fragment( $html );
     *     if ( $processor->next_tag( array( 'breadcrumbs' => array( 'DIV', 'FIGURE', 'IMG' ) ) ) ) {
     *         $processor->add_class( 'responsive-image' );
     *     }
     *
     * #### Breadcrumbs
     *
     * Breadcrumbs represent the stack of open elements from the root
     * of the document or fragment down to the currently-matched node,
     * if one is currently selected. Call WP_HTML_Processor::get_breadcrumbs()
     * to inspect the breadcrumbs for a matched tag.
     *
     * Breadcrumbs can specify nested HTML structure and are equivalent
     * to a CSS selector comprising tag names separated by the child
     * combinator, such as "DIV > FIGURE > IMG".
     *
     * Since all elements find themselves inside a full HTML document
     * when parsed, the return value from `get_breadcrumbs()` will always
     * contain any implicit outermost elements. For example, when parsing
     * with `create_fragment()` in the `BODY` context (the default), any
     * tag in the given HTML document will contain `array( 'HTML', 'BODY', … )`
     * in its breadcrumbs.
     *
     * Despite containing the implied outermost elements in their breadcrumbs,
     * tags may be found with the shortest-matching breadcrumb query. That is,
     * `array( 'IMG' )` matches all IMG elements and `array( 'P', 'IMG' )`
     * matches all IMG elements directly inside a P element. To ensure that no
     * partial matches erroneously match it's possible to specify in a query
     * the full breadcrumb match all the way down from the root HTML element.
     *
     * Example:
     *
     *     $html = '<figure><img><figcaption>A <em>lovely</em> day outside</figcaption></figure>';
     *     //               ----- Matches here.
     *     $processor->next_tag( array( 'breadcrumbs' => array( 'FIGURE', 'IMG' ) ) );
     *
     *     $html = '<figure><img><figcaption>A <em>lovely</em> day outside</figcaption></figure>';
     *     //                                  ---- Matches here.
     *     $processor->next_tag( array( 'breadcrumbs' => array( 'FIGURE', 'FIGCAPTION', 'EM' ) ) );
     *
     *     $html = '<div><img></div><img>';
     *     //                       ----- Matches here, because IMG must be a direct child of the implicit BODY.
     *     $processor->next_tag( array( 'breadcrumbs' => array( 'BODY', 'IMG' ) ) );
     *
     * ## HTML Support
     *
     * This class implements a small part of the HTML5 specification.
     * It's designed to operate within its support and abort early whenever
     * encountering circumstances it can't properly handle. This is
     * the principle way in which this class remains as simple as possible
     * without cutting corners and breaking compliance.
     *
     * ### Supported elements
     *
     * If any unsupported element appears in the HTML input the HTML Processor
     * will abort early and stop all processing. This draconian measure ensures
     * that the HTML Processor won't break any HTML it doesn't fully understand.
     *
     * The HTML Processor supports all elements other than a specific set:
     *
     *  - Any element inside a TABLE.
     *  - Any element inside foreign content, including SVG and MATH.
     *  - Any element outside the IN BODY insertion mode, e.g. doctype declarations, meta, links.
     *
     * ### Supported markup
     *
     * Some kinds of non-normative HTML involve reconstruction of formatting elements and
     * re-parenting of mis-nested elements. For example, a DIV tag found inside a TABLE
     * may in fact belong _before_ the table in the DOM. If the HTML Processor encounters
     * such a case it will stop processing.
     *
     * The following list illustrates some common examples of unexpected HTML inputs that
     * the HTML Processor properly parses and represents:
     *
     *  - HTML with optional tags omitted, e.g. `<p>one<p>two`.
     *  - HTML with unexpected tag closers, e.g. `<p>one </span> more</p>`.
     *  - Non-void tags with self-closing flag, e.g. `<div/>the DIV is still open.</div>`.
     *  - Heading elements which close open heading elements of another level, e.g. `<h1>Closed by </h2>`.
     *  - Elements containing text that looks like other tags but isn't, e.g. `<title>The <img> is plaintext</title>`.
     *  - SCRIPT and STYLE tags containing text that looks like HTML but isn't, e.g. `<script>document.write('<p>Hi</p>');</script>`.
     *  - SCRIPT content which has been escaped, e.g. `<script><!-- document.write('<script>console.log("hi")</script>') --></script>`.
     *
     * ### Unsupported Features
     *
     * This parser does not report parse errors.
     *
     * Normally, when additional HTML or BODY tags are encountered in a document, if there
     * are any additional attributes on them that aren't found on the previous elements,
     * the existing HTML and BODY elements adopt those missing attribute values. This
     * parser does not add those additional attributes.
     *
     * In certain situations, elements are moved to a different part of the document in
     * a process called "adoption" and "fostering." Because the nodes move to a location
     * in the document that the parser had already processed, this parser does not support
     * these situations and will bail.
     *
     * @since 6.4.0
     *
     * @see WP_HTML_Tag_Processor
     * @see https://html.spec.whatwg.org/
     */
    class WP_HTML_Processor extends \WP_HTML_Tag_Processor
    {
        /**
         * The maximum number of bookmarks allowed to exist at any given time.
         *
         * HTML processing requires more bookmarks than basic tag processing,
         * so this class constant from the Tag Processor is overwritten.
         *
         * @since 6.4.0
         *
         * @var int
         */
        const MAX_BOOKMARKS = 100;
        /**
         * Creates an HTML processor in the fragment parsing mode.
         *
         * Use this for cases where you are processing chunks of HTML that
         * will be found within a bigger HTML document, such as rendered
         * block output that exists within a post, `the_content` inside a
         * rendered site layout.
         *
         * Fragment parsing occurs within a context, which is an HTML element
         * that the document will eventually be placed in. It becomes important
         * when special elements have different rules than others, such as inside
         * a TEXTAREA or a TITLE tag where things that look like tags are text,
         * or inside a SCRIPT tag where things that look like HTML syntax are JS.
         *
         * The context value should be a representation of the tag into which the
         * HTML is found. For most cases this will be the body element. The HTML
         * form is provided because a context element may have attributes that
         * impact the parse, such as with a SCRIPT tag and its `type` attribute.
         *
         * ## Current HTML Support
         *
         *  - The only supported context is `<body>`, which is the default value.
         *  - The only supported document encoding is `UTF-8`, which is the default value.
         *
         * @since 6.4.0
         * @since 6.6.0 Returns `static` instead of `self` so it can create subclass instances.
         *
         * @param string $html     Input HTML fragment to process.
         * @param string $context  Context element for the fragment, must be default of `<body>`.
         * @param string $encoding Text encoding of the document; must be default of 'UTF-8'.
         * @return static|null The created processor if successful, otherwise null.
         */
        public static function create_fragment($html, $context = '<body>', $encoding = 'UTF-8')
        {
        }
        /**
         * Creates an HTML processor in the full parsing mode.
         *
         * It's likely that a fragment parser is more appropriate, unless sending an
         * entire HTML document from start to finish. Consider a fragment parser with
         * a context node of `<body>`.
         *
         * Since UTF-8 is the only currently-accepted charset, if working with a
         * document that isn't UTF-8, it's important to convert the document before
         * creating the processor: pass in the converted HTML.
         *
         * @param string      $html                    Input HTML document to process.
         * @param string|null $known_definite_encoding Optional. If provided, specifies the charset used
         *                                             in the input byte stream. Currently must be UTF-8.
         * @return static|null The created processor if successful, otherwise null.
         */
        public static function create_full_parser($html, $known_definite_encoding = 'UTF-8')
        {
        }
        /**
         * Constructor.
         *
         * Do not use this method. Use the static creator methods instead.
         *
         * @access private
         *
         * @since 6.4.0
         *
         * @see WP_HTML_Processor::create_fragment()
         *
         * @param string      $html                                  HTML to process.
         * @param string|null $use_the_static_create_methods_instead This constructor should not be called manually.
         */
        public function __construct($html, $use_the_static_create_methods_instead = \null)
        {
        }
        /**
         * Returns the last error, if any.
         *
         * Various situations lead to parsing failure but this class will
         * return `false` in all those cases. To determine why something
         * failed it's possible to request the last error. This can be
         * helpful to know to distinguish whether a given tag couldn't
         * be found or if content in the document caused the processor
         * to give up and abort processing.
         *
         * Example
         *
         *     $processor = WP_HTML_Processor::create_fragment( '<template><strong><button><em><p><em>' );
         *     false === $processor->next_tag();
         *     WP_HTML_Processor::ERROR_UNSUPPORTED === $processor->get_last_error();
         *
         * @since 6.4.0
         *
         * @see self::ERROR_UNSUPPORTED
         * @see self::ERROR_EXCEEDED_MAX_BOOKMARKS
         *
         * @return string|null The last error, if one exists, otherwise null.
         */
        public function get_last_error() : ?string
        {
        }
        /**
         * Returns context for why the parser aborted due to unsupported HTML, if it did.
         *
         * This is meant for debugging purposes, not for production use.
         *
         * @since 6.7.0
         *
         * @see self::$unsupported_exception
         *
         * @return WP_HTML_Unsupported_Exception|null
         */
        public function get_unsupported_exception()
        {
        }
        /**
         * Finds the next tag matching the $query.
         *
         * @todo Support matching the class name and tag name.
         *
         * @since 6.4.0
         * @since 6.6.0 Visits all tokens, including virtual ones.
         *
         * @throws Exception When unable to allocate a bookmark for the next token in the input HTML document.
         *
         * @param array|string|null $query {
         *     Optional. Which tag name to find, having which class, etc. Default is to find any tag.
         *
         *     @type string|null $tag_name     Which tag to find, or `null` for "any tag."
         *     @type string      $tag_closers  'visit' to pause at tag closers, 'skip' or unset to only visit openers.
         *     @type int|null    $match_offset Find the Nth tag matching all search criteria.
         *                                     1 for "first" tag, 3 for "third," etc.
         *                                     Defaults to first tag.
         *     @type string|null $class_name   Tag must contain this whole class name to match.
         *     @type string[]    $breadcrumbs  DOM sub-path at which element is found, e.g. `array( 'FIGURE', 'IMG' )`.
         *                                     May also contain the wildcard `*` which matches a single element, e.g. `array( 'SECTION', '*' )`.
         * }
         * @return bool Whether a tag was matched.
         * @phpstan-param null|array{
         *   tag_name?: string|null,
         *   tag_closers?: string,
         *   match_offset?: int|null,
         *   class_name?: string|null,
         *   breadcrumbs?: string[],
         * } $query
         */
        public function next_tag($query = \null) : bool
        {
        }
        /**
         * Finds the next token in the HTML document.
         *
         * This doesn't currently have a way to represent non-tags and doesn't process
         * semantic rules for text nodes. For access to the raw tokens consider using
         * WP_HTML_Tag_Processor instead.
         *
         * @since 6.5.0 Added for internal support; do not use.
         * @since 6.7.2 Refactored so subclasses may extend.
         *
         * @return bool Whether a token was parsed.
         */
        public function next_token() : bool
        {
        }
        /**
         * Indicates if the current tag token is a tag closer.
         *
         * Example:
         *
         *     $p = WP_HTML_Processor::create_fragment( '<div></div>' );
         *     $p->next_tag( array( 'tag_name' => 'div', 'tag_closers' => 'visit' ) );
         *     $p->is_tag_closer() === false;
         *
         *     $p->next_tag( array( 'tag_name' => 'div', 'tag_closers' => 'visit' ) );
         *     $p->is_tag_closer() === true;
         *
         * @since 6.6.0 Subclassed for HTML Processor.
         *
         * @return bool Whether the current tag is a tag closer.
         */
        public function is_tag_closer() : bool
        {
        }
        /**
         * Indicates if the currently-matched tag matches the given breadcrumbs.
         *
         * A "*" represents a single tag wildcard, where any tag matches, but not no tags.
         *
         * At some point this function _may_ support a `**` syntax for matching any number
         * of unspecified tags in the breadcrumb stack. This has been intentionally left
         * out, however, to keep this function simple and to avoid introducing backtracking,
         * which could open up surprising performance breakdowns.
         *
         * Example:
         *
         *     $processor = WP_HTML_Processor::create_fragment( '<div><span><figure><img></figure></span></div>' );
         *     $processor->next_tag( 'img' );
         *     true  === $processor->matches_breadcrumbs( array( 'figure', 'img' ) );
         *     true  === $processor->matches_breadcrumbs( array( 'span', 'figure', 'img' ) );
         *     false === $processor->matches_breadcrumbs( array( 'span', 'img' ) );
         *     true  === $processor->matches_breadcrumbs( array( 'span', '*', 'img' ) );
         *
         * @since 6.4.0
         *
         * @param string[] $breadcrumbs DOM sub-path at which element is found, e.g. `array( 'FIGURE', 'IMG' )`.
         *                              May also contain the wildcard `*` which matches a single element, e.g. `array( 'SECTION', '*' )`.
         * @return bool Whether the currently-matched tag is found at the given nested structure.
         */
        public function matches_breadcrumbs($breadcrumbs) : bool
        {
        }
        /**
         * Indicates if the currently-matched node expects a closing
         * token, or if it will self-close on the next step.
         *
         * Most HTML elements expect a closer, such as a P element or
         * a DIV element. Others, like an IMG element are void and don't
         * have a closing tag. Special elements, such as SCRIPT and STYLE,
         * are treated just like void tags. Text nodes and self-closing
         * foreign content will also act just like a void tag, immediately
         * closing as soon as the processor advances to the next token.
         *
         * @since 6.6.0
         *
         * @param WP_HTML_Token|null $node Optional. Node to examine, if provided.
         *                                 Default is to examine current node.
         * @return bool|null Whether to expect a closer for the currently-matched node,
         *                   or `null` if not matched on any token.
         */
        public function expects_closer(?\WP_HTML_Token $node = \null) : ?bool
        {
        }
        /**
         * Steps through the HTML document and stop at the next tag, if any.
         *
         * @since 6.4.0
         *
         * @throws Exception When unable to allocate a bookmark for the next token in the input HTML document.
         *
         * @see self::PROCESS_NEXT_NODE
         * @see self::REPROCESS_CURRENT_NODE
         *
         * @param string $node_to_process Whether to parse the next node or reprocess the current node.
         * @return bool Whether a tag was matched.
         */
        public function step($node_to_process = self::PROCESS_NEXT_NODE) : bool
        {
        }
        /**
         * Computes the HTML breadcrumbs for the currently-matched node, if matched.
         *
         * Breadcrumbs start at the outermost parent and descend toward the matched element.
         * They always include the entire path from the root HTML node to the matched element.
         *
         * @todo It could be more efficient to expose a generator-based version of this function
         *       to avoid creating the array copy on tag iteration. If this is done, it would likely
         *       be more useful to walk up the stack when yielding instead of starting at the top.
         *
         * Example
         *
         *     $processor = WP_HTML_Processor::create_fragment( '<p><strong><em><img></em></strong></p>' );
         *     $processor->next_tag( 'IMG' );
         *     $processor->get_breadcrumbs() === array( 'HTML', 'BODY', 'P', 'STRONG', 'EM', 'IMG' );
         *
         * @since 6.4.0
         *
         * @return string[]|null Array of tag names representing path to matched node, if matched, otherwise NULL.
         */
        public function get_breadcrumbs() : ?array
        {
        }
        /**
         * Returns the nesting depth of the current location in the document.
         *
         * Example:
         *
         *     $processor = WP_HTML_Processor::create_fragment( '<div><p></p></div>' );
         *     // The processor starts in the BODY context, meaning it has depth from the start: HTML > BODY.
         *     2 === $processor->get_current_depth();
         *
         *     // Opening the DIV element increases the depth.
         *     $processor->next_token();
         *     3 === $processor->get_current_depth();
         *
         *     // Opening the P element increases the depth.
         *     $processor->next_token();
         *     4 === $processor->get_current_depth();
         *
         *     // The P element is closed during `next_token()` so the depth is decreased to reflect that.
         *     $processor->next_token();
         *     3 === $processor->get_current_depth();
         *
         * @since 6.6.0
         *
         * @return int Nesting-depth of current location in the document.
         */
        public function get_current_depth() : int
        {
        }
        /**
         * Normalizes an HTML fragment by serializing it.
         *
         * This method assumes that the given HTML snippet is found in BODY context.
         * For normalizing full documents or fragments found in other contexts, create
         * a new processor using {@see WP_HTML_Processor::create_fragment} or
         * {@see WP_HTML_Processor::create_full_parser} and call {@see WP_HTML_Processor::serialize}
         * on the created instances.
         *
         * Many aspects of an input HTML fragment may be changed during normalization.
         *
         *  - Attribute values will be double-quoted.
         *  - Duplicate attributes will be removed.
         *  - Omitted tags will be added.
         *  - Tag and attribute name casing will be lower-cased,
         *    except for specific SVG and MathML tags or attributes.
         *  - Text will be re-encoded, null bytes handled,
         *    and invalid UTF-8 replaced with U+FFFD.
         *  - Any incomplete syntax trailing at the end will be omitted,
         *    for example, an unclosed comment opener will be removed.
         *
         * Example:
         *
         *     echo WP_HTML_Processor::normalize( '<a href=#anchor v=5 href="/" enabled>One</a another v=5><!--' );
         *     // <a href="#anchor" v="5" enabled>One</a>
         *
         *     echo WP_HTML_Processor::normalize( '<div></p>fun<table><td>cell</div>' );
         *     // <div><p></p>fun<table><tbody><tr><td>cell</td></tr></tbody></table></div>
         *
         *     echo WP_HTML_Processor::normalize( '<![CDATA[invalid comment]]> syntax < <> "oddities"' );
         *     // <!--[CDATA[invalid comment]]--> syntax &lt; &lt;&gt; &quot;oddities&quot;
         *
         * @since 6.7.0
         *
         * @param string $html Input HTML to normalize.
         *
         * @return string|null Normalized output, or `null` if unable to normalize.
         */
        public static function normalize(string $html) : ?string
        {
        }
        /**
         * Returns normalized HTML for a fragment by serializing it.
         *
         * This differs from {@see WP_HTML_Processor::normalize} in that it starts with
         * a specific HTML Processor, which _must_ not have already started scanning;
         * it must be in the initial ready state and will be in the completed state once
         * serialization is complete.
         *
         * Many aspects of an input HTML fragment may be changed during normalization.
         *
         *  - Attribute values will be double-quoted.
         *  - Duplicate attributes will be removed.
         *  - Omitted tags will be added.
         *  - Tag and attribute name casing will be lower-cased,
         *    except for specific SVG and MathML tags or attributes.
         *  - Text will be re-encoded, null bytes handled,
         *    and invalid UTF-8 replaced with U+FFFD.
         *  - Any incomplete syntax trailing at the end will be omitted,
         *    for example, an unclosed comment opener will be removed.
         *
         * Example:
         *
         *     $processor = WP_HTML_Processor::create_fragment( '<a href=#anchor v=5 href="/" enabled>One</a another v=5><!--' );
         *     echo $processor->serialize();
         *     // <a href="#anchor" v="5" enabled>One</a>
         *
         *     $processor = WP_HTML_Processor::create_fragment( '<div></p>fun<table><td>cell</div>' );
         *     echo $processor->serialize();
         *     // <div><p></p>fun<table><tbody><tr><td>cell</td></tr></tbody></table></div>
         *
         *     $processor = WP_HTML_Processor::create_fragment( '<![CDATA[invalid comment]]> syntax < <> "oddities"' );
         *     echo $processor->serialize();
         *     // <!--[CDATA[invalid comment]]--> syntax &lt; &lt;&gt; &quot;oddities&quot;
         *
         * @since 6.7.0
         *
         * @return string|null Normalized HTML markup represented by processor,
         *                     or `null` if unable to generate serialization.
         */
        public function serialize() : ?string
        {
        }
        /**
         * Serializes the currently-matched token.
         *
         * This method produces a fully-normative HTML string for the currently-matched token,
         * if able. If not matched at any token or if the token doesn't correspond to any HTML
         * it will return an empty string (for example, presumptuous end tags are ignored).
         *
         * @see static::serialize()
         *
         * @since 6.7.0
         *
         * @return string Serialization of token, or empty string if no serialization exists.
         */
        protected function serialize_token() : string
        {
        }
        /**
         * Indicates the namespace of the current token, or "html" if there is none.
         *
         * @return string One of "html", "math", or "svg".
         */
        public function get_namespace() : string
        {
        }
        /**
         * Returns the uppercase name of the matched tag.
         *
         * The semantic rules for HTML specify that certain tags be reprocessed
         * with a different tag name. Because of this, the tag name presented
         * by the HTML Processor may differ from the one reported by the HTML
         * Tag Processor, which doesn't apply these semantic rules.
         *
         * Example:
         *
         *     $processor = new WP_HTML_Tag_Processor( '<div class="test">Test</div>' );
         *     $processor->next_tag() === true;
         *     $processor->get_tag() === 'DIV';
         *
         *     $processor->next_tag() === false;
         *     $processor->get_tag() === null;
         *
         * @since 6.4.0
         *
         * @return string|null Name of currently matched tag in input HTML, or `null` if none found.
         */
        public function get_tag() : ?string
        {
        }
        /**
         * Indicates if the currently matched tag contains the self-closing flag.
         *
         * No HTML elements ought to have the self-closing flag and for those, the self-closing
         * flag will be ignored. For void elements this is benign because they "self close"
         * automatically. For non-void HTML elements though problems will appear if someone
         * intends to use a self-closing element in place of that element with an empty body.
         * For HTML foreign elements and custom elements the self-closing flag determines if
         * they self-close or not.
         *
         * This function does not determine if a tag is self-closing,
         * but only if the self-closing flag is present in the syntax.
         *
         * @since 6.6.0 Subclassed for the HTML Processor.
         *
         * @return bool Whether the currently matched tag contains the self-closing flag.
         */
        public function has_self_closing_flag() : bool
        {
        }
        /**
         * Returns the node name represented by the token.
         *
         * This matches the DOM API value `nodeName`. Some values
         * are static, such as `#text` for a text node, while others
         * are dynamically generated from the token itself.
         *
         * Dynamic names:
         *  - Uppercase tag name for tag matches.
         *  - `html` for DOCTYPE declarations.
         *
         * Note that if the Tag Processor is not matched on a token
         * then this function will return `null`, either because it
         * hasn't yet found a token or because it reached the end
         * of the document without matching a token.
         *
         * @since 6.6.0 Subclassed for the HTML Processor.
         *
         * @return string|null Name of the matched token.
         */
        public function get_token_name() : ?string
        {
        }
        /**
         * Indicates the kind of matched token, if any.
         *
         * This differs from `get_token_name()` in that it always
         * returns a static string indicating the type, whereas
         * `get_token_name()` may return values derived from the
         * token itself, such as a tag name or processing
         * instruction tag.
         *
         * Possible values:
         *  - `#tag` when matched on a tag.
         *  - `#text` when matched on a text node.
         *  - `#cdata-section` when matched on a CDATA node.
         *  - `#comment` when matched on a comment.
         *  - `#doctype` when matched on a DOCTYPE declaration.
         *  - `#presumptuous-tag` when matched on an empty tag closer.
         *  - `#funky-comment` when matched on a funky comment.
         *
         * @since 6.6.0 Subclassed for the HTML Processor.
         *
         * @return string|null What kind of token is matched, or null.
         */
        public function get_token_type() : ?string
        {
        }
        /**
         * Returns the value of a requested attribute from a matched tag opener if that attribute exists.
         *
         * Example:
         *
         *     $p = WP_HTML_Processor::create_fragment( '<div enabled class="test" data-test-id="14">Test</div>' );
         *     $p->next_token() === true;
         *     $p->get_attribute( 'data-test-id' ) === '14';
         *     $p->get_attribute( 'enabled' ) === true;
         *     $p->get_attribute( 'aria-label' ) === null;
         *
         *     $p->next_tag() === false;
         *     $p->get_attribute( 'class' ) === null;
         *
         * @since 6.6.0 Subclassed for HTML Processor.
         *
         * @param string $name Name of attribute whose value is requested.
         * @return string|true|null Value of attribute or `null` if not available. Boolean attributes return `true`.
         */
        public function get_attribute($name)
        {
        }
        /**
         * Updates or creates a new attribute on the currently matched tag with the passed value.
         *
         * For boolean attributes special handling is provided:
         *  - When `true` is passed as the value, then only the attribute name is added to the tag.
         *  - When `false` is passed, the attribute gets removed if it existed before.
         *
         * For string attributes, the value is escaped using the `esc_attr` function.
         *
         * @since 6.6.0 Subclassed for the HTML Processor.
         *
         * @param string      $name  The attribute name to target.
         * @param string|bool $value The new attribute value.
         * @return bool Whether an attribute value was set.
         */
        public function set_attribute($name, $value) : bool
        {
        }
        /**
         * Remove an attribute from the currently-matched tag.
         *
         * @since 6.6.0 Subclassed for HTML Processor.
         *
         * @param string $name The attribute name to remove.
         * @return bool Whether an attribute was removed.
         */
        public function remove_attribute($name) : bool
        {
        }
        /**
         * Gets lowercase names of all attributes matching a given prefix in the current tag.
         *
         * Note that matching is case-insensitive. This is in accordance with the spec:
         *
         * > There must never be two or more attributes on
         * > the same start tag whose names are an ASCII
         * > case-insensitive match for each other.
         *     - HTML 5 spec
         *
         * Example:
         *
         *     $p = new WP_HTML_Tag_Processor( '<div data-ENABLED class="test" DATA-test-id="14">Test</div>' );
         *     $p->next_tag( array( 'class_name' => 'test' ) ) === true;
         *     $p->get_attribute_names_with_prefix( 'data-' ) === array( 'data-enabled', 'data-test-id' );
         *
         *     $p->next_tag() === false;
         *     $p->get_attribute_names_with_prefix( 'data-' ) === null;
         *
         * @since 6.6.0 Subclassed for the HTML Processor.
         *
         * @see https://html.spec.whatwg.org/multipage/syntax.html#attributes-2:ascii-case-insensitive
         *
         * @param string $prefix Prefix of requested attribute names.
         * @return array|null List of attribute names, or `null` when no tag opener is matched.
         */
        public function get_attribute_names_with_prefix($prefix) : ?array
        {
        }
        /**
         * Adds a new class name to the currently matched tag.
         *
         * @since 6.6.0 Subclassed for the HTML Processor.
         *
         * @param string $class_name The class name to add.
         * @return bool Whether the class was set to be added.
         */
        public function add_class($class_name) : bool
        {
        }
        /**
         * Removes a class name from the currently matched tag.
         *
         * @since 6.6.0 Subclassed for the HTML Processor.
         *
         * @param string $class_name The class name to remove.
         * @return bool Whether the class was set to be removed.
         */
        public function remove_class($class_name) : bool
        {
        }
        /**
         * Returns if a matched tag contains the given ASCII case-insensitive class name.
         *
         * @since 6.6.0 Subclassed for the HTML Processor.
         *
         * @todo When reconstructing active formatting elements with attributes, find a way
         *       to indicate if the virtually-reconstructed formatting elements contain the
         *       wanted class name.
         *
         * @param string $wanted_class Look for this CSS class name, ASCII case-insensitive.
         * @return bool|null Whether the matched tag contains the given class name, or null if not matched.
         */
        public function has_class($wanted_class) : ?bool
        {
        }
        /**
         * Generator for a foreach loop to step through each class name for the matched tag.
         *
         * This generator function is designed to be used inside a "foreach" loop.
         *
         * Example:
         *
         *     $p = WP_HTML_Processor::create_fragment( "<div class='free &lt;egg&lt;\tlang-en'>" );
         *     $p->next_tag();
         *     foreach ( $p->class_list() as $class_name ) {
         *         echo "{$class_name} ";
         *     }
         *     // Outputs: "free <egg> lang-en "
         *
         * @since 6.6.0 Subclassed for the HTML Processor.
         */
        public function class_list()
        {
        }
        /**
         * Returns the modifiable text for a matched token, or an empty string.
         *
         * Modifiable text is text content that may be read and changed without
         * changing the HTML structure of the document around it. This includes
         * the contents of `#text` nodes in the HTML as well as the inner
         * contents of HTML comments, Processing Instructions, and others, even
         * though these nodes aren't part of a parsed DOM tree. They also contain
         * the contents of SCRIPT and STYLE tags, of TEXTAREA tags, and of any
         * other section in an HTML document which cannot contain HTML markup (DATA).
         *
         * If a token has no modifiable text then an empty string is returned to
         * avoid needless crashing or type errors. An empty string does not mean
         * that a token has modifiable text, and a token with modifiable text may
         * have an empty string (e.g. a comment with no contents).
         *
         * @since 6.6.0 Subclassed for the HTML Processor.
         *
         * @return string
         */
        public function get_modifiable_text() : string
        {
        }
        /**
         * Indicates what kind of comment produced the comment node.
         *
         * Because there are different kinds of HTML syntax which produce
         * comments, the Tag Processor tracks and exposes this as a type
         * for the comment. Nominally only regular HTML comments exist as
         * they are commonly known, but a number of unrelated syntax errors
         * also produce comments.
         *
         * @see self::COMMENT_AS_ABRUPTLY_CLOSED_COMMENT
         * @see self::COMMENT_AS_CDATA_LOOKALIKE
         * @see self::COMMENT_AS_INVALID_HTML
         * @see self::COMMENT_AS_HTML_COMMENT
         * @see self::COMMENT_AS_PI_NODE_LOOKALIKE
         *
         * @since 6.6.0 Subclassed for the HTML Processor.
         *
         * @return string|null
         */
        public function get_comment_type() : ?string
        {
        }
        /**
         * Removes a bookmark that is no longer needed.
         *
         * Releasing a bookmark frees up the small
         * performance overhead it requires.
         *
         * @since 6.4.0
         *
         * @param string $bookmark_name Name of the bookmark to remove.
         * @return bool Whether the bookmark already existed before removal.
         */
        public function release_bookmark($bookmark_name) : bool
        {
        }
        /**
         * Moves the internal cursor in the HTML Processor to a given bookmark's location.
         *
         * Be careful! Seeking backwards to a previous location resets the parser to the
         * start of the document and reparses the entire contents up until it finds the
         * sought-after bookmarked location.
         *
         * In order to prevent accidental infinite loops, there's a
         * maximum limit on the number of times seek() can be called.
         *
         * @throws Exception When unable to allocate a bookmark for the next token in the input HTML document.
         *
         * @since 6.4.0
         *
         * @param string $bookmark_name Jump to the place in the document identified by this bookmark name.
         * @return bool Whether the internal cursor was successfully moved to the bookmark's location.
         */
        public function seek($bookmark_name) : bool
        {
        }
        /**
         * Sets a bookmark in the HTML document.
         *
         * Bookmarks represent specific places or tokens in the HTML
         * document, such as a tag opener or closer. When applying
         * edits to a document, such as setting an attribute, the
         * text offsets of that token may shift; the bookmark is
         * kept updated with those shifts and remains stable unless
         * the entire span of text in which the token sits is removed.
         *
         * Release bookmarks when they are no longer needed.
         *
         * Example:
         *
         *     <main><h2>Surprising fact you may not know!</h2></main>
         *           ^  ^
         *            \-|-- this `H2` opener bookmark tracks the token
         *
         *     <main class="clickbait"><h2>Surprising fact you may no…
         *                             ^  ^
         *                              \-|-- it shifts with edits
         *
         * Bookmarks provide the ability to seek to a previously-scanned
         * place in the HTML document. This avoids the need to re-scan
         * the entire document.
         *
         * Example:
         *
         *     <ul><li>One</li><li>Two</li><li>Three</li></ul>
         *                                 ^^^^
         *                                 want to note this last item
         *
         *     $p = new WP_HTML_Tag_Processor( $html );
         *     $in_list = false;
         *     while ( $p->next_tag( array( 'tag_closers' => $in_list ? 'visit' : 'skip' ) ) ) {
         *         if ( 'UL' === $p->get_tag() ) {
         *             if ( $p->is_tag_closer() ) {
         *                 $in_list = false;
         *                 $p->set_bookmark( 'resume' );
         *                 if ( $p->seek( 'last-li' ) ) {
         *                     $p->add_class( 'last-li' );
         *                 }
         *                 $p->seek( 'resume' );
         *                 $p->release_bookmark( 'last-li' );
         *                 $p->release_bookmark( 'resume' );
         *             } else {
         *                 $in_list = true;
         *             }
         *         }
         *
         *         if ( 'LI' === $p->get_tag() ) {
         *             $p->set_bookmark( 'last-li' );
         *         }
         *     }
         *
         * Bookmarks intentionally hide the internal string offsets
         * to which they refer. They are maintained internally as
         * updates are applied to the HTML document and therefore
         * retain their "position" - the location to which they
         * originally pointed. The inability to use bookmarks with
         * functions like `substr` is therefore intentional to guard
         * against accidentally breaking the HTML.
         *
         * Because bookmarks allocate memory and require processing
         * for every applied update, they are limited and require
         * a name. They should not be created with programmatically-made
         * names, such as "li_{$index}" with some loop. As a general
         * rule they should only be created with string-literal names
         * like "start-of-section" or "last-paragraph".
         *
         * Bookmarks are a powerful tool to enable complicated behavior.
         * Consider double-checking that you need this tool if you are
         * reaching for it, as inappropriate use could lead to broken
         * HTML structure or unwanted processing overhead.
         *
         * @since 6.4.0
         *
         * @param string $bookmark_name Identifies this particular bookmark.
         * @return bool Whether the bookmark was successfully created.
         */
        public function set_bookmark($bookmark_name) : bool
        {
        }
        /**
         * Checks whether a bookmark with the given name exists.
         *
         * @since 6.5.0
         *
         * @param string $bookmark_name Name to identify a bookmark that potentially exists.
         * @return bool Whether that bookmark exists.
         */
        public function has_bookmark($bookmark_name) : bool
        {
        }
        /**
         * Returns whether an element of a given name is in the HTML special category.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#special
         *
         * @param WP_HTML_Token|string $tag_name Node to check, or only its name if in the HTML namespace.
         * @return bool Whether the element of the given name is in the special category.
         */
        public static function is_special($tag_name) : bool
        {
        }
        /**
         * Returns whether a given element is an HTML Void Element
         *
         * > area, base, br, col, embed, hr, img, input, link, meta, source, track, wbr
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#void-elements
         *
         * @param string $tag_name Name of HTML tag to check.
         * @return bool Whether the given tag is an HTML Void Element.
         */
        public static function is_void($tag_name) : bool
        {
        }
        /**
         * Gets an encoding from a given string.
         *
         * This is an algorithm defined in the WHAT-WG specification.
         *
         * Example:
         *
         *     'UTF-8' === self::get_encoding( 'utf8' );
         *     'UTF-8' === self::get_encoding( "  \tUTF-8 " );
         *     null    === self::get_encoding( 'UTF-7' );
         *     null    === self::get_encoding( 'utf8; charset=' );
         *
         * @see https://encoding.spec.whatwg.org/#concept-encoding-get
         *
         * @todo As this parser only supports UTF-8, only the UTF-8
         *       encodings are detected. Add more as desired, but the
         *       parser will bail on non-UTF-8 encodings.
         *
         * @since 6.7.0
         *
         * @param string $label A string which may specify a known encoding.
         * @return string|null Known encoding if matched, otherwise null.
         */
        protected static function get_encoding(string $label) : ?string
        {
        }
        /*
         * Constants that would pollute the top of the class if they were found there.
         */
        /**
         * Indicates that the next HTML token should be parsed and processed.
         *
         * @since 6.4.0
         *
         * @var string
         */
        const PROCESS_NEXT_NODE = 'process-next-node';
        /**
         * Indicates that the current HTML token should be reprocessed in the newly-selected insertion mode.
         *
         * @since 6.4.0
         *
         * @var string
         */
        const REPROCESS_CURRENT_NODE = 'reprocess-current-node';
        /**
         * Indicates that the current HTML token should be processed without advancing the parser.
         *
         * @since 6.5.0
         *
         * @var string
         */
        const PROCESS_CURRENT_NODE = 'process-current-node';
        /**
         * Indicates that the parser encountered unsupported markup and has bailed.
         *
         * @since 6.4.0
         *
         * @var string
         */
        const ERROR_UNSUPPORTED = 'unsupported';
        /**
         * Indicates that the parser encountered more HTML tokens than it
         * was able to process and has bailed.
         *
         * @since 6.4.0
         *
         * @var string
         */
        const ERROR_EXCEEDED_MAX_BOOKMARKS = 'exceeded-max-bookmarks';
        /**
         * Unlock code that must be passed into the constructor to create this class.
         *
         * This class extends the WP_HTML_Tag_Processor, which has a public class
         * constructor. Therefore, it's not possible to have a private constructor here.
         *
         * This unlock code is used to ensure that anyone calling the constructor is
         * doing so with a full understanding that it's intended to be a private API.
         *
         * @access private
         */
        const CONSTRUCTOR_UNLOCK_CODE = 'Use WP_HTML_Processor::create_fragment() instead of calling the class constructor directly.';
    }
    /**
     * Core class used by the HTML tag processor to represent a textual span
     * inside an HTML document.
     *
     * This is a two-tuple in disguise, used to avoid the memory overhead
     * involved in using an array for the same purpose.
     *
     * This class is for internal usage of the WP_HTML_Tag_Processor class.
     *
     * @access private
     * @since 6.2.0
     * @since 6.5.0 Replaced `end` with `length` to more closely align with `substr()`.
     *
     * @see WP_HTML_Tag_Processor
     */
    class WP_HTML_Span
    {
        /**
         * Byte offset into document where span begins.
         *
         * @since 6.2.0
         *
         * @var int
         */
        public $start;
        /**
         * Byte length of this span.
         *
         * @since 6.5.0
         *
         * @var int
         */
        public $length;
        /**
         * Constructor.
         *
         * @since 6.2.0
         *
         * @param int $start  Byte offset into document where replacement span begins.
         * @param int $length Byte length of span.
         */
        public function __construct(int $start, int $length)
        {
        }
    }
    /**
     * Core class used by the HTML Processor as a record for stack operations.
     *
     * This class is for internal usage of the WP_HTML_Processor class.
     *
     * @access private
     * @since 6.6.0
     *
     * @see WP_HTML_Processor
     */
    class WP_HTML_Stack_Event
    {
        /**
         * Refers to popping an element off of the stack of open elements.
         *
         * @since 6.6.0
         */
        const POP = 'pop';
        /**
         * Refers to pushing an element onto the stack of open elements.
         *
         * @since 6.6.0
         */
        const PUSH = 'push';
        /**
         * References the token associated with the stack push event,
         * even if this is a pop event for that element.
         *
         * @since 6.6.0
         *
         * @var WP_HTML_Token
         */
        public $token;
        /**
         * Indicates which kind of stack operation this event represents.
         *
         * May be one of the class constants.
         *
         * @since 6.6.0
         *
         * @see self::POP
         * @see self::PUSH
         *
         * @var string
         */
        public $operation;
        /**
         * Indicates if the stack element is a real or virtual node.
         *
         * @since 6.6.0
         *
         * @var string
         */
        public $provenance;
        /**
         * Constructor function.
         *
         * @since 6.6.0
         *
         * @param WP_HTML_Token $token      Token associated with stack event, always an opening token.
         * @param string        $operation  One of self::PUSH or self::POP.
         * @param string        $provenance "virtual" or "real".
         */
        public function __construct(\WP_HTML_Token $token, string $operation, string $provenance)
        {
        }
    }
    /**
     * Core class used by the HTML tag processor as a data structure for replacing
     * existing content from start to end, allowing to drastically improve performance.
     *
     * This class is for internal usage of the WP_HTML_Tag_Processor class.
     *
     * @access private
     * @since 6.2.0
     * @since 6.5.0 Replace `end` with `length` to more closely match `substr()`.
     *
     * @see WP_HTML_Tag_Processor
     */
    class WP_HTML_Text_Replacement
    {
        /**
         * Byte offset into document where replacement span begins.
         *
         * @since 6.2.0
         *
         * @var int
         */
        public $start;
        /**
         * Byte length of span being replaced.
         *
         * @since 6.5.0
         *
         * @var int
         */
        public $length;
        /**
         * Span of text to insert in document to replace existing content from start to end.
         *
         * @since 6.2.0
         *
         * @var string
         */
        public $text;
        /**
         * Constructor.
         *
         * @since 6.2.0
         *
         * @param int    $start  Byte offset into document where replacement span begins.
         * @param int    $length Byte length of span in document being replaced.
         * @param string $text   Span of text to insert in document to replace existing content from start to end.
         */
        public function __construct(int $start, int $length, string $text)
        {
        }
    }
    /**
     * Core class used by the HTML processor during HTML parsing
     * for referring to tokens in the input HTML string.
     *
     * This class is designed for internal use by the HTML processor.
     *
     * @since 6.4.0
     *
     * @access private
     *
     * @see WP_HTML_Processor
     */
    class WP_HTML_Token
    {
        /**
         * Name of bookmark corresponding to source of token in input HTML string.
         *
         * Having a bookmark name does not imply that the token still exists. It
         * may be that the source token and underlying bookmark was wiped out by
         * some modification to the source HTML.
         *
         * @since 6.4.0
         *
         * @var string
         */
        public $bookmark_name = \null;
        /**
         * Name of node; lowercase names such as "marker" are not HTML elements.
         *
         * For HTML elements/tags this value should come from WP_HTML_Processor::get_tag().
         *
         * @since 6.4.0
         *
         * @see WP_HTML_Processor::get_tag()
         *
         * @var string
         */
        public $node_name = \null;
        /**
         * Whether node contains the self-closing flag.
         *
         * A node may have a self-closing flag when it shouldn't. This value
         * only reports if the flag is present in the original HTML.
         *
         * @since 6.4.0
         *
         * @see https://html.spec.whatwg.org/#self-closing-flag
         *
         * @var bool
         */
        public $has_self_closing_flag = \false;
        /**
         * Indicates if the element is an HTML element or if it's inside foreign content.
         *
         * @since 6.7.0
         *
         * @var string 'html', 'svg', or 'math'.
         */
        public $namespace = 'html';
        /**
         * Indicates which kind of integration point the element is, if any.
         *
         * @since 6.7.0
         *
         * @var string|null 'math', 'html', or null if not an integration point.
         */
        public $integration_node_type = \null;
        /**
         * Called when token is garbage-collected or otherwise destroyed.
         *
         * @var callable|null
         */
        public $on_destroy = \null;
        /**
         * Constructor - creates a reference to a token in some external HTML string.
         *
         * @since 6.4.0
         *
         * @param string|null   $bookmark_name         Name of bookmark corresponding to location in HTML where token is found,
         *                                             or `null` for markers and nodes without a bookmark.
         * @param string        $node_name             Name of node token represents; if uppercase, an HTML element; if lowercase, a special value like "marker".
         * @param bool          $has_self_closing_flag Whether the source token contains the self-closing flag, regardless of whether it's valid.
         * @param callable|null $on_destroy            Optional. Function to call when destroying token, useful for releasing the bookmark.
         */
        public function __construct(?string $bookmark_name, string $node_name, bool $has_self_closing_flag, ?callable $on_destroy = \null)
        {
        }
        /**
         * Destructor.
         *
         * @since 6.4.0
         */
        public function __destruct()
        {
        }
        /**
         * Wakeup magic method.
         *
         * @since 6.4.2
         */
        public function __wakeup()
        {
        }
    }
    /**
     * Core class used by the HTML processor during HTML parsing
     * for indicating that a given operation is unsupported.
     *
     * This class is designed for internal use by the HTML processor.
     *
     * The HTML API aims to operate in compliance with the HTML5
     * specification, but does not implement the full specification.
     * In cases where it lacks support it should not cause breakage
     * or unexpected behavior. In the cases where it recognizes that
     * it cannot proceed, this class is used to abort from any
     * operation and signify that the given HTML cannot be processed.
     *
     * @since 6.4.0
     * @since 6.7.0 Gained contextual information for use in debugging parse failures.
     *
     * @access private
     *
     * @see WP_HTML_Processor
     */
    class WP_HTML_Unsupported_Exception extends \Exception
    {
        /**
         * Name of the matched token when the exception was raised,
         * if matched on a token.
         *
         * This does not imply that the token itself was unsupported, but it
         * may have been the case that the token triggered part of the HTML
         * parsing that isn't supported, such as the adoption agency algorithm.
         *
         * @since 6.7.0
         *
         * @var string
         */
        public $token_name;
        /**
         * Number of bytes into the input HTML document where the parser was
         * parsing when the exception was raised.
         *
         * Use this to reconstruct context for the failure.
         *
         * @since 6.7.0
         *
         * @var int
         */
        public $token_at;
        /**
         * Full raw text of the matched token when the exception was raised,
         * if matched on a token.
         *
         * Whereas the `$token_name` will be normalized, this contains the full
         * raw text of the token, including original casing, duplicated attributes,
         * and other syntactic variations that are normally abstracted in the HTML API.
         *
         * @since 6.7.0
         *
         * @var string
         */
        public $token;
        /**
         * Stack of open elements when the exception was raised.
         *
         * Use this to trace the parsing circumstances which led to the exception.
         *
         * @since 6.7.0
         *
         * @var string[]
         */
        public $stack_of_open_elements = array();
        /**
         * List of active formatting elements when the exception was raised.
         *
         * Use this to trace the parsing circumstances which led to the exception.
         *
         * @since 6.7.0
         *
         * @var string[]
         */
        public $active_formatting_elements = array();
        /**
         * Constructor function.
         *
         * @since 6.7.0
         *
         * @param string   $message                    Brief message explaining what is unsupported, the reason this exception was raised.
         * @param string   $token_name                 Normalized name of matched token when this exception was raised.
         * @param int      $token_at                   Number of bytes into source HTML document where matched token starts.
         * @param string   $token                      Full raw text of matched token when this exception was raised.
         * @param string[] $stack_of_open_elements     Stack of open elements when this exception was raised.
         * @param string[] $active_formatting_elements List of active formatting elements when this exception was raised.
         */
        public function __construct(string $message, string $token_name, int $token_at, string $token, array $stack_of_open_elements, array $active_formatting_elements)
        {
        }
    }
    /**
     * Class used to iterate over the tags of an HTML string and help process the
     * directive attributes.
     *
     * @since 6.5.0
     *
     * @access private
     */
    final class WP_Interactivity_API_Directives_Processor extends \WP_HTML_Tag_Processor
    {
        /**
         * List of tags whose closer tag is not visited by the WP_HTML_Tag_Processor.
         *
         * @since 6.5.0
         * @var string[]
         */
        const TAGS_THAT_DONT_VISIT_CLOSER_TAG = array('SCRIPT', 'IFRAME', 'NOEMBED', 'NOFRAMES', 'STYLE', 'TEXTAREA', 'TITLE', 'XMP');
        /**
         * Returns the content between two balanced template tags.
         *
         * It positions the cursor in the closer tag of the balanced template tag,
         * if it exists.
         *
         * @since 6.5.0
         *
         * @access private
         *
         * @return string|null The content between the current opener template tag and its matching closer tag or null if it
         *                     doesn't find the matching closing tag or the current tag is not a template opener tag.
         */
        public function get_content_between_balanced_template_tags()
        {
        }
        /**
         * Sets the content between two balanced tags.
         *
         * @since 6.5.0
         *
         * @access private
         *
         * @param string $new_content The string to replace the content between the matching tags.
         * @return bool Whether the content was successfully replaced.
         */
        public function set_content_between_balanced_tags(string $new_content) : bool
        {
        }
        /**
         * Appends content after the closing tag of a template tag.
         *
         * It positions the cursor in the closer tag of the balanced template tag,
         * if it exists.
         *
         * @access private
         *
         * @param string $new_content The string to append after the closing template tag.
         * @return bool Whether the content was successfully appended.
         */
        public function append_content_after_template_tag_closer(string $new_content) : bool
        {
        }
        /**
         * Skips processing the content between tags.
         *
         * It positions the cursor in the closer tag of the foreign element, if it
         * exists.
         *
         * This function is intended to skip processing SVG and MathML inner content
         * instead of bailing out the whole processing.
         *
         * @since 6.5.0
         *
         * @access private
         *
         * @return bool Whether the foreign content was successfully skipped.
         */
        public function skip_to_tag_closer() : bool
        {
        }
        /**
         * Finds the matching closing tag for an opening tag.
         *
         * When called while the processor is on an open tag, it traverses the HTML
         * until it finds the matching closer tag, respecting any in-between content,
         * including nested tags of the same name. Returns false when called on a
         * closer tag, a tag that doesn't have a closer tag (void), a tag that
         * doesn't visit the closer tag, or if no matching closing tag was found.
         *
         * @since 6.5.0
         *
         * @access private
         *
         * @return bool Whether a matching closing tag was found.
         */
        public function next_balanced_tag_closer_tag() : bool
        {
        }
        /**
         * Checks whether the current tag has and will visit its matching closer tag.
         *
         * @since 6.5.0
         *
         * @access private
         *
         * @return bool Whether the current tag has a closer tag.
         */
        public function has_and_visits_its_closer_tag() : bool
        {
        }
    }
    /**
     * Class used to process the Interactivity API on the server.
     *
     * @since 6.5.0
     */
    final class WP_Interactivity_API
    {
        /**
         * Gets and/or sets the initial state of an Interactivity API store for a
         * given namespace.
         *
         * If state for that store namespace already exists, it merges the new
         * provided state with the existing one.
         *
         * When no namespace is specified, it returns the state defined for the
         * current value in the internal namespace stack during a `process_directives` call.
         *
         * @since 6.5.0
         * @since 6.6.0 The `$store_namespace` param is optional.
         *
         * @param string $store_namespace Optional. The unique store namespace identifier.
         * @param array  $state           Optional. The array that will be merged with the existing state for the specified
         *                                store namespace.
         * @return array The current state for the specified store namespace. This will be the updated state if a $state
         *               argument was provided.
         */
        public function state(?string $store_namespace = \null, ?array $state = \null) : array
        {
        }
        /**
         * Gets and/or sets the configuration of the Interactivity API for a given
         * store namespace.
         *
         * If configuration for that store namespace exists, it merges the new
         * provided configuration with the existing one.
         *
         * @since 6.5.0
         *
         * @param string $store_namespace The unique store namespace identifier.
         * @param array  $config          Optional. The array that will be merged with the existing configuration for the
         *                                specified store namespace.
         * @return array The configuration for the specified store namespace. This will be the updated configuration if a
         *               $config argument was provided.
         */
        public function config(string $store_namespace, array $config = array()) : array
        {
        }
        /**
         * Prints the serialized client-side interactivity data.
         *
         * Encodes the config and initial state into JSON and prints them inside a
         * script tag of type "application/json". Once in the browser, the state will
         * be parsed and used to hydrate the client-side interactivity stores and the
         * configuration will be available using a `getConfig` utility.
         *
         * @since 6.5.0
         *
         * @deprecated 6.7.0 Client data passing is handled by the {@see "script_module_data_{$module_id}"} filter.
         */
        public function print_client_interactivity_data()
        {
        }
        /**
         * Set client-side interactivity-router data.
         *
         * Once in the browser, the state will be parsed and used to hydrate the client-side
         * interactivity stores and the configuration will be available using a `getConfig` utility.
         *
         * @since 6.7.0
         *
         * @param array $data Data to filter.
         * @return array Data for the Interactivity Router script module.
         */
        public function filter_script_module_interactivity_router_data(array $data) : array
        {
        }
        /**
         * Set client-side interactivity data.
         *
         * Once in the browser, the state will be parsed and used to hydrate the client-side
         * interactivity stores and the configuration will be available using a `getConfig` utility.
         *
         * @since 6.7.0
         *
         * @param array $data Data to filter.
         * @return array Data for the Interactivity API script module.
         */
        public function filter_script_module_interactivity_data(array $data) : array
        {
        }
        /**
         * Returns the latest value on the context stack with the passed namespace.
         *
         * When the namespace is omitted, it uses the current namespace on the
         * namespace stack during a `process_directives` call.
         *
         * @since 6.6.0
         *
         * @param string $store_namespace Optional. The unique store namespace identifier.
         */
        public function get_context(?string $store_namespace = \null) : array
        {
        }
        /**
         * Returns an array representation of the current element being processed.
         *
         * The returned array contains a copy of the element attributes.
         *
         * @since 6.7.0
         *
         * @return array{attributes: array<string, string|bool>}|null Current element.
         */
        public function get_element() : ?array
        {
        }
        /**
         * Registers the `@wordpress/interactivity` script modules.
         *
         * @deprecated 6.7.0 Script Modules registration is handled by {@see wp_default_script_modules()}.
         *
         * @since 6.5.0
         */
        public function register_script_modules()
        {
        }
        /**
         * Adds the necessary hooks for the Interactivity API.
         *
         * @since 6.5.0
         */
        public function add_hooks()
        {
        }
        /**
         * Processes the interactivity directives contained within the HTML content
         * and updates the markup accordingly.
         *
         * @since 6.5.0
         *
         * @param string $html The HTML content to process.
         * @return string The processed HTML content. It returns the original content when the HTML contains unbalanced tags.
         */
        public function process_directives(string $html) : string
        {
        }
        /**
         * Deprecated.
         *
         * @since 6.5.0
         * @deprecated 6.7.0 Use {@see WP_Interactivity_API::print_router_markup} instead.
         */
        public function print_router_loading_and_screen_reader_markup()
        {
        }
        /**
         * Outputs markup for the @wordpress/interactivity-router script module.
         *
         * This method prints a div element representing a loading bar visible during
         * navigation.
         *
         * @since 6.7.0
         */
        public function print_router_markup()
        {
        }
    }
    /**
     * Class WP_Translation_Controller.
     *
     * @since 6.5.0
     */
    final class WP_Translation_Controller
    {
        /**
         * Utility method to retrieve the main instance of the class.
         *
         * The instance will be created if it does not exist yet.
         *
         * @since 6.5.0
         *
         * @return WP_Translation_Controller
         */
        public static function get_instance() : \WP_Translation_Controller
        {
        }
        /**
         * Returns the current locale.
         *
         * @since 6.5.0
         *
         * @return string Locale.
         */
        public function get_locale() : string
        {
        }
        /**
         * Sets the current locale.
         *
         * @since 6.5.0
         *
         * @param string $locale Locale.
         */
        public function set_locale(string $locale)
        {
        }
        /**
         * Loads a translation file for a given text domain.
         *
         * @since 6.5.0
         *
         * @param string $translation_file Translation file.
         * @param string $textdomain       Optional. Text domain. Default 'default'.
         * @param string $locale           Optional. Locale. Default current locale.
         * @return bool True on success, false otherwise.
         */
        public function load_file(string $translation_file, string $textdomain = 'default', ?string $locale = \null) : bool
        {
        }
        /**
         * Unloads a translation file for a given text domain.
         *
         * @since 6.5.0
         *
         * @param WP_Translation_File|string $file       Translation file instance or file name.
         * @param string                     $textdomain Optional. Text domain. Default 'default'.
         * @param string                     $locale     Optional. Locale. Defaults to all locales.
         * @return bool True on success, false otherwise.
         */
        public function unload_file($file, string $textdomain = 'default', ?string $locale = \null) : bool
        {
        }
        /**
         * Unloads all translation files for a given text domain.
         *
         * @since 6.5.0
         *
         * @param string $textdomain Optional. Text domain. Default 'default'.
         * @param string $locale     Optional. Locale. Defaults to all locales.
         * @return bool True on success, false otherwise.
         */
        public function unload_textdomain(string $textdomain = 'default', ?string $locale = \null) : bool
        {
        }
        /**
         * Determines whether translations are loaded for a given text domain.
         *
         * @since 6.5.0
         *
         * @param string $textdomain Optional. Text domain. Default 'default'.
         * @param string $locale     Optional. Locale. Default current locale.
         * @return bool True if there are any loaded translations, false otherwise.
         */
        public function is_textdomain_loaded(string $textdomain = 'default', ?string $locale = \null) : bool
        {
        }
        /**
         * Translates a singular string.
         *
         * @since 6.5.0
         *
         * @param string $text       Text to translate.
         * @param string $context    Optional. Context for the string. Default empty string.
         * @param string $textdomain Optional. Text domain. Default 'default'.
         * @param string $locale     Optional. Locale. Default current locale.
         * @return string|false Translation on success, false otherwise.
         */
        public function translate(string $text, string $context = '', string $textdomain = 'default', ?string $locale = \null)
        {
        }
        /**
         * Translates plurals.
         *
         * Checks both singular+plural combinations as well as just singulars,
         * in case the translation file does not store the plural.
         *
         * @since 6.5.0
         *
         * @param array       $plurals {
         *     Pair of singular and plural translations.
         *
         *     @type string $0 Singular translation.
         *     @type string $1 Plural translation.
         * }
         * @param int         $number     Number of items.
         * @param string      $context    Optional. Context for the string. Default empty string.
         * @param string      $textdomain Optional. Text domain. Default 'default'.
         * @param string|null $locale     Optional. Locale. Default current locale.
         * @return string|false Translation on success, false otherwise.
         * @phpstan-param array{
         *   0: string,
         *   1: string,
         * } $plurals
         */
        public function translate_plural(array $plurals, int $number, string $context = '', string $textdomain = 'default', ?string $locale = \null)
        {
        }
        /**
         * Returns all existing headers for a given text domain.
         *
         * @since 6.5.0
         *
         * @param string $textdomain Optional. Text domain. Default 'default'.
         * @return array<string, string> Headers.
         */
        public function get_headers(string $textdomain = 'default') : array
        {
        }
        /**
         * Returns all entries for a given text domain.
         *
         * @since 6.5.0
         *
         * @param string $textdomain Optional. Text domain. Default 'default'.
         * @return array<string, string> Entries.
         */
        public function get_entries(string $textdomain = 'default') : array
        {
        }
        /**
         * Returns a boolean to indicate whether a translation exists for a given string with optional text domain and locale.
         *
         * @since 6.7.0
         *
         * @param string  $singular   Singular translation to check.
         * @param string  $textdomain Optional. Text domain. Default 'default'.
         * @param ?string $locale     Optional. Locale. Default current locale.
         * @return bool  True if the translation exists, false otherwise.
         */
        public function has_translation(string $singular, string $textdomain = 'default', ?string $locale = \null) : bool
        {
        }
    }
    /**
     * Class WP_Translation_File.
     *
     * @since 6.5.0
     */
    abstract class WP_Translation_File
    {
        /**
         * List of headers.
         *
         * @since 6.5.0
         * @var array<string, string>
         */
        protected $headers = array();
        /**
         * Whether file has been parsed.
         *
         * @since 6.5.0
         * @var bool
         */
        protected $parsed = \false;
        /**
         * Error information.
         *
         * @since 6.5.0
         * @var string|null Error message or null if no error.
         */
        protected $error;
        /**
         * File name.
         *
         * @since 6.5.0
         * @var string
         */
        protected $file = '';
        /**
         * Translation entries.
         *
         * @since 6.5.0
         * @var array<string, string>
         */
        protected $entries = array();
        /**
         * Plural forms function.
         *
         * @since 6.5.0
         * @var callable|null Plural forms.
         */
        protected $plural_forms = \null;
        /**
         * Constructor.
         *
         * @since 6.5.0
         *
         * @param string $file File to load.
         */
        protected function __construct(string $file)
        {
        }
        /**
         * Creates a new WP_Translation_File instance for a given file.
         *
         * @since 6.5.0
         *
         * @param string      $file     File name.
         * @param string|null $filetype Optional. File type. Default inferred from file name.
         * @return false|WP_Translation_File
         */
        public static function create(string $file, ?string $filetype = \null)
        {
        }
        /**
         * Creates a new WP_Translation_File instance for a given file.
         *
         * @since 6.5.0
         *
         * @param string $file     Source file name.
         * @param string $filetype Desired target file type.
         * @return string|false Transformed translation file contents on success, false otherwise.
         */
        public static function transform(string $file, string $filetype)
        {
        }
        /**
         * Returns all headers.
         *
         * @since 6.5.0
         *
         * @return array<string, string> Headers.
         */
        public function headers() : array
        {
        }
        /**
         * Returns all entries.
         *
         * @since 6.5.0
         *
         * @return array<string, string[]> Entries.
         */
        public function entries() : array
        {
        }
        /**
         * Returns the current error information.
         *
         * @since 6.5.0
         *
         * @return string|null Error message or null if no error.
         */
        public function error()
        {
        }
        /**
         * Returns the file name.
         *
         * @since 6.5.0
         *
         * @return string File name.
         */
        public function get_file() : string
        {
        }
        /**
         * Translates a given string.
         *
         * @since 6.5.0
         *
         * @param string $text String to translate.
         * @return false|string Translation(s) on success, false otherwise.
         */
        public function translate(string $text)
        {
        }
        /**
         * Returns the plural form for a given number.
         *
         * @since 6.5.0
         *
         * @param int $number Count.
         * @return int Plural form.
         */
        public function get_plural_form(int $number) : int
        {
        }
        /**
         * Returns the plural forms expression as a tuple.
         *
         * @since 6.5.0
         *
         * @param string $header Plural-Forms header string.
         * @return string Plural forms expression.
         */
        protected function get_plural_expression_from_header(string $header) : string
        {
        }
        /**
         * Makes a function, which will return the right translation index, according to the
         * plural forms header.
         *
         * @since 6.5.0
         *
         * @param string $expression Plural form expression.
         * @return callable(int $num): int Plural forms function.
         */
        protected function make_plural_form_function(string $expression) : callable
        {
        }
        /**
         * Imports translations from another file.
         *
         * @since 6.5.0
         *
         * @param WP_Translation_File $source Source file.
         * @return bool True on success, false otherwise.
         */
        protected function import(\WP_Translation_File $source) : bool
        {
        }
        /**
         * Parses the file.
         *
         * @since 6.5.0
         */
        protected abstract function parse_file();
        /**
         * Exports translation contents as a string.
         *
         * @since 6.5.0
         *
         * @return string Translation file contents.
         */
        public abstract function export();
    }
    /**
     * Class WP_Translation_File_MO.
     *
     * @since 6.5.0
     */
    class WP_Translation_File_MO extends \WP_Translation_File
    {
        /**
         * Endian value.
         *
         * V for little endian, N for big endian, or false.
         *
         * Used for unpack().
         *
         * @since 6.5.0
         * @var false|'V'|'N'
         */
        protected $uint32 = \false;
        /**
         * The magic number of the GNU message catalog format.
         *
         * @since 6.5.0
         * @var int
         */
        const MAGIC_MARKER = 0x950412de;
        /**
         * Detects endian and validates file.
         *
         * @since 6.5.0
         *
         * @param string $header File contents.
         * @return false|'V'|'N' V for little endian, N for big endian, or false on failure.
         */
        protected function detect_endian_and_validate_file(string $header)
        {
        }
        /**
         * Parses the file.
         *
         * @since 6.5.0
         *
         * @return bool True on success, false otherwise.
         */
        protected function parse_file() : bool
        {
        }
        /**
         * Exports translation contents as a string.
         *
         * @since 6.5.0
         *
         * @return string Translation file contents.
         */
        public function export() : string
        {
        }
    }
    /**
     * Class WP_Translation_File_PHP.
     *
     * @since 6.5.0
     */
    class WP_Translation_File_PHP extends \WP_Translation_File
    {
        /**
         * Parses the file.
         *
         * @since 6.5.0
         * @phpstan-return void
         */
        protected function parse_file()
        {
        }
        /**
         * Exports translation contents as a string.
         *
         * @since 6.5.0
         *
         * @return string Translation file contents.
         */
        public function export() : string
        {
        }
    }
    /**
     * Class WP_Translations.
     *
     * @since 6.5.0
     *
     * @property-read array<string, string> $headers
     * @property-read array<string, string[]> $entries
     */
    class WP_Translations
    {
        /**
         * Text domain.
         *
         * @since 6.5.0
         * @var string
         */
        protected $textdomain = 'default';
        /**
         * Translation controller instance.
         *
         * @since 6.5.0
         * @var WP_Translation_Controller
         */
        protected $controller;
        /**
         * Constructor.
         *
         * @since 6.5.0
         *
         * @param WP_Translation_Controller $controller I18N controller.
         * @param string                    $textdomain Optional. Text domain. Default 'default'.
         */
        public function __construct(\WP_Translation_Controller $controller, string $textdomain = 'default')
        {
        }
        /**
         * Magic getter for backward compatibility.
         *
         * @since 6.5.0
         *
         * @param string $name Property name.
         * @return mixed
         */
        public function __get(string $name)
        {
        }
        /**
         * Translates a plural string.
         *
         * @since 6.5.0
         *
         * @param string|null $singular Singular string.
         * @param string|null $plural   Plural string.
         * @param int|float   $count    Count. Should be an integer, but some plugins pass floats.
         * @param string|null $context  Context.
         * @return string|null Translation if it exists, or the unchanged singular string.
         * @phpstan-template T of string|null
         * @phpstan-param T $singular
         * @phpstan-param int $count
         * @phpstan-return ($singular is null ? null : ($plural is null ? T : string))
         */
        public function translate_plural($singular, $plural, $count = 1, $context = '')
        {
        }
        /**
         * Translates a singular string.
         *
         * @since 6.5.0
         *
         * @param string|null $singular Singular string.
         * @param string|null $context  Context.
         * @return string|null Translation if it exists, or the unchanged singular string
         * @phpstan-return ($singular is null ? null : string)
         */
        public function translate($singular, $context = '')
        {
        }
    }
    class wp_atom_server
    {
        public function __call($name, $arguments)
        {
        }
        public static function __callStatic($name, $arguments)
        {
        }
    }
    /**
     * Translation_Entry class encapsulates a translatable string.
     *
     * @since 2.8.0
     */
    #[\AllowDynamicProperties]
    class Translation_Entry
    {
        /**
         * Whether the entry contains a string and its plural form, default is false.
         *
         * @var bool
         */
        public $is_plural = \false;
        public $context = \null;
        public $singular = \null;
        public $plural = \null;
        public $translations = array();
        public $translator_comments = '';
        public $extracted_comments = '';
        public $references = array();
        public $flags = array();
        /**
         * @param array $args {
         *     Arguments array, supports the following keys:
         *
         *     @type string $singular            The string to translate, if omitted an
         *                                       empty entry will be created.
         *     @type string $plural              The plural form of the string, setting
         *                                       this will set `$is_plural` to true.
         *     @type array  $translations        Translations of the string and possibly
         *                                       its plural forms.
         *     @type string $context             A string differentiating two equal strings
         *                                       used in different contexts.
         *     @type string $translator_comments Comments left by translators.
         *     @type string $extracted_comments  Comments left by developers.
         *     @type array  $references          Places in the code this string is used, in
         *                                       relative_to_root_path/file.php:linenum form.
         *     @type array  $flags               Flags like php-format.
         * }
         * @phpstan-param array{
         *   singular?: string,
         *   plural?: string,
         *   translations?: array,
         *   context?: string,
         *   translator_comments?: string,
         *   extracted_comments?: string,
         *   references?: array,
         *   flags?: array,
         * } $args
         * @phpstan-return void
         */
        public function __construct($args = array())
        {
        }
        /**
         * PHP4 constructor.
         *
         * @since 2.8.0
         * @deprecated 5.4.0 Use __construct() instead.
         *
         * @see Translation_Entry::__construct()
         */
        public function Translation_Entry($args = array())
        {
        }
        /**
         * Generates a unique key for this entry.
         *
         * @since 2.8.0
         *
         * @return string|false The key or false if the entry is null.
         */
        public function key()
        {
        }
        /**
         * Merges another translation entry with the current one.
         *
         * @since 2.8.0
         *
         * @param Translation_Entry $other Other translation entry.
         */
        public function merge_with(&$other)
        {
        }
    }
    /**
     * Translations class.
     *
     * @since 2.8.0
     */
    #[\AllowDynamicProperties]
    class Translations
    {
        /**
         * List of translation entries.
         *
         * @since 2.8.0
         *
         * @var Translation_Entry[]
         */
        public $entries = array();
        /**
         * List of translation headers.
         *
         * @since 2.8.0
         *
         * @var array<string, string>
         */
        public $headers = array();
        /**
         * Adds an entry to the PO structure.
         *
         * @since 2.8.0
         *
         * @param array|Translation_Entry $entry
         * @return bool True on success, false if the entry doesn't have a key.
         */
        public function add_entry($entry)
        {
        }
        /**
         * Adds or merges an entry to the PO structure.
         *
         * @since 2.8.0
         *
         * @param array|Translation_Entry $entry
         * @return bool True on success, false if the entry doesn't have a key.
         */
        public function add_entry_or_merge($entry)
        {
        }
        /**
         * Sets $header PO header to $value
         *
         * If the header already exists, it will be overwritten
         *
         * TODO: this should be out of this class, it is gettext specific
         *
         * @since 2.8.0
         *
         * @param string $header header name, without trailing :
         * @param string $value header value, without trailing \n
         */
        public function set_header($header, $value)
        {
        }
        /**
         * Sets translation headers.
         *
         * @since 2.8.0
         *
         * @param array $headers Associative array of headers.
         */
        public function set_headers($headers)
        {
        }
        /**
         * Returns a given translation header.
         *
         * @since 2.8.0
         *
         * @param string $header
         * @return string|false Header if it exists, false otherwise.
         */
        public function get_header($header)
        {
        }
        /**
         * Returns a given translation entry.
         *
         * @since 2.8.0
         *
         * @param Translation_Entry $entry Translation entry.
         * @return Translation_Entry|false Translation entry if it exists, false otherwise.
         */
        public function translate_entry(&$entry)
        {
        }
        /**
         * Translates a singular string.
         *
         * @since 2.8.0
         *
         * @param string $singular
         * @param string $context
         * @return string
         */
        public function translate($singular, $context = \null)
        {
        }
        /**
         * Given the number of items, returns the 0-based index of the plural form to use
         *
         * Here, in the base Translations class, the common logic for English is implemented:
         *  0 if there is one element, 1 otherwise
         *
         * This function should be overridden by the subclasses. For example MO/PO can derive the logic
         * from their headers.
         *
         * @since 2.8.0
         *
         * @param int $count Number of items.
         * @return int Plural form to use.
         */
        public function select_plural_form($count)
        {
        }
        /**
         * Returns the plural forms count.
         *
         * @since 2.8.0
         *
         * @return int Plural forms count.
         */
        public function get_plural_forms_count()
        {
        }
        /**
         * Translates a plural string.
         *
         * @since 2.8.0
         *
         * @param string $singular
         * @param string $plural
         * @param int    $count
         * @param string $context
         * @return string
         */
        public function translate_plural($singular, $plural, $count, $context = \null)
        {
        }
        /**
         * Merges other translations into the current one.
         *
         * @since 2.8.0
         *
         * @param Translations $other Another Translation object, whose translations will be merged in this one (passed by reference).
         */
        public function merge_with(&$other)
        {
        }
        /**
         * Merges originals with existing entries.
         *
         * @since 2.8.0
         *
         * @param Translations $other
         */
        public function merge_originals_with(&$other)
        {
        }
    }
    /**
     * Gettext_Translations class.
     *
     * @since 2.8.0
     */
    class Gettext_Translations extends \Translations
    {
        /**
         * Number of plural forms.
         *
         * @var int
         *
         * @since 2.8.0
         */
        public $_nplurals;
        /**
         * Callback to retrieve the plural form.
         *
         * @var callable
         *
         * @since 2.8.0
         */
        public $_gettext_select_plural_form;
        /**
         * The gettext implementation of select_plural_form.
         *
         * It lives in this class, because there are more than one descendant, which will use it and
         * they can't share it effectively.
         *
         * @since 2.8.0
         *
         * @param int $count Plural forms count.
         * @return int Plural form to use.
         */
        public function gettext_select_plural_form($count)
        {
        }
        /**
         * Returns the nplurals and plural forms expression from the Plural-Forms header.
         *
         * @since 2.8.0
         *
         * @param string $header
         * @return array{0: int, 1: string}
         */
        public function nplurals_and_expression_from_header($header)
        {
        }
        /**
         * Makes a function, which will return the right translation index, according to the
         * plural forms header.
         *
         * @since 2.8.0
         *
         * @param int    $nplurals
         * @param string $expression
         * @return callable
         */
        public function make_plural_form_function($nplurals, $expression)
        {
        }
        /**
         * Adds parentheses to the inner parts of ternary operators in
         * plural expressions, because PHP evaluates ternary operators from left to right
         *
         * @since 2.8.0
         * @deprecated 6.5.0 Use the Plural_Forms class instead.
         *
         * @see Plural_Forms
         *
         * @param string $expression the expression without parentheses
         * @return string the expression with parentheses added
         */
        public function parenthesize_plural_exression($expression)
        {
        }
        /**
         * Prepare translation headers.
         *
         * @since 2.8.0
         *
         * @param string $translation
         * @return array<string, string> Translation headers
         */
        public function make_headers($translation)
        {
        }
        /**
         * Sets translation headers.
         *
         * @since 2.8.0
         *
         * @param string $header
         * @param string $value
         */
        public function set_header($header, $value)
        {
        }
    }
    class MO extends \Gettext_Translations
    {
        /**
         * Number of plural forms.
         *
         * @var int
         */
        public $_nplurals = 2;
        /**
         * Returns the loaded MO file.
         *
         * @return string The loaded MO file.
         */
        public function get_filename()
        {
        }
        /**
         * Fills up with the entries from MO file $filename
         *
         * @param string $filename MO file to load
         * @return bool True if the import from file was successful, otherwise false.
         */
        public function import_from_file($filename)
        {
        }
        /**
         * @param string $filename
         * @return bool
         */
        public function export_to_file($filename)
        {
        }
        /**
         * @return string|false
         */
        public function export()
        {
        }
        /**
         * @param Translation_Entry $entry
         * @return bool
         */
        public function is_entry_good_for_export($entry)
        {
        }
        /**
         * @param resource $fh
         * @return true
         */
        public function export_to_file_handle($fh)
        {
        }
        /**
         * @param Translation_Entry $entry
         * @return string
         */
        public function export_original($entry)
        {
        }
        /**
         * @param Translation_Entry $entry
         * @return string
         */
        public function export_translations($entry)
        {
        }
        /**
         * @return string
         */
        public function export_headers()
        {
        }
        /**
         * @param int $magic
         * @return string|false
         */
        public function get_byteorder($magic)
        {
        }
        /**
         * @param POMO_FileReader $reader
         * @return bool True if the import was successful, otherwise false.
         */
        public function import_from_reader($reader)
        {
        }
        /**
         * Build a Translation_Entry from original string and translation strings,
         * found in a MO file
         *
         * @static
         * @param string $original original string to translate from MO file. Might contain
         *  0x04 as context separator or 0x00 as singular/plural separator
         * @param string $translation translation string from MO file. Might contain
         *  0x00 as a plural translations separator
         * @return Translation_Entry Entry instance.
         */
        public function &make_entry($original, $translation)
        {
        }
        /**
         * @param int $count
         * @return string
         */
        public function select_plural_form($count)
        {
        }
        /**
         * @return int
         */
        public function get_plural_forms_count()
        {
        }
    }
    #[\AllowDynamicProperties]
    class Plural_Forms
    {
        /**
         * Operator characters.
         *
         * @since 4.9.0
         * @var string OP_CHARS Operator characters.
         */
        const OP_CHARS = '|&><!=%?:';
        /**
         * Valid number characters.
         *
         * @since 4.9.0
         * @var string NUM_CHARS Valid number characters.
         */
        const NUM_CHARS = '0123456789';
        /**
         * Operator precedence.
         *
         * Operator precedence from highest to lowest. Higher numbers indicate
         * higher precedence, and are executed first.
         *
         * @see https://en.wikipedia.org/wiki/Operators_in_C_and_C%2B%2B#Operator_precedence
         *
         * @since 4.9.0
         * @var array $op_precedence Operator precedence from highest to lowest.
         */
        protected static $op_precedence = array('%' => 6, '<' => 5, '<=' => 5, '>' => 5, '>=' => 5, '==' => 4, '!=' => 4, '&&' => 3, '||' => 2, '?:' => 1, '?' => 1, '(' => 0, ')' => 0);
        /**
         * Tokens generated from the string.
         *
         * @since 4.9.0
         * @var array $tokens List of tokens.
         */
        protected $tokens = array();
        /**
         * Cache for repeated calls to the function.
         *
         * @since 4.9.0
         * @var array $cache Map of $n => $result
         */
        protected $cache = array();
        /**
         * Constructor.
         *
         * @since 4.9.0
         *
         * @param string $str Plural function (just the bit after `plural=` from Plural-Forms)
         */
        public function __construct($str)
        {
        }
        /**
         * Parse a Plural-Forms string into tokens.
         *
         * Uses the shunting-yard algorithm to convert the string to Reverse Polish
         * Notation tokens.
         *
         * @since 4.9.0
         *
         * @throws Exception If there is a syntax or parsing error with the string.
         *
         * @param string $str String to parse.
         */
        protected function parse($str)
        {
        }
        /**
         * Get the plural form for a number.
         *
         * Caches the value for repeated calls.
         *
         * @since 4.9.0
         *
         * @param int $num Number to get plural form for.
         * @return int Plural form value.
         */
        public function get($num)
        {
        }
        /**
         * Execute the plural form function.
         *
         * @since 4.9.0
         *
         * @throws Exception If the plural form value cannot be calculated.
         *
         * @param int $n Variable "n" to substitute.
         * @return int Plural form value.
         */
        public function execute($n)
        {
        }
    }
    class PO extends \Gettext_Translations
    {
        public $comments_before_headers = '';
        /**
         * Exports headers to a PO entry
         *
         * @return string msgid/msgstr PO entry for this PO file headers, doesn't contain newline at the end
         */
        public function export_headers()
        {
        }
        /**
         * Exports all entries to PO format
         *
         * @return string sequence of msgid/msgstr PO strings, doesn't contain a newline at the end
         */
        public function export_entries()
        {
        }
        /**
         * Exports the whole PO file as a string
         *
         * @param bool $include_headers whether to include the headers in the export
         * @return string ready for inclusion in PO file string for headers and all the entries
         */
        public function export($include_headers = \true)
        {
        }
        /**
         * Same as {@link export}, but writes the result to a file
         *
         * @param string $filename        Where to write the PO string.
         * @param bool   $include_headers Whether to include the headers in the export.
         * @return bool true on success, false on error
         */
        public function export_to_file($filename, $include_headers = \true)
        {
        }
        /**
         * Text to include as a comment before the start of the PO contents
         *
         * Doesn't need to include # in the beginning of lines, these are added automatically
         *
         * @param string $text Text to include as a comment.
         */
        public function set_comment_before_headers($text)
        {
        }
        /**
         * Formats a string in PO-style
         *
         * @param string $input_string the string to format
         * @return string the poified string
         */
        public static function poify($input_string)
        {
        }
        /**
         * Gives back the original string from a PO-formatted string
         *
         * @param string $input_string PO-formatted string
         * @return string unescaped string
         */
        public static function unpoify($input_string)
        {
        }
        /**
         * Inserts $with in the beginning of every new line of $input_string and
         * returns the modified string
         *
         * @param string $input_string prepend lines in this string
         * @param string $with         prepend lines with this string
         */
        public static function prepend_each_line($input_string, $with)
        {
        }
        /**
         * Prepare a text as a comment -- wraps the lines and prepends #
         * and a special character to each line
         *
         * @access private
         * @param string $text the comment text
         * @param string $char character to denote a special PO comment,
         *  like :, default is a space
         */
        public static function comment_block($text, $char = ' ')
        {
        }
        /**
         * Builds a string from the entry for inclusion in PO file
         *
         * @param Translation_Entry $entry the entry to convert to po string.
         * @return string|false PO-style formatted string for the entry or
         *  false if the entry is empty
         */
        public static function export_entry($entry)
        {
        }
        public static function match_begin_and_end_newlines($translation, $original)
        {
        }
        /**
         * @param string $filename
         * @return bool
         */
        public function import_from_file($filename)
        {
        }
        /**
         * Helper function for read_entry
         *
         * @param string $context
         * @return bool
         */
        protected static function is_final($context)
        {
        }
        /**
         * @param resource $f
         * @param int      $lineno
         * @return null|false|array
         */
        public function read_entry($f, $lineno = 0)
        {
        }
        /**
         * @param resource $f
         * @param string   $action
         * @return bool
         */
        public function read_line($f, $action = 'read')
        {
        }
        /**
         * @param Translation_Entry $entry
         * @param string            $po_comment_line
         */
        public function add_comment_to_entry(&$entry, $po_comment_line)
        {
        }
        /**
         * @param string $s
         * @return string
         */
        public static function trim_quotes($s)
        {
        }
    }
    #[\AllowDynamicProperties]
    class POMO_Reader
    {
        public $endian = 'little';
        public $_pos;
        public $is_overloaded;
        /**
         * PHP5 constructor.
         */
        public function __construct()
        {
        }
        /**
         * PHP4 constructor.
         *
         * @deprecated 5.4.0 Use __construct() instead.
         *
         * @see POMO_Reader::__construct()
         */
        public function POMO_Reader()
        {
        }
        /**
         * Sets the endianness of the file.
         *
         * @param string $endian Set the endianness of the file. Accepts 'big', or 'little'.
         * @phpstan-param 'big'|'little' $endian
         */
        public function setEndian($endian)
        {
        }
        /**
         * Reads a 32bit Integer from the Stream
         *
         * @return mixed The integer, corresponding to the next 32 bits from
         *  the stream of false if there are not enough bytes or on error
         */
        public function readint32()
        {
        }
        /**
         * Reads an array of 32-bit Integers from the Stream
         *
         * @param int $count How many elements should be read
         * @return mixed Array of integers or false if there isn't
         *  enough data or on error
         */
        public function readint32array($count)
        {
        }
        /**
         * @param string $input_string
         * @param int    $start
         * @param int    $length
         * @return string
         */
        public function substr($input_string, $start, $length)
        {
        }
        /**
         * @param string $input_string
         * @return int
         */
        public function strlen($input_string)
        {
        }
        /**
         * @param string $input_string
         * @param int    $chunk_size
         * @return array
         */
        public function str_split($input_string, $chunk_size)
        {
        }
        /**
         * @return int
         */
        public function pos()
        {
        }
        /**
         * @return true
         */
        public function is_resource()
        {
        }
        /**
         * @return true
         */
        public function close()
        {
        }
    }
    class POMO_FileReader extends \POMO_Reader
    {
        /**
         * File pointer resource.
         *
         * @var resource|false
         */
        public $_f;
        /**
         * @param string $filename
         */
        public function __construct($filename)
        {
        }
        /**
         * PHP4 constructor.
         *
         * @deprecated 5.4.0 Use __construct() instead.
         *
         * @see POMO_FileReader::__construct()
         */
        public function POMO_FileReader($filename)
        {
        }
        /**
         * @param int $bytes
         * @return string|false Returns read string, otherwise false.
         */
        public function read($bytes)
        {
        }
        /**
         * @param int $pos
         * @return bool
         */
        public function seekto($pos)
        {
        }
        /**
         * @return bool
         */
        public function is_resource()
        {
        }
        /**
         * @return bool
         */
        public function feof()
        {
        }
        /**
         * @return bool
         */
        public function close()
        {
        }
        /**
         * @return string
         */
        public function read_all()
        {
        }
    }
    /**
     * Provides file-like methods for manipulating a string instead
     * of a physical file.
     */
    class POMO_StringReader extends \POMO_Reader
    {
        public $_str = '';
        /**
         * PHP5 constructor.
         */
        public function __construct($str = '')
        {
        }
        /**
         * PHP4 constructor.
         *
         * @deprecated 5.4.0 Use __construct() instead.
         *
         * @see POMO_StringReader::__construct()
         */
        public function POMO_StringReader($str = '')
        {
        }
        /**
         * @param string $bytes
         * @return string
         */
        public function read($bytes)
        {
        }
        /**
         * @param int $pos
         * @return int
         */
        public function seekto($pos)
        {
        }
        /**
         * @return int
         */
        public function length()
        {
        }
        /**
         * @return string
         */
        public function read_all()
        {
        }
    }
    /**
     * Reads the contents of the file in the beginning.
     */
    class POMO_CachedFileReader extends \POMO_StringReader
    {
        /**
         * PHP5 constructor.
         */
        public function __construct($filename)
        {
        }
        /**
         * PHP4 constructor.
         *
         * @deprecated 5.4.0 Use __construct() instead.
         *
         * @see POMO_CachedFileReader::__construct()
         */
        public function POMO_CachedFileReader($filename)
        {
        }
    }
    /**
     * Reads the contents of the file in the beginning.
     */
    class POMO_CachedIntFileReader extends \POMO_CachedFileReader
    {
        /**
         * PHP5 constructor.
         */
        public function __construct($filename)
        {
        }
        /**
         * PHP4 constructor.
         *
         * @deprecated 5.4.0 Use __construct() instead.
         *
         * @see POMO_CachedIntFileReader::__construct()
         */
        public function POMO_CachedIntFileReader($filename)
        {
        }
    }
    /**
     * Provides the same interface as Translations, but doesn't do anything.
     *
     * @since 2.8.0
     */
    #[\AllowDynamicProperties]
    class NOOP_Translations
    {
        /**
         * List of translation entries.
         *
         * @since 2.8.0
         *
         * @var Translation_Entry[]
         */
        public $entries = array();
        /**
         * List of translation headers.
         *
         * @since 2.8.0
         *
         * @var array<string, string>
         */
        public $headers = array();
        public function add_entry($entry)
        {
        }
        /**
         * Sets a translation header.
         *
         * @since 2.8.0
         *
         * @param string $header
         * @param string $value
         */
        public function set_header($header, $value)
        {
        }
        /**
         * Sets translation headers.
         *
         * @since 2.8.0
         *
         * @param array $headers
         */
        public function set_headers($headers)
        {
        }
        /**
         * Returns a translation header.
         *
         * @since 2.8.0
         *
         * @param string $header
         * @return false
         */
        public function get_header($header)
        {
        }
        /**
         * Returns a given translation entry.
         *
         * @since 2.8.0
         *
         * @param Translation_Entry $entry
         * @return false
         */
        public function translate_entry(&$entry)
        {
        }
        /**
         * Translates a singular string.
         *
         * @since 2.8.0
         *
         * @param string $singular
         * @param string $context
         */
        public function translate($singular, $context = \null)
        {
        }
        /**
         * Returns the plural form to use.
         *
         * @since 2.8.0
         *
         * @param int $count
         * @return int
         */
        public function select_plural_form($count)
        {
        }
        /**
         * Returns the plural forms count.
         *
         * @since 2.8.0
         *
         * @return int
         */
        public function get_plural_forms_count()
        {
        }
        /**
         * Translates a plural string.
         *
         * @since 2.8.0
         *
         * @param string $singular
         * @param string $plural
         * @param int    $count
         * @param string $context
         * @return string
         */
        public function translate_plural($singular, $plural, $count, $context = \null)
        {
        }
        /**
         * Merges other translations into the current one.
         *
         * @since 2.8.0
         *
         * @param Translations $other
         */
        public function merge_with(&$other)
        {
        }
    }
    /**
     * Core class used to implement a REST request object.
     *
     * Contains data from the request, to be passed to the callback.
     *
     * Note: This implements ArrayAccess, and acts as an array of parameters when
     * used in that manner. It does not use ArrayObject (as we cannot rely on SPL),
     * so be aware it may have non-array behavior in some cases.
     *
     * Note: When using features provided by ArrayAccess, be aware that WordPress deliberately
     * does not distinguish between arguments of the same name for different request methods.
     * For instance, in a request with `GET id=1` and `POST id=2`, `$request['id']` will equal
     * 2 (`POST`) not 1 (`GET`). For more precision between request methods, use
     * WP_REST_Request::get_body_params(), WP_REST_Request::get_url_params(), etc.
     *
     * @since 4.4.0
     *
     * @link https://www.php.net/manual/en/class.arrayaccess.php
     * @phpstan-template T of array
     * @phpstan-implements ArrayAccess<key-of<T>, value-of<T>>
     */
    #[\AllowDynamicProperties]
    class WP_REST_Request implements \ArrayAccess
    {
        /**
         * HTTP method.
         *
         * @since 4.4.0
         * @var string
         */
        protected $method = '';
        /**
         * Parameters passed to the request.
         *
         * These typically come from the `$_GET`, `$_POST` and `$_FILES`
         * superglobals when being created from the global scope.
         *
         * @since 4.4.0
         * @var array Contains GET, POST and FILES keys mapping to arrays of data.
         */
        protected $params;
        /**
         * HTTP headers for the request.
         *
         * @since 4.4.0
         * @var array Map of key to value. Key is always lowercase, as per HTTP specification.
         */
        protected $headers = array();
        /**
         * Body data.
         *
         * @since 4.4.0
         * @var string Binary data from the request.
         */
        protected $body = \null;
        /**
         * Route matched for the request.
         *
         * @since 4.4.0
         * @var string
         */
        protected $route;
        /**
         * Attributes (options) for the route that was matched.
         *
         * This is the options array used when the route was registered, typically
         * containing the callback as well as the valid methods for the route.
         *
         * @since 4.4.0
         * @var array Attributes for the request.
         */
        protected $attributes = array();
        /**
         * Used to determine if the JSON data has been parsed yet.
         *
         * Allows lazy-parsing of JSON data where possible.
         *
         * @since 4.4.0
         * @var bool
         */
        protected $parsed_json = \false;
        /**
         * Used to determine if the body data has been parsed yet.
         *
         * @since 4.4.0
         * @var bool
         */
        protected $parsed_body = \false;
        /**
         * Constructor.
         *
         * @since 4.4.0
         *
         * @param string $method     Optional. Request method. Default empty.
         * @param string $route      Optional. Request route. Default empty.
         * @param array  $attributes Optional. Request attributes. Default empty array.
         */
        public function __construct($method = '', $route = '', $attributes = array())
        {
        }
        /**
         * Retrieves the HTTP method for the request.
         *
         * @since 4.4.0
         *
         * @return string HTTP method.
         */
        public function get_method()
        {
        }
        /**
         * Sets HTTP method for the request.
         *
         * @since 4.4.0
         *
         * @param string $method HTTP method.
         */
        public function set_method($method)
        {
        }
        /**
         * Retrieves all headers from the request.
         *
         * @since 4.4.0
         *
         * @return array Map of key to value. Key is always lowercase, as per HTTP specification.
         */
        public function get_headers()
        {
        }
        /**
         * Canonicalizes the header name.
         *
         * Ensures that header names are always treated the same regardless of
         * source. Header names are always case-insensitive.
         *
         * Note that we treat `-` (dashes) and `_` (underscores) as the same
         * character, as per header parsing rules in both Apache and nginx.
         *
         * @link https://stackoverflow.com/q/18185366
         * @link https://www.nginx.com/resources/wiki/start/topics/tutorials/config_pitfalls/#missing-disappearing-http-headers
         * @link https://nginx.org/en/docs/http/ngx_http_core_module.html#underscores_in_headers
         *
         * @since 4.4.0
         *
         * @param string $key Header name.
         * @return string Canonicalized name.
         */
        public static function canonicalize_header_name($key)
        {
        }
        /**
         * Retrieves the given header from the request.
         *
         * If the header has multiple values, they will be concatenated with a comma
         * as per the HTTP specification. Be aware that some non-compliant headers
         * (notably cookie headers) cannot be joined this way.
         *
         * @since 4.4.0
         *
         * @param string $key Header name, will be canonicalized to lowercase.
         * @return string|null String value if set, null otherwise.
         */
        public function get_header($key)
        {
        }
        /**
         * Retrieves header values from the request.
         *
         * @since 4.4.0
         *
         * @param string $key Header name, will be canonicalized to lowercase.
         * @return array|null List of string values if set, null otherwise.
         */
        public function get_header_as_array($key)
        {
        }
        /**
         * Sets the header on request.
         *
         * @since 4.4.0
         *
         * @param string $key   Header name.
         * @param string $value Header value, or list of values.
         */
        public function set_header($key, $value)
        {
        }
        /**
         * Appends a header value for the given header.
         *
         * @since 4.4.0
         *
         * @param string $key   Header name.
         * @param string $value Header value, or list of values.
         */
        public function add_header($key, $value)
        {
        }
        /**
         * Removes all values for a header.
         *
         * @since 4.4.0
         *
         * @param string $key Header name.
         */
        public function remove_header($key)
        {
        }
        /**
         * Sets headers on the request.
         *
         * @since 4.4.0
         *
         * @param array $headers  Map of header name to value.
         * @param bool  $override If true, replace the request's headers. Otherwise, merge with existing.
         */
        public function set_headers($headers, $override = \true)
        {
        }
        /**
         * Retrieves the Content-Type of the request.
         *
         * @since 4.4.0
         *
         * @return array|null Map containing 'value' and 'parameters' keys
         *                    or null when no valid Content-Type header was
         *                    available.
         */
        public function get_content_type()
        {
        }
        /**
         * Checks if the request has specified a JSON Content-Type.
         *
         * @since 5.6.0
         *
         * @return bool True if the Content-Type header is JSON.
         */
        public function is_json_content_type()
        {
        }
        /**
         * Retrieves the parameter priority order.
         *
         * Used when checking parameters in WP_REST_Request::get_param().
         *
         * @since 4.4.0
         *
         * @return string[] Array of types to check, in order of priority.
         */
        protected function get_parameter_order()
        {
        }
        /**
         * Retrieves a parameter from the request.
         *
         * @since 4.4.0
         *
         * @param string $key Parameter name.
         * @return mixed|null Value if set, null otherwise.
         * @phpstan-template TOffset of key-of<T>
         * @phpstan-param TOffset $key
         * @phpstan-return T[TOffset]|null
         */
        public function get_param($key)
        {
        }
        /**
         * Checks if a parameter exists in the request.
         *
         * This allows distinguishing between an omitted parameter,
         * and a parameter specifically set to null.
         *
         * @since 5.3.0
         *
         * @param string $key Parameter name.
         * @return bool True if a param exists for the given key.
         * @phpstan-param key-of<T> $key
         */
        public function has_param($key)
        {
        }
        /**
         * Sets a parameter on the request.
         *
         * If the given parameter key exists in any parameter type an update will take place,
         * otherwise a new param will be created in the first parameter type (respecting
         * get_parameter_order()).
         *
         * @since 4.4.0
         *
         * @param string $key   Parameter name.
         * @param mixed  $value Parameter value.
         * @phpstan-template TOffset of key-of<T>
         * @phpstan-param TOffset $key
         * @phpstan-param T[TOffset] $value
         * @phpstan-return void
         */
        public function set_param($key, $value)
        {
        }
        /**
         * Retrieves merged parameters from the request.
         *
         * The equivalent of get_param(), but returns all parameters for the request.
         * Handles merging all the available values into a single array.
         *
         * @since 4.4.0
         *
         * @return array Map of key to value.
         * @phpstan-return T
         */
        public function get_params()
        {
        }
        /**
         * Retrieves parameters from the route itself.
         *
         * These are parsed from the URL using the regex.
         *
         * @since 4.4.0
         *
         * @return array Parameter map of key to value.
         */
        public function get_url_params()
        {
        }
        /**
         * Sets parameters from the route.
         *
         * Typically, this is set after parsing the URL.
         *
         * @since 4.4.0
         *
         * @param array $params Parameter map of key to value.
         */
        public function set_url_params($params)
        {
        }
        /**
         * Retrieves parameters from the query string.
         *
         * These are the parameters you'd typically find in `$_GET`.
         *
         * @since 4.4.0
         *
         * @return array Parameter map of key to value
         */
        public function get_query_params()
        {
        }
        /**
         * Sets parameters from the query string.
         *
         * Typically, this is set from `$_GET`.
         *
         * @since 4.4.0
         *
         * @param array $params Parameter map of key to value.
         */
        public function set_query_params($params)
        {
        }
        /**
         * Retrieves parameters from the body.
         *
         * These are the parameters you'd typically find in `$_POST`.
         *
         * @since 4.4.0
         *
         * @return array Parameter map of key to value.
         */
        public function get_body_params()
        {
        }
        /**
         * Sets parameters from the body.
         *
         * Typically, this is set from `$_POST`.
         *
         * @since 4.4.0
         *
         * @param array $params Parameter map of key to value.
         */
        public function set_body_params($params)
        {
        }
        /**
         * Retrieves multipart file parameters from the body.
         *
         * These are the parameters you'd typically find in `$_FILES`.
         *
         * @since 4.4.0
         *
         * @return array Parameter map of key to value
         */
        public function get_file_params()
        {
        }
        /**
         * Sets multipart file parameters from the body.
         *
         * Typically, this is set from `$_FILES`.
         *
         * @since 4.4.0
         *
         * @param array $params Parameter map of key to value.
         */
        public function set_file_params($params)
        {
        }
        /**
         * Retrieves the default parameters.
         *
         * These are the parameters set in the route registration.
         *
         * @since 4.4.0
         *
         * @return array Parameter map of key to value
         */
        public function get_default_params()
        {
        }
        /**
         * Sets default parameters.
         *
         * These are the parameters set in the route registration.
         *
         * @since 4.4.0
         *
         * @param array $params Parameter map of key to value.
         */
        public function set_default_params($params)
        {
        }
        /**
         * Retrieves the request body content.
         *
         * @since 4.4.0
         *
         * @return string Binary data from the request body.
         */
        public function get_body()
        {
        }
        /**
         * Sets body content.
         *
         * @since 4.4.0
         *
         * @param string $data Binary data from the request body.
         */
        public function set_body($data)
        {
        }
        /**
         * Retrieves the parameters from a JSON-formatted body.
         *
         * @since 4.4.0
         *
         * @return array Parameter map of key to value.
         */
        public function get_json_params()
        {
        }
        /**
         * Parses the JSON parameters.
         *
         * Avoids parsing the JSON data until we need to access it.
         *
         * @since 4.4.0
         * @since 4.7.0 Returns error instance if value cannot be decoded.
         * @return true|WP_Error True if the JSON data was passed or no JSON data was provided, WP_Error if invalid JSON was passed.
         */
        protected function parse_json_params()
        {
        }
        /**
         * Parses the request body parameters.
         *
         * Parses out URL-encoded bodies for request methods that aren't supported
         * natively by PHP.
         *
         * @since 4.4.0
         * @phpstan-return void
         */
        protected function parse_body_params()
        {
        }
        /**
         * Retrieves the route that matched the request.
         *
         * @since 4.4.0
         *
         * @return string Route matching regex.
         */
        public function get_route()
        {
        }
        /**
         * Sets the route that matched the request.
         *
         * @since 4.4.0
         *
         * @param string $route Route matching regex.
         */
        public function set_route($route)
        {
        }
        /**
         * Retrieves the attributes for the request.
         *
         * These are the options for the route that was matched.
         *
         * @since 4.4.0
         *
         * @return array Attributes for the request.
         */
        public function get_attributes()
        {
        }
        /**
         * Sets the attributes for the request.
         *
         * @since 4.4.0
         *
         * @param array $attributes Attributes for the request.
         */
        public function set_attributes($attributes)
        {
        }
        /**
         * Sanitizes (where possible) the params on the request.
         *
         * This is primarily based off the sanitize_callback param on each registered
         * argument.
         *
         * @since 4.4.0
         *
         * @return true|WP_Error True if parameters were sanitized, WP_Error if an error occurred during sanitization.
         */
        public function sanitize_params()
        {
        }
        /**
         * Checks whether this request is valid according to its attributes.
         *
         * @since 4.4.0
         *
         * @return true|WP_Error True if there are no parameters to validate or if all pass validation,
         *                       WP_Error if required parameters are missing.
         */
        public function has_valid_params()
        {
        }
        /**
         * Checks if a parameter is set.
         *
         * @since 4.4.0
         *
         * @param string $offset Parameter name.
         * @return bool Whether the parameter is set.
         * @phpstan-param key-of<T> $offset
         */
        #[\ReturnTypeWillChange]
        public function offsetExists($offset)
        {
        }
        /**
         * Retrieves a parameter from the request.
         *
         * @since 4.4.0
         *
         * @param string $offset Parameter name.
         * @return mixed|null Value if set, null otherwise.
         * @phpstan-template TOffset of key-of<T>
         * @phpstan-param TOffset $offset
         * @phpstan-return T[TOffset]|null
         */
        #[\ReturnTypeWillChange]
        public function offsetGet($offset)
        {
        }
        /**
         * Sets a parameter on the request.
         *
         * @since 4.4.0
         *
         * @param string $offset Parameter name.
         * @param mixed  $value  Parameter value.
         * @phpstan-template TOffset of key-of<T>
         * @phpstan-param TOffset $offset
         * @phpstan-param T[TOffset] $value
         * @phpstan-return void
         */
        #[\ReturnTypeWillChange]
        public function offsetSet($offset, $value)
        {
        }
        /**
         * Removes a parameter from the request.
         *
         * @since 4.4.0
         *
         * @param string $offset Parameter name.
         * @phpstan-template TOffset of key-of<T>
         * @phpstan-param TOffset $offset
         * @phpstan-return void
         */
        #[\ReturnTypeWillChange]
        public function offsetUnset($offset)
        {
        }
        /**
         * Retrieves a WP_REST_Request object from a full URL.
         *
         * @since 4.5.0
         *
         * @param string $url URL with protocol, domain, path and query args.
         * @return WP_REST_Request|false WP_REST_Request object on success, false on failure.
         */
        public static function from_url($url)
        {
        }
    }
    /**
     * Core class used to implement a REST response object.
     *
     * @since 4.4.0
     *
     * @see WP_HTTP_Response
     */
    class WP_REST_Response extends \WP_HTTP_Response
    {
        /**
         * Links related to the response.
         *
         * @since 4.4.0
         * @var array
         */
        protected $links = array();
        /**
         * The route that was to create the response.
         *
         * @since 4.4.0
         * @var string
         */
        protected $matched_route = '';
        /**
         * The handler that was used to create the response.
         *
         * @since 4.4.0
         * @var null|array
         */
        protected $matched_handler = \null;
        /**
         * Adds a link to the response.
         *
         * @internal The $rel parameter is first, as this looks nicer when sending multiple.
         *
         * @since 4.4.0
         *
         * @link https://tools.ietf.org/html/rfc5988
         * @link https://www.iana.org/assignments/link-relations/link-relations.xml
         *
         * @param string $rel        Link relation. Either an IANA registered type,
         *                           or an absolute URL.
         * @param string $href       Target URI for the link.
         * @param array  $attributes Optional. Link parameters to send along with the URL. Default empty array.
         */
        public function add_link($rel, $href, $attributes = array())
        {
        }
        /**
         * Removes a link from the response.
         *
         * @since 4.4.0
         *
         * @param string $rel  Link relation. Either an IANA registered type, or an absolute URL.
         * @param string $href Optional. Only remove links for the relation matching the given href.
         *                     Default null.
         * @phpstan-return void
         */
        public function remove_link($rel, $href = \null)
        {
        }
        /**
         * Adds multiple links to the response.
         *
         * Link data should be an associative array with link relation as the key.
         * The value can either be an associative array of link attributes
         * (including `href` with the URL for the response), or a list of these
         * associative arrays.
         *
         * @since 4.4.0
         *
         * @param array $links Map of link relation to list of links.
         */
        public function add_links($links)
        {
        }
        /**
         * Retrieves links for the response.
         *
         * @since 4.4.0
         *
         * @return array List of links.
         */
        public function get_links()
        {
        }
        /**
         * Sets a single link header.
         *
         * @internal The $rel parameter is first, as this looks nicer when sending multiple.
         *
         * @since 4.4.0
         *
         * @link https://tools.ietf.org/html/rfc5988
         * @link https://www.iana.org/assignments/link-relations/link-relations.xml
         *
         * @param string $rel   Link relation. Either an IANA registered type, or an absolute URL.
         * @param string $link  Target IRI for the link.
         * @param array  $other Optional. Other parameters to send, as an associative array.
         *                      Default empty array.
         */
        public function link_header($rel, $link, $other = array())
        {
        }
        /**
         * Retrieves the route that was used.
         *
         * @since 4.4.0
         *
         * @return string The matched route.
         */
        public function get_matched_route()
        {
        }
        /**
         * Sets the route (regex for path) that caused the response.
         *
         * @since 4.4.0
         *
         * @param string $route Route name.
         */
        public function set_matched_route($route)
        {
        }
        /**
         * Retrieves the handler that was used to generate the response.
         *
         * @since 4.4.0
         *
         * @return null|array The handler that was used to create the response.
         */
        public function get_matched_handler()
        {
        }
        /**
         * Sets the handler that was responsible for generating the response.
         *
         * @since 4.4.0
         *
         * @param array $handler The matched handler.
         */
        public function set_matched_handler($handler)
        {
        }
        /**
         * Checks if the response is an error, i.e. >= 400 response code.
         *
         * @since 4.4.0
         *
         * @return bool Whether the response is an error.
         */
        public function is_error()
        {
        }
        /**
         * Retrieves a WP_Error object from the response.
         *
         * @since 4.4.0
         *
         * @return WP_Error|null WP_Error or null on not an errored response.
         */
        public function as_error()
        {
        }
        /**
         * Retrieves the CURIEs (compact URIs) used for relations.
         *
         * @since 4.5.0
         *
         * @return array Compact URIs.
         */
        public function get_curies()
        {
        }
    }
    /**
     * Core class used to implement the WordPress REST API server.
     *
     * @since 4.4.0
     */
    #[\AllowDynamicProperties]
    class WP_REST_Server
    {
        /**
         * Alias for GET transport method.
         *
         * @since 4.4.0
         * @var string
         */
        const READABLE = 'GET';
        /**
         * Alias for POST transport method.
         *
         * @since 4.4.0
         * @var string
         */
        const CREATABLE = 'POST';
        /**
         * Alias for POST, PUT, PATCH transport methods together.
         *
         * @since 4.4.0
         * @var string
         */
        const EDITABLE = 'POST, PUT, PATCH';
        /**
         * Alias for DELETE transport method.
         *
         * @since 4.4.0
         * @var string
         */
        const DELETABLE = 'DELETE';
        /**
         * Alias for GET, POST, PUT, PATCH & DELETE transport methods together.
         *
         * @since 4.4.0
         * @var string
         */
        const ALLMETHODS = 'GET, POST, PUT, PATCH, DELETE';
        /**
         * Namespaces registered to the server.
         *
         * @since 4.4.0
         * @var array
         */
        protected $namespaces = array();
        /**
         * Endpoints registered to the server.
         *
         * @since 4.4.0
         * @var array
         */
        protected $endpoints = array();
        /**
         * Options defined for the routes.
         *
         * @since 4.4.0
         * @var array
         */
        protected $route_options = array();
        /**
         * Caches embedded requests.
         *
         * @since 5.4.0
         * @var array
         */
        protected $embed_cache = array();
        /**
         * Stores request objects that are currently being handled.
         *
         * @since 6.5.0
         * @var array
         */
        protected $dispatching_requests = array();
        /**
         * Instantiates the REST server.
         *
         * @since 4.4.0
         */
        public function __construct()
        {
        }
        /**
         * Checks the authentication headers if supplied.
         *
         * @since 4.4.0
         *
         * @return WP_Error|null|true WP_Error indicates unsuccessful login, null indicates successful
         *                            or no authentication provided
         */
        public function check_authentication()
        {
        }
        /**
         * Converts an error to a response object.
         *
         * This iterates over all error codes and messages to change it into a flat
         * array. This enables simpler client behavior, as it is represented as a
         * list in JSON rather than an object/map.
         *
         * @since 4.4.0
         * @since 5.7.0 Converted to a wrapper of {@see rest_convert_error_to_response()}.
         *
         * @param WP_Error $error WP_Error instance.
         * @return WP_REST_Response List of associative arrays with code and message keys.
         */
        protected function error_to_response($error)
        {
        }
        /**
         * Retrieves an appropriate error representation in JSON.
         *
         * Note: This should only be used in WP_REST_Server::serve_request(), as it
         * cannot handle WP_Error internally. All callbacks and other internal methods
         * should instead return a WP_Error with the data set to an array that includes
         * a 'status' key, with the value being the HTTP status to send.
         *
         * @since 4.4.0
         *
         * @param string $code    WP_Error-style code.
         * @param string $message Human-readable message.
         * @param int    $status  Optional. HTTP status code to send. Default null.
         * @return string JSON representation of the error
         */
        protected function json_error($code, $message, $status = \null)
        {
        }
        /**
         * Gets the encoding options passed to {@see wp_json_encode}.
         *
         * @since 6.1.0
         *
         * @param \WP_REST_Request $request The current request object.
         *
         * @return int The JSON encode options.
         */
        protected function get_json_encode_options(\WP_REST_Request $request)
        {
        }
        /**
         * Handles serving a REST API request.
         *
         * Matches the current server URI to a route and runs the first matching
         * callback then outputs a JSON representation of the returned value.
         *
         * @since 4.4.0
         *
         * @see WP_REST_Server::dispatch()
         *
         * @global WP_User $current_user The currently authenticated user.
         *
         * @param string $path Optional. The request route. If not set, `$_SERVER['PATH_INFO']` will be used.
         *                     Default null.
         * @return null|false Null if not served and a HEAD request, false otherwise.
         */
        public function serve_request($path = \null)
        {
        }
        /**
         * Converts a response to data to send.
         *
         * @since 4.4.0
         * @since 5.4.0 The `$embed` parameter can now contain a list of link relations to include.
         *
         * @param WP_REST_Response $response Response object.
         * @param bool|string[]    $embed    Whether to embed all links, a filtered list of link relations, or no links.
         * @return array {
         *     Data with sub-requests embedded.
         *
         *     @type array $_links    Links.
         *     @type array $_embedded Embedded objects.
         * }
         * @phpstan-return array{
         *   _links: array,
         *   _embedded: array,
         * }
         */
        public function response_to_data($response, $embed)
        {
        }
        /**
         * Retrieves links from a response.
         *
         * Extracts the links from a response into a structured hash, suitable for
         * direct output.
         *
         * @since 4.4.0
         *
         * @param WP_REST_Response $response Response to extract links from.
         * @return array Map of link relation to list of link hashes.
         */
        public static function get_response_links($response)
        {
        }
        /**
         * Gets the target links for a REST API Link.
         *
         * @since 6.7.0
         *
         * @param array $link
         *
         * @return array|null
         */
        protected static function get_target_hints_for_link($link)
        {
        }
        /**
         * Retrieves the CURIEs (compact URIs) used for relations.
         *
         * Extracts the links from a response into a structured hash, suitable for
         * direct output.
         *
         * @since 4.5.0
         *
         * @param WP_REST_Response $response Response to extract links from.
         * @return array Map of link relation to list of link hashes.
         */
        public static function get_compact_response_links($response)
        {
        }
        /**
         * Embeds the links from the data into the request.
         *
         * @since 4.4.0
         * @since 5.4.0 The `$embed` parameter can now contain a list of link relations to include.
         *
         * @param array         $data  Data from the request.
         * @param bool|string[] $embed Whether to embed all links or a filtered list of link relations.
         * @return array {
         *     Data with sub-requests embedded.
         *
         *     @type array $_links    Links.
         *     @type array $_embedded Embedded objects.
         * }
         * @phpstan-return array{
         *   _links: array,
         *   _embedded: array,
         * }
         */
        protected function embed_links($data, $embed = \true)
        {
        }
        /**
         * Wraps the response in an envelope.
         *
         * The enveloping technique is used to work around browser/client
         * compatibility issues. Essentially, it converts the full HTTP response to
         * data instead.
         *
         * @since 4.4.0
         * @since 6.0.0 The `$embed` parameter can now contain a list of link relations to include.
         *
         * @param WP_REST_Response $response Response object.
         * @param bool|string[]    $embed    Whether to embed all links, a filtered list of link relations, or no links.
         * @return WP_REST_Response New response with wrapped data
         */
        public function envelope_response($response, $embed)
        {
        }
        /**
         * Registers a route to the server.
         *
         * @since 4.4.0
         *
         * @param string $route_namespace Namespace.
         * @param string $route           The REST route.
         * @param array  $route_args      Route arguments.
         * @param bool   $override        Optional. Whether the route should be overridden if it already exists.
         *                                Default false.
         */
        public function register_route($route_namespace, $route, $route_args, $override = \false)
        {
        }
        /**
         * Retrieves the route map.
         *
         * The route map is an associative array with path regexes as the keys. The
         * value is an indexed array with the callback function/method as the first
         * item, and a bitmask of HTTP methods as the second item (see the class
         * constants).
         *
         * Each route can be mapped to more than one callback by using an array of
         * the indexed arrays. This allows mapping e.g. GET requests to one callback
         * and POST requests to another.
         *
         * Note that the path regexes (array keys) must have @ escaped, as this is
         * used as the delimiter with preg_match()
         *
         * @since 4.4.0
         * @since 5.4.0 Added `$route_namespace` parameter.
         *
         * @param string $route_namespace Optionally, only return routes in the given namespace.
         * @return array `'/path/regex' => array( $callback, $bitmask )` or
         *               `'/path/regex' => array( array( $callback, $bitmask ), ...)`.
         */
        public function get_routes($route_namespace = '')
        {
        }
        /**
         * Retrieves namespaces registered on the server.
         *
         * @since 4.4.0
         *
         * @return string[] List of registered namespaces.
         */
        public function get_namespaces()
        {
        }
        /**
         * Retrieves specified options for a route.
         *
         * @since 4.4.0
         *
         * @param string $route Route pattern to fetch options for.
         * @return array|null Data as an associative array if found, or null if not found.
         */
        public function get_route_options($route)
        {
        }
        /**
         * Matches the request to a callback and call it.
         *
         * @since 4.4.0
         *
         * @param WP_REST_Request $request Request to attempt dispatching.
         * @return WP_REST_Response Response returned by the callback.
         */
        public function dispatch($request)
        {
        }
        /**
         * Returns whether the REST server is currently dispatching / responding to a request.
         *
         * This may be a standalone REST API request, or an internal request dispatched from within a regular page load.
         *
         * @since 6.5.0
         *
         * @return bool Whether the REST server is currently handling a request.
         */
        public function is_dispatching()
        {
        }
        /**
         * Matches a request object to its handler.
         *
         * @access private
         * @since 5.6.0
         *
         * @param WP_REST_Request $request The request object.
         * @return array|WP_Error The route and request handler on success or a WP_Error instance if no handler was found.
         */
        protected function match_request_to_handler($request)
        {
        }
        /**
         * Dispatches the request to the callback handler.
         *
         * @access private
         * @since 5.6.0
         *
         * @param WP_REST_Request $request  The request object.
         * @param string          $route    The matched route regex.
         * @param array           $handler  The matched route handler.
         * @param WP_Error|null   $response The current error object if any.
         * @return WP_REST_Response
         */
        protected function respond_to_request($request, $route, $handler, $response)
        {
        }
        /**
         * Returns if an error occurred during most recent JSON encode/decode.
         *
         * Strings to be translated will be in format like
         * "Encoding error: Maximum stack depth exceeded".
         *
         * @since 4.4.0
         *
         * @return false|string Boolean false or string error message.
         */
        protected function get_json_last_error()
        {
        }
        /**
         * Retrieves the site index.
         *
         * This endpoint describes the capabilities of the site.
         *
         * @since 4.4.0
         *
         * @param array $request {
         *     Request.
         *
         *     @type string $context Context.
         * }
         * @return WP_REST_Response The API root index data.
         * @phpstan-param array{
         *   context?: string,
         * } $request
         */
        public function get_index($request)
        {
        }
        /**
         * Adds a link to the active theme for users who have proper permissions.
         *
         * @since 5.7.0
         *
         * @param WP_REST_Response $response REST API response.
         */
        protected function add_active_theme_link_to_index(\WP_REST_Response $response)
        {
        }
        /**
         * Exposes the site logo through the WordPress REST API.
         *
         * This is used for fetching this information when user has no rights
         * to update settings.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Response $response REST API response.
         */
        protected function add_site_logo_to_index(\WP_REST_Response $response)
        {
        }
        /**
         * Exposes the site icon through the WordPress REST API.
         *
         * This is used for fetching this information when user has no rights
         * to update settings.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Response $response REST API response.
         */
        protected function add_site_icon_to_index(\WP_REST_Response $response)
        {
        }
        /**
         * Exposes an image through the WordPress REST API.
         * This is used for fetching this information when user has no rights
         * to update settings.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Response $response REST API response.
         * @param int              $image_id Image attachment ID.
         * @param string           $type     Type of Image.
         */
        protected function add_image_to_index(\WP_REST_Response $response, $image_id, $type)
        {
        }
        /**
         * Retrieves the index for a namespace.
         *
         * @since 4.4.0
         *
         * @param WP_REST_Request $request REST request instance.
         * @return WP_REST_Response|WP_Error WP_REST_Response instance if the index was found,
         *                                   WP_Error if the namespace isn't set.
         */
        public function get_namespace_index($request)
        {
        }
        /**
         * Retrieves the publicly-visible data for routes.
         *
         * @since 4.4.0
         *
         * @param array  $routes  Routes to get data for.
         * @param string $context Optional. Context for data. Accepts 'view' or 'help'. Default 'view'.
         * @return array[] Route data to expose in indexes, keyed by route.
         * @phpstan-param 'view'|'help' $context
         */
        public function get_data_for_routes($routes, $context = 'view')
        {
        }
        /**
         * Retrieves publicly-visible data for the route.
         *
         * @since 4.4.0
         *
         * @param string $route     Route to get data for.
         * @param array  $callbacks Callbacks to convert to data.
         * @param string $context   Optional. Context for the data. Accepts 'view' or 'help'. Default 'view'.
         * @return array|null Data for the route, or null if no publicly-visible data.
         * @phpstan-param 'view'|'help' $context
         */
        public function get_data_for_route($route, $callbacks, $context = 'view')
        {
        }
        /**
         * Gets the maximum number of requests that can be included in a batch.
         *
         * @since 5.6.0
         *
         * @return int The maximum requests.
         */
        protected function get_max_batch_size()
        {
        }
        /**
         * Serves the batch/v1 request.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $batch_request The batch request object.
         * @return WP_REST_Response The generated response object.
         */
        public function serve_batch_request_v1(\WP_REST_Request $batch_request)
        {
        }
        /**
         * Sends an HTTP status code.
         *
         * @since 4.4.0
         *
         * @param int $code HTTP status.
         */
        protected function set_status($code)
        {
        }
        /**
         * Sends an HTTP header.
         *
         * @since 4.4.0
         *
         * @param string $key Header key.
         * @param string $value Header value.
         */
        public function send_header($key, $value)
        {
        }
        /**
         * Sends multiple HTTP headers.
         *
         * @since 4.4.0
         *
         * @param array $headers Map of header name to header value.
         */
        public function send_headers($headers)
        {
        }
        /**
         * Removes an HTTP header from the current response.
         *
         * @since 4.8.0
         *
         * @param string $key Header key.
         */
        public function remove_header($key)
        {
        }
        /**
         * Retrieves the raw request entity (body).
         *
         * @since 4.4.0
         *
         * @global string $HTTP_RAW_POST_DATA Raw post data.
         *
         * @return string Raw request data.
         */
        public static function get_raw_data()
        {
        }
        /**
         * Extracts headers from a PHP-style $_SERVER array.
         *
         * @since 4.4.0
         *
         * @param array $server Associative array similar to `$_SERVER`.
         * @return array Headers extracted from the input.
         */
        public function get_headers($server)
        {
        }
    }
    /**
     * Core base controller for managing and interacting with REST API items.
     *
     * @since 4.7.0
     */
    #[\AllowDynamicProperties]
    abstract class WP_REST_Controller
    {
        /**
         * The namespace of this controller's route.
         *
         * @since 4.7.0
         * @var string
         */
        protected $namespace;
        /**
         * The base of this controller's route.
         *
         * @since 4.7.0
         * @var string
         */
        protected $rest_base;
        /**
         * Cached results of get_item_schema.
         *
         * @since 5.3.0
         * @var array
         */
        protected $schema;
        /**
         * Registers the routes for the objects of the controller.
         *
         * @since 4.7.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks if a given request has access to get items.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves a collection of items.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Checks if a given request has access to get a specific item.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Retrieves one item from the collection.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Checks if a given request has access to create items.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to create items, WP_Error object otherwise.
         */
        public function create_item_permissions_check($request)
        {
        }
        /**
         * Creates one item from the collection.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Checks if a given request has access to update a specific item.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to update the item, WP_Error object otherwise.
         */
        public function update_item_permissions_check($request)
        {
        }
        /**
         * Updates one item from the collection.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Checks if a given request has access to delete a specific item.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to delete the item, WP_Error object otherwise.
         */
        public function delete_item_permissions_check($request)
        {
        }
        /**
         * Deletes one item from the collection.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Prepares one item for create or update operation.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Request object.
         * @return object|WP_Error The prepared item, or WP_Error object on failure.
         */
        protected function prepare_item_for_database($request)
        {
        }
        /**
         * Prepares the item for the REST response.
         *
         * @since 4.7.0
         *
         * @param mixed           $item    WordPress representation of the item.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares a response for insertion into a collection.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Response $response Response object.
         * @return array|mixed Response data, ready for insertion into collection data.
         */
        public function prepare_response_for_collection($response)
        {
        }
        /**
         * Filters a response based on the context defined in the schema.
         *
         * @since 4.7.0
         *
         * @param array  $response_data Response data to filter.
         * @param string $context       Context defined in the schema.
         * @return array Filtered response.
         */
        public function filter_response_by_context($response_data, $context)
        {
        }
        /**
         * Retrieves the item's schema, conforming to JSON Schema.
         *
         * @since 4.7.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the item's schema for display / public consumption purposes.
         *
         * @since 4.7.0
         *
         * @return array Public item schema data.
         */
        public function get_public_item_schema()
        {
        }
        /**
         * Retrieves the query params for the collections.
         *
         * @since 4.7.0
         *
         * @return array Query parameters for the collection.
         */
        public function get_collection_params()
        {
        }
        /**
         * Retrieves the magical context param.
         *
         * Ensures consistent descriptions between endpoints, and populates enum from schema.
         *
         * @since 4.7.0
         *
         * @param array $args Optional. Additional arguments for context parameter. Default empty array.
         * @return array Context parameter details.
         */
        public function get_context_param($args = array())
        {
        }
        /**
         * Adds the values from additional fields to a data object.
         *
         * @since 4.7.0
         *
         * @param array           $response_data Prepared response array.
         * @param WP_REST_Request $request       Full details about the request.
         * @return array Modified data object with additional fields.
         */
        protected function add_additional_fields_to_object($response_data, $request)
        {
        }
        /**
         * Updates the values of additional fields added to a data object.
         *
         * @since 4.7.0
         *
         * @param object          $data_object Data model like WP_Term or WP_Post.
         * @param WP_REST_Request $request     Full details about the request.
         * @return true|WP_Error True on success, WP_Error object if a field cannot be updated.
         */
        protected function update_additional_fields_for_object($data_object, $request)
        {
        }
        /**
         * Adds the schema from additional fields to a schema array.
         *
         * The type of object is inferred from the passed schema.
         *
         * @since 4.7.0
         *
         * @param array $schema Schema array.
         * @return array Modified Schema array.
         */
        protected function add_additional_fields_schema($schema)
        {
        }
        /**
         * Retrieves all of the registered additional fields for a given object-type.
         *
         * @since 4.7.0
         *
         * @global array $wp_rest_additional_fields Holds registered fields, organized by object type.
         *
         * @param string $object_type Optional. The object type.
         * @return array Registered additional fields (if any), empty array if none or if the object type
         *               could not be inferred.
         */
        protected function get_additional_fields($object_type = \null)
        {
        }
        /**
         * Retrieves the object type this controller is responsible for managing.
         *
         * @since 4.7.0
         *
         * @return string Object type for the controller.
         */
        protected function get_object_type()
        {
        }
        /**
         * Gets an array of fields to be included on the response.
         *
         * Included fields are based on item schema and `_fields=` request argument.
         *
         * @since 4.9.6
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return string[] Fields to be included in the response.
         */
        public function get_fields_for_response($request)
        {
        }
        /**
         * Retrieves an array of endpoint arguments from the item schema for the controller.
         *
         * @since 4.7.0
         *
         * @param string $method Optional. HTTP method of the request. The arguments for `CREATABLE` requests are
         *                       checked for required values and may fall-back to a given default, this is not done
         *                       on `EDITABLE` requests. Default WP_REST_Server::CREATABLE.
         * @return array Endpoint arguments.
         */
        public function get_endpoint_args_for_item_schema($method = \WP_REST_Server::CREATABLE)
        {
        }
        /**
         * Sanitizes the slug value.
         *
         * @since 4.7.0
         *
         * @internal We can't use sanitize_title() directly, as the second
         * parameter is the fallback title, which would end up being set to the
         * request object.
         *
         * @see https://github.com/WP-API/WP-API/issues/1585
         *
         * @todo Remove this in favour of https://core.trac.wordpress.org/ticket/34659
         *
         * @param string $slug Slug value passed in request.
         * @return string Sanitized value for the slug.
         */
        public function sanitize_slug($slug)
        {
        }
    }
    /**
     * Core class to access a user's application passwords via the REST API.
     *
     * @since 5.6.0
     *
     * @see   WP_REST_Controller
     */
    class WP_REST_Application_Passwords_Controller extends \WP_REST_Controller
    {
        /**
         * Application Passwords controller constructor.
         *
         * @since 5.6.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the REST API routes for the application passwords controller.
         *
         * @since 5.6.0
         */
        public function register_routes()
        {
        }
        /**
         * Checks if a given request has access to get application passwords.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves a collection of application passwords.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Checks if a given request has access to get a specific application password.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Retrieves one application password from the collection.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Checks if a given request has access to create application passwords.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to create items, WP_Error object otherwise.
         */
        public function create_item_permissions_check($request)
        {
        }
        /**
         * Creates an application password.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Checks if a given request has access to update application passwords.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to create items, WP_Error object otherwise.
         */
        public function update_item_permissions_check($request)
        {
        }
        /**
         * Updates an application password.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Checks if a given request has access to delete all application passwords for a user.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to delete the item, WP_Error object otherwise.
         */
        public function delete_items_permissions_check($request)
        {
        }
        /**
         * Deletes all application passwords for a user.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_items($request)
        {
        }
        /**
         * Checks if a given request has access to delete a specific application password for a user.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to delete the item, WP_Error object otherwise.
         */
        public function delete_item_permissions_check($request)
        {
        }
        /**
         * Deletes an application password for a user.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Checks if a given request has access to get the currently used application password for a user.
         *
         * @since 5.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, WP_Error object otherwise.
         */
        public function get_current_item_permissions_check($request)
        {
        }
        /**
         * Retrieves the application password being currently used for authentication of a user.
         *
         * @since 5.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_current_item($request)
        {
        }
        /**
         * Performs a permissions check for the request.
         *
         * @since 5.6.0
         * @deprecated 5.7.0 Use `edit_user` directly or one of the specific meta capabilities introduced in 5.7.0.
         *
         * @param WP_REST_Request $request
         * @return true|WP_Error
         */
        protected function do_permissions_check($request)
        {
        }
        /**
         * Prepares an application password for a create or update operation.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Request object.
         * @return object|WP_Error The prepared item, or WP_Error object on failure.
         */
        protected function prepare_item_for_database($request)
        {
        }
        /**
         * Prepares the application password for the REST response.
         *
         * @since 5.6.0
         *
         * @param array           $item    WordPress representation of the item.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 5.6.0
         *
         * @param WP_User $user The requested user.
         * @param array   $item The application password.
         * @return array The list of links.
         */
        protected function prepare_links(\WP_User $user, $item)
        {
        }
        /**
         * Gets the requested user.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request The request object.
         * @return WP_User|WP_Error The WordPress user associated with the request, or a WP_Error if none found.
         */
        protected function get_user($request)
        {
        }
        /**
         * Gets the requested application password for a user.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request The request object.
         * @return array|WP_Error The application password details if found, a WP_Error otherwise.
         */
        protected function get_application_password($request)
        {
        }
        /**
         * Retrieves the query params for the collections.
         *
         * @since 5.6.0
         *
         * @return array Query parameters for the collection.
         */
        public function get_collection_params()
        {
        }
        /**
         * Retrieves the application password's schema, conforming to JSON Schema.
         *
         * @since 5.6.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
    }
    /**
     * Core class to access posts via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Posts_Controller extends \WP_REST_Controller
    {
        /**
         * Post type.
         *
         * @since 4.7.0
         * @var string
         */
        protected $post_type;
        /**
         * Instance of a post meta fields object.
         *
         * @since 4.7.0
         * @var WP_REST_Post_Meta_Fields
         */
        protected $meta;
        /**
         * Passwordless post access permitted.
         *
         * @since 5.7.1
         * @var int[]
         */
        protected $password_check_passed = array();
        /**
         * Whether the controller supports batching.
         *
         * @since 5.9.0
         * @var array
         */
        protected $allow_batch = array('v1' => \true);
        /**
         * Constructor.
         *
         * @since 4.7.0
         *
         * @param string $post_type Post type.
         */
        public function __construct($post_type)
        {
        }
        /**
         * Registers the routes for posts.
         *
         * @since 4.7.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks if a given request has access to read posts.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Overrides the result of the post password check for REST requested posts.
         *
         * Allow users to read the content of password protected posts if they have
         * previously passed a permission check or if they have the `edit_post` capability
         * for the post being checked.
         *
         * @since 5.7.1
         *
         * @param bool    $required Whether the post requires a password check.
         * @param WP_Post $post     The post been password checked.
         * @return bool Result of password check taking into account REST API considerations.
         */
        public function check_password_required($required, $post)
        {
        }
        /**
         * Retrieves a collection of posts.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Gets the post, if the ID is valid.
         *
         * @since 4.7.2
         *
         * @param int $id Supplied ID.
         * @return WP_Post|WP_Error Post object if ID is valid, WP_Error otherwise.
         */
        protected function get_post($id)
        {
        }
        /**
         * Checks if a given request has access to read a post.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return bool|WP_Error True if the request has read access for the item, WP_Error object or false otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Checks if the user can access password-protected content.
         *
         * This method determines whether we need to override the regular password
         * check in core with a filter.
         *
         * @since 4.7.0
         *
         * @param WP_Post         $post    Post to check against.
         * @param WP_REST_Request $request Request data to check.
         * @return bool True if the user can access password-protected content, otherwise false.
         */
        public function can_access_password_content($post, $request)
        {
        }
        /**
         * Retrieves a single post.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Checks if a given request has access to create a post.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to create items, WP_Error object otherwise.
         */
        public function create_item_permissions_check($request)
        {
        }
        /**
         * Creates a single post.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Checks if a given request has access to update a post.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to update the item, WP_Error object otherwise.
         */
        public function update_item_permissions_check($request)
        {
        }
        /**
         * Updates a single post.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Checks if a given request has access to delete a post.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to delete the item, WP_Error object otherwise.
         */
        public function delete_item_permissions_check($request)
        {
        }
        /**
         * Deletes a single post.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Determines the allowed query_vars for a get_items() response and prepares
         * them for WP_Query.
         *
         * @since 4.7.0
         *
         * @param array           $prepared_args Optional. Prepared WP_Query arguments. Default empty array.
         * @param WP_REST_Request $request       Optional. Full details about the request.
         * @return array Items query arguments.
         */
        protected function prepare_items_query($prepared_args = array(), $request = \null)
        {
        }
        /**
         * Checks the post_date_gmt or modified_gmt and prepare any post or
         * modified date for single post output.
         *
         * @since 4.7.0
         *
         * @param string      $date_gmt GMT publication time.
         * @param string|null $date     Optional. Local publication time. Default null.
         * @return string|null ISO8601/RFC3339 formatted datetime.
         */
        protected function prepare_date_response($date_gmt, $date = \null)
        {
        }
        /**
         * Prepares a single post for create or update.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Request object.
         * @return stdClass|WP_Error Post object or WP_Error.
         */
        protected function prepare_item_for_database($request)
        {
        }
        /**
         * Checks whether the status is valid for the given post.
         *
         * Allows for sending an update request with the current status, even if that status would not be acceptable.
         *
         * @since 5.6.0
         *
         * @param string          $status  The provided status.
         * @param WP_REST_Request $request The request object.
         * @param string          $param   The parameter name.
         * @return true|WP_Error True if the status is valid, or WP_Error if not.
         */
        public function check_status($status, $request, $param)
        {
        }
        /**
         * Determines validity and normalizes the given status parameter.
         *
         * @since 4.7.0
         *
         * @param string       $post_status Post status.
         * @param WP_Post_Type $post_type   Post type.
         * @return string|WP_Error Post status or WP_Error if lacking the proper permission.
         */
        protected function handle_status_param($post_status, $post_type)
        {
        }
        /**
         * Determines the featured media based on a request param.
         *
         * @since 4.7.0
         *
         * @param int $featured_media Featured Media ID.
         * @param int $post_id        Post ID.
         * @return bool|WP_Error Whether the post thumbnail was successfully deleted, otherwise WP_Error.
         */
        protected function handle_featured_media($featured_media, $post_id)
        {
        }
        /**
         * Checks whether the template is valid for the given post.
         *
         * @since 4.9.0
         *
         * @param string          $template Page template filename.
         * @param WP_REST_Request $request  Request.
         * @return true|WP_Error True if template is still valid or if the same as existing value, or a WP_Error if template not supported.
         */
        public function check_template($template, $request)
        {
        }
        /**
         * Sets the template for a post.
         *
         * @since 4.7.0
         * @since 4.9.0 Added the `$validate` parameter.
         *
         * @param string $template Page template filename.
         * @param int    $post_id  Post ID.
         * @param bool   $validate Whether to validate that the template selected is valid.
         */
        public function handle_template($template, $post_id, $validate = \false)
        {
        }
        /**
         * Updates the post's terms from a REST request.
         *
         * @since 4.7.0
         *
         * @param int             $post_id The post ID to update the terms form.
         * @param WP_REST_Request $request The request object with post and terms data.
         * @return null|WP_Error WP_Error on an error assigning any of the terms, otherwise null.
         */
        protected function handle_terms($post_id, $request)
        {
        }
        /**
         * Checks whether current user can assign all terms sent with the current request.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request The request object with post and terms data.
         * @return bool Whether the current user can assign the provided terms.
         */
        protected function check_assign_terms_permission($request)
        {
        }
        /**
         * Checks if a given post type can be viewed or managed.
         *
         * @since 4.7.0
         *
         * @param WP_Post_Type|string $post_type Post type name or object.
         * @return bool Whether the post type is allowed in REST.
         */
        protected function check_is_post_type_allowed($post_type)
        {
        }
        /**
         * Checks if a post can be read.
         *
         * Correctly handles posts with the inherit status.
         *
         * @since 4.7.0
         *
         * @param WP_Post $post Post object.
         * @return bool Whether the post can be read.
         */
        public function check_read_permission($post)
        {
        }
        /**
         * Checks if a post can be edited.
         *
         * @since 4.7.0
         *
         * @param WP_Post $post Post object.
         * @return bool Whether the post can be edited.
         */
        protected function check_update_permission($post)
        {
        }
        /**
         * Checks if a post can be created.
         *
         * @since 4.7.0
         *
         * @param WP_Post $post Post object.
         * @return bool Whether the post can be created.
         */
        protected function check_create_permission($post)
        {
        }
        /**
         * Checks if a post can be deleted.
         *
         * @since 4.7.0
         *
         * @param WP_Post $post Post object.
         * @return bool Whether the post can be deleted.
         */
        protected function check_delete_permission($post)
        {
        }
        /**
         * Prepares a single post output for response.
         *
         * @since 4.7.0
         * @since 5.9.0 Renamed `$post` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @global WP_Post $post Global post object.
         *
         * @param WP_Post         $item    Post object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Overwrites the default protected and private title format.
         *
         * By default, WordPress will show password protected or private posts with a title of
         * "Protected: %s" or "Private: %s", as the REST API communicates the status of a post
         * in a machine-readable format, we remove the prefix.
         *
         * @since 4.7.0
         *
         * @return string Title format.
         */
        public function protected_title_format()
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 4.7.0
         *
         * @param WP_Post $post Post object.
         * @return array Links for the given post.
         */
        protected function prepare_links($post)
        {
        }
        /**
         * Gets the link relations available for the post and current user.
         *
         * @since 4.9.8
         *
         * @param WP_Post         $post    Post object.
         * @param WP_REST_Request $request Request object.
         * @return array List of link relations.
         */
        protected function get_available_actions($post, $request)
        {
        }
        /**
         * Retrieves the post's schema, conforming to JSON Schema.
         *
         * @since 4.7.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves Link Description Objects that should be added to the Schema for the posts collection.
         *
         * @since 4.9.8
         *
         * @return array
         */
        protected function get_schema_links()
        {
        }
        /**
         * Retrieves the query params for the posts collection.
         *
         * @since 4.7.0
         * @since 5.4.0 The `tax_relation` query parameter was added.
         * @since 5.7.0 The `modified_after` and `modified_before` query parameters were added.
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
        /**
         * Sanitizes and validates the list of post statuses, including whether the
         * user can query private statuses.
         *
         * @since 4.7.0
         *
         * @param string|array    $statuses  One or more post statuses.
         * @param WP_REST_Request $request   Full details about the request.
         * @param string          $parameter Additional parameter to pass to validation.
         * @return array|WP_Error A list of valid statuses, otherwise WP_Error object.
         */
        public function sanitize_post_statuses($statuses, $request, $parameter)
        {
        }
    }
    /**
     * Core controller used to access attachments via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Posts_Controller
     */
    class WP_REST_Attachments_Controller extends \WP_REST_Posts_Controller
    {
        /**
         * Whether the controller supports batching.
         *
         * @since 5.9.0
         * @var false
         */
        protected $allow_batch = \false;
        /**
         * Registers the routes for attachments.
         *
         * @since 5.3.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Determines the allowed query_vars for a get_items() response and
         * prepares for WP_Query.
         *
         * @since 4.7.0
         *
         * @param array           $prepared_args Optional. Array of prepared arguments. Default empty array.
         * @param WP_REST_Request $request       Optional. Request to prepare items for.
         * @return array Array of query arguments.
         */
        protected function prepare_items_query($prepared_args = array(), $request = \null)
        {
        }
        /**
         * Checks if a given request has access to create an attachment.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error Boolean true if the attachment may be created, or a WP_Error if not.
         */
        public function create_item_permissions_check($request)
        {
        }
        /**
         * Creates a single attachment.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Inserts the attachment post in the database. Does not update the attachment meta.
         *
         * @since 5.3.0
         *
         * @param WP_REST_Request $request
         * @return array|WP_Error
         */
        protected function insert_attachment($request)
        {
        }
        /**
         * Determines the featured media based on a request param.
         *
         * @since 6.5.0
         *
         * @param int $featured_media Featured Media ID.
         * @param int $post_id        Post ID.
         * @return bool|WP_Error Whether the post thumbnail was successfully deleted, otherwise WP_Error.
         */
        protected function handle_featured_media($featured_media, $post_id)
        {
        }
        /**
         * Updates a single attachment.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, WP_Error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Performs post-processing on an attachment.
         *
         * @since 5.3.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, WP_Error object on failure.
         */
        public function post_process_item($request)
        {
        }
        /**
         * Checks if a given request can perform post-processing on an attachment.
         *
         * @since 5.3.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to update the item, WP_Error object otherwise.
         */
        public function post_process_item_permissions_check($request)
        {
        }
        /**
         * Checks if a given request has access to editing media.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function edit_media_item_permissions_check($request)
        {
        }
        /**
         * Applies edits to a media item and creates a new attachment record.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, WP_Error object on failure.
         */
        public function edit_media_item($request)
        {
        }
        /**
         * Prepares a single attachment for create or update.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Request object.
         * @return stdClass|WP_Error Post object.
         */
        protected function prepare_item_for_database($request)
        {
        }
        /**
         * Prepares a single attachment output for response.
         *
         * @since 4.7.0
         * @since 5.9.0 Renamed `$post` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Post         $item    Attachment object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Retrieves the attachment's schema, conforming to JSON Schema.
         *
         * @since 4.7.0
         *
         * @return array Item schema as an array.
         */
        public function get_item_schema()
        {
        }
        /**
         * Handles an upload via raw POST data.
         *
         * @since 4.7.0
         * @since 6.6.0 Added the `$time` parameter.
         *
         * @param string      $data    Supplied file data.
         * @param array       $headers HTTP headers from the request.
         * @param string|null $time    Optional. Time formatted in 'yyyy/mm'. Default null.
         * @return array|WP_Error Data from wp_handle_sideload().
         */
        protected function upload_from_data($data, $headers, $time = \null)
        {
        }
        /**
         * Parses filename from a Content-Disposition header value.
         *
         * As per RFC6266:
         *
         *     content-disposition = "Content-Disposition" ":"
         *                            disposition-type *( ";" disposition-parm )
         *
         *     disposition-type    = "inline" | "attachment" | disp-ext-type
         *                         ; case-insensitive
         *     disp-ext-type       = token
         *
         *     disposition-parm    = filename-parm | disp-ext-parm
         *
         *     filename-parm       = "filename" "=" value
         *                         | "filename*" "=" ext-value
         *
         *     disp-ext-parm       = token "=" value
         *                         | ext-token "=" ext-value
         *     ext-token           = <the characters in token, followed by "*">
         *
         * @since 4.7.0
         *
         * @link https://tools.ietf.org/html/rfc2388
         * @link https://tools.ietf.org/html/rfc6266
         *
         * @param string[] $disposition_header List of Content-Disposition header values.
         * @return string|null Filename if available, or null if not found.
         */
        public static function get_filename_from_disposition($disposition_header)
        {
        }
        /**
         * Retrieves the query params for collections of attachments.
         *
         * @since 4.7.0
         *
         * @return array Query parameters for the attachment collection as an array.
         */
        public function get_collection_params()
        {
        }
        /**
         * Handles an upload via multipart/form-data ($_FILES).
         *
         * @since 4.7.0
         * @since 6.6.0 Added the `$time` parameter.
         *
         * @param array       $files   Data from the `$_FILES` superglobal.
         * @param array       $headers HTTP headers from the request.
         * @param string|null $time    Optional. Time formatted in 'yyyy/mm'. Default null.
         * @return array|WP_Error Data from wp_handle_upload().
         */
        protected function upload_from_file($files, $headers, $time = \null)
        {
        }
        /**
         * Retrieves the supported media types.
         *
         * Media types are considered the MIME type category.
         *
         * @since 4.7.0
         *
         * @return array Array of supported media types.
         */
        protected function get_media_types()
        {
        }
        /**
         * Determine if uploaded file exceeds space quota on multisite.
         *
         * Replicates check_upload_size().
         *
         * @since 4.9.8
         *
         * @param array $file $_FILES array for a given file.
         * @return true|WP_Error True if can upload, error for errors.
         */
        protected function check_upload_size($file)
        {
        }
        /**
         * Gets the request args for the edit item route.
         *
         * @since 5.5.0
         *
         * @return array
         */
        protected function get_edit_media_item_args()
        {
        }
    }
    /**
     * Core class used to access revisions via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Revisions_Controller extends \WP_REST_Controller
    {
        /**
         * Instance of a revision meta fields object.
         *
         * @since 6.4.0
         * @var WP_REST_Post_Meta_Fields
         */
        protected $meta;
        /**
         * Constructor.
         *
         * @since 4.7.0
         *
         * @param string $parent_post_type Post type of the parent.
         */
        public function __construct($parent_post_type)
        {
        }
        /**
         * Registers the routes for revisions based on post types supporting revisions.
         *
         * @since 4.7.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Get the parent post, if the ID is valid.
         *
         * @since 4.7.2
         *
         * @param int $parent_post_id Supplied ID.
         * @return WP_Post|WP_Error Post object if ID is valid, WP_Error otherwise.
         */
        protected function get_parent($parent_post_id)
        {
        }
        /**
         * Checks if a given request has access to get revisions.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Get the revision, if the ID is valid.
         *
         * @since 4.7.2
         *
         * @param int $id Supplied ID.
         * @return WP_Post|WP_Error Revision post object if ID is valid, WP_Error otherwise.
         */
        protected function get_revision($id)
        {
        }
        /**
         * Gets a collection of revisions.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Checks if a given request has access to get a specific revision.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Retrieves one revision from the collection.
         *
         * @since 4.7.0
         * @since 6.5.0 Added a condition to check that parent id matches revision parent id.
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Checks if a given request has access to delete a revision.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to delete the item, WP_Error object otherwise.
         */
        public function delete_item_permissions_check($request)
        {
        }
        /**
         * Deletes a single revision.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Determines the allowed query_vars for a get_items() response and prepares
         * them for WP_Query.
         *
         * @since 5.0.0
         *
         * @param array           $prepared_args Optional. Prepared WP_Query arguments. Default empty array.
         * @param WP_REST_Request $request       Optional. Full details about the request.
         * @return array Items query arguments.
         */
        protected function prepare_items_query($prepared_args = array(), $request = \null)
        {
        }
        /**
         * Prepares the revision for the REST response.
         *
         * @since 4.7.0
         * @since 5.9.0 Renamed `$post` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @global WP_Post $post Global post object.
         *
         * @param WP_Post         $item    Post revision object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Checks the post_date_gmt or modified_gmt and prepare any post or
         * modified date for single post output.
         *
         * @since 4.7.0
         *
         * @param string      $date_gmt GMT publication time.
         * @param string|null $date     Optional. Local publication time. Default null.
         * @return string|null ISO8601/RFC3339 formatted datetime, otherwise null.
         */
        protected function prepare_date_response($date_gmt, $date = \null)
        {
        }
        /**
         * Retrieves the revision's schema, conforming to JSON Schema.
         *
         * @since 4.7.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the query params for collections.
         *
         * @since 4.7.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
        /**
         * Checks the post excerpt and prepare it for single post output.
         *
         * @since 4.7.0
         *
         * @param string  $excerpt The post excerpt.
         * @param WP_Post $post    Post revision object.
         * @return string Prepared excerpt or empty string.
         */
        protected function prepare_excerpt_response($excerpt, $post)
        {
        }
    }
    /**
     * Core class used to access autosaves via the REST API.
     *
     * @since 5.0.0
     *
     * @see WP_REST_Revisions_Controller
     * @see WP_REST_Controller
     */
    class WP_REST_Autosaves_Controller extends \WP_REST_Revisions_Controller
    {
        /**
         * Constructor.
         *
         * @since 5.0.0
         *
         * @param string $parent_post_type Post type of the parent.
         */
        public function __construct($parent_post_type)
        {
        }
        /**
         * Registers the routes for autosaves.
         *
         * @since 5.0.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Get the parent post.
         *
         * @since 5.0.0
         *
         * @param int $parent_id Supplied ID.
         * @return WP_Post|WP_Error Post object if ID is valid, WP_Error otherwise.
         */
        protected function get_parent($parent_id)
        {
        }
        /**
         * Checks if a given request has access to get autosaves.
         *
         * @since 5.0.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Checks if a given request has access to create an autosave revision.
         *
         * Autosave revisions inherit permissions from the parent post,
         * check if the current user has permission to edit the post.
         *
         * @since 5.0.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to create the item, WP_Error object otherwise.
         */
        public function create_item_permissions_check($request)
        {
        }
        /**
         * Creates, updates or deletes an autosave revision.
         *
         * @since 5.0.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Get the autosave, if the ID is valid.
         *
         * @since 5.0.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_Post|WP_Error Revision post object if ID is valid, WP_Error otherwise.
         */
        public function get_item($request)
        {
        }
        /**
         * Gets a collection of autosaves using wp_get_post_autosave.
         *
         * Contains the user's autosave, for empty if it doesn't exist.
         *
         * @since 5.0.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Retrieves the autosave's schema, conforming to JSON Schema.
         *
         * @since 5.0.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Creates autosave for the specified post.
         *
         * From wp-admin/post.php.
         *
         * @since 5.0.0
         * @since 6.4.0 The `$meta` parameter was added.
         *
         * @param array $post_data Associative array containing the post data.
         * @param array $meta      Associative array containing the post meta data.
         * @return mixed The autosave revision ID or WP_Error.
         */
        public function create_post_autosave($post_data, array $meta = array())
        {
        }
        /**
         * Prepares the revision for the REST response.
         *
         * @since 5.0.0
         * @since 5.9.0 Renamed `$post` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Post         $item    Post revision object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Retrieves the query params for the autosaves collection.
         *
         * @since 5.0.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
    }
    /**
     * Controller which provides REST endpoint for the blocks.
     *
     * @since 5.5.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Block_Directory_Controller extends \WP_REST_Controller
    {
        /**
         * Constructs the controller.
         */
        public function __construct()
        {
        }
        /**
         * Registers the necessary REST API routes.
         */
        public function register_routes()
        {
        }
        /**
         * Checks whether a given request has permission to install and activate plugins.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has permission, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Search and retrieve blocks metadata
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Parse block metadata for a block, and prepare it for an API response.
         *
         * @since 5.5.0
         * @since 5.9.0 Renamed `$plugin` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param array           $item    The plugin metadata.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Generates a list of links to include in the response for the plugin.
         *
         * @since 5.5.0
         *
         * @param array $plugin The plugin data from WordPress.org.
         * @return array
         */
        protected function prepare_links($plugin)
        {
        }
        /**
         * Finds an installed plugin for the given slug.
         *
         * @since 5.5.0
         *
         * @param string $slug The WordPress.org directory slug for a plugin.
         * @return string The plugin file found matching it.
         */
        protected function find_plugin_for_slug($slug)
        {
        }
        /**
         * Retrieves the theme's schema, conforming to JSON Schema.
         *
         * @since 5.5.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the search params for the blocks collection.
         *
         * @since 5.5.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
    }
    /**
     * Core class used to access block pattern categories via the REST API.
     *
     * @since 6.0.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Block_Pattern_Categories_Controller extends \WP_REST_Controller
    {
        /**
         * Constructs the controller.
         *
         * @since 6.0.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the routes for the objects of the controller.
         *
         * @since 6.0.0
         */
        public function register_routes()
        {
        }
        /**
         * Checks whether a given request has permission to read block patterns.
         *
         * @since 6.0.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves all block pattern categories.
         *
         * @since 6.0.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Prepare a raw block pattern category before it gets output in a REST API response.
         *
         * @since 6.0.0
         *
         * @param array           $item    Raw category as registered, before any changes.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Retrieves the block pattern category schema, conforming to JSON Schema.
         *
         * @since 6.0.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
    }
    /**
     * Core class used to access block patterns via the REST API.
     *
     * @since 6.0.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Block_Patterns_Controller extends \WP_REST_Controller
    {
        /**
         * An array that maps old categories names to new ones.
         *
         * @since 6.2.0
         * @var array
         */
        protected static $categories_migration = array('buttons' => 'call-to-action', 'columns' => 'text', 'query' => 'posts');
        /**
         * Constructs the controller.
         *
         * @since 6.0.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the routes for the objects of the controller.
         *
         * @since 6.0.0
         */
        public function register_routes()
        {
        }
        /**
         * Checks whether a given request has permission to read block patterns.
         *
         * @since 6.0.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves all block patterns.
         *
         * @since 6.0.0
         * @since 6.2.0 Added migration for old core pattern categories to the new ones.
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Migrates old core pattern categories to the new categories.
         *
         * Core pattern categories are revamped. Migration is needed to ensure
         * backwards compatibility.
         *
         * @since 6.2.0
         *
         * @param array $pattern Raw pattern as registered, before applying any changes.
         * @return array Migrated pattern.
         */
        protected function migrate_pattern_categories($pattern)
        {
        }
        /**
         * Prepare a raw block pattern before it gets output in a REST API response.
         *
         * @since 6.0.0
         * @since 6.3.0 Added `source` property.
         *
         * @param array           $item    Raw pattern as registered, before any changes.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Retrieves the block pattern schema, conforming to JSON Schema.
         *
         * @since 6.0.0
         * @since 6.3.0 Added `source` property.
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
    }
    /**
     * Controller which provides REST endpoint for rendering a block.
     *
     * @since 5.0.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Block_Renderer_Controller extends \WP_REST_Controller
    {
        /**
         * Constructs the controller.
         *
         * @since 5.0.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the necessary REST API routes, one for each dynamic block.
         *
         * @since 5.0.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks if a given request has access to read blocks.
         *
         * @since 5.0.0
         *
         * @global WP_Post $post Global post object.
         *
         * @param WP_REST_Request $request Request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Returns block output from block's registered render_callback.
         *
         * @since 5.0.0
         *
         * @global WP_Post $post Global post object.
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Retrieves block's output schema, conforming to JSON Schema.
         *
         * @since 5.0.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
    }
    /**
     * Core class used to access block types via the REST API.
     *
     * @since 5.5.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Block_Types_Controller extends \WP_REST_Controller
    {
        const NAME_PATTERN = '^[a-z][a-z0-9-]*/[a-z][a-z0-9-]*$';
        /**
         * Instance of WP_Block_Type_Registry.
         *
         * @since 5.5.0
         * @var WP_Block_Type_Registry
         */
        protected $block_registry;
        /**
         * Instance of WP_Block_Styles_Registry.
         *
         * @since 5.5.0
         * @var WP_Block_Styles_Registry
         */
        protected $style_registry;
        /**
         * Constructor.
         *
         * @since 5.5.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the routes for block types.
         *
         * @since 5.5.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks whether a given request has permission to read post block types.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves all post block types, depending on user context.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Checks if a given request has access to read a block type.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Checks whether a given block type should be visible.
         *
         * @since 5.5.0
         *
         * @return true|WP_Error True if the block type is visible, WP_Error otherwise.
         */
        protected function check_read_permission()
        {
        }
        /**
         * Get the block, if the name is valid.
         *
         * @since 5.5.0
         *
         * @param string $name Block name.
         * @return WP_Block_Type|WP_Error Block type object if name is valid, WP_Error otherwise.
         */
        protected function get_block($name)
        {
        }
        /**
         * Retrieves a specific block type.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Prepares a block type object for serialization.
         *
         * @since 5.5.0
         * @since 5.9.0 Renamed `$block_type` to `$item` to match parent class for PHP 8 named parameter support.
         * @since 6.3.0 Added `selectors` field.
         * @since 6.5.0 Added `view_script_module_ids` field.
         *
         * @param WP_Block_Type   $item    Block type data.
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response Block type data.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 5.5.0
         *
         * @param WP_Block_Type $block_type Block type data.
         * @return array Links for the given block type.
         */
        protected function prepare_links($block_type)
        {
        }
        /**
         * Retrieves the block type' schema, conforming to JSON Schema.
         *
         * @since 5.5.0
         * @since 6.3.0 Added `selectors` field.
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the query params for collections.
         *
         * @since 5.5.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
    }
    /**
     * Controller which provides a REST endpoint for the editor to read, create,
     * edit, and delete synced patterns (formerly called reusable blocks).
     * Patterns are stored as posts with the wp_block post type.
     *
     * @since 5.0.0
     *
     * @see WP_REST_Posts_Controller
     * @see WP_REST_Controller
     */
    class WP_REST_Blocks_Controller extends \WP_REST_Posts_Controller
    {
        /**
         * Checks if a pattern can be read.
         *
         * @since 5.0.0
         *
         * @param WP_Post $post Post object that backs the block.
         * @return bool Whether the pattern can be read.
         */
        public function check_read_permission($post)
        {
        }
        /**
         * Filters a response based on the context defined in the schema.
         *
         * @since 5.0.0
         * @since 6.3.0 Adds the `wp_pattern_sync_status` postmeta property to the top level of response.
         *
         * @param array  $data    Response data to filter.
         * @param string $context Context defined in the schema.
         * @return array Filtered response.
         */
        public function filter_response_by_context($data, $context)
        {
        }
        /**
         * Retrieves the pattern's schema, conforming to JSON Schema.
         *
         * @since 5.0.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
    }
    /**
     * Core controller used to access comments via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Comments_Controller extends \WP_REST_Controller
    {
        /**
         * Instance of a comment meta fields object.
         *
         * @since 4.7.0
         * @var WP_REST_Comment_Meta_Fields
         */
        protected $meta;
        /**
         * Constructor.
         *
         * @since 4.7.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the routes for comments.
         *
         * @since 4.7.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks if a given request has access to read comments.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves a list of comment items.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Get the comment, if the ID is valid.
         *
         * @since 4.7.2
         *
         * @param int $id Supplied ID.
         * @return WP_Comment|WP_Error Comment object if ID is valid, WP_Error otherwise.
         */
        protected function get_comment($id)
        {
        }
        /**
         * Checks if a given request has access to read the comment.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Retrieves a comment.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Checks if a given request has access to create a comment.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to create items, error object otherwise.
         */
        public function create_item_permissions_check($request)
        {
        }
        /**
         * Creates a comment.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Checks if a given REST request has access to update a comment.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to update the item, error object otherwise.
         */
        public function update_item_permissions_check($request)
        {
        }
        /**
         * Updates a comment.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Checks if a given request has access to delete a comment.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to delete the item, error object otherwise.
         */
        public function delete_item_permissions_check($request)
        {
        }
        /**
         * Deletes a comment.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Prepares a single comment output for response.
         *
         * @since 4.7.0
         * @since 5.9.0 Renamed `$comment` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Comment      $item    Comment object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 4.7.0
         *
         * @param WP_Comment $comment Comment object.
         * @return array Links for the given comment.
         */
        protected function prepare_links($comment)
        {
        }
        /**
         * Prepends internal property prefix to query parameters to match our response fields.
         *
         * @since 4.7.0
         *
         * @param string $query_param Query parameter.
         * @return string The normalized query parameter.
         */
        protected function normalize_query_param($query_param)
        {
        }
        /**
         * Checks comment_approved to set comment status for single comment output.
         *
         * @since 4.7.0
         *
         * @param string|int $comment_approved comment status.
         * @return string Comment status.
         */
        protected function prepare_status_response($comment_approved)
        {
        }
        /**
         * Prepares a single comment to be inserted into the database.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Request object.
         * @return array|WP_Error Prepared comment, otherwise WP_Error object.
         */
        protected function prepare_item_for_database($request)
        {
        }
        /**
         * Retrieves the comment's schema, conforming to JSON Schema.
         *
         * @since 4.7.0
         *
         * @return array
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the query params for collections.
         *
         * @since 4.7.0
         *
         * @return array Comments collection parameters.
         */
        public function get_collection_params()
        {
        }
        /**
         * Sets the comment_status of a given comment object when creating or updating a comment.
         *
         * @since 4.7.0
         *
         * @param string|int $new_status New comment status.
         * @param int        $comment_id Comment ID.
         * @return bool Whether the status was changed.
         */
        protected function handle_status_param($new_status, $comment_id)
        {
        }
        /**
         * Checks if the post can be read.
         *
         * Correctly handles posts with the inherit status.
         *
         * @since 4.7.0
         *
         * @param WP_Post         $post    Post object.
         * @param WP_REST_Request $request Request data to check.
         * @return bool Whether post can be read.
         */
        protected function check_read_post_permission($post, $request)
        {
        }
        /**
         * Checks if the comment can be read.
         *
         * @since 4.7.0
         *
         * @param WP_Comment      $comment Comment object.
         * @param WP_REST_Request $request Request data to check.
         * @return bool Whether the comment can be read.
         */
        protected function check_read_permission($comment, $request)
        {
        }
        /**
         * Checks if a comment can be edited or deleted.
         *
         * @since 4.7.0
         *
         * @param WP_Comment $comment Comment object.
         * @return bool Whether the comment can be edited or deleted.
         */
        protected function check_edit_permission($comment)
        {
        }
        /**
         * Checks a comment author email for validity.
         *
         * Accepts either a valid email address or empty string as a valid comment
         * author email address. Setting the comment author email to an empty
         * string is allowed when a comment is being updated.
         *
         * @since 4.7.0
         *
         * @param string          $value   Author email value submitted.
         * @param WP_REST_Request $request Full details about the request.
         * @param string          $param   The parameter name.
         * @return string|WP_Error The sanitized email address, if valid,
         *                         otherwise an error.
         */
        public function check_comment_author_email($value, $request, $param)
        {
        }
        /**
         * If empty comments are not allowed, checks if the provided comment content is not empty.
         *
         * @since 5.6.0
         *
         * @param array $prepared_comment The prepared comment data.
         * @return bool True if the content is allowed, false otherwise.
         */
        protected function check_is_comment_content_allowed($prepared_comment)
        {
        }
    }
    /**
     * Controller which provides REST endpoint for exporting current templates
     * and template parts.
     *
     * @since 5.9.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Edit_Site_Export_Controller extends \WP_REST_Controller
    {
        /**
         * Constructor.
         *
         * @since 5.9.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the site export route.
         *
         * @since 5.9.0
         */
        public function register_routes()
        {
        }
        /**
         * Checks whether a given request has permission to export.
         *
         * @since 5.9.0
         *
         * @return true|WP_Error True if the request has access, or WP_Error object.
         */
        public function permissions_check()
        {
        }
        /**
         * Output a ZIP file with an export of the current templates
         * and template parts from the site editor, and close the connection.
         *
         * @since 5.9.0
         *
         * @return void|WP_Error
         */
        public function export()
        {
        }
    }
    /**
     * Font Library Controller class.
     *
     * @since 6.5.0
     */
    class WP_REST_Font_Collections_Controller extends \WP_REST_Controller
    {
        /**
         * Constructor.
         *
         * @since 6.5.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the routes for the objects of the controller.
         *
         * @since 6.5.0
         */
        public function register_routes()
        {
        }
        /**
         * Gets the font collections available.
         *
         * @since 6.5.0
         *
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Gets a font collection.
         *
         * @since 6.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Prepare a single collection output for response.
         *
         * @since 6.5.0
         *
         * @param WP_Font_Collection $item    Font collection object.
         * @param WP_REST_Request    $request Request object.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Retrieves the font collection's schema, conforming to JSON Schema.
         *
         * @since 6.5.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 6.5.0
         *
         * @param WP_Font_Collection $collection Font collection data
         * @return array Links for the given font collection.
         */
        protected function prepare_links($collection)
        {
        }
        /**
         * Retrieves the search params for the font collections.
         *
         * @since 6.5.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
        /**
         * Checks whether the user has permissions to use the Fonts Collections.
         *
         * @since 6.5.0
         *
         * @return true|WP_Error True if the request has write access for the item, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
    }
    /**
     * Class to access font faces through the REST API.
     */
    class WP_REST_Font_Faces_Controller extends \WP_REST_Posts_Controller
    {
        /**
         * The latest version of theme.json schema supported by the controller.
         *
         * @since 6.5.0
         * @var int
         */
        const LATEST_THEME_JSON_VERSION_SUPPORTED = 3;
        /**
         * Whether the controller supports batching.
         *
         * @since 6.5.0
         * @var false
         */
        protected $allow_batch = \false;
        /**
         * Registers the routes for posts.
         *
         * @since 6.5.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks if a given request has access to font faces.
         *
         * @since 6.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Checks if a given request has access to a font face.
         *
         * @since 6.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Validates settings when creating a font face.
         *
         * @since 6.5.0
         *
         * @param string          $value   Encoded JSON string of font face settings.
         * @param WP_REST_Request $request Request object.
         * @return true|WP_Error True if the settings are valid, otherwise a WP_Error object.
         */
        public function validate_create_font_face_settings($value, $request)
        {
        }
        /**
         * Sanitizes the font face settings when creating a font face.
         *
         * @since 6.5.0
         *
         * @param string $value Encoded JSON string of font face settings.
         * @return array Decoded and sanitized array of font face settings.
         */
        public function sanitize_font_face_settings($value)
        {
        }
        /**
         * Retrieves a collection of font faces within the parent font family.
         *
         * @since 6.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Retrieves a single font face within the parent font family.
         *
         * @since 6.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Creates a font face for the parent font family.
         *
         * @since 6.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Deletes a single font face.
         *
         * @since 6.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Prepares a single font face output for response.
         *
         * @since 6.5.0
         *
         * @param WP_Post         $item    Post object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Retrieves the post's schema, conforming to JSON Schema.
         *
         * @since 6.5.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the item's schema for display / public consumption purposes.
         *
         * @since 6.5.0
         *
         * @return array Public item schema data.
         */
        public function get_public_item_schema()
        {
        }
        /**
         * Retrieves the query params for the font face collection.
         *
         * @since 6.5.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
        /**
         * Get the params used when creating a new font face.
         *
         * @since 6.5.0
         *
         * @return array Font face create arguments.
         */
        public function get_create_params()
        {
        }
        /**
         * Get the parent font family, if the ID is valid.
         *
         * @since 6.5.0
         *
         * @param int $font_family_id Supplied ID.
         * @return WP_Post|WP_Error Post object if ID is valid, WP_Error otherwise.
         */
        protected function get_parent_font_family_post($font_family_id)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 6.5.0
         *
         * @param WP_Post $post Post object.
         * @return array Links for the given post.
         */
        protected function prepare_links($post)
        {
        }
        /**
         * Prepares a single font face post for creation.
         *
         * @since 6.5.0
         *
         * @param WP_REST_Request $request Request object.
         * @return stdClass Post object.
         */
        protected function prepare_item_for_database($request)
        {
        }
        /**
         * Sanitizes a single src value for a font face.
         *
         * @since 6.5.0
         *
         * @param string $value Font face src that is a URL or the key for a $_FILES array item.
         * @return string Sanitized value.
         */
        protected function sanitize_src($value)
        {
        }
        /**
         * Handles the upload of a font file using wp_handle_upload().
         *
         * @since 6.5.0
         *
         * @param array $file Single file item from $_FILES.
         * @return array|WP_Error Array containing uploaded file attributes on success, or WP_Error object on failure.
         */
        protected function handle_font_file_upload($file)
        {
        }
        /**
         * Handles file upload error.
         *
         * @since 6.5.0
         *
         * @param array  $file    File upload data.
         * @param string $message Error message from wp_handle_upload().
         * @return WP_Error WP_Error object.
         */
        public function handle_font_file_upload_error($file, $message)
        {
        }
        /**
         * Returns relative path to an uploaded font file.
         *
         * The path is relative to the current fonts directory.
         *
         * @since 6.5.0
         * @access private
         *
         * @param string $path Full path to the file.
         * @return string Relative path on success, unchanged path on failure.
         */
        protected function relative_fonts_path($path)
        {
        }
        /**
         * Gets the font face's settings from the post.
         *
         * @since 6.5.0
         *
         * @param WP_Post $post Font face post object.
         * @return array Font face settings array.
         */
        protected function get_settings_from_post($post)
        {
        }
    }
    /**
     * Font Families Controller class.
     *
     * @since 6.5.0
     */
    class WP_REST_Font_Families_Controller extends \WP_REST_Posts_Controller
    {
        /**
         * The latest version of theme.json schema supported by the controller.
         *
         * @since 6.5.0
         * @var int
         */
        const LATEST_THEME_JSON_VERSION_SUPPORTED = 3;
        /**
         * Whether the controller supports batching.
         *
         * @since 6.5.0
         * @var false
         */
        protected $allow_batch = \false;
        /**
         * Checks if a given request has access to font families.
         *
         * @since 6.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Checks if a given request has access to a font family.
         *
         * @since 6.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Validates settings when creating or updating a font family.
         *
         * @since 6.5.0
         *
         * @param string          $value   Encoded JSON string of font family settings.
         * @param WP_REST_Request $request Request object.
         * @return true|WP_Error True if the settings are valid, otherwise a WP_Error object.
         */
        public function validate_font_family_settings($value, $request)
        {
        }
        /**
         * Sanitizes the font family settings when creating or updating a font family.
         *
         * @since 6.5.0
         *
         * @param string $value Encoded JSON string of font family settings.
         * @return array Decoded array of font family settings.
         */
        public function sanitize_font_family_settings($value)
        {
        }
        /**
         * Creates a single font family.
         *
         * @since 6.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Deletes a single font family.
         *
         * @since 6.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Prepares a single font family output for response.
         *
         * @since 6.5.0
         *
         * @param WP_Post         $item    Post object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Retrieves the post's schema, conforming to JSON Schema.
         *
         * @since 6.5.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the item's schema for display / public consumption purposes.
         *
         * @since 6.5.0
         *
         * @return array Public item schema data.
         */
        public function get_public_item_schema()
        {
        }
        /**
         * Retrieves the query params for the font family collection.
         *
         * @since 6.5.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
        /**
         * Get the arguments used when creating or updating a font family.
         *
         * @since 6.5.0
         *
         * @return array Font family create/edit arguments.
         */
        public function get_endpoint_args_for_item_schema($method = \WP_REST_Server::CREATABLE)
        {
        }
        /**
         * Get the child font face post IDs.
         *
         * @since 6.5.0
         *
         * @param int $font_family_id Font family post ID.
         * @return int[] Array of child font face post IDs.
         */
        protected function get_font_face_ids($font_family_id)
        {
        }
        /**
         * Prepares font family links for the request.
         *
         * @since 6.5.0
         *
         * @param WP_Post $post Post object.
         * @return array Links for the given post.
         */
        protected function prepare_links($post)
        {
        }
        /**
         * Prepares child font face links for the request.
         *
         * @param int $font_family_id Font family post ID.
         * @return array Links for the child font face posts.
         */
        protected function prepare_font_face_links($font_family_id)
        {
        }
        /**
         * Prepares a single font family post for create or update.
         *
         * @since 6.5.0
         *
         * @param WP_REST_Request $request Request object.
         * @return stdClass|WP_Error Post object or WP_Error.
         */
        protected function prepare_item_for_database($request)
        {
        }
        /**
         * Gets the font family's settings from the post.
         *
         * @since 6.5.0
         *
         * @param WP_Post $post Font family post object.
         * @return array Font family settings array.
         */
        protected function get_settings_from_post($post)
        {
        }
    }
    /**
     * Base Global Styles REST API Controller.
     */
    class WP_REST_Global_Styles_Controller extends \WP_REST_Posts_Controller
    {
        /**
         * Whether the controller supports batching.
         *
         * @since 6.6.0
         * @var array
         */
        protected $allow_batch = array('v1' => \false);
        /**
         * Constructor.
         *
         * @since 6.6.0
         *
         * @param string $post_type Post type.
         */
        public function __construct($post_type = 'wp_global_styles')
        {
        }
        /**
         * Registers the controllers routes.
         *
         * @since 5.9.0
         */
        public function register_routes()
        {
        }
        /**
         * Sanitize the global styles ID or stylesheet to decode endpoint.
         * For example, `wp/v2/global-styles/twentytwentytwo%200.4.0`
         * would be decoded to `twentytwentytwo 0.4.0`.
         *
         * @since 5.9.0
         *
         * @param string $id_or_stylesheet Global styles ID or stylesheet.
         * @return string Sanitized global styles ID or stylesheet.
         */
        public function _sanitize_global_styles_callback($id_or_stylesheet)
        {
        }
        /**
         * Get the post, if the ID is valid.
         *
         * @since 5.9.0
         *
         * @param int $id Supplied ID.
         * @return WP_Post|WP_Error Post object if ID is valid, WP_Error otherwise.
         */
        protected function get_post($id)
        {
        }
        /**
         * Checks if a given request has access to read a single global style.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Checks if a global style can be read.
         *
         * @since 5.9.0
         *
         * @param WP_Post $post Post object.
         * @return bool Whether the post can be read.
         */
        public function check_read_permission($post)
        {
        }
        /**
         * Checks if a given request has access to write a single global styles config.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has write access for the item, WP_Error object otherwise.
         */
        public function update_item_permissions_check($request)
        {
        }
        /**
         * Prepares a single global styles config for update.
         *
         * @since 5.9.0
         * @since 6.2.0 Added validation of styles.css property.
         * @since 6.6.0 Added registration of block style variations from theme.json sources (theme.json, user theme.json, partials).
         *
         * @param WP_REST_Request $request Request object.
         * @return stdClass|WP_Error Prepared item on success. WP_Error on when the custom CSS is not valid.
         */
        protected function prepare_item_for_database($request)
        {
        }
        /**
         * Prepare a global styles config output for response.
         *
         * @since 5.9.0
         * @since 6.6.0 Added custom relative theme file URIs to `_links`.
         *
         * @param WP_Post         $post    Global Styles post object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($post, $request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 5.9.0
         * @since 6.3.0 Adds revisions count and rest URL href to version-history.
         *
         * @param integer $id ID.
         * @return array Links for the given post.
         */
        protected function prepare_links($id)
        {
        }
        /**
         * Get the link relations available for the post and current user.
         *
         * @since 5.9.0
         * @since 6.2.0 Added 'edit-css' action.
         * @since 6.6.0 Added $post and $request parameters.
         *
         * @param WP_Post         $post    Post object.
         * @param WP_REST_Request $request Request object.
         * @return array List of link relations.
         */
        protected function get_available_actions($post, $request)
        {
        }
        /**
         * Retrieves the query params for the global styles collection.
         *
         * @since 5.9.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
        /**
         * Retrieves the global styles type' schema, conforming to JSON Schema.
         *
         * @since 5.9.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Checks if a given request has access to read a single theme global styles config.
         *
         * @since 5.9.0
         * @since 6.7.0 Allow users with edit post capabilities to view theme global styles.
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, WP_Error object otherwise.
         */
        public function get_theme_item_permissions_check($request)
        {
        }
        /**
         * Returns the given theme global styles config.
         *
         * @since 5.9.0
         * @since 6.6.0 Added custom relative theme file URIs to `_links`.
         *
         * @param WP_REST_Request $request The request instance.
         * @return WP_REST_Response|WP_Error
         */
        public function get_theme_item($request)
        {
        }
        /**
         * Checks if a given request has access to read a single theme global styles config.
         *
         * @since 6.0.0
         * @since 6.7.0 Allow users with edit post capabilities to view theme global styles.
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, WP_Error object otherwise.
         */
        public function get_theme_items_permissions_check($request)
        {
        }
        /**
         * Returns the given theme global styles variations.
         *
         * @since 6.0.0
         * @since 6.2.0 Returns parent theme variations, if they exist.
         * @since 6.6.0 Added custom relative theme file URIs to `_links` for each item.
         *
         * @param WP_REST_Request $request The request instance.
         *
         * @return WP_REST_Response|WP_Error
         */
        public function get_theme_items($request)
        {
        }
        /**
         * Validate style.css as valid CSS.
         *
         * Currently just checks for invalid markup.
         *
         * @since 6.2.0
         * @since 6.4.0 Changed method visibility to protected.
         *
         * @param string $css CSS to validate.
         * @return true|WP_Error True if the input was validated, otherwise WP_Error.
         */
        protected function validate_custom_css($css)
        {
        }
    }
    /**
     * Core class used to access global styles revisions via the REST API.
     *
     * @since 6.3.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Global_Styles_Revisions_Controller extends \WP_REST_Revisions_Controller
    {
        /**
         * The base of the parent controller's route.
         *
         * @since 6.3.0
         * @var string
         */
        protected $parent_base;
        /**
         * Parent post type.
         *
         * @since 6.6.0
         * @var string
         */
        protected $parent_post_type;
        /**
         * Constructor.
         *
         * @since 6.3.0
         * @since 6.6.0 Extends class from WP_REST_Revisions_Controller.
         *
         * @param string $parent_post_type Post type of the parent.
         */
        public function __construct($parent_post_type = 'wp_global_styles')
        {
        }
        /**
         * Registers the controller's routes.
         *
         * @since 6.3.0
         * @since 6.6.0 Added route to fetch individual global styles revisions.
         */
        public function register_routes()
        {
        }
        /**
         * Returns decoded JSON from post content string,
         * or a 404 if not found.
         *
         * @since 6.3.0
         *
         * @param string $raw_json Encoded JSON from global styles custom post content.
         * @return Array|WP_Error
         */
        protected function get_decoded_global_styles_json($raw_json)
        {
        }
        /**
         * Returns paginated revisions of the given global styles config custom post type.
         *
         * The bulk of the body is taken from WP_REST_Revisions_Controller->get_items,
         * but global styles does not require as many parameters.
         *
         * @since 6.3.0
         *
         * @param WP_REST_Request $request The request instance.
         * @return WP_REST_Response|WP_Error
         */
        public function get_items($request)
        {
        }
        /**
         * Prepares the revision for the REST response.
         *
         * @since 6.3.0
         * @since 6.6.0 Added resolved URI links to the response.
         *
         * @param WP_Post         $post    Post revision object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response|WP_Error Response object.
         */
        public function prepare_item_for_response($post, $request)
        {
        }
        /**
         * Retrieves the revision's schema, conforming to JSON Schema.
         *
         * @since 6.3.0
         * @since 6.6.0 Merged parent and parent controller schema data.
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the query params for collections.
         * Removes params that are not supported by global styles revisions.
         *
         * @since 6.6.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
    }
    /**
     * Core class to access nav items via the REST API.
     *
     * @since 5.9.0
     *
     * @see WP_REST_Posts_Controller
     */
    class WP_REST_Menu_Items_Controller extends \WP_REST_Posts_Controller
    {
        /**
         * Gets the nav menu item, if the ID is valid.
         *
         * @since 5.9.0
         *
         * @param int $id Supplied ID.
         * @return object|WP_Error Post object if ID is valid, WP_Error otherwise.
         */
        protected function get_nav_menu_item($id)
        {
        }
        /**
         * Checks if a given request has access to read menu items.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Checks if a given request has access to read a menu item if they have access to edit them.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return bool|WP_Error True if the request has read access for the item, WP_Error object or false otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Checks whether the current user has read permission for the endpoint.
         *
         * This allows for any user that can `edit_theme_options` or edit any REST API available post type.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, WP_Error object otherwise.
         */
        protected function check_has_read_only_access($request)
        {
        }
        /**
         * Creates a single nav menu item.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Updates a single nav menu item.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Deletes a single nav menu item.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error True on success, or WP_Error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Prepares a single nav menu item for create or update.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Request object.
         *
         * @return object|WP_Error
         */
        protected function prepare_item_for_database($request)
        {
        }
        /**
         * Prepares a single nav menu item output for response.
         *
         * @since 5.9.0
         *
         * @param WP_Post         $item    Post object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 5.9.0
         *
         * @param WP_Post $post Post object.
         * @return array Links for the given post.
         */
        protected function prepare_links($post)
        {
        }
        /**
         * Retrieves Link Description Objects that should be added to the Schema for the nav menu items collection.
         *
         * @since 5.9.0
         *
         * @return array
         */
        protected function get_schema_links()
        {
        }
        /**
         * Retrieves the nav menu item's schema, conforming to JSON Schema.
         *
         * @since 5.9.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the query params for the nav menu items collection.
         *
         * @since 5.9.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
        /**
         * Determines the allowed query_vars for a get_items() response and prepares
         * them for WP_Query.
         *
         * @since 5.9.0
         *
         * @param array           $prepared_args Optional. Prepared WP_Query arguments. Default empty array.
         * @param WP_REST_Request $request       Optional. Full details about the request.
         * @return array Items query arguments.
         */
        protected function prepare_items_query($prepared_args = array(), $request = \null)
        {
        }
        /**
         * Gets the id of the menu that the given menu item belongs to.
         *
         * @since 5.9.0
         *
         * @param int $menu_item_id Menu item id.
         * @return int
         */
        protected function get_menu_id($menu_item_id)
        {
        }
    }
    /**
     * Core class used to access menu locations via the REST API.
     *
     * @since 5.9.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Menu_Locations_Controller extends \WP_REST_Controller
    {
        /**
         * Menu Locations Constructor.
         *
         * @since 5.9.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the routes for the objects of the controller.
         *
         * @since 5.9.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks whether a given request has permission to read menu locations.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves all menu locations, depending on user context.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Checks if a given request has access to read a menu location.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Retrieves a specific menu location.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Prepares a menu location object for serialization.
         *
         * @since 5.9.0
         *
         * @param stdClass        $item    Post status data.
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response Menu location data.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 5.9.0
         *
         * @param stdClass $location Menu location.
         * @return array Links for the given menu location.
         */
        protected function prepare_links($location)
        {
        }
        /**
         * Retrieves the menu location's schema, conforming to JSON Schema.
         *
         * @since 5.9.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the query params for collections.
         *
         * @since 5.9.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
    }
    /**
     * Core class used to managed terms associated with a taxonomy via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Terms_Controller extends \WP_REST_Controller
    {
        /**
         * Taxonomy key.
         *
         * @since 4.7.0
         * @var string
         */
        protected $taxonomy;
        /**
         * Instance of a term meta fields object.
         *
         * @since 4.7.0
         * @var WP_REST_Term_Meta_Fields
         */
        protected $meta;
        /**
         * Column to have the terms be sorted by.
         *
         * @since 4.7.0
         * @var string
         */
        protected $sort_column;
        /**
         * Number of terms that were found.
         *
         * @since 4.7.0
         * @var int
         */
        protected $total_terms;
        /**
         * Whether the controller supports batching.
         *
         * @since 5.9.0
         * @var array
         */
        protected $allow_batch = array('v1' => \true);
        /**
         * Constructor.
         *
         * @since 4.7.0
         *
         * @param string $taxonomy Taxonomy key.
         */
        public function __construct($taxonomy)
        {
        }
        /**
         * Registers the routes for terms.
         *
         * @since 4.7.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks if the terms for a post can be read.
         *
         * @since 6.0.3
         *
         * @param WP_Post         $post    Post object.
         * @param WP_REST_Request $request Full details about the request.
         * @return bool Whether the terms for the post can be read.
         */
        public function check_read_terms_permission_for_post($post, $request)
        {
        }
        /**
         * Checks if a request has access to read terms in the specified taxonomy.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return bool|WP_Error True if the request has read access, otherwise false or WP_Error object.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves terms associated with a taxonomy.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Get the term, if the ID is valid.
         *
         * @since 4.7.2
         *
         * @param int $id Supplied ID.
         * @return WP_Term|WP_Error Term object if ID is valid, WP_Error otherwise.
         */
        protected function get_term($id)
        {
        }
        /**
         * Checks if a request has access to read or edit the specified term.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, otherwise WP_Error object.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Gets a single term from a taxonomy.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Checks if a request has access to create a term.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return bool|WP_Error True if the request has access to create items, otherwise false or WP_Error object.
         */
        public function create_item_permissions_check($request)
        {
        }
        /**
         * Creates a single term in a taxonomy.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Checks if a request has access to update the specified term.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to update the item, false or WP_Error object otherwise.
         */
        public function update_item_permissions_check($request)
        {
        }
        /**
         * Updates a single term from a taxonomy.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Checks if a request has access to delete the specified term.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to delete the item, otherwise false or WP_Error object.
         */
        public function delete_item_permissions_check($request)
        {
        }
        /**
         * Deletes a single term from a taxonomy.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Prepares a single term for create or update.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Request object.
         * @return object Term object.
         */
        public function prepare_item_for_database($request)
        {
        }
        /**
         * Prepares a single term output for response.
         *
         * @since 4.7.0
         *
         * @param WP_Term         $item    Term object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 4.7.0
         *
         * @param WP_Term $term Term object.
         * @return array Links for the given term.
         */
        protected function prepare_links($term)
        {
        }
        /**
         * Retrieves the term's schema, conforming to JSON Schema.
         *
         * @since 4.7.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the query params for collections.
         *
         * @since 4.7.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
        /**
         * Checks that the taxonomy is valid.
         *
         * @since 4.7.0
         *
         * @param string $taxonomy Taxonomy to check.
         * @return bool Whether the taxonomy is allowed for REST management.
         */
        protected function check_is_taxonomy_allowed($taxonomy)
        {
        }
    }
    /**
     * Core class used to managed menu terms associated via the REST API.
     *
     * @since 5.9.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Menus_Controller extends \WP_REST_Terms_Controller
    {
        /**
         * Checks if a request has access to read menus.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return bool|WP_Error True if the request has read access, otherwise false or WP_Error object.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Checks if a request has access to read or edit the specified menu.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, otherwise WP_Error object.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Gets the term, if the ID is valid.
         *
         * @since 5.9.0
         *
         * @param int $id Supplied ID.
         * @return WP_Term|WP_Error Term object if ID is valid, WP_Error otherwise.
         */
        protected function get_term($id)
        {
        }
        /**
         * Checks whether the current user has read permission for the endpoint.
         *
         * This allows for any user that can `edit_theme_options` or edit any REST API available post type.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the current user has permission, WP_Error object otherwise.
         */
        protected function check_has_read_only_access($request)
        {
        }
        /**
         * Prepares a single term output for response.
         *
         * @since 5.9.0
         *
         * @param WP_Term         $term    Term object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($term, $request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 5.9.0
         *
         * @param WP_Term $term Term object.
         * @return array Links for the given term.
         */
        protected function prepare_links($term)
        {
        }
        /**
         * Prepares a single term for create or update.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Request object.
         * @return object Prepared term data.
         */
        public function prepare_item_for_database($request)
        {
        }
        /**
         * Creates a single term in a taxonomy.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Updates a single term from a taxonomy.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Deletes a single term from a taxonomy.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Returns the value of a menu's auto_add setting.
         *
         * @since 5.9.0
         *
         * @param int $menu_id The menu id to query.
         * @return bool The value of auto_add.
         */
        protected function get_menu_auto_add($menu_id)
        {
        }
        /**
         * Updates the menu's auto add from a REST request.
         *
         * @since 5.9.0
         *
         * @param int             $menu_id The menu id to update.
         * @param WP_REST_Request $request Full details about the request.
         * @return bool True if the auto add setting was successfully updated.
         */
        protected function handle_auto_add($menu_id, $request)
        {
        }
        /**
         * Returns the names of the locations assigned to the menu.
         *
         * @since 5.9.0
         *
         * @param int $menu_id The menu id.
         * @return string[] The locations assigned to the menu.
         */
        protected function get_menu_locations($menu_id)
        {
        }
        /**
         * Updates the menu's locations from a REST request.
         *
         * @since 5.9.0
         *
         * @param int             $menu_id The menu id to update.
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True on success, a WP_Error on an error updating any of the locations.
         */
        protected function handle_locations($menu_id, $request)
        {
        }
        /**
         * Retrieves the term's schema, conforming to JSON Schema.
         *
         * @since 5.9.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
    }
    /**
     * REST Controller to fetch a fallback Navigation Block Menu. If needed it creates one.
     *
     * @since 6.3.0
     */
    class WP_REST_Navigation_Fallback_Controller extends \WP_REST_Controller
    {
        /**
         * Constructs the controller.
         *
         * @since 6.3.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the controllers routes.
         *
         * @since 6.3.0
         */
        public function register_routes()
        {
        }
        /**
         * Checks if a given request has access to read fallbacks.
         *
         * @since 6.3.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Gets the most appropriate fallback Navigation Menu.
         *
         * @since 6.3.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Retrieves the fallbacks' schema, conforming to JSON Schema.
         *
         * @since 6.3.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Matches the post data to the schema we want.
         *
         * @since 6.3.0
         *
         * @param WP_Post         $item    The wp_navigation Post object whose response is being prepared.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response $response The response data.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
    }
    /**
     * Controller which provides REST endpoint for block patterns.
     *
     * This simply proxies the endpoint at http://api.wordpress.org/patterns/1.0/. That isn't necessary for
     * functionality, but is desired for privacy. It prevents api.wordpress.org from knowing the user's IP address.
     *
     * @since 5.8.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Pattern_Directory_Controller extends \WP_REST_Controller
    {
        /**
         * Constructs the controller.
         *
         * @since 5.8.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the necessary REST API routes.
         *
         * @since 5.8.0
         */
        public function register_routes()
        {
        }
        /**
         * Checks whether a given request has permission to view the local block pattern directory.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has permission, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Search and retrieve block patterns metadata
         *
         * @since 5.8.0
         * @since 6.0.0 Added 'slug' to request.
         * @since 6.2.0 Added 'per_page', 'page', 'offset', 'order', and 'orderby' to request.
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Prepare a raw block pattern before it gets output in a REST API response.
         *
         * @since 5.8.0
         * @since 5.9.0 Renamed `$raw_pattern` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param object          $item    Raw pattern from api.wordpress.org, before any changes.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Retrieves the block pattern's schema, conforming to JSON Schema.
         *
         * @since 5.8.0
         * @since 6.2.0 Added `'block_types'` to schema.
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the search parameters for the block pattern's collection.
         *
         * @since 5.8.0
         * @since 6.2.0 Added 'per_page', 'page', 'offset', 'order', and 'orderby' to request.
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
        /**
         * Include a hash of the query args, so that different requests are stored in
         * separate caches.
         *
         * MD5 is chosen for its speed, low-collision rate, universal availability, and to stay
         * under the character limit for `_site_transient_timeout_{...}` keys.
         *
         * @link https://stackoverflow.com/questions/3665247/fastest-hash-for-non-cryptographic-uses
         *
         * @since 6.0.0
         *
         * @param array $query_args Query arguments to generate a transient key from.
         * @return string Transient key.
         */
        protected function get_transient_key($query_args)
        {
        }
    }
    /**
     * Core class to access plugins via the REST API.
     *
     * @since 5.5.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Plugins_Controller extends \WP_REST_Controller
    {
        const PATTERN = '[^.\\/]+(?:\\/[^.\\/]+)?';
        /**
         * Plugins controller constructor.
         *
         * @since 5.5.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the routes for the plugins controller.
         *
         * @since 5.5.0
         */
        public function register_routes()
        {
        }
        /**
         * Checks if a given request has access to get plugins.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves a collection of plugins.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Checks if a given request has access to get a specific plugin.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Retrieves one plugin from the site.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Checks if the given plugin can be viewed by the current user.
         *
         * On multisite, this hides non-active network only plugins if the user does not have permission
         * to manage network plugins.
         *
         * @since 5.5.0
         *
         * @param string $plugin The plugin file to check.
         * @return true|WP_Error True if can read, a WP_Error instance otherwise.
         */
        protected function check_read_permission($plugin)
        {
        }
        /**
         * Checks if a given request has access to upload plugins.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to create items, WP_Error object otherwise.
         */
        public function create_item_permissions_check($request)
        {
        }
        /**
         * Uploads a plugin and optionally activates it.
         *
         * @since 5.5.0
         *
         * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Checks if a given request has access to update a specific plugin.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to update the item, WP_Error object otherwise.
         */
        public function update_item_permissions_check($request)
        {
        }
        /**
         * Updates one plugin.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Checks if a given request has access to delete a specific plugin.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to delete the item, WP_Error object otherwise.
         */
        public function delete_item_permissions_check($request)
        {
        }
        /**
         * Deletes one plugin from the site.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Prepares the plugin for the REST response.
         *
         * @since 5.5.0
         *
         * @param array           $item    Unmarked up and untranslated plugin data from {@see get_plugin_data()}.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 5.5.0
         *
         * @param array $item The plugin item.
         * @return array[]
         */
        protected function prepare_links($item)
        {
        }
        /**
         * Gets the plugin header data for a plugin.
         *
         * @since 5.5.0
         *
         * @param string $plugin The plugin file to get data for.
         * @return array|WP_Error The plugin data, or a WP_Error if the plugin is not installed.
         */
        protected function get_plugin_data($plugin)
        {
        }
        /**
         * Get's the activation status for a plugin.
         *
         * @since 5.5.0
         *
         * @param string $plugin The plugin file to check.
         * @return string Either 'network-active', 'active' or 'inactive'.
         * @phpstan-return 'network-active'|'active'|'inactive'
         */
        protected function get_plugin_status($plugin)
        {
        }
        /**
         * Handle updating a plugin's status.
         *
         * @since 5.5.0
         *
         * @param string $plugin         The plugin file to update.
         * @param string $new_status     The plugin's new status.
         * @param string $current_status The plugin's current status.
         * @return true|WP_Error
         */
        protected function plugin_status_permission_check($plugin, $new_status, $current_status)
        {
        }
        /**
         * Handle updating a plugin's status.
         *
         * @since 5.5.0
         *
         * @param string $plugin         The plugin file to update.
         * @param string $new_status     The plugin's new status.
         * @param string $current_status The plugin's current status.
         * @return true|WP_Error
         */
        protected function handle_plugin_status($plugin, $new_status, $current_status)
        {
        }
        /**
         * Checks that the "plugin" parameter is a valid path.
         *
         * @since 5.5.0
         *
         * @param string $file The plugin file parameter.
         * @return bool
         */
        public function validate_plugin_param($file)
        {
        }
        /**
         * Sanitizes the "plugin" parameter to be a proper plugin file with ".php" appended.
         *
         * @since 5.5.0
         *
         * @param string $file The plugin file parameter.
         * @return string
         */
        public function sanitize_plugin_param($file)
        {
        }
        /**
         * Checks if the plugin matches the requested parameters.
         *
         * @since 5.5.0
         *
         * @param WP_REST_Request $request The request to require the plugin matches against.
         * @param array           $item    The plugin item.
         * @return bool
         */
        protected function does_plugin_match_request($request, $item)
        {
        }
        /**
         * Checks if the plugin is installed.
         *
         * @since 5.5.0
         *
         * @param string $plugin The plugin file.
         * @return bool
         */
        protected function is_plugin_installed($plugin)
        {
        }
        /**
         * Determine if the endpoints are available.
         *
         * Only the 'Direct' filesystem transport, and SSH/FTP when credentials are stored are supported at present.
         *
         * @since 5.5.0
         *
         * @return true|WP_Error True if filesystem is available, WP_Error otherwise.
         */
        protected function is_filesystem_available()
        {
        }
        /**
         * Retrieves the plugin's schema, conforming to JSON Schema.
         *
         * @since 5.5.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the query params for the collections.
         *
         * @since 5.5.0
         *
         * @return array Query parameters for the collection.
         */
        public function get_collection_params()
        {
        }
    }
    /**
     * Core class used to access post statuses via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Post_Statuses_Controller extends \WP_REST_Controller
    {
        /**
         * Constructor.
         *
         * @since 4.7.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the routes for post statuses.
         *
         * @since 4.7.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks whether a given request has permission to read post statuses.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves all post statuses, depending on user context.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Checks if a given request has access to read a post status.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Checks whether a given post status should be visible.
         *
         * @since 4.7.0
         *
         * @param object $status Post status.
         * @return bool True if the post status is visible, otherwise false.
         */
        protected function check_read_permission($status)
        {
        }
        /**
         * Retrieves a specific post status.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Prepares a post status object for serialization.
         *
         * @since 4.7.0
         * @since 5.9.0 Renamed `$status` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param stdClass        $item    Post status data.
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response Post status data.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Retrieves the post status' schema, conforming to JSON Schema.
         *
         * @since 4.7.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the query params for collections.
         *
         * @since 4.7.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
    }
    /**
     * Core class to access post types via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Post_Types_Controller extends \WP_REST_Controller
    {
        /**
         * Constructor.
         *
         * @since 4.7.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the routes for post types.
         *
         * @since 4.7.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks whether a given request has permission to read types.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves all public post types.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Retrieves a specific post type.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Prepares a post type object for serialization.
         *
         * @since 4.7.0
         * @since 5.9.0 Renamed `$post_type` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Post_Type    $item    Post type object.
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 6.1.0
         *
         * @param WP_Post_Type $post_type The post type.
         * @return array Links for the given post type.
         */
        protected function prepare_links($post_type)
        {
        }
        /**
         * Retrieves the post type's schema, conforming to JSON Schema.
         *
         * @since 4.7.0
         * @since 4.8.0 The `supports` property was added.
         * @since 5.9.0 The `visibility` and `rest_namespace` properties were added.
         * @since 6.1.0 The `icon` property was added.
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the query params for collections.
         *
         * @since 4.7.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
    }
    /**
     * Core class to search through all WordPress content via the REST API.
     *
     * @since 5.0.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Search_Controller extends \WP_REST_Controller
    {
        /**
         * ID property name.
         */
        const PROP_ID = 'id';
        /**
         * Title property name.
         */
        const PROP_TITLE = 'title';
        /**
         * URL property name.
         */
        const PROP_URL = 'url';
        /**
         * Type property name.
         */
        const PROP_TYPE = 'type';
        /**
         * Subtype property name.
         */
        const PROP_SUBTYPE = 'subtype';
        /**
         * Identifier for the 'any' type.
         */
        const TYPE_ANY = 'any';
        /**
         * Search handlers used by the controller.
         *
         * @since 5.0.0
         * @var WP_REST_Search_Handler[]
         */
        protected $search_handlers = array();
        /**
         * Constructor.
         *
         * @since 5.0.0
         *
         * @param array $search_handlers List of search handlers to use in the controller. Each search
         *                               handler instance must extend the `WP_REST_Search_Handler` class.
         */
        public function __construct(array $search_handlers)
        {
        }
        /**
         * Registers the routes for the search controller.
         *
         * @since 5.0.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks if a given request has access to search content.
         *
         * @since 5.0.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has search access, WP_Error object otherwise.
         */
        public function get_items_permission_check($request)
        {
        }
        /**
         * Retrieves a collection of search results.
         *
         * @since 5.0.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Prepares a single search result for response.
         *
         * @since 5.0.0
         * @since 5.6.0 The `$id` parameter can accept a string.
         * @since 5.9.0 Renamed `$id` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param int|string      $item    ID of the item to prepare.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Retrieves the item schema, conforming to JSON Schema.
         *
         * @since 5.0.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the query params for the search results collection.
         *
         * @since 5.0.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
        /**
         * Sanitizes the list of subtypes, to ensure only subtypes of the passed type are included.
         *
         * @since 5.0.0
         *
         * @param string|array    $subtypes  One or more subtypes.
         * @param WP_REST_Request $request   Full details about the request.
         * @param string          $parameter Parameter name.
         * @return string[]|WP_Error List of valid subtypes, or WP_Error object on failure.
         */
        public function sanitize_subtypes($subtypes, $request, $parameter)
        {
        }
        /**
         * Gets the search handler to handle the current request.
         *
         * @since 5.0.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Search_Handler|WP_Error Search handler for the request type, or WP_Error object on failure.
         */
        protected function get_search_handler($request)
        {
        }
    }
    /**
     * Core class used to manage a site's settings via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Settings_Controller extends \WP_REST_Controller
    {
        /**
         * Constructor.
         *
         * @since 4.7.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the routes for the site's settings.
         *
         * @since 4.7.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks if a given request has access to read and manage settings.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return bool True if the request has read access for the item, otherwise false.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Retrieves the settings.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return array|WP_Error Array on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Prepares a value for output based off a schema array.
         *
         * @since 4.7.0
         *
         * @param mixed $value  Value to prepare.
         * @param array $schema Schema to match.
         * @return mixed The prepared value.
         */
        protected function prepare_value($value, $schema)
        {
        }
        /**
         * Updates settings for the settings object.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return array|WP_Error Array on success, or error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Retrieves all of the registered options for the Settings API.
         *
         * @since 4.7.0
         *
         * @return array Array of registered options.
         */
        protected function get_registered_options()
        {
        }
        /**
         * Retrieves the site setting schema, conforming to JSON Schema.
         *
         * @since 4.7.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Custom sanitize callback used for all options to allow the use of 'null'.
         *
         * By default, the schema of settings will throw an error if a value is set to
         * `null` as it's not a valid value for something like "type => string". We
         * provide a wrapper sanitizer to allow the use of `null`.
         *
         * @since 4.7.0
         *
         * @param mixed           $value   The value for the setting.
         * @param WP_REST_Request $request The request object.
         * @param string          $param   The parameter name.
         * @return mixed|WP_Error
         */
        public function sanitize_callback($value, $request, $param)
        {
        }
        /**
         * Recursively add additionalProperties = false to all objects in a schema
         * if no additionalProperties setting is specified.
         *
         * This is needed to restrict properties of objects in settings values to only
         * registered items, as the REST API will allow additional properties by
         * default.
         *
         * @since 4.9.0
         * @deprecated 6.1.0 Use {@see rest_default_additional_properties_to_false()} instead.
         *
         * @param array $schema The schema array.
         * @return array
         */
        protected function set_additional_properties_to_false($schema)
        {
        }
    }
    /**
     * Core class used to manage a site's sidebars.
     *
     * @since 5.8.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Sidebars_Controller extends \WP_REST_Controller
    {
        /**
         * Tracks whether {@see retrieve_widgets()} has been called in the current request.
         *
         * @since 5.9.0
         * @var bool
         */
        protected $widgets_retrieved = \false;
        /**
         * Sidebars controller constructor.
         *
         * @since 5.8.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the controllers routes.
         *
         * @since 5.8.0
         */
        public function register_routes()
        {
        }
        /**
         * Checks if a given request has access to get sidebars.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves the list of sidebars (active or inactive).
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response Response object on success.
         */
        public function get_items($request)
        {
        }
        /**
         * Checks if a given request has access to get a single sidebar.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Checks if a sidebar can be read publicly.
         *
         * @since 5.9.0
         *
         * @param array $sidebar The registered sidebar configuration.
         * @return bool Whether the side can be read.
         */
        protected function check_read_permission($sidebar)
        {
        }
        /**
         * Retrieves one sidebar from the collection.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Checks if a given request has access to update sidebars.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function update_item_permissions_check($request)
        {
        }
        /**
         * Updates a sidebar.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response Response object on success, or WP_Error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Checks if the user has permissions to make the request.
         *
         * @since 5.8.0
         *
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        protected function do_permissions_check()
        {
        }
        /**
         * Retrieves the registered sidebar with the given id.
         *
         * @since 5.8.0
         *
         * @param string|int $id ID of the sidebar.
         * @return array|null The discovered sidebar, or null if it is not registered.
         */
        protected function get_sidebar($id)
        {
        }
        /**
         * Looks for "lost" widgets once per request.
         *
         * @since 5.9.0
         *
         * @see retrieve_widgets()
         */
        protected function retrieve_widgets()
        {
        }
        /**
         * Prepares a single sidebar output for response.
         *
         * @since 5.8.0
         * @since 5.9.0 Renamed `$raw_sidebar` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @global array $wp_registered_sidebars The registered sidebars.
         * @global array $wp_registered_widgets  The registered widgets.
         *
         * @param array           $item    Sidebar instance.
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response Prepared response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the sidebar.
         *
         * @since 5.8.0
         *
         * @param array $sidebar Sidebar.
         * @return array Links for the given widget.
         */
        protected function prepare_links($sidebar)
        {
        }
        /**
         * Retrieves the block type' schema, conforming to JSON Schema.
         *
         * @since 5.8.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
    }
    /**
     * Core class for interacting with Site Health tests.
     *
     * @since 5.6.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Site_Health_Controller extends \WP_REST_Controller
    {
        /**
         * Site Health controller constructor.
         *
         * @since 5.6.0
         *
         * @param WP_Site_Health $site_health An instance of the site health class.
         */
        public function __construct($site_health)
        {
        }
        /**
         * Registers API routes.
         *
         * @since 5.6.0
         * @since 6.1.0 Adds page-cache async test.
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Validates if the current user can request this REST endpoint.
         *
         * @since 5.6.0
         *
         * @param string $check The endpoint check being ran.
         * @return bool
         */
        protected function validate_request_permission($check)
        {
        }
        /**
         * Checks if background updates work as expected.
         *
         * @since 5.6.0
         *
         * @return array
         */
        public function test_background_updates()
        {
        }
        /**
         * Checks that the site can reach the WordPress.org API.
         *
         * @since 5.6.0
         *
         * @return array
         */
        public function test_dotorg_communication()
        {
        }
        /**
         * Checks that loopbacks can be performed.
         *
         * @since 5.6.0
         *
         * @return array
         */
        public function test_loopback_requests()
        {
        }
        /**
         * Checks that the site's frontend can be accessed over HTTPS.
         *
         * @since 5.7.0
         *
         * @return array
         */
        public function test_https_status()
        {
        }
        /**
         * Checks that the authorization header is valid.
         *
         * @since 5.6.0
         *
         * @return array
         */
        public function test_authorization_header()
        {
        }
        /**
         * Checks that full page cache is active.
         *
         * @since 6.1.0
         *
         * @return array The test result.
         */
        public function test_page_cache()
        {
        }
        /**
         * Gets the current directory sizes for this install.
         *
         * @since 5.6.0
         *
         * @return array|WP_Error
         */
        public function get_directory_sizes()
        {
        }
        /**
         * Loads the admin textdomain for Site Health tests.
         *
         * The {@see WP_Site_Health} class is defined in WP-Admin, while the REST API operates in a front-end context.
         * This means that the translations for Site Health won't be loaded by default in {@see load_default_textdomain()}.
         *
         * @since 5.6.0
         */
        protected function load_admin_textdomain()
        {
        }
        /**
         * Gets the schema for each site health test.
         *
         * @since 5.6.0
         *
         * @return array The test schema.
         */
        public function get_item_schema()
        {
        }
    }
    /**
     * Core class used to manage taxonomies via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Taxonomies_Controller extends \WP_REST_Controller
    {
        /**
         * Constructor.
         *
         * @since 4.7.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the routes for taxonomies.
         *
         * @since 4.7.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks whether a given request has permission to read taxonomies.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves all public taxonomies.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Checks if a given request has access to a taxonomy.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return bool|WP_Error True if the request has read access for the item, otherwise false or WP_Error object.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Retrieves a specific taxonomy.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Prepares a taxonomy object for serialization.
         *
         * @since 4.7.0
         * @since 5.9.0 Renamed `$taxonomy` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_Taxonomy     $item    Taxonomy data.
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 6.1.0
         *
         * @param WP_Taxonomy $taxonomy The taxonomy.
         * @return array Links for the given taxonomy.
         */
        protected function prepare_links($taxonomy)
        {
        }
        /**
         * Retrieves the taxonomy's schema, conforming to JSON Schema.
         *
         * @since 4.7.0
         * @since 5.0.0 The `visibility` property was added.
         * @since 5.9.0 The `rest_namespace` property was added.
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the query params for collections.
         *
         * @since 4.7.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
    }
    /**
     * Core class used to access template autosaves via the REST API.
     *
     * @since 6.4.0
     *
     * @see WP_REST_Autosaves_Controller
     */
    class WP_REST_Template_Autosaves_Controller extends \WP_REST_Autosaves_Controller
    {
        /**
         * Constructor.
         *
         * @since 6.4.0
         *
         * @param string $parent_post_type Post type of the parent.
         */
        public function __construct($parent_post_type)
        {
        }
        /**
         * Registers the routes for autosaves.
         *
         * @since 6.4.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Prepares the item for the REST response.
         *
         * @since 6.4.0
         *
         * @param WP_Post         $item    Post revision object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Gets the autosave, if the ID is valid.
         *
         * @since 6.4.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_Post|WP_Error Autosave post object if ID is valid, WP_Error otherwise.
         */
        public function get_item($request)
        {
        }
        /**
         * Get the parent post.
         *
         * @since 6.4.0
         *
         * @param int $parent_id Supplied ID.
         * @return WP_Post|WP_Error Post object if ID is valid, WP_Error otherwise.
         */
        protected function get_parent($parent_id)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 6.4.0
         *
         * @param WP_Block_Template $template Template.
         * @return array Links for the given post.
         */
        protected function prepare_links($template)
        {
        }
        /**
         * Retrieves the autosave's schema, conforming to JSON Schema.
         *
         * @since 6.4.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
    }
    /**
     * Core class used to access template revisions via the REST API.
     *
     * @since 6.4.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Template_Revisions_Controller extends \WP_REST_Revisions_Controller
    {
        /**
         * Constructor.
         *
         * @since 6.4.0
         *
         * @param string $parent_post_type Post type of the parent.
         */
        public function __construct($parent_post_type)
        {
        }
        /**
         * Registers the routes for revisions based on post types supporting revisions.
         *
         * @since 6.4.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Gets the parent post, if the template ID is valid.
         *
         * @since 6.4.0
         *
         * @param string $parent_template_id Supplied ID.
         * @return WP_Post|WP_Error Post object if ID is valid, WP_Error otherwise.
         */
        protected function get_parent($parent_template_id)
        {
        }
        /**
         * Prepares the item for the REST response.
         *
         * @since 6.4.0
         *
         * @param WP_Post         $item    Post revision object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Checks if a given request has access to delete a revision.
         *
         * @since 6.4.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to delete the item, WP_Error object otherwise.
         */
        public function delete_item_permissions_check($request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 6.4.0
         *
         * @param WP_Block_Template $template Template.
         * @return array Links for the given post.
         */
        protected function prepare_links($template)
        {
        }
        /**
         * Retrieves the item's schema, conforming to JSON Schema.
         *
         * @since 6.4.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
    }
    /**
     * Base Templates REST API Controller.
     *
     * @since 5.8.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Templates_Controller extends \WP_REST_Controller
    {
        /**
         * Post type.
         *
         * @since 5.8.0
         * @var string
         */
        protected $post_type;
        /**
         * Constructor.
         *
         * @since 5.8.0
         *
         * @param string $post_type Post type.
         */
        public function __construct($post_type)
        {
        }
        /**
         * Registers the controllers routes.
         *
         * @since 5.8.0
         * @since 6.1.0 Endpoint for fallback template content.
         */
        public function register_routes()
        {
        }
        /**
         * Returns the fallback template for the given slug.
         *
         * @since 6.1.0
         * @since 6.3.0 Ignore empty templates.
         *
         * @param WP_REST_Request $request The request instance.
         * @return WP_REST_Response|WP_Error
         */
        public function get_template_fallback($request)
        {
        }
        /**
         * Checks if the user has permissions to make the request.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        protected function permissions_check($request)
        {
        }
        /**
         * Requesting this endpoint for a template like 'twentytwentytwo//home'
         * requires using a path like /wp/v2/templates/twentytwentytwo//home. There
         * are special cases when WordPress routing corrects the name to contain
         * only a single slash like 'twentytwentytwo/home'.
         *
         * This method doubles the last slash if it's not already doubled. It relies
         * on the template ID format {theme_name}//{template_slug} and the fact that
         * slugs cannot contain slashes.
         *
         * @since 5.9.0
         * @see https://core.trac.wordpress.org/ticket/54507
         *
         * @param string $id Template ID.
         * @return string Sanitized template ID.
         */
        public function _sanitize_template_id($id)
        {
        }
        /**
         * Checks if a given request has access to read templates.
         *
         * @since 5.8.0
         * @since 6.6.0 Allow users with edit_posts capability to read templates.
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Returns a list of templates.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request The request instance.
         * @return WP_REST_Response
         */
        public function get_items($request)
        {
        }
        /**
         * Checks if a given request has access to read a single template.
         *
         * @since 5.8.0
         * @since 6.6.0 Allow users with edit_posts capability to read individual templates.
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Returns the given template
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request The request instance.
         * @return WP_REST_Response|WP_Error
         */
        public function get_item($request)
        {
        }
        /**
         * Checks if a given request has access to write a single template.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has write access for the item, WP_Error object otherwise.
         */
        public function update_item_permissions_check($request)
        {
        }
        /**
         * Updates a single template.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Checks if a given request has access to create a template.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to create items, WP_Error object otherwise.
         */
        public function create_item_permissions_check($request)
        {
        }
        /**
         * Creates a single template.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Checks if a given request has access to delete a single template.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has delete access for the item, WP_Error object otherwise.
         */
        public function delete_item_permissions_check($request)
        {
        }
        /**
         * Deletes a single template.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Prepares a single template for create or update.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Request object.
         * @return stdClass|WP_Error Changes to pass to wp_update_post.
         */
        protected function prepare_item_for_database($request)
        {
        }
        /**
         * Prepare a single template output for response
         *
         * @since 5.8.0
         * @since 5.9.0 Renamed `$template` to `$item` to match parent class for PHP 8 named parameter support.
         * @since 6.3.0 Added `modified` property to the response.
         *
         * @param WP_Block_Template $item    Template instance.
         * @param WP_REST_Request   $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 5.8.0
         *
         * @param integer $id ID.
         * @return array Links for the given post.
         */
        protected function prepare_links($id)
        {
        }
        /**
         * Get the link relations available for the post and current user.
         *
         * @since 5.8.0
         *
         * @return string[] List of link relations.
         */
        protected function get_available_actions()
        {
        }
        /**
         * Retrieves the query params for the posts collection.
         *
         * @since 5.8.0
         * @since 5.9.0 Added `'area'` and `'post_type'`.
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
        /**
         * Retrieves the block type' schema, conforming to JSON Schema.
         *
         * @since 5.8.0
         * @since 5.9.0 Added `'area'`.
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
    }
    /**
     * Core class used to manage themes via the REST API.
     *
     * @since 5.0.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Themes_Controller extends \WP_REST_Controller
    {
        /**
         * Matches theme's directory: `/themes/<subdirectory>/<theme>/` or `/themes/<theme>/`.
         * Excludes invalid directory name characters: `/:<>*?"|`.
         */
        const PATTERN = '[^\\/:<>\\*\\?"\\|]+(?:\\/[^\\/:<>\\*\\?"\\|]+)?';
        /**
         * Constructor.
         *
         * @since 5.0.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the routes for themes.
         *
         * @since 5.0.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Sanitize the stylesheet to decode endpoint.
         *
         * @since 5.9.0
         *
         * @param string $stylesheet The stylesheet name.
         * @return string Sanitized stylesheet.
         */
        public function _sanitize_stylesheet_callback($stylesheet)
        {
        }
        /**
         * Checks if a given request has access to read the theme.
         *
         * @since 5.0.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, otherwise WP_Error object.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Checks if a given request has access to read the theme.
         *
         * @since 5.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, otherwise WP_Error object.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Checks if a theme can be read.
         *
         * @since 5.7.0
         *
         * @return true|WP_Error True if the theme can be read, WP_Error object otherwise.
         */
        protected function check_read_active_theme_permission()
        {
        }
        /**
         * Retrieves a single theme.
         *
         * @since 5.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Retrieves a collection of themes.
         *
         * @since 5.0.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Prepares a single theme output for response.
         *
         * @since 5.0.0
         * @since 5.9.0 Renamed `$theme` to `$item` to match parent class for PHP 8 named parameter support.
         * @since 6.6.0 Added `stylesheet_uri` and `template_uri` fields.
         *
         * @param WP_Theme        $item    Theme object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the request.
         *
         * @since 5.7.0
         *
         * @param WP_Theme $theme Theme data.
         * @return array Links for the given block type.
         */
        protected function prepare_links($theme)
        {
        }
        /**
         * Helper function to compare two themes.
         *
         * @since 5.7.0
         *
         * @param WP_Theme $theme_a First theme to compare.
         * @param WP_Theme $theme_b Second theme to compare.
         * @return bool
         */
        protected function is_same_theme($theme_a, $theme_b)
        {
        }
        /**
         * Prepares the theme support value for inclusion in the REST API response.
         *
         * @since 5.5.0
         *
         * @param mixed           $support The raw value from get_theme_support().
         * @param array           $args    The feature's registration args.
         * @param string          $feature The feature name.
         * @param WP_REST_Request $request The request object.
         * @return mixed The prepared support value.
         */
        protected function prepare_theme_support($support, $args, $feature, $request)
        {
        }
        /**
         * Retrieves the theme's schema, conforming to JSON Schema.
         *
         * @since 5.0.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the search params for the themes collection.
         *
         * @since 5.0.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
        /**
         * Sanitizes and validates the list of theme status.
         *
         * @since 5.0.0
         * @deprecated 5.7.0
         *
         * @param string|array    $statuses  One or more theme statuses.
         * @param WP_REST_Request $request   Full details about the request.
         * @param string          $parameter Additional parameter to pass to validation.
         * @return array|WP_Error A list of valid statuses, otherwise WP_Error object.
         */
        public function sanitize_theme_status($statuses, $request, $parameter)
        {
        }
    }
    /**
     * Controller which provides REST endpoint for retrieving information
     * from a remote site's HTML response.
     *
     * @since 5.9.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_URL_Details_Controller extends \WP_REST_Controller
    {
        /**
         * Constructs the controller.
         *
         * @since 5.9.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the necessary REST API routes.
         *
         * @since 5.9.0
         */
        public function register_routes()
        {
        }
        /**
         * Retrieves the item's schema, conforming to JSON Schema.
         *
         * @since 5.9.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the contents of the title tag from the HTML response.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error The parsed details as a response object. WP_Error if there are errors.
         */
        public function parse_url_details($request)
        {
        }
        /**
         * Checks whether a given request has permission to read remote URLs.
         *
         * @since 5.9.0
         *
         * @return true|WP_Error True if the request has permission, else WP_Error.
         */
        public function permissions_check()
        {
        }
    }
    /**
     * Core class used to manage users via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Users_Controller extends \WP_REST_Controller
    {
        /**
         * Instance of a user meta fields object.
         *
         * @since 4.7.0
         * @var WP_REST_User_Meta_Fields
         */
        protected $meta;
        /**
         * Whether the controller supports batching.
         *
         * @since 6.6.0
         * @var array
         */
        protected $allow_batch = array('v1' => \true);
        /**
         * Constructor.
         *
         * @since 4.7.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the routes for users.
         *
         * @since 4.7.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks for a valid value for the reassign parameter when deleting users.
         *
         * The value can be an integer, 'false', false, or ''.
         *
         * @since 4.7.0
         *
         * @param int|bool        $value   The value passed to the reassign parameter.
         * @param WP_REST_Request $request Full details about the request.
         * @param string          $param   The parameter that is being sanitized.
         * @return int|bool|WP_Error
         */
        public function check_reassign($value, $request, $param)
        {
        }
        /**
         * Permissions check for getting all users.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, otherwise WP_Error object.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves all users.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Get the user, if the ID is valid.
         *
         * @since 4.7.2
         *
         * @param int $id Supplied ID.
         * @return WP_User|WP_Error True if ID is valid, WP_Error otherwise.
         */
        protected function get_user($id)
        {
        }
        /**
         * Checks if a given request has access to read a user.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, otherwise WP_Error object.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Retrieves a single user.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Retrieves the current user.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_current_item($request)
        {
        }
        /**
         * Checks if a given request has access create users.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to create items, WP_Error object otherwise.
         */
        public function create_item_permissions_check($request)
        {
        }
        /**
         * Creates a single user.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Checks if a given request has access to update a user.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to update the item, WP_Error object otherwise.
         */
        public function update_item_permissions_check($request)
        {
        }
        /**
         * Updates a single user.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Checks if a given request has access to update the current user.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to update the item, WP_Error object otherwise.
         */
        public function update_current_item_permissions_check($request)
        {
        }
        /**
         * Updates the current user.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function update_current_item($request)
        {
        }
        /**
         * Checks if a given request has access delete a user.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to delete the item, WP_Error object otherwise.
         */
        public function delete_item_permissions_check($request)
        {
        }
        /**
         * Deletes a single user.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Checks if a given request has access to delete the current user.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has access to delete the item, WP_Error object otherwise.
         */
        public function delete_current_item_permissions_check($request)
        {
        }
        /**
         * Deletes the current user.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_current_item($request)
        {
        }
        /**
         * Prepares a single user output for response.
         *
         * @since 4.7.0
         * @since 5.9.0 Renamed `$user` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param WP_User         $item    User object.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response Response object.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the user request.
         *
         * @since 4.7.0
         *
         * @param WP_User $user User object.
         * @return array Links for the given user.
         */
        protected function prepare_links($user)
        {
        }
        /**
         * Prepares a single user for creation or update.
         *
         * @since 4.7.0
         *
         * @param WP_REST_Request $request Request object.
         * @return object User object.
         */
        protected function prepare_item_for_database($request)
        {
        }
        /**
         * Determines if the current user is allowed to make the desired roles change.
         *
         * @since 4.7.0
         *
         * @global WP_Roles $wp_roles WordPress role management object.
         *
         * @param int   $user_id User ID.
         * @param array $roles   New user roles.
         * @return true|WP_Error True if the current user is allowed to make the role change,
         *                       otherwise a WP_Error object.
         */
        protected function check_role_update($user_id, $roles)
        {
        }
        /**
         * Check a username for the REST API.
         *
         * Performs a couple of checks like edit_user() in wp-admin/includes/user.php.
         *
         * @since 4.7.0
         *
         * @param string          $value   The username submitted in the request.
         * @param WP_REST_Request $request Full details about the request.
         * @param string          $param   The parameter name.
         * @return string|WP_Error The sanitized username, if valid, otherwise an error.
         */
        public function check_username($value, $request, $param)
        {
        }
        /**
         * Check a user password for the REST API.
         *
         * Performs a couple of checks like edit_user() in wp-admin/includes/user.php.
         *
         * @since 4.7.0
         *
         * @param string          $value   The password submitted in the request.
         * @param WP_REST_Request $request Full details about the request.
         * @param string          $param   The parameter name.
         * @return string|WP_Error The sanitized password, if valid, otherwise an error.
         */
        public function check_user_password($value, $request, $param)
        {
        }
        /**
         * Retrieves the user's schema, conforming to JSON Schema.
         *
         * @since 4.7.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * Retrieves the query params for collections.
         *
         * @since 4.7.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
    }
    /**
     * Core class to access widget types via the REST API.
     *
     * @since 5.8.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Widget_Types_Controller extends \WP_REST_Controller
    {
        /**
         * Constructor.
         *
         * @since 5.8.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the widget type routes.
         *
         * @since 5.8.0
         *
         * @see register_rest_route()
         */
        public function register_routes()
        {
        }
        /**
         * Checks whether a given request has permission to read widget types.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves the list of all widget types.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_items($request)
        {
        }
        /**
         * Checks if a given request has access to read a widget type.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access for the item, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Checks whether the user can read widget types.
         *
         * @since 5.8.0
         *
         * @return true|WP_Error True if the widget type is visible, WP_Error otherwise.
         */
        protected function check_read_permission()
        {
        }
        /**
         * Gets the details about the requested widget.
         *
         * @since 5.8.0
         *
         * @param string $id The widget type id.
         * @return array|WP_Error The array of widget data if the name is valid, WP_Error otherwise.
         */
        public function get_widget($id)
        {
        }
        /**
         * Normalize array of widgets.
         *
         * @since 5.8.0
         *
         * @global WP_Widget_Factory $wp_widget_factory
         * @global array             $wp_registered_widgets The list of registered widgets.
         *
         * @return array Array of widgets.
         */
        protected function get_widgets()
        {
        }
        /**
         * Retrieves a single widget type from the collection.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Prepares a widget type object for serialization.
         *
         * @since 5.8.0
         * @since 5.9.0 Renamed `$widget_type` to `$item` to match parent class for PHP 8 named parameter support.
         *
         * @param array           $item    Widget type data.
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response Widget type data.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the widget type.
         *
         * @since 5.8.0
         *
         * @param array $widget_type Widget type data.
         * @return array Links for the given widget type.
         */
        protected function prepare_links($widget_type)
        {
        }
        /**
         * Retrieves the widget type's schema, conforming to JSON Schema.
         *
         * @since 5.8.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
        /**
         * An RPC-style endpoint which can be used by clients to turn user input in
         * a widget admin form into an encoded instance object.
         *
         * Accepts:
         *
         * - id:        A widget type ID.
         * - instance:  A widget's encoded instance object. Optional.
         * - form_data: Form data from submitting a widget's admin form. Optional.
         *
         * Returns:
         * - instance: The encoded instance object after updating the widget with
         *             the given form data.
         * - form:     The widget's admin form after updating the widget with the
         *             given form data.
         *
         * @since 5.8.0
         *
         * @global WP_Widget_Factory $wp_widget_factory
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function encode_form_data($request)
        {
        }
        /**
         * Renders a single Legacy Widget and wraps it in a JSON-encodable array.
         *
         * @since 5.9.0
         *
         * @param WP_REST_Request $request Full details about the request.
         *
         * @return array An array with rendered Legacy Widget HTML.
         */
        public function render($request)
        {
        }
        /**
         * Retrieves the query params for collections.
         *
         * @since 5.8.0
         *
         * @return array Collection parameters.
         */
        public function get_collection_params()
        {
        }
    }
    /**
     * Core class to access widgets via the REST API.
     *
     * @since 5.8.0
     *
     * @see WP_REST_Controller
     */
    class WP_REST_Widgets_Controller extends \WP_REST_Controller
    {
        /**
         * Tracks whether {@see retrieve_widgets()} has been called in the current request.
         *
         * @since 5.9.0
         * @var bool
         */
        protected $widgets_retrieved = \false;
        /**
         * Whether the controller supports batching.
         *
         * @since 5.9.0
         * @var array
         */
        protected $allow_batch = array('v1' => \true);
        /**
         * Widgets controller constructor.
         *
         * @since 5.8.0
         */
        public function __construct()
        {
        }
        /**
         * Registers the widget routes for the controller.
         *
         * @since 5.8.0
         */
        public function register_routes()
        {
        }
        /**
         * Checks if a given request has access to get widgets.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_items_permissions_check($request)
        {
        }
        /**
         * Retrieves a collection of widgets.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response Response object.
         */
        public function get_items($request)
        {
        }
        /**
         * Checks if a given request has access to get a widget.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function get_item_permissions_check($request)
        {
        }
        /**
         * Checks if a sidebar can be read publicly.
         *
         * @since 5.9.0
         *
         * @param string $sidebar_id The sidebar ID.
         * @return bool Whether the sidebar can be read.
         */
        protected function check_read_sidebar_permission($sidebar_id)
        {
        }
        /**
         * Gets an individual widget.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function get_item($request)
        {
        }
        /**
         * Checks if a given request has access to create widgets.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function create_item_permissions_check($request)
        {
        }
        /**
         * Creates a widget.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function create_item($request)
        {
        }
        /**
         * Checks if a given request has access to update widgets.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function update_item_permissions_check($request)
        {
        }
        /**
         * Updates an existing widget.
         *
         * @since 5.8.0
         *
         * @global WP_Widget_Factory $wp_widget_factory
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function update_item($request)
        {
        }
        /**
         * Checks if a given request has access to delete widgets.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error True if the request has read access, WP_Error object otherwise.
         */
        public function delete_item_permissions_check($request)
        {
        }
        /**
         * Deletes a widget.
         *
         * @since 5.8.0
         *
         * @global WP_Widget_Factory $wp_widget_factory
         * @global array             $wp_registered_widget_updates The registered widget update functions.
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function delete_item($request)
        {
        }
        /**
         * Performs a permissions check for managing widgets.
         *
         * @since 5.8.0
         *
         * @param WP_REST_Request $request Full details about the request.
         * @return true|WP_Error
         */
        protected function permissions_check($request)
        {
        }
        /**
         * Looks for "lost" widgets once per request.
         *
         * @since 5.9.0
         *
         * @see retrieve_widgets()
         */
        protected function retrieve_widgets()
        {
        }
        /**
         * Saves the widget in the request object.
         *
         * @since 5.8.0
         *
         * @global WP_Widget_Factory $wp_widget_factory
         * @global array             $wp_registered_widget_updates The registered widget update functions.
         *
         * @param WP_REST_Request $request    Full details about the request.
         * @param string          $sidebar_id ID of the sidebar the widget belongs to.
         * @return string|WP_Error The saved widget ID.
         */
        protected function save_widget($request, $sidebar_id)
        {
        }
        /**
         * Prepares the widget for the REST response.
         *
         * @since 5.8.0
         *
         * @global WP_Widget_Factory $wp_widget_factory
         * @global array             $wp_registered_widgets The registered widgets.
         *
         * @param array           $item    An array containing a widget_id and sidebar_id.
         * @param WP_REST_Request $request Request object.
         * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
         */
        public function prepare_item_for_response($item, $request)
        {
        }
        /**
         * Prepares links for the widget.
         *
         * @since 5.8.0
         *
         * @param array $prepared Widget.
         * @return array Links for the given widget.
         */
        protected function prepare_links($prepared)
        {
        }
        /**
         * Gets the list of collection params.
         *
         * @since 5.8.0
         *
         * @return array[]
         */
        public function get_collection_params()
        {
        }
        /**
         * Retrieves the widget's schema, conforming to JSON Schema.
         *
         * @since 5.8.0
         *
         * @return array Item schema data.
         */
        public function get_item_schema()
        {
        }
    }
    /**
     * Core class to manage meta values for an object via the REST API.
     *
     * @since 4.7.0
     */
    #[\AllowDynamicProperties]
    abstract class WP_REST_Meta_Fields
    {
        /**
         * Retrieves the object meta type.
         *
         * @since 4.7.0
         *
         * @return string One of 'post', 'comment', 'term', 'user', or anything
         *                else supported by `_get_meta_table()`.
         */
        protected abstract function get_meta_type();
        /**
         * Retrieves the object meta subtype.
         *
         * @since 4.9.8
         *
         * @return string Subtype for the meta type, or empty string if no specific subtype.
         */
        protected function get_meta_subtype()
        {
        }
        /**
         * Retrieves the object type for register_rest_field().
         *
         * @since 4.7.0
         *
         * @return string The REST field type, such as post type name, taxonomy name, 'comment', or `user`.
         */
        protected abstract function get_rest_field_type();
        /**
         * Registers the meta field.
         *
         * @since 4.7.0
         * @deprecated 5.6.0
         *
         * @see register_rest_field()
         */
        public function register_field()
        {
        }
        /**
         * Retrieves the meta field value.
         *
         * @since 4.7.0
         *
         * @param int             $object_id Object ID to fetch meta for.
         * @param WP_REST_Request $request   Full details about the request.
         * @return array Array containing the meta values keyed by name.
         */
        public function get_value($object_id, $request)
        {
        }
        /**
         * Prepares a meta value for a response.
         *
         * This is required because some native types cannot be stored correctly
         * in the database, such as booleans. We need to cast back to the relevant
         * type before passing back to JSON.
         *
         * @since 4.7.0
         *
         * @param mixed           $value   Meta value to prepare.
         * @param WP_REST_Request $request Current request object.
         * @param array           $args    Options for the field.
         * @return mixed Prepared value.
         */
        protected function prepare_value_for_response($value, $request, $args)
        {
        }
        /**
         * Updates meta values.
         *
         * @since 4.7.0
         *
         * @param array $meta      Array of meta parsed from the request.
         * @param int   $object_id Object ID to fetch meta for.
         * @return null|WP_Error Null on success, WP_Error object on failure.
         */
        public function update_value($meta, $object_id)
        {
        }
        /**
         * Deletes a meta value for an object.
         *
         * @since 4.7.0
         *
         * @param int    $object_id Object ID the field belongs to.
         * @param string $meta_key  Key for the field.
         * @param string $name      Name for the field that is exposed in the REST API.
         * @return true|WP_Error True if meta field is deleted, WP_Error otherwise.
         */
        protected function delete_meta_value($object_id, $meta_key, $name)
        {
        }
        /**
         * Updates multiple meta values for an object.
         *
         * Alters the list of values in the database to match the list of provided values.
         *
         * @since 4.7.0
         * @since 6.7.0 Stores values into DB even if provided registered default value.
         *
         * @param int    $object_id Object ID to update.
         * @param string $meta_key  Key for the custom field.
         * @param string $name      Name for the field that is exposed in the REST API.
         * @param array  $values    List of values to update to.
         * @return true|WP_Error True if meta fields are updated, WP_Error otherwise.
         */
        protected function update_multi_meta_value($object_id, $meta_key, $name, $values)
        {
        }
        /**
         * Updates a meta value for an object.
         *
         * @since 4.7.0
         * @since 6.7.0 Stores values into DB even if provided registered default value.
         *
         * @param int    $object_id Object ID to update.
         * @param string $meta_key  Key for the custom field.
         * @param string $name      Name for the field that is exposed in the REST API.
         * @param mixed  $value     Updated value.
         * @return true|WP_Error True if the meta field was updated, WP_Error otherwise.
         */
        protected function update_meta_value($object_id, $meta_key, $name, $value)
        {
        }
        /**
         * Checks if the user provided value is equivalent to a stored value for the given meta key.
         *
         * @since 5.5.0
         *
         * @param string $meta_key     The meta key being checked.
         * @param string $subtype      The object subtype.
         * @param mixed  $stored_value The currently stored value retrieved from get_metadata().
         * @param mixed  $user_value   The value provided by the user.
         * @return bool
         */
        protected function is_meta_value_same_as_stored_value($meta_key, $subtype, $stored_value, $user_value)
        {
        }
        /**
         * Retrieves all the registered meta fields.
         *
         * @since 4.7.0
         *
         * @return array Registered fields.
         */
        protected function get_registered_fields()
        {
        }
        /**
         * Retrieves the object's meta schema, conforming to JSON Schema.
         *
         * @since 4.7.0
         *
         * @return array Field schema data.
         */
        public function get_field_schema()
        {
        }
        /**
         * Prepares a meta value for output.
         *
         * Default preparation for meta fields. Override by passing the
         * `prepare_callback` in your `show_in_rest` options.
         *
         * @since 4.7.0
         *
         * @param mixed           $value   Meta value from the database.
         * @param WP_REST_Request $request Request object.
         * @param array           $args    REST-specific options for the meta key.
         * @return mixed Value prepared for output. If a non-JsonSerializable object, null.
         */
        public static function prepare_value($value, $request, $args)
        {
        }
        /**
         * Check the 'meta' value of a request is an associative array.
         *
         * @since 4.7.0
         *
         * @param mixed           $value   The meta value submitted in the request.
         * @param WP_REST_Request $request Full details about the request.
         * @param string          $param   The parameter name.
         * @return array|false The meta array, if valid, false otherwise.
         */
        public function check_meta_is_array($value, $request, $param)
        {
        }
        /**
         * Recursively add additionalProperties = false to all objects in a schema if no additionalProperties setting
         * is specified.
         *
         * This is needed to restrict properties of objects in meta values to only
         * registered items, as the REST API will allow additional properties by
         * default.
         *
         * @since 5.3.0
         * @deprecated 5.6.0 Use rest_default_additional_properties_to_false() instead.
         *
         * @param array $schema The schema array.
         * @return array
         */
        protected function default_additional_properties_to_false($schema)
        {
        }
        /**
         * Gets the empty value for a schema type.
         *
         * @since 5.3.0
         *
         * @param string $type The schema type.
         * @return mixed
         */
        protected static function get_empty_value_for_type($type)
        {
        }
    }
    /**
     * Core class to manage comment meta via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Meta_Fields
     */
    class WP_REST_Comment_Meta_Fields extends \WP_REST_Meta_Fields
    {
        /**
         * Retrieves the comment type for comment meta.
         *
         * @since 4.7.0
         *
         * @return string The meta type.
         */
        protected function get_meta_type()
        {
        }
        /**
         * Retrieves the comment meta subtype.
         *
         * @since 4.9.8
         *
         * @return string 'comment' There are no subtypes.
         */
        protected function get_meta_subtype()
        {
        }
        /**
         * Retrieves the type for register_rest_field() in the context of comments.
         *
         * @since 4.7.0
         *
         * @return string The REST field type.
         */
        public function get_rest_field_type()
        {
        }
    }
    /**
     * Core class used to manage meta values for posts via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Meta_Fields
     */
    class WP_REST_Post_Meta_Fields extends \WP_REST_Meta_Fields
    {
        /**
         * Post type to register fields for.
         *
         * @since 4.7.0
         * @var string
         */
        protected $post_type;
        /**
         * Constructor.
         *
         * @since 4.7.0
         *
         * @param string $post_type Post type to register fields for.
         */
        public function __construct($post_type)
        {
        }
        /**
         * Retrieves the post meta type.
         *
         * @since 4.7.0
         *
         * @return string The meta type.
         */
        protected function get_meta_type()
        {
        }
        /**
         * Retrieves the post meta subtype.
         *
         * @since 4.9.8
         *
         * @return string Subtype for the meta type, or empty string if no specific subtype.
         */
        protected function get_meta_subtype()
        {
        }
        /**
         * Retrieves the type for register_rest_field().
         *
         * @since 4.7.0
         *
         * @see register_rest_field()
         *
         * @return string The REST field type.
         */
        public function get_rest_field_type()
        {
        }
    }
    /**
     * Core class used to manage meta values for terms via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Meta_Fields
     */
    class WP_REST_Term_Meta_Fields extends \WP_REST_Meta_Fields
    {
        /**
         * Taxonomy to register fields for.
         *
         * @since 4.7.0
         * @var string
         */
        protected $taxonomy;
        /**
         * Constructor.
         *
         * @since 4.7.0
         *
         * @param string $taxonomy Taxonomy to register fields for.
         */
        public function __construct($taxonomy)
        {
        }
        /**
         * Retrieves the term meta type.
         *
         * @since 4.7.0
         *
         * @return string The meta type.
         */
        protected function get_meta_type()
        {
        }
        /**
         * Retrieves the term meta subtype.
         *
         * @since 4.9.8
         *
         * @return string Subtype for the meta type, or empty string if no specific subtype.
         */
        protected function get_meta_subtype()
        {
        }
        /**
         * Retrieves the type for register_rest_field().
         *
         * @since 4.7.0
         *
         * @return string The REST field type.
         */
        public function get_rest_field_type()
        {
        }
    }
    /**
     * Core class used to manage meta values for users via the REST API.
     *
     * @since 4.7.0
     *
     * @see WP_REST_Meta_Fields
     */
    class WP_REST_User_Meta_Fields extends \WP_REST_Meta_Fields
    {
        /**
         * Retrieves the user meta type.
         *
         * @since 4.7.0
         *
         * @return string The user meta type.
         */
        protected function get_meta_type()
        {
        }
        /**
         * Retrieves the user meta subtype.
         *
         * @since 4.9.8
         *
         * @return string 'user' There are no subtypes.
         */
        protected function get_meta_subtype()
        {
        }
        /**
         * Retrieves the type for register_rest_field().
         *
         * @since 4.7.0
         *
         * @return string The user REST field type.
         */
        public function get_rest_field_type()
        {
        }
    }
    /**
     * Core base class representing a search handler for an object type in the REST API.
     *
     * @since 5.0.0
     */
    #[\AllowDynamicProperties]
    abstract class WP_REST_Search_Handler
    {
        /**
         * Field containing the IDs in the search result.
         */
        const RESULT_IDS = 'ids';
        /**
         * Field containing the total count in the search result.
         */
        const RESULT_TOTAL = 'total';
        /**
         * Object type managed by this search handler.
         *
         * @since 5.0.0
         * @var string
         */
        protected $type = '';
        /**
         * Object subtypes managed by this search handler.
         *
         * @since 5.0.0
         * @var string[]
         */
        protected $subtypes = array();
        /**
         * Gets the object type managed by this search handler.
         *
         * @since 5.0.0
         *
         * @return string Object type identifier.
         */
        public function get_type()
        {
        }
        /**
         * Gets the object subtypes managed by this search handler.
         *
         * @since 5.0.0
         *
         * @return string[] Array of object subtype identifiers.
         */
        public function get_subtypes()
        {
        }
        /**
         * Searches the object type content for a given search request.
         *
         * @since 5.0.0
         *
         * @param WP_REST_Request $request Full REST request.
         * @return array Associative array containing an `WP_REST_Search_Handler::RESULT_IDS` containing
         *               an array of found IDs and `WP_REST_Search_Handler::RESULT_TOTAL` containing the
         *               total count for the matching search results.
         */
        public abstract function search_items(\WP_REST_Request $request);
        /**
         * Prepares the search result for a given ID.
         *
         * @since 5.0.0
         * @since 5.6.0 The `$id` parameter can accept a string.
         *
         * @param int|string $id     Item ID.
         * @param array      $fields Fields to include for the item.
         * @return array Associative array containing all fields for the item.
         */
        public abstract function prepare_item($id, array $fields);
        /**
         * Prepares links for the search result of a given ID.
         *
         * @since 5.0.0
         * @since 5.6.0 The `$id` parameter can accept a string.
         *
         * @param int|string $id Item ID.
         * @return array Links for the given item.
         */
        public abstract function prepare_item_links($id);
    }
    /**
     * Core class representing a search handler for post formats in the REST API.
     *
     * @since 5.6.0
     *
     * @see WP_REST_Search_Handler
     */
    class WP_REST_Post_Format_Search_Handler extends \WP_REST_Search_Handler
    {
        /**
         * Constructor.
         *
         * @since 5.6.0
         */
        public function __construct()
        {
        }
        /**
         * Searches the post formats for a given search request.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full REST request.
         * @return array {
         *     Associative array containing found IDs and total count for the matching search results.
         *
         *     @type string[] $ids   Array containing slugs for the matching post formats.
         *     @type int      $total Total count for the matching search results.
         * }
         * @phpstan-return array{
         *   ids: string[],
         *   total: int,
         * }
         */
        public function search_items(\WP_REST_Request $request)
        {
        }
        /**
         * Prepares the search result for a given post format.
         *
         * @since 5.6.0
         *
         * @param string $id     Item ID, the post format slug.
         * @param array  $fields Fields to include for the item.
         * @return array {
         *     Associative array containing fields for the post format based on the `$fields` parameter.
         *
         *     @type string $id    Optional. Post format slug.
         *     @type string $title Optional. Post format name.
         *     @type string $url   Optional. Post format permalink URL.
         *     @type string $type  Optional. String 'post-format'.
         *}
         * @phpstan-return array{
         *   id: string,
         *   title: string,
         *   url: string,
         *   type: string,
         * }
         */
        public function prepare_item($id, array $fields)
        {
        }
        /**
         * Prepares links for the search result.
         *
         * @since 5.6.0
         *
         * @param string $id Item ID, the post format slug.
         * @return array Links for the given item.
         */
        public function prepare_item_links($id)
        {
        }
    }
    /**
     * Core class representing a search handler for posts in the REST API.
     *
     * @since 5.0.0
     *
     * @see WP_REST_Search_Handler
     */
    class WP_REST_Post_Search_Handler extends \WP_REST_Search_Handler
    {
        /**
         * Constructor.
         *
         * @since 5.0.0
         */
        public function __construct()
        {
        }
        /**
         * Searches posts for a given search request.
         *
         * @since 5.0.0
         *
         * @param WP_REST_Request $request Full REST request.
         * @return array {
         *     Associative array containing found IDs and total count for the matching search results.
         *
         *     @type int[] $ids   Array containing the matching post IDs.
         *     @type int   $total Total count for the matching search results.
         * }
         * @phpstan-return array{
         *   ids: int[],
         *   total: int,
         * }
         */
        public function search_items(\WP_REST_Request $request)
        {
        }
        /**
         * Prepares the search result for a given post ID.
         *
         * @since 5.0.0
         *
         * @param int   $id     Post ID.
         * @param array $fields Fields to include for the post.
         * @return array {
         *     Associative array containing fields for the post based on the `$fields` parameter.
         *
         *     @type int    $id    Optional. Post ID.
         *     @type string $title Optional. Post title.
         *     @type string $url   Optional. Post permalink URL.
         *     @type string $type  Optional. Post type.
         * }
         * @phpstan-return array{
         *   id: int,
         *   title: string,
         *   url: string,
         *   type: string,
         * }
         */
        public function prepare_item($id, array $fields)
        {
        }
        /**
         * Prepares links for the search result of a given ID.
         *
         * @since 5.0.0
         *
         * @param int $id Item ID.
         * @return array Links for the given item.
         */
        public function prepare_item_links($id)
        {
        }
        /**
         * Overwrites the default protected and private title format.
         *
         * By default, WordPress will show password protected or private posts with a title of
         * "Protected: %s" or "Private: %s", as the REST API communicates the status of a post
         * in a machine-readable format, we remove the prefix.
         *
         * @since 5.0.0
         *
         * @return string Title format.
         */
        public function protected_title_format()
        {
        }
        /**
         * Attempts to detect the route to access a single item.
         *
         * @since 5.0.0
         * @deprecated 5.5.0 Use rest_get_route_for_post()
         * @see rest_get_route_for_post()
         *
         * @param WP_Post $post Post object.
         * @return string REST route relative to the REST base URI, or empty string if unknown.
         */
        protected function detect_rest_item_route($post)
        {
        }
    }
    /**
     * Core class representing a search handler for terms in the REST API.
     *
     * @since 5.6.0
     *
     * @see WP_REST_Search_Handler
     */
    class WP_REST_Term_Search_Handler extends \WP_REST_Search_Handler
    {
        /**
         * Constructor.
         *
         * @since 5.6.0
         */
        public function __construct()
        {
        }
        /**
         * Searches terms for a given search request.
         *
         * @since 5.6.0
         *
         * @param WP_REST_Request $request Full REST request.
         * @return array {
         *     Associative array containing found IDs and total count for the matching search results.
         *
         *     @type int[]               $ids   Found term IDs.
         *     @type string|int|WP_Error $total Numeric string containing the number of terms in that
         *                                      taxonomy, 0 if there are no results, or WP_Error if
         *                                      the requested taxonomy does not exist.
         * }
         * @phpstan-return array{
         *   ids: int[],
         *   total: string|int|WP_Error,
         * }
         */
        public function search_items(\WP_REST_Request $request)
        {
        }
        /**
         * Prepares the search result for a given term ID.
         *
         * @since 5.6.0
         *
         * @param int   $id     Term ID.
         * @param array $fields Fields to include for the term.
         * @return array {
         *     Associative array containing fields for the term based on the `$fields` parameter.
         *
         *     @type int    $id    Optional. Term ID.
         *     @type string $title Optional. Term name.
         *     @type string $url   Optional. Term permalink URL.
         *     @type string $type  Optional. Term taxonomy name.
         * }
         * @phpstan-return array{
         *   id: int,
         *   title: string,
         *   url: string,
         *   type: string,
         * }
         */
        public function prepare_item($id, array $fields)
        {
        }
        /**
         * Prepares links for the search result of a given ID.
         *
         * @since 5.6.0
         *
         * @param int $id Item ID.
         * @return array[] Array of link arrays for the given item.
         */
        public function prepare_item_links($id)
        {
        }
    }
    /**
     * Class WP_Sitemaps_Index.
     * Builds the sitemap index page that lists the links to all of the sitemaps.
     *
     * @since 5.5.0
     */
    #[\AllowDynamicProperties]
    class WP_Sitemaps_Index
    {
        /**
         * The main registry of supported sitemaps.
         *
         * @since 5.5.0
         * @var WP_Sitemaps_Registry
         */
        protected $registry;
        /**
         * WP_Sitemaps_Index constructor.
         *
         * @since 5.5.0
         *
         * @param WP_Sitemaps_Registry $registry Sitemap provider registry.
         */
        public function __construct(\WP_Sitemaps_Registry $registry)
        {
        }
        /**
         * Gets a sitemap list for the index.
         *
         * @since 5.5.0
         *
         * @return array[] Array of all sitemaps.
         */
        public function get_sitemap_list()
        {
        }
        /**
         * Builds the URL for the sitemap index.
         *
         * @since 5.5.0
         *
         * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
         *
         * @return string The sitemap index URL.
         */
        public function get_index_url()
        {
        }
    }
    /**
     * Class WP_Sitemaps_Provider.
     *
     * @since 5.5.0
     */
    #[\AllowDynamicProperties]
    abstract class WP_Sitemaps_Provider
    {
        /**
         * Provider name.
         *
         * This will also be used as the public-facing name in URLs.
         *
         * @since 5.5.0
         *
         * @var string
         */
        protected $name = '';
        /**
         * Object type name (e.g. 'post', 'term', 'user').
         *
         * @since 5.5.0
         *
         * @var string
         */
        protected $object_type = '';
        /**
         * Gets a URL list for a sitemap.
         *
         * @since 5.5.0
         *
         * @param int    $page_num       Page of results.
         * @param string $object_subtype Optional. Object subtype name. Default empty.
         * @return array[] Array of URL information for a sitemap.
         */
        public abstract function get_url_list($page_num, $object_subtype = '');
        /**
         * Gets the max number of pages available for the object type.
         *
         * @since 5.5.0
         *
         * @param string $object_subtype Optional. Object subtype. Default empty.
         * @return int Total number of pages.
         */
        public abstract function get_max_num_pages($object_subtype = '');
        /**
         * Gets data about each sitemap type.
         *
         * @since 5.5.0
         *
         * @return array[] Array of sitemap types including object subtype name and number of pages.
         */
        public function get_sitemap_type_data()
        {
        }
        /**
         * Lists sitemap pages exposed by this provider.
         *
         * The returned data is used to populate the sitemap entries of the index.
         *
         * @since 5.5.0
         *
         * @return array[] Array of sitemap entries.
         */
        public function get_sitemap_entries()
        {
        }
        /**
         * Gets the URL of a sitemap entry.
         *
         * @since 5.5.0
         *
         * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
         *
         * @param string $name The name of the sitemap.
         * @param int    $page The page of the sitemap.
         * @return string The composed URL for a sitemap entry.
         */
        public function get_sitemap_url($name, $page)
        {
        }
        /**
         * Returns the list of supported object subtypes exposed by the provider.
         *
         * @since 5.5.0
         *
         * @return array List of object subtypes objects keyed by their name.
         */
        public function get_object_subtypes()
        {
        }
    }
    /**
     * Class WP_Sitemaps_Registry.
     *
     * @since 5.5.0
     */
    #[\AllowDynamicProperties]
    class WP_Sitemaps_Registry
    {
        /**
         * Adds a new sitemap provider.
         *
         * @since 5.5.0
         *
         * @param string               $name     Name of the sitemap provider.
         * @param WP_Sitemaps_Provider $provider Instance of a WP_Sitemaps_Provider.
         * @return bool Whether the provider was added successfully.
         */
        public function add_provider($name, \WP_Sitemaps_Provider $provider)
        {
        }
        /**
         * Returns a single registered sitemap provider.
         *
         * @since 5.5.0
         *
         * @param string $name Sitemap provider name.
         * @return WP_Sitemaps_Provider|null Sitemap provider if it exists, null otherwise.
         */
        public function get_provider($name)
        {
        }
        /**
         * Returns all registered sitemap providers.
         *
         * @since 5.5.0
         *
         * @return WP_Sitemaps_Provider[] Array of sitemap providers.
         */
        public function get_providers()
        {
        }
    }
    /**
     * Class WP_Sitemaps_Renderer
     *
     * @since 5.5.0
     */
    #[\AllowDynamicProperties]
    class WP_Sitemaps_Renderer
    {
        /**
         * XSL stylesheet for styling a sitemap for web browsers.
         *
         * @since 5.5.0
         *
         * @var string
         */
        protected $stylesheet = '';
        /**
         * XSL stylesheet for styling a sitemap for web browsers.
         *
         * @since 5.5.0
         *
         * @var string
         */
        protected $stylesheet_index = '';
        /**
         * WP_Sitemaps_Renderer constructor.
         *
         * @since 5.5.0
         */
        public function __construct()
        {
        }
        /**
         * Gets the URL for the sitemap stylesheet.
         *
         * @since 5.5.0
         *
         * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
         *
         * @return string The sitemap stylesheet URL.
         */
        public function get_sitemap_stylesheet_url()
        {
        }
        /**
         * Gets the URL for the sitemap index stylesheet.
         *
         * @since 5.5.0
         *
         * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
         *
         * @return string The sitemap index stylesheet URL.
         */
        public function get_sitemap_index_stylesheet_url()
        {
        }
        /**
         * Renders a sitemap index.
         *
         * @since 5.5.0
         *
         * @param array $sitemaps Array of sitemap URLs.
         */
        public function render_index($sitemaps)
        {
        }
        /**
         * Gets XML for a sitemap index.
         *
         * @since 5.5.0
         *
         * @param array $sitemaps Array of sitemap URLs.
         * @return string|false A well-formed XML string for a sitemap index. False on error.
         */
        public function get_sitemap_index_xml($sitemaps)
        {
        }
        /**
         * Renders a sitemap.
         *
         * @since 5.5.0
         *
         * @param array $url_list Array of URLs for a sitemap.
         */
        public function render_sitemap($url_list)
        {
        }
        /**
         * Gets XML for a sitemap.
         *
         * @since 5.5.0
         *
         * @param array $url_list Array of URLs for a sitemap.
         * @return string|false A well-formed XML string for a sitemap index. False on error.
         */
        public function get_sitemap_xml($url_list)
        {
        }
    }
    /**
     * Stylesheet provider class.
     *
     * @since 5.5.0
     */
    #[\AllowDynamicProperties]
    class WP_Sitemaps_Stylesheet
    {
        /**
         * Renders the XSL stylesheet depending on whether it's the sitemap index or not.
         *
         * @param string $type Stylesheet type. Either 'sitemap' or 'index'.
         * @phpstan-param 'sitemap'|'index' $type
         * @phpstan-return never
         */
        public function render_stylesheet($type)
        {
        }
        /**
         * Returns the escaped XSL for all sitemaps, except index.
         *
         * @since 5.5.0
         */
        public function get_sitemap_stylesheet()
        {
        }
        /**
         * Returns the escaped XSL for the index sitemaps.
         *
         * @since 5.5.0
         */
        public function get_sitemap_index_stylesheet()
        {
        }
        /**
         * Gets the CSS to be included in sitemap XSL stylesheets.
         *
         * @since 5.5.0
         *
         * @return string The CSS.
         */
        public function get_stylesheet_css()
        {
        }
    }
    /**
     * Class WP_Sitemaps.
     *
     * @since 5.5.0
     */
    #[\AllowDynamicProperties]
    class WP_Sitemaps
    {
        /**
         * The main index of supported sitemaps.
         *
         * @since 5.5.0
         *
         * @var WP_Sitemaps_Index
         */
        public $index;
        /**
         * The main registry of supported sitemaps.
         *
         * @since 5.5.0
         *
         * @var WP_Sitemaps_Registry
         */
        public $registry;
        /**
         * An instance of the renderer class.
         *
         * @since 5.5.0
         *
         * @var WP_Sitemaps_Renderer
         */
        public $renderer;
        /**
         * WP_Sitemaps constructor.
         *
         * @since 5.5.0
         */
        public function __construct()
        {
        }
        /**
         * Initiates all sitemap functionality.
         *
         * If sitemaps are disabled, only the rewrite rules will be registered
         * by this method, in order to properly send 404s.
         *
         * @since 5.5.0
         * @phpstan-return void
         */
        public function init()
        {
        }
        /**
         * Determines whether sitemaps are enabled or not.
         *
         * @since 5.5.0
         *
         * @return bool Whether sitemaps are enabled.
         */
        public function sitemaps_enabled()
        {
        }
        /**
         * Registers and sets up the functionality for all supported sitemaps.
         *
         * @since 5.5.0
         */
        public function register_sitemaps()
        {
        }
        /**
         * Registers sitemap rewrite tags and routing rules.
         *
         * @since 5.5.0
         */
        public function register_rewrites()
        {
        }
        /**
         * Renders sitemap templates based on rewrite rules.
         *
         * @since 5.5.0
         *
         * @global WP_Query $wp_query WordPress Query object.
         * @phpstan-return void
         */
        public function render_sitemaps()
        {
        }
        /**
         * Redirects a URL to the wp-sitemap.xml
         *
         * @since 5.5.0
         * @deprecated 6.7.0 Deprecated in favor of {@see WP_Rewrite::rewrite_rules()}
         *
         * @param bool     $bypass Pass-through of the pre_handle_404 filter value.
         * @param WP_Query $query  The WP_Query object.
         * @return bool Bypass value.
         */
        public function redirect_sitemapxml($bypass, $query)
        {
        }
        /**
         * Adds the sitemap index to robots.txt.
         *
         * @since 5.5.0
         *
         * @param string $output    robots.txt output.
         * @param bool   $is_public Whether the site is public.
         * @return string The robots.txt output.
         */
        public function add_robots($output, $is_public)
        {
        }
    }
    /**
     * Posts XML sitemap provider.
     *
     * @since 5.5.0
     */
    class WP_Sitemaps_Posts extends \WP_Sitemaps_Provider
    {
        /**
         * WP_Sitemaps_Posts constructor.
         *
         * @since 5.5.0
         */
        public function __construct()
        {
        }
        /**
         * Returns the public post types, which excludes nav_items and similar types.
         * Attachments are also excluded. This includes custom post types with public = true.
         *
         * @since 5.5.0
         *
         * @return WP_Post_Type[] Array of registered post type objects keyed by their name.
         */
        public function get_object_subtypes()
        {
        }
        /**
         * Gets a URL list for a post type sitemap.
         *
         * @since 5.5.0
         * @since 5.9.0 Renamed `$post_type` to `$object_subtype` to match parent class
         *              for PHP 8 named parameter support.
         *
         * @param int    $page_num       Page of results.
         * @param string $object_subtype Optional. Post type name. Default empty.
         *
         * @return array[] Array of URL information for a sitemap.
         */
        public function get_url_list($page_num, $object_subtype = '')
        {
        }
        /**
         * Gets the max number of pages available for the object type.
         *
         * @since 5.5.0
         * @since 5.9.0 Renamed `$post_type` to `$object_subtype` to match parent class
         *              for PHP 8 named parameter support.
         *
         * @param string $object_subtype Optional. Post type name. Default empty.
         * @return int Total number of pages.
         */
        public function get_max_num_pages($object_subtype = '')
        {
        }
        /**
         * Returns the query args for retrieving posts to list in the sitemap.
         *
         * @since 5.5.0
         * @since 6.1.0 Added `ignore_sticky_posts` default parameter.
         *
         * @param string $post_type Post type name.
         * @return array Array of WP_Query arguments.
         */
        protected function get_posts_query_args($post_type)
        {
        }
    }
    /**
     * Taxonomies XML sitemap provider.
     *
     * @since 5.5.0
     */
    class WP_Sitemaps_Taxonomies extends \WP_Sitemaps_Provider
    {
        /**
         * WP_Sitemaps_Taxonomies constructor.
         *
         * @since 5.5.0
         */
        public function __construct()
        {
        }
        /**
         * Returns all public, registered taxonomies.
         *
         * @since 5.5.0
         *
         * @return WP_Taxonomy[] Array of registered taxonomy objects keyed by their name.
         */
        public function get_object_subtypes()
        {
        }
        /**
         * Gets a URL list for a taxonomy sitemap.
         *
         * @since 5.5.0
         * @since 5.9.0 Renamed `$taxonomy` to `$object_subtype` to match parent class
         *              for PHP 8 named parameter support.
         *
         * @param int    $page_num       Page of results.
         * @param string $object_subtype Optional. Taxonomy name. Default empty.
         * @return array[] Array of URL information for a sitemap.
         */
        public function get_url_list($page_num, $object_subtype = '')
        {
        }
        /**
         * Gets the max number of pages available for the object type.
         *
         * @since 5.5.0
         * @since 5.9.0 Renamed `$taxonomy` to `$object_subtype` to match parent class
         *              for PHP 8 named parameter support.
         *
         * @param string $object_subtype Optional. Taxonomy name. Default empty.
         * @return int Total number of pages.
         */
        public function get_max_num_pages($object_subtype = '')
        {
        }
        /**
         * Returns the query args for retrieving taxonomy terms to list in the sitemap.
         *
         * @since 5.5.0
         *
         * @param string $taxonomy Taxonomy name.
         * @return array Array of WP_Term_Query arguments.
         */
        protected function get_taxonomies_query_args($taxonomy)
        {
        }
    }
    /**
     * Users XML sitemap provider.
     *
     * @since 5.5.0
     */
    class WP_Sitemaps_Users extends \WP_Sitemaps_Provider
    {
        /**
         * WP_Sitemaps_Users constructor.
         *
         * @since 5.5.0
         */
        public function __construct()
        {
        }
        /**
         * Gets a URL list for a user sitemap.
         *
         * @since 5.5.0
         *
         * @param int    $page_num       Page of results.
         * @param string $object_subtype Optional. Not applicable for Users but
         *                               required for compatibility with the parent
         *                               provider class. Default empty.
         * @return array[] Array of URL information for a sitemap.
         */
        public function get_url_list($page_num, $object_subtype = '')
        {
        }
        /**
         * Gets the max number of pages available for the object type.
         *
         * @since 5.5.0
         *
         * @see WP_Sitemaps_Provider::max_num_pages
         *
         * @param string $object_subtype Optional. Not applicable for Users but
         *                               required for compatibility with the parent
         *                               provider class. Default empty.
         * @return int Total page count.
         */
        public function get_max_num_pages($object_subtype = '')
        {
        }
        /**
         * Returns the query args for retrieving users to list in the sitemap.
         *
         * @since 5.5.0
         *
         * @return array Array of WP_User_Query arguments.
         */
        protected function get_users_query_args()
        {
        }
    }
    /**
     * Core class used for style engine CSS declarations.
     *
     * Holds, sanitizes, processes, and prints CSS declarations for the style engine.
     *
     * @since 6.1.0
     */
    #[\AllowDynamicProperties]
    class WP_Style_Engine_CSS_Declarations
    {
        /**
         * An array of CSS declarations (property => value pairs).
         *
         * @since 6.1.0
         *
         * @var string[]
         */
        protected $declarations = array();
        /**
         * Constructor for this object.
         *
         * If a `$declarations` array is passed, it will be used to populate
         * the initial `$declarations` prop of the object by calling add_declarations().
         *
         * @since 6.1.0
         *
         * @param string[] $declarations Optional. An associative array of CSS definitions,
         *                               e.g. `array( "$property" => "$value", "$property" => "$value" )`.
         *                               Default empty array.
         */
        public function __construct($declarations = array())
        {
        }
        /**
         * Adds a single declaration.
         *
         * @since 6.1.0
         *
         * @param string $property The CSS property.
         * @param string $value    The CSS value.
         * @return WP_Style_Engine_CSS_Declarations Returns the object to allow chaining methods.
         */
        public function add_declaration($property, $value)
        {
        }
        /**
         * Removes a single declaration.
         *
         * @since 6.1.0
         *
         * @param string $property The CSS property.
         * @return WP_Style_Engine_CSS_Declarations Returns the object to allow chaining methods.
         */
        public function remove_declaration($property)
        {
        }
        /**
         * Adds multiple declarations.
         *
         * @since 6.1.0
         *
         * @param string[] $declarations An array of declarations.
         * @return WP_Style_Engine_CSS_Declarations Returns the object to allow chaining methods.
         */
        public function add_declarations($declarations)
        {
        }
        /**
         * Removes multiple declarations.
         *
         * @since 6.1.0
         *
         * @param string[] $properties Optional. An array of properties. Default empty array.
         * @return WP_Style_Engine_CSS_Declarations Returns the object to allow chaining methods.
         */
        public function remove_declarations($properties = array())
        {
        }
        /**
         * Gets the declarations array.
         *
         * @since 6.1.0
         *
         * @return string[] The declarations array.
         */
        public function get_declarations()
        {
        }
        /**
         * Filters a CSS property + value pair.
         *
         * @since 6.1.0
         *
         * @param string $property The CSS property.
         * @param string $value    The value to be filtered.
         * @param string $spacer   Optional. The spacer between the colon and the value.
         *                         Default empty string.
         * @return string The filtered declaration or an empty string.
         */
        protected static function filter_declaration($property, $value, $spacer = '')
        {
        }
        /**
         * Filters and compiles the CSS declarations.
         *
         * @since 6.1.0
         *
         * @param bool $should_prettify Optional. Whether to add spacing, new lines and indents.
         *                              Default false.
         * @param int  $indent_count    Optional. The number of tab indents to apply to the rule.
         *                              Applies if `prettify` is `true`. Default 0.
         * @return string The CSS declarations.
         */
        public function get_declarations_string($should_prettify = \false, $indent_count = 0)
        {
        }
        /**
         * Sanitizes property names.
         *
         * @since 6.1.0
         *
         * @param string $property The CSS property.
         * @return string The sanitized property name.
         */
        protected function sanitize_property($property)
        {
        }
    }
    /**
     * Core class used for style engine CSS rules.
     *
     * Holds, sanitizes, processes, and prints CSS declarations for the style engine.
     *
     * @since 6.1.0
     */
    #[\AllowDynamicProperties]
    class WP_Style_Engine_CSS_Rule
    {
        /**
         * The selector.
         *
         * @since 6.1.0
         * @var string
         */
        protected $selector;
        /**
         * The selector declarations.
         *
         * Contains a WP_Style_Engine_CSS_Declarations object.
         *
         * @since 6.1.0
         * @var WP_Style_Engine_CSS_Declarations
         */
        protected $declarations;
        /**
         * A parent CSS selector in the case of nested CSS, or a CSS nested @rule,
         * such as `@media (min-width: 80rem)` or `@layer module`.
         *
         * @since 6.6.0
         * @var string
         */
        protected $rules_group;
        /**
         * Constructor.
         *
         * @since 6.1.0
         * @since 6.6.0 Added the `$rules_group` parameter.
         *
         * @param string                                    $selector     Optional. The CSS selector. Default empty string.
         * @param string[]|WP_Style_Engine_CSS_Declarations $declarations Optional. An associative array of CSS definitions,
         *                                                                e.g. `array( "$property" => "$value", "$property" => "$value" )`,
         *                                                                or a WP_Style_Engine_CSS_Declarations object.
         *                                                                Default empty array.
         * @param string                                    $rules_group  A parent CSS selector in the case of nested CSS, or a CSS nested @rule,
         *                                                                such as `@media (min-width: 80rem)` or `@layer module`.
         */
        public function __construct($selector = '', $declarations = array(), $rules_group = '')
        {
        }
        /**
         * Sets the selector.
         *
         * @since 6.1.0
         *
         * @param string $selector The CSS selector.
         * @return WP_Style_Engine_CSS_Rule Returns the object to allow chaining of methods.
         */
        public function set_selector($selector)
        {
        }
        /**
         * Sets the declarations.
         *
         * @since 6.1.0
         *
         * @param string[]|WP_Style_Engine_CSS_Declarations $declarations An array of declarations (property => value pairs),
         *                                                                or a WP_Style_Engine_CSS_Declarations object.
         * @return WP_Style_Engine_CSS_Rule Returns the object to allow chaining of methods.
         */
        public function add_declarations($declarations)
        {
        }
        /**
         * Sets the rules group.
         *
         * @since 6.6.0
         *
         * @param string $rules_group A parent CSS selector in the case of nested CSS, or a CSS nested @rule,
         *                            such as `@media (min-width: 80rem)` or `@layer module`.
         * @return WP_Style_Engine_CSS_Rule Returns the object to allow chaining of methods.
         */
        public function set_rules_group($rules_group)
        {
        }
        /**
         * Gets the rules group.
         *
         * @since 6.6.0
         *
         * @return string
         */
        public function get_rules_group()
        {
        }
        /**
         * Gets the declarations object.
         *
         * @since 6.1.0
         *
         * @return WP_Style_Engine_CSS_Declarations The declarations object.
         */
        public function get_declarations()
        {
        }
        /**
         * Gets the full selector.
         *
         * @since 6.1.0
         *
         * @return string
         */
        public function get_selector()
        {
        }
        /**
         * Gets the CSS.
         *
         * @since 6.1.0
         * @since 6.6.0 Added support for nested CSS with rules groups.
         *
         * @param bool $should_prettify Optional. Whether to add spacing, new lines and indents.
         *                              Default false.
         * @param int  $indent_count    Optional. The number of tab indents to apply to the rule.
         *                              Applies if `prettify` is `true`. Default 0.
         * @return string
         */
        public function get_css($should_prettify = \false, $indent_count = 0)
        {
        }
    }
    /**
     * Core class used as a store for WP_Style_Engine_CSS_Rule objects.
     *
     * Holds, sanitizes, processes, and prints CSS declarations for the style engine.
     *
     * @since 6.1.0
     */
    #[\AllowDynamicProperties]
    class WP_Style_Engine_CSS_Rules_Store
    {
        /**
         * An array of named WP_Style_Engine_CSS_Rules_Store objects.
         *
         * @static
         *
         * @since 6.1.0
         * @var WP_Style_Engine_CSS_Rules_Store[]
         */
        protected static $stores = array();
        /**
         * The store name.
         *
         * @since 6.1.0
         * @var string
         */
        protected $name = '';
        /**
         * An array of CSS Rules objects assigned to the store.
         *
         * @since 6.1.0
         * @var WP_Style_Engine_CSS_Rule[]
         */
        protected $rules = array();
        /**
         * Gets an instance of the store.
         *
         * @since 6.1.0
         *
         * @param string $store_name The name of the store.
         * @return WP_Style_Engine_CSS_Rules_Store|void
         */
        public static function get_store($store_name = 'default')
        {
        }
        /**
         * Gets an array of all available stores.
         *
         * @since 6.1.0
         *
         * @return WP_Style_Engine_CSS_Rules_Store[]
         */
        public static function get_stores()
        {
        }
        /**
         * Clears all stores from static::$stores.
         *
         * @since 6.1.0
         */
        public static function remove_all_stores()
        {
        }
        /**
         * Sets the store name.
         *
         * @since 6.1.0
         *
         * @param string $name The store name.
         */
        public function set_name($name)
        {
        }
        /**
         * Gets the store name.
         *
         * @since 6.1.0
         *
         * @return string
         */
        public function get_name()
        {
        }
        /**
         * Gets an array of all rules.
         *
         * @since 6.1.0
         *
         * @return WP_Style_Engine_CSS_Rule[]
         */
        public function get_all_rules()
        {
        }
        /**
         * Gets a WP_Style_Engine_CSS_Rule object by its selector.
         * If the rule does not exist, it will be created.
         *
         * @since 6.1.0
         * @since 6.6.0 Added the $rules_group parameter.
         *
         * @param string $selector The CSS selector.
         * @param string $rules_group A parent CSS selector in the case of nested CSS, or a CSS nested @rule,
         *                            such as `@media (min-width: 80rem)` or `@layer module`.
         * @return WP_Style_Engine_CSS_Rule|void Returns a WP_Style_Engine_CSS_Rule object,
         *                                       or void if the selector is empty.
         */
        public function add_rule($selector, $rules_group = '')
        {
        }
        /**
         * Removes a selector from the store.
         *
         * @since 6.1.0
         *
         * @param string $selector The CSS selector.
         */
        public function remove_rule($selector)
        {
        }
    }
    /**
     * Core class used to compile styles from stores or collection of CSS rules.
     *
     * @since 6.1.0
     */
    #[\AllowDynamicProperties]
    class WP_Style_Engine_Processor
    {
        /**
         * A collection of Style Engine Store objects.
         *
         * @since 6.1.0
         * @var WP_Style_Engine_CSS_Rules_Store[]
         */
        protected $stores = array();
        /**
         * The set of CSS rules that this processor will work on.
         *
         * @since 6.1.0
         * @var WP_Style_Engine_CSS_Rule[]
         */
        protected $css_rules = array();
        /**
         * Adds a store to the processor.
         *
         * @since 6.1.0
         *
         * @param WP_Style_Engine_CSS_Rules_Store $store The store to add.
         * @return WP_Style_Engine_Processor Returns the object to allow chaining methods.
         */
        public function add_store($store)
        {
        }
        /**
         * Adds rules to be processed.
         *
         * @since 6.1.0
         * @since 6.6.0 Added support for rules_group.
         *
         * @param WP_Style_Engine_CSS_Rule|WP_Style_Engine_CSS_Rule[] $css_rules A single, or an array of,
         *                                                                       WP_Style_Engine_CSS_Rule objects
         *                                                                       from a store or otherwise.
         * @return WP_Style_Engine_Processor Returns the object to allow chaining methods.
         */
        public function add_rules($css_rules)
        {
        }
        /**
         * Gets the CSS rules as a string.
         *
         * @since 6.1.0
         * @since 6.4.0 The Optimization is no longer the default.
         *
         * @param array $options   {
         *     Optional. An array of options. Default empty array.
         *
         *     @type bool $optimize Whether to optimize the CSS output, e.g. combine rules.
         *                          Default false.
         *     @type bool $prettify Whether to add new lines and indents to output.
         *                          Defaults to whether the `SCRIPT_DEBUG` constant is defined.
         * }
         * @return string The computed CSS.
         * @phpstan-param array{
         *   optimize?: bool,
         *   prettify?: bool,
         * } $options
         */
        public function get_css($options = array())
        {
        }
    }
    /**
     * The main class integrating all other WP_Style_Engine_* classes.
     *
     * The Style Engine aims to provide a consistent API for rendering styling for blocks
     * across both client-side and server-side applications.
     *
     * This class is final and should not be extended.
     *
     * This class is for internal Core usage and is not supposed to be used by extenders
     * (plugins and/or themes). This is a low-level API that may need to do breaking changes.
     * Please, use wp_style_engine_get_styles() instead.
     *
     * @access private
     * @since 6.1.0
     * @since 6.3.0 Added support for text-columns.
     * @since 6.4.0 Added support for background.backgroundImage.
     * @since 6.5.0 Added support for background.backgroundPosition,
     *              background.backgroundRepeat and dimensions.aspectRatio.
     * @since 6.7.0 Added support for typography.writingMode.
     */
    #[\AllowDynamicProperties]
    final class WP_Style_Engine
    {
        /**
         * Style definitions that contain the instructions to parse/output valid Gutenberg styles from a block's attributes.
         *
         * For every style definition, the following properties are valid:
         *
         *  - classnames    => (array) an array of classnames to be returned for block styles. The key is a classname or pattern.
         *                    A value of `true` means the classname should be applied always. Otherwise, a valid CSS property (string)
         *                    to match the incoming value, e.g., "color" to match var:preset|color|somePresetSlug.
         *  - css_vars      => (array) an array of key value pairs used to generate CSS var values.
         *                     The key should be the CSS property name that matches the second element of the preset string value,
         *                     i.e., "color" in var:preset|color|somePresetSlug. The value is a CSS var pattern (e.g. `--wp--preset--color--$slug`),
         *                     whose `$slug` fragment will be replaced with the preset slug, which is the third element of the preset string value,
         *                     i.e., `somePresetSlug` in var:preset|color|somePresetSlug.
         *  - property_keys => (array) array of keys whose values represent a valid CSS property, e.g., "margin" or "border".
         *  - path          => (array) a path that accesses the corresponding style value in the block style object.
         *  - value_func    => (string) the name of a function to generate a CSS definition array for a particular style object. The output of this function should be `array( "$property" => "$value", ... )`.
         *
         * @since 6.1.0
         * @var array
         */
        const BLOCK_STYLE_DEFINITIONS_METADATA = array('background' => array('backgroundImage' => array('property_keys' => array('default' => 'background-image'), 'value_func' => array(self::class, 'get_url_or_value_css_declaration'), 'path' => array('background', 'backgroundImage')), 'backgroundPosition' => array('property_keys' => array('default' => 'background-position'), 'path' => array('background', 'backgroundPosition')), 'backgroundRepeat' => array('property_keys' => array('default' => 'background-repeat'), 'path' => array('background', 'backgroundRepeat')), 'backgroundSize' => array('property_keys' => array('default' => 'background-size'), 'path' => array('background', 'backgroundSize')), 'backgroundAttachment' => array('property_keys' => array('default' => 'background-attachment'), 'path' => array('background', 'backgroundAttachment'))), 'color' => array('text' => array('property_keys' => array('default' => 'color'), 'path' => array('color', 'text'), 'css_vars' => array('color' => '--wp--preset--color--$slug'), 'classnames' => array('has-text-color' => \true, 'has-$slug-color' => 'color')), 'background' => array('property_keys' => array('default' => 'background-color'), 'path' => array('color', 'background'), 'css_vars' => array('color' => '--wp--preset--color--$slug'), 'classnames' => array('has-background' => \true, 'has-$slug-background-color' => 'color')), 'gradient' => array('property_keys' => array('default' => 'background'), 'path' => array('color', 'gradient'), 'css_vars' => array('gradient' => '--wp--preset--gradient--$slug'), 'classnames' => array('has-background' => \true, 'has-$slug-gradient-background' => 'gradient'))), 'border' => array('color' => array('property_keys' => array('default' => 'border-color', 'individual' => 'border-%s-color'), 'path' => array('border', 'color'), 'classnames' => array('has-border-color' => \true, 'has-$slug-border-color' => 'color')), 'radius' => array('property_keys' => array('default' => 'border-radius', 'individual' => 'border-%s-radius'), 'path' => array('border', 'radius')), 'style' => array('property_keys' => array('default' => 'border-style', 'individual' => 'border-%s-style'), 'path' => array('border', 'style')), 'width' => array('property_keys' => array('default' => 'border-width', 'individual' => 'border-%s-width'), 'path' => array('border', 'width')), 'top' => array('value_func' => array(self::class, 'get_individual_property_css_declarations'), 'path' => array('border', 'top'), 'css_vars' => array('color' => '--wp--preset--color--$slug')), 'right' => array('value_func' => array(self::class, 'get_individual_property_css_declarations'), 'path' => array('border', 'right'), 'css_vars' => array('color' => '--wp--preset--color--$slug')), 'bottom' => array('value_func' => array(self::class, 'get_individual_property_css_declarations'), 'path' => array('border', 'bottom'), 'css_vars' => array('color' => '--wp--preset--color--$slug')), 'left' => array('value_func' => array(self::class, 'get_individual_property_css_declarations'), 'path' => array('border', 'left'), 'css_vars' => array('color' => '--wp--preset--color--$slug'))), 'shadow' => array('shadow' => array('property_keys' => array('default' => 'box-shadow'), 'path' => array('shadow'), 'css_vars' => array('shadow' => '--wp--preset--shadow--$slug'))), 'dimensions' => array('aspectRatio' => array('property_keys' => array('default' => 'aspect-ratio'), 'path' => array('dimensions', 'aspectRatio'), 'classnames' => array('has-aspect-ratio' => \true)), 'minHeight' => array('property_keys' => array('default' => 'min-height'), 'path' => array('dimensions', 'minHeight'), 'css_vars' => array('spacing' => '--wp--preset--spacing--$slug'))), 'spacing' => array('padding' => array('property_keys' => array('default' => 'padding', 'individual' => 'padding-%s'), 'path' => array('spacing', 'padding'), 'css_vars' => array('spacing' => '--wp--preset--spacing--$slug')), 'margin' => array('property_keys' => array('default' => 'margin', 'individual' => 'margin-%s'), 'path' => array('spacing', 'margin'), 'css_vars' => array('spacing' => '--wp--preset--spacing--$slug'))), 'typography' => array('fontSize' => array('property_keys' => array('default' => 'font-size'), 'path' => array('typography', 'fontSize'), 'css_vars' => array('font-size' => '--wp--preset--font-size--$slug'), 'classnames' => array('has-$slug-font-size' => 'font-size')), 'fontFamily' => array('property_keys' => array('default' => 'font-family'), 'css_vars' => array('font-family' => '--wp--preset--font-family--$slug'), 'path' => array('typography', 'fontFamily'), 'classnames' => array('has-$slug-font-family' => 'font-family')), 'fontStyle' => array('property_keys' => array('default' => 'font-style'), 'path' => array('typography', 'fontStyle')), 'fontWeight' => array('property_keys' => array('default' => 'font-weight'), 'path' => array('typography', 'fontWeight')), 'lineHeight' => array('property_keys' => array('default' => 'line-height'), 'path' => array('typography', 'lineHeight')), 'textColumns' => array('property_keys' => array('default' => 'column-count'), 'path' => array('typography', 'textColumns')), 'textDecoration' => array('property_keys' => array('default' => 'text-decoration'), 'path' => array('typography', 'textDecoration')), 'textTransform' => array('property_keys' => array('default' => 'text-transform'), 'path' => array('typography', 'textTransform')), 'letterSpacing' => array('property_keys' => array('default' => 'letter-spacing'), 'path' => array('typography', 'letterSpacing')), 'writingMode' => array('property_keys' => array('default' => 'writing-mode'), 'path' => array('typography', 'writingMode'))));
        /**
         * Stores a CSS rule using the provided CSS selector and CSS declarations.
         *
         * @since 6.1.0
         * @since 6.6.0 Added the `$rules_group` parameter.
         *
         * @param string   $store_name       A valid store key.
         * @param string   $css_selector     When a selector is passed, the function will return
         *                                   a full CSS rule `$selector { ...rules }`
         *                                   otherwise a concatenated string of properties and values.
         * @param string[] $css_declarations An associative array of CSS definitions,
         *                                   e.g. `array( "$property" => "$value", "$property" => "$value" )`.
         * @param string $rules_group        Optional. A parent CSS selector in the case of nested CSS, or a CSS nested @rule,
         *                                   such as `@media (min-width: 80rem)` or `@layer module`.
         * @phpstan-return void
         */
        public static function store_css_rule($store_name, $css_selector, $css_declarations, $rules_group = '')
        {
        }
        /**
         * Returns a store by store key.
         *
         * @since 6.1.0
         *
         * @param string $store_name A store key.
         * @return WP_Style_Engine_CSS_Rules_Store|null
         */
        public static function get_store($store_name)
        {
        }
        /**
         * Returns classnames and CSS based on the values in a styles object.
         *
         * Return values are parsed based on the instructions in BLOCK_STYLE_DEFINITIONS_METADATA.
         *
         * @since 6.1.0
         *
         * @param array $block_styles The style object.
         * @param array $options      {
         *     Optional. An array of options. Default empty array.
         *
         *     @type bool        $convert_vars_to_classnames Whether to skip converting incoming CSS var patterns,
         *                                                   e.g. `var:preset|<PRESET_TYPE>|<PRESET_SLUG>`,
         *                                                   to `var( --wp--preset--* )` values. Default false.
         *     @type string      $selector                   Optional. When a selector is passed,
         *                                                   the value of `$css` in the return value will comprise
         *                                                   a full CSS rule `$selector { ...$css_declarations }`,
         *                                                   otherwise, the value will be a concatenated string
         *                                                   of CSS declarations.
         * }
         * @return array {
         *     @type string[] $classnames   Array of class names.
         *     @type string[] $declarations An associative array of CSS definitions,
         *                                  e.g. `array( "$property" => "$value", "$property" => "$value" )`.
         * }
         * @phpstan-param array{
         *   convert_vars_to_classnames?: bool,
         *   selector?: string,
         * } $options
         * @phpstan-return array{
         *   classnames: string[],
         *   declarations: string[],
         * }
         */
        public static function parse_block_styles($block_styles, $options)
        {
        }
        /**
         * Returns compiled CSS from CSS declarations.
         *
         * @since 6.1.0
         *
         * @param string[] $css_declarations An associative array of CSS definitions,
         *                                   e.g. `array( "$property" => "$value", "$property" => "$value" )`.
         * @param string   $css_selector     When a selector is passed, the function will return
         *                                   a full CSS rule `$selector { ...rules }`,
         *                                   otherwise a concatenated string of properties and values.
         * @return string A compiled CSS string.
         */
        public static function compile_css($css_declarations, $css_selector)
        {
        }
        /**
         * Returns a compiled stylesheet from stored CSS rules.
         *
         * @since 6.1.0
         *
         * @param WP_Style_Engine_CSS_Rule[] $css_rules An array of WP_Style_Engine_CSS_Rule objects
         *                                              from a store or otherwise.
         * @param array                      $options   {
         *     Optional. An array of options. Default empty array.
         *
         *     @type string|null $context  An identifier describing the origin of the style object,
         *                                 e.g. 'block-supports' or 'global-styles'. Default 'block-supports'.
         *                                 When set, the style engine will attempt to store the CSS rules.
         *     @type bool        $optimize Whether to optimize the CSS output, e.g. combine rules.
         *                                 Default false.
         *     @type bool        $prettify Whether to add new lines and indents to output.
         *                                 Defaults to whether the `SCRIPT_DEBUG` constant is defined.
         * }
         * @return string A compiled stylesheet from stored CSS rules.
         * @phpstan-param array{
         *   context?: string|null,
         *   optimize?: bool,
         *   prettify?: bool,
         * } $options
         */
        public static function compile_stylesheet_from_css_rules($css_rules, $options = array())
        {
        }
    }
    /**
     * Core class used to implement the Navigation Menu widget.
     *
     * @since 3.0.0
     *
     * @see WP_Widget
     */
    class WP_Nav_Menu_Widget extends \WP_Widget
    {
        /**
         * Sets up a new Navigation Menu widget instance.
         *
         * @since 3.0.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the content for the current Navigation Menu widget instance.
         *
         * @since 3.0.0
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current Navigation Menu widget instance.
         * @phpstan-return void
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Handles updating settings for the current Navigation Menu widget instance.
         *
         * @since 3.0.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Updated settings to save.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Outputs the settings form for the Navigation Menu widget.
         *
         * @since 3.0.0
         *
         * @global WP_Customize_Manager $wp_customize
         *
         * @param array $instance Current settings.
         */
        public function form($instance)
        {
        }
    }
    /**
     * Core class used to implement the Archives widget.
     *
     * @since 2.8.0
     *
     * @see WP_Widget
     */
    class WP_Widget_Archives extends \WP_Widget
    {
        /**
         * Sets up a new Archives widget instance.
         *
         * @since 2.8.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the content for the current Archives widget instance.
         *
         * @since 2.8.0
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current Archives widget instance.
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Handles updating settings for the current Archives widget instance.
         *
         * @since 2.8.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget_Archives::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Updated settings to save.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Outputs the settings form for the Archives widget.
         *
         * @since 2.8.0
         *
         * @param array $instance Current settings.
         */
        public function form($instance)
        {
        }
    }
    /**
     * Core class used to implement a Block widget.
     *
     * @since 5.8.0
     *
     * @see WP_Widget
     */
    class WP_Widget_Block extends \WP_Widget
    {
        /**
         * Default instance.
         *
         * @since 5.8.0
         * @var array
         */
        protected $default_instance = array('content' => '');
        /**
         * Sets up a new Block widget instance.
         *
         * @since 5.8.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the content for the current Block widget instance.
         *
         * @since 5.8.0
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current Block widget instance.
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Handles updating settings for the current Block widget instance.
         *
         * @since 5.8.0
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Settings to save or bool false to cancel saving.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Outputs the Block widget settings form.
         *
         * @since 5.8.0
         *
         * @see WP_Widget_Custom_HTML::render_control_template_scripts()
         *
         * @param array $instance Current instance.
         */
        public function form($instance)
        {
        }
        /**
         * Makes sure no block widget is considered to be wide.
         *
         * @since 5.8.0
         *
         * @param bool   $is_wide   Whether the widget is considered wide.
         * @param string $widget_id Widget ID.
         * @return bool Updated `is_wide` value.
         */
        public function set_is_wide_widget_in_customizer($is_wide, $widget_id)
        {
        }
    }
    /**
     * Core class used to implement the Calendar widget.
     *
     * @since 2.8.0
     *
     * @see WP_Widget
     */
    class WP_Widget_Calendar extends \WP_Widget
    {
        /**
         * Sets up a new Calendar widget instance.
         *
         * @since 2.8.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the content for the current Calendar widget instance.
         *
         * @since 2.8.0
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance The settings for the particular instance of the widget.
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Handles updating settings for the current Calendar widget instance.
         *
         * @since 2.8.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Updated settings to save.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Outputs the settings form for the Calendar widget.
         *
         * @since 2.8.0
         *
         * @param array $instance Current settings.
         */
        public function form($instance)
        {
        }
    }
    /**
     * Core class used to implement a Categories widget.
     *
     * @since 2.8.0
     *
     * @see WP_Widget
     */
    class WP_Widget_Categories extends \WP_Widget
    {
        /**
         * Sets up a new Categories widget instance.
         *
         * @since 2.8.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the content for the current Categories widget instance.
         *
         * @since 2.8.0
         * @since 4.2.0 Creates a unique HTML ID for the `<select>` element
         *              if more than one instance is displayed on the page.
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current Categories widget instance.
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Handles updating settings for the current Categories widget instance.
         *
         * @since 2.8.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Updated settings to save.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Outputs the settings form for the Categories widget.
         *
         * @since 2.8.0
         *
         * @param array $instance Current settings.
         */
        public function form($instance)
        {
        }
    }
    /**
     * Core class used to implement a Custom HTML widget.
     *
     * @since 4.8.1
     *
     * @see WP_Widget
     */
    class WP_Widget_Custom_HTML extends \WP_Widget
    {
        /**
         * Whether or not the widget has been registered yet.
         *
         * @since 4.9.0
         * @var bool
         */
        protected $registered = \false;
        /**
         * Default instance.
         *
         * @since 4.8.1
         * @var array
         */
        protected $default_instance = array('title' => '', 'content' => '');
        /**
         * Sets up a new Custom HTML widget instance.
         *
         * @since 4.8.1
         */
        public function __construct()
        {
        }
        /**
         * Add hooks for enqueueing assets when registering all widget instances of this widget class.
         *
         * @since 4.9.0
         *
         * @param int $number Optional. The unique order number of this widget instance
         *                    compared to other instances of the same class. Default -1.
         * @phpstan-return void
         */
        public function _register_one($number = -1)
        {
        }
        /**
         * Filters gallery shortcode attributes.
         *
         * Prevents all of a site's attachments from being shown in a gallery displayed on a
         * non-singular template where a $post context is not available.
         *
         * @since 4.9.0
         *
         * @param array $attrs Attributes.
         * @return array Attributes.
         */
        public function _filter_gallery_shortcode_attrs($attrs)
        {
        }
        /**
         * Outputs the content for the current Custom HTML widget instance.
         *
         * @since 4.8.1
         *
         * @global WP_Post $post Global post object.
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current Custom HTML widget instance.
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Handles updating settings for the current Custom HTML widget instance.
         *
         * @since 4.8.1
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Settings to save or bool false to cancel saving.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Loads the required scripts and styles for the widget control.
         *
         * @since 4.9.0
         */
        public function enqueue_admin_scripts()
        {
        }
        /**
         * Outputs the Custom HTML widget settings form.
         *
         * @since 4.8.1
         * @since 4.9.0 The form contains only hidden sync inputs. For the control UI, see `WP_Widget_Custom_HTML::render_control_template_scripts()`.
         *
         * @see WP_Widget_Custom_HTML::render_control_template_scripts()
         *
         * @param array $instance Current instance.
         */
        public function form($instance)
        {
        }
        /**
         * Render form template scripts.
         *
         * @since 4.9.0
         */
        public static function render_control_template_scripts()
        {
        }
        /**
         * Add help text to widgets admin screen.
         *
         * @since 4.9.0
         */
        public static function add_help_text()
        {
        }
    }
    /**
     * Core class used to implement a Links widget.
     *
     * @since 2.8.0
     *
     * @see WP_Widget
     */
    class WP_Widget_Links extends \WP_Widget
    {
        /**
         * Sets up a new Links widget instance.
         *
         * @since 2.8.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the content for the current Links widget instance.
         *
         * @since 2.8.0
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current Links widget instance.
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Handles updating settings for the current Links widget instance.
         *
         * @since 2.8.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Updated settings to save.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Outputs the settings form for the Links widget.
         *
         * @since 2.8.0
         *
         * @param array $instance Current settings.
         */
        public function form($instance)
        {
        }
    }
    /**
     * Core class that implements a media widget.
     *
     * @since 4.8.0
     *
     * @see WP_Widget
     */
    abstract class WP_Widget_Media extends \WP_Widget
    {
        /**
         * Translation labels.
         *
         * @since 4.8.0
         * @var array
         */
        public $l10n = array('add_to_widget' => '', 'replace_media' => '', 'edit_media' => '', 'media_library_state_multi' => '', 'media_library_state_single' => '', 'missing_attachment' => '', 'no_media_selected' => '', 'add_media' => '');
        /**
         * Whether or not the widget has been registered yet.
         *
         * @since 4.8.1
         * @var bool
         */
        protected $registered = \false;
        /**
         * The default widget description.
         *
         * @since 6.0.0
         * @var string
         */
        protected static $default_description = '';
        /**
         * The default localized strings used by the widget.
         *
         * @since 6.0.0
         * @var string[]
         */
        protected static $l10n_defaults = array();
        /**
         * Constructor.
         *
         * @since 4.8.0
         *
         * @param string $id_base         Base ID for the widget, lowercase and unique.
         * @param string $name            Name for the widget displayed on the configuration page.
         * @param array  $widget_options  Optional. Widget options. See wp_register_sidebar_widget() for
         *                                information on accepted arguments. Default empty array.
         * @param array  $control_options Optional. Widget control options. See wp_register_widget_control()
         *                                for information on accepted arguments. Default empty array.
         * @phpstan-param array{
         *   classname?: string,
         *   description?: string,
         *   show_instance_in_rest?: bool,
         * } $widget_options See wp_register_sidebar_widget()
         * @phpstan-param array{
         *   height?: int,
         *   width?: int,
         *   id_base?: int|string,
         * } $control_options See wp_register_widget_control()
         */
        public function __construct($id_base, $name, $widget_options = array(), $control_options = array())
        {
        }
        /**
         * Add hooks while registering all widget instances of this widget class.
         *
         * @since 4.8.0
         *
         * @param int $number Optional. The unique order number of this widget instance
         *                    compared to other instances of the same class. Default -1.
         * @phpstan-return void
         */
        public function _register_one($number = -1)
        {
        }
        /**
         * Get schema for properties of a widget instance (item).
         *
         * @since 4.8.0
         *
         * @see WP_REST_Controller::get_item_schema()
         * @see WP_REST_Controller::get_additional_fields()
         * @link https://core.trac.wordpress.org/ticket/35574
         *
         * @return array Schema for properties.
         */
        public function get_instance_schema()
        {
        }
        /**
         * Determine if the supplied attachment is for a valid attachment post with the specified MIME type.
         *
         * @since 4.8.0
         *
         * @param int|WP_Post $attachment Attachment post ID or object.
         * @param string      $mime_type  MIME type.
         * @return bool Is matching MIME type.
         */
        public function is_attachment_with_mime_type($attachment, $mime_type)
        {
        }
        /**
         * Sanitize a token list string, such as used in HTML rel and class attributes.
         *
         * @since 4.8.0
         *
         * @link http://w3c.github.io/html/infrastructure.html#space-separated-tokens
         * @link https://developer.mozilla.org/en-US/docs/Web/API/DOMTokenList
         * @param string|array $tokens List of tokens separated by spaces, or an array of tokens.
         * @return string Sanitized token string list.
         */
        public function sanitize_token_list($tokens)
        {
        }
        /**
         * Displays the widget on the front-end.
         *
         * @since 4.8.0
         *
         * @see WP_Widget::widget()
         *
         * @param array $args     Display arguments including before_title, after_title, before_widget, and after_widget.
         * @param array $instance Saved setting from the database.
         * @phpstan-return void
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Sanitizes the widget form values as they are saved.
         *
         * @since 4.8.0
         * @since 5.9.0 Renamed `$instance` to `$old_instance` to match parent class
         *              for PHP 8 named parameter support.
         *
         * @see WP_Widget::update()
         * @see WP_REST_Request::has_valid_params()
         * @see WP_REST_Request::sanitize_params()
         *
         * @param array $new_instance Values just sent to be saved.
         * @param array $old_instance Previously saved values from database.
         * @return array Updated safe values to be saved.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Render the media on the frontend.
         *
         * @since 4.8.0
         *
         * @param array $instance Widget instance props.
         */
        public abstract function render_media($instance);
        /**
         * Outputs the settings update form.
         *
         * Note that the widget UI itself is rendered with JavaScript via `MediaWidgetControl#render()`.
         *
         * @since 4.8.0
         *
         * @see \WP_Widget_Media::render_control_template_scripts() Where the JS template is located.
         *
         * @param array $instance Current settings.
         */
        public final function form($instance)
        {
        }
        /**
         * Filters the default media display states for items in the Media list table.
         *
         * @since 4.8.0
         *
         * @param array   $states An array of media states.
         * @param WP_Post $post   The current attachment object.
         * @return array
         */
        public function display_media_state($states, $post = \null)
        {
        }
        /**
         * Enqueue preview scripts.
         *
         * These scripts normally are enqueued just-in-time when a widget is rendered.
         * In the customizer, however, widgets can be dynamically added and rendered via
         * selective refresh, and so it is important to unconditionally enqueue them in
         * case a widget does get added.
         *
         * @since 4.8.0
         */
        public function enqueue_preview_scripts()
        {
        }
        /**
         * Loads the required scripts and styles for the widget control.
         *
         * @since 4.8.0
         */
        public function enqueue_admin_scripts()
        {
        }
        /**
         * Render form template scripts.
         *
         * @since 4.8.0
         */
        public function render_control_template_scripts()
        {
        }
        /**
         * Resets the cache for the default labels.
         *
         * @since 6.0.0
         */
        public static function reset_default_labels()
        {
        }
        /**
         * Whether the widget has content to show.
         *
         * @since 4.8.0
         *
         * @param array $instance Widget instance props.
         * @return bool Whether widget has content.
         */
        protected function has_content($instance)
        {
        }
        /**
         * Returns the default description of the widget.
         *
         * @since 6.0.0
         *
         * @return string
         */
        protected static function get_default_description()
        {
        }
        /**
         * Returns the default localized strings used by the widget.
         *
         * @since 6.0.0
         *
         * @return (string|array)[]
         */
        protected static function get_l10n_defaults()
        {
        }
    }
    /**
     * Core class that implements an audio widget.
     *
     * @since 4.8.0
     *
     * @see WP_Widget_Media
     * @see WP_Widget
     */
    class WP_Widget_Media_Audio extends \WP_Widget_Media
    {
        /**
         * Constructor.
         *
         * @since 4.8.0
         */
        public function __construct()
        {
        }
        /**
         * Get schema for properties of a widget instance (item).
         *
         * @since 4.8.0
         *
         * @see WP_REST_Controller::get_item_schema()
         * @see WP_REST_Controller::get_additional_fields()
         * @link https://core.trac.wordpress.org/ticket/35574
         *
         * @return array Schema for properties.
         */
        public function get_instance_schema()
        {
        }
        /**
         * Render the media on the frontend.
         *
         * @since 4.8.0
         *
         * @param array $instance Widget instance props.
         */
        public function render_media($instance)
        {
        }
        /**
         * Enqueue preview scripts.
         *
         * These scripts normally are enqueued just-in-time when an audio shortcode is used.
         * In the customizer, however, widgets can be dynamically added and rendered via
         * selective refresh, and so it is important to unconditionally enqueue them in
         * case a widget does get added.
         *
         * @since 4.8.0
         */
        public function enqueue_preview_scripts()
        {
        }
        /**
         * Loads the required media files for the media manager and scripts for media widgets.
         *
         * @since 4.8.0
         */
        public function enqueue_admin_scripts()
        {
        }
        /**
         * Render form template scripts.
         *
         * @since 4.8.0
         */
        public function render_control_template_scripts()
        {
        }
    }
    /**
     * Core class that implements a gallery widget.
     *
     * @since 4.9.0
     *
     * @see WP_Widget_Media
     * @see WP_Widget
     */
    class WP_Widget_Media_Gallery extends \WP_Widget_Media
    {
        /**
         * Constructor.
         *
         * @since 4.9.0
         */
        public function __construct()
        {
        }
        /**
         * Get schema for properties of a widget instance (item).
         *
         * @since 4.9.0
         *
         * @see WP_REST_Controller::get_item_schema()
         * @see WP_REST_Controller::get_additional_fields()
         * @link https://core.trac.wordpress.org/ticket/35574
         *
         * @return array Schema for properties.
         */
        public function get_instance_schema()
        {
        }
        /**
         * Render the media on the frontend.
         *
         * @since 4.9.0
         *
         * @param array $instance Widget instance props.
         */
        public function render_media($instance)
        {
        }
        /**
         * Loads the required media files for the media manager and scripts for media widgets.
         *
         * @since 4.9.0
         */
        public function enqueue_admin_scripts()
        {
        }
        /**
         * Render form template scripts.
         *
         * @since 4.9.0
         */
        public function render_control_template_scripts()
        {
        }
        /**
         * Whether the widget has content to show.
         *
         * @since 4.9.0
         * @access protected
         *
         * @param array $instance Widget instance props.
         * @return bool Whether widget has content.
         */
        protected function has_content($instance)
        {
        }
    }
    /**
     * Core class that implements an image widget.
     *
     * @since 4.8.0
     *
     * @see WP_Widget_Media
     * @see WP_Widget
     */
    class WP_Widget_Media_Image extends \WP_Widget_Media
    {
        /**
         * Constructor.
         *
         * @since 4.8.0
         */
        public function __construct()
        {
        }
        /**
         * Get schema for properties of a widget instance (item).
         *
         * @since 4.8.0
         *
         * @see WP_REST_Controller::get_item_schema()
         * @see WP_REST_Controller::get_additional_fields()
         * @link https://core.trac.wordpress.org/ticket/35574
         *
         * @return array Schema for properties.
         */
        public function get_instance_schema()
        {
        }
        /**
         * Render the media on the frontend.
         *
         * @since 4.8.0
         *
         * @param array $instance Widget instance props.
         * @phpstan-return void
         */
        public function render_media($instance)
        {
        }
        /**
         * Loads the required media files for the media manager and scripts for media widgets.
         *
         * @since 4.8.0
         */
        public function enqueue_admin_scripts()
        {
        }
        /**
         * Render form template scripts.
         *
         * @since 4.8.0
         */
        public function render_control_template_scripts()
        {
        }
    }
    /**
     * Core class that implements a video widget.
     *
     * @since 4.8.0
     *
     * @see WP_Widget_Media
     * @see WP_Widget
     */
    class WP_Widget_Media_Video extends \WP_Widget_Media
    {
        /**
         * Constructor.
         *
         * @since 4.8.0
         */
        public function __construct()
        {
        }
        /**
         * Get schema for properties of a widget instance (item).
         *
         * @since 4.8.0
         *
         * @see WP_REST_Controller::get_item_schema()
         * @see WP_REST_Controller::get_additional_fields()
         * @link https://core.trac.wordpress.org/ticket/35574
         *
         * @return array Schema for properties.
         */
        public function get_instance_schema()
        {
        }
        /**
         * Render the media on the frontend.
         *
         * @since 4.8.0
         *
         * @param array $instance Widget instance props.
         * @phpstan-return void
         */
        public function render_media($instance)
        {
        }
        /**
         * Inject max-width and remove height for videos too constrained to fit inside sidebars on frontend.
         *
         * @since 4.8.0
         *
         * @param string $html Video shortcode HTML output.
         * @return string HTML Output.
         */
        public function inject_video_max_width_style($html)
        {
        }
        /**
         * Enqueue preview scripts.
         *
         * These scripts normally are enqueued just-in-time when a video shortcode is used.
         * In the customizer, however, widgets can be dynamically added and rendered via
         * selective refresh, and so it is important to unconditionally enqueue them in
         * case a widget does get added.
         *
         * @since 4.8.0
         */
        public function enqueue_preview_scripts()
        {
        }
        /**
         * Loads the required scripts and styles for the widget control.
         *
         * @since 4.8.0
         */
        public function enqueue_admin_scripts()
        {
        }
        /**
         * Render form template scripts.
         *
         * @since 4.8.0
         */
        public function render_control_template_scripts()
        {
        }
    }
    /**
     * Core class used to implement a Meta widget.
     *
     * Displays log in/out, RSS feed links, etc.
     *
     * @since 2.8.0
     *
     * @see WP_Widget
     */
    class WP_Widget_Meta extends \WP_Widget
    {
        /**
         * Sets up a new Meta widget instance.
         *
         * @since 2.8.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the content for the current Meta widget instance.
         *
         * @since 2.8.0
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current Meta widget instance.
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Handles updating settings for the current Meta widget instance.
         *
         * @since 2.8.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Updated settings to save.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Outputs the settings form for the Meta widget.
         *
         * @since 2.8.0
         *
         * @param array $instance Current settings.
         */
        public function form($instance)
        {
        }
    }
    /**
     * Core class used to implement a Pages widget.
     *
     * @since 2.8.0
     *
     * @see WP_Widget
     */
    class WP_Widget_Pages extends \WP_Widget
    {
        /**
         * Sets up a new Pages widget instance.
         *
         * @since 2.8.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the content for the current Pages widget instance.
         *
         * @since 2.8.0
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current Pages widget instance.
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Handles updating settings for the current Pages widget instance.
         *
         * @since 2.8.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Updated settings to save.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Outputs the settings form for the Pages widget.
         *
         * @since 2.8.0
         *
         * @param array $instance Current settings.
         */
        public function form($instance)
        {
        }
    }
    /**
     * Core class used to implement a Recent Comments widget.
     *
     * @since 2.8.0
     *
     * @see WP_Widget
     */
    class WP_Widget_Recent_Comments extends \WP_Widget
    {
        /**
         * Sets up a new Recent Comments widget instance.
         *
         * @since 2.8.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the default styles for the Recent Comments widget.
         *
         * @since 2.8.0
         * @phpstan-return void
         */
        public function recent_comments_style()
        {
        }
        /**
         * Outputs the content for the current Recent Comments widget instance.
         *
         * @since 2.8.0
         * @since 5.4.0 Creates a unique HTML ID for the `<ul>` element
         *              if more than one instance is displayed on the page.
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current Recent Comments widget instance.
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Handles updating settings for the current Recent Comments widget instance.
         *
         * @since 2.8.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Updated settings to save.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Outputs the settings form for the Recent Comments widget.
         *
         * @since 2.8.0
         *
         * @param array $instance Current settings.
         */
        public function form($instance)
        {
        }
        /**
         * Flushes the Recent Comments widget cache.
         *
         * @since 2.8.0
         *
         * @deprecated 4.4.0 Fragment caching was removed in favor of split queries.
         */
        public function flush_widget_cache()
        {
        }
    }
    /**
     * Core class used to implement a Recent Posts widget.
     *
     * @since 2.8.0
     *
     * @see WP_Widget
     */
    class WP_Widget_Recent_Posts extends \WP_Widget
    {
        /**
         * Sets up a new Recent Posts widget instance.
         *
         * @since 2.8.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the content for the current Recent Posts widget instance.
         *
         * @since 2.8.0
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current Recent Posts widget instance.
         * @phpstan-return void
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Handles updating the settings for the current Recent Posts widget instance.
         *
         * @since 2.8.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Updated settings to save.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Outputs the settings form for the Recent Posts widget.
         *
         * @since 2.8.0
         *
         * @param array $instance Current settings.
         */
        public function form($instance)
        {
        }
    }
    /**
     * Core class used to implement a RSS widget.
     *
     * @since 2.8.0
     *
     * @see WP_Widget
     */
    class WP_Widget_RSS extends \WP_Widget
    {
        /**
         * Sets up a new RSS widget instance.
         *
         * @since 2.8.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the content for the current RSS widget instance.
         *
         * @since 2.8.0
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current RSS widget instance.
         * @phpstan-return void
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Handles updating settings for the current RSS widget instance.
         *
         * @since 2.8.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Updated settings to save.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Outputs the settings form for the RSS widget.
         *
         * @since 2.8.0
         *
         * @param array $instance Current settings.
         */
        public function form($instance)
        {
        }
    }
    /**
     * Core class used to implement a Search widget.
     *
     * @since 2.8.0
     *
     * @see WP_Widget
     */
    class WP_Widget_Search extends \WP_Widget
    {
        /**
         * Sets up a new Search widget instance.
         *
         * @since 2.8.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the content for the current Search widget instance.
         *
         * @since 2.8.0
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current Search widget instance.
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Outputs the settings form for the Search widget.
         *
         * @since 2.8.0
         *
         * @param array $instance Current settings.
         */
        public function form($instance)
        {
        }
        /**
         * Handles updating settings for the current Search widget instance.
         *
         * @since 2.8.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Updated settings.
         */
        public function update($new_instance, $old_instance)
        {
        }
    }
    /**
     * Core class used to implement a Tag cloud widget.
     *
     * @since 2.8.0
     *
     * @see WP_Widget
     */
    class WP_Widget_Tag_Cloud extends \WP_Widget
    {
        /**
         * Sets up a new Tag Cloud widget instance.
         *
         * @since 2.8.0
         */
        public function __construct()
        {
        }
        /**
         * Outputs the content for the current Tag Cloud widget instance.
         *
         * @since 2.8.0
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current Tag Cloud widget instance.
         * @phpstan-return void
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Handles updating settings for the current Tag Cloud widget instance.
         *
         * @since 2.8.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Settings to save or bool false to cancel saving.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Outputs the Tag Cloud widget settings form.
         *
         * @since 2.8.0
         *
         * @param array $instance Current settings.
         */
        public function form($instance)
        {
        }
        /**
         * Retrieves the taxonomy for the current Tag cloud widget instance.
         *
         * @since 4.4.0
         *
         * @param array $instance Current settings.
         * @return string Name of the current taxonomy if set, otherwise 'post_tag'.
         */
        public function _get_current_taxonomy($instance)
        {
        }
    }
    /**
     * Core class used to implement a Text widget.
     *
     * @since 2.8.0
     *
     * @see WP_Widget
     */
    class WP_Widget_Text extends \WP_Widget
    {
        /**
         * Whether or not the widget has been registered yet.
         *
         * @since 4.8.1
         * @var bool
         */
        protected $registered = \false;
        /**
         * Sets up a new Text widget instance.
         *
         * @since 2.8.0
         */
        public function __construct()
        {
        }
        /**
         * Adds hooks for enqueueing assets when registering all widget instances of this widget class.
         *
         * @param int $number Optional. The unique order number of this widget instance
         *                    compared to other instances of the same class. Default -1.
         * @phpstan-return void
         */
        public function _register_one($number = -1)
        {
        }
        /**
         * Determines whether a given instance is legacy and should bypass using TinyMCE.
         *
         * @since 4.8.1
         *
         * @param array $instance {
         *     Instance data.
         *
         *     @type string      $text   Content.
         *     @type bool|string $filter Whether autop or content filters should apply.
         *     @type bool        $legacy Whether widget is in legacy mode.
         * }
         * @return bool Whether Text widget instance contains legacy data.
         * @phpstan-param array{
         *   text?: string,
         *   filter?: bool|string,
         *   legacy?: bool,
         * } $instance
         */
        public function is_legacy_instance($instance)
        {
        }
        /**
         * Filters gallery shortcode attributes.
         *
         * Prevents all of a site's attachments from being shown in a gallery displayed on a
         * non-singular template where a $post context is not available.
         *
         * @since 4.9.0
         *
         * @param array $attrs Attributes.
         * @return array Attributes.
         */
        public function _filter_gallery_shortcode_attrs($attrs)
        {
        }
        /**
         * Outputs the content for the current Text widget instance.
         *
         * @since 2.8.0
         *
         * @global WP_Post $post Global post object.
         *
         * @param array $args     Display arguments including 'before_title', 'after_title',
         *                        'before_widget', and 'after_widget'.
         * @param array $instance Settings for the current Text widget instance.
         */
        public function widget($args, $instance)
        {
        }
        /**
         * Injects max-width and removes height for videos too constrained to fit inside sidebars on frontend.
         *
         * @since 4.9.0
         *
         * @see WP_Widget_Media_Video::inject_video_max_width_style()
         *
         * @param array $matches Pattern matches from preg_replace_callback.
         * @return string HTML Output.
         */
        public function inject_video_max_width_style($matches)
        {
        }
        /**
         * Handles updating settings for the current Text widget instance.
         *
         * @since 2.8.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            WP_Widget::form().
         * @param array $old_instance Old settings for this instance.
         * @return array Settings to save or bool false to cancel saving.
         */
        public function update($new_instance, $old_instance)
        {
        }
        /**
         * Enqueues preview scripts.
         *
         * These scripts normally are enqueued just-in-time when a playlist shortcode is used.
         * However, in the customizer, a playlist shortcode may be used in a text widget and
         * dynamically added via selective refresh, so it is important to unconditionally enqueue them.
         *
         * @since 4.9.3
         */
        public function enqueue_preview_scripts()
        {
        }
        /**
         * Loads the required scripts and styles for the widget control.
         *
         * @since 4.8.0
         */
        public function enqueue_admin_scripts()
        {
        }
        /**
         * Outputs the Text widget settings form.
         *
         * @since 2.8.0
         * @since 4.8.0 Form only contains hidden inputs which are synced with JS template.
         * @since 4.8.1 Restored original form to be displayed when in legacy mode.
         *
         * @see WP_Widget_Text::render_control_template_scripts()
         * @see _WP_Editors::editor()
         *
         * @param array $instance Current settings.
         */
        public function form($instance)
        {
        }
        /**
         * Renders form template scripts.
         *
         * @since 4.8.0
         * @since 4.9.0 The method is now static.
         */
        public static function render_control_template_scripts()
        {
        }
    }
}
/**
 * Copyright (c) 2021, Alliance for Open Media. All rights reserved
 *
 * This source code is subject to the terms of the BSD 2 Clause License and
 * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
 * was not distributed with this source code in the LICENSE file, you can
 * obtain it at www.aomedia.org/license/software. If the Alliance for Open
 * Media Patent License 1.0 was not distributed with this source code in the
 * PATENTS file, you can obtain it at www.aomedia.org/license/patent.
 *
 * Note: this class is from libavifinfo - https://aomedia.googlesource.com/libavifinfo/+/refs/heads/main/avifinfo.php at f509487.
 * It is used as a fallback to parse AVIF files when the server doesn't support AVIF,
 * primarily to identify the width and height of the image.
 *
 * Note PHP 8.2 added native support for AVIF, so this class can be removed when WordPress requires PHP 8.2.
 */
namespace Avifinfo {
    /**
     * Reads an unsigned integer with most significant bits first.
     *
     * @param binary string $input     Must be at least $num_bytes-long.
     * @param int           $num_bytes Number of parsed bytes.
     * @return int                     Value.
     */
    function read_big_endian($input, $num_bytes)
    {
    }
    /**
     * Reads bytes and advances the stream position by the same count.
     *
     * @param stream               $handle    Bytes will be read from this resource.
     * @param int                  $num_bytes Number of bytes read. Must be greater than 0.
     * @return binary string|false            The raw bytes or false on failure.
     */
    function read($handle, $num_bytes)
    {
    }
    /**
     * Advances the stream position by the given offset.
     *
     * @param stream $handle    Bytes will be skipped from this resource.
     * @param int    $num_bytes Number of skipped bytes. Can be 0.
     * @return bool             True on success or false on failure.
     */
    function skip($handle, $num_bytes)
    {
    }
}
namespace {
    /**
     * Adds an action hook specific to this page.
     *
     * Fires on {@see 'wp_head'}.
     *
     * @since MU (3.0.0)
     */
    function do_activate_header()
    {
    }
    /**
     * Loads styles specific to this page.
     *
     * @since MU (3.0.0)
     */
    function wpmu_activate_stylesheet()
    {
    }
    /**
     * Display JavaScript on the page.
     *
     * @since 3.5.0
     */
    function export_add_js()
    {
    }
    /**
     * Creates the date options fields for exporting a given post type.
     *
     * @since 3.1.0
     *
     * @global wpdb      $wpdb      WordPress database abstraction object.
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     *
     * @param string $post_type The post type. Default 'post'.
     * @phpstan-return void
     */
    function export_date_options($post_type = 'post')
    {
    }
    /**
     * Handles the Heartbeat API in the no-privilege context via AJAX .
     *
     * Runs when the user is not logged in.
     *
     * @since 3.6.0
     * @phpstan-return never
     */
    function wp_ajax_nopriv_heartbeat()
    {
    }
    /**
     * Handles fetching a list table via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_fetch_list()
    {
    }
    /**
     * Handles tag search via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_ajax_tag_search()
    {
    }
    /**
     * Handles compression testing via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_wp_compression_test()
    {
    }
    /**
     * Handles image editor previews via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_imgedit_preview()
    {
    }
    /**
     * Handles oEmbed caching via AJAX.
     *
     * @since 3.1.0
     *
     * @global WP_Embed $wp_embed WordPress Embed object.
     * @phpstan-return never
     */
    function wp_ajax_oembed_cache()
    {
    }
    /**
     * Handles user autocomplete via AJAX.
     *
     * @since 3.4.0
     * @phpstan-return never
     */
    function wp_ajax_autocomplete_user()
    {
    }
    /**
     * Handles Ajax requests for community events
     *
     * @since 4.8.0
     */
    function wp_ajax_get_community_events()
    {
    }
    /**
     * Handles dashboard widgets via AJAX.
     *
     * @since 3.4.0
     * @phpstan-return never
     */
    function wp_ajax_dashboard_widgets()
    {
    }
    /**
     * Handles Customizer preview logged-in status via AJAX.
     *
     * @since 3.4.0
     * @phpstan-return never
     */
    function wp_ajax_logged_in()
    {
    }
    /**
     * Sends back current comment total and new page links if they need to be updated.
     *
     * Contrary to normal success Ajax response ("1"), die with time() on success.
     *
     * @since 2.7.0
     * @access private
     *
     * @param int $comment_id
     * @param int $delta
     */
    function _wp_ajax_delete_comment_response($comment_id, $delta = -1)
    {
    }
    /**
     * Handles adding a hierarchical term via AJAX.
     *
     * @since 3.1.0
     * @access private
     */
    function _wp_ajax_add_hierarchical_term()
    {
    }
    /**
     * Handles deleting a comment via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_delete_comment()
    {
    }
    /**
     * Handles deleting a tag via AJAX.
     *
     * @since 3.1.0
     */
    function wp_ajax_delete_tag()
    {
    }
    /**
     * Handles deleting a link via AJAX.
     *
     * @since 3.1.0
     */
    function wp_ajax_delete_link()
    {
    }
    /**
     * Handles deleting meta via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_delete_meta()
    {
    }
    /**
     * Handles deleting a post via AJAX.
     *
     * @since 3.1.0
     *
     * @param string $action Action to perform.
     */
    function wp_ajax_delete_post($action)
    {
    }
    /**
     * Handles sending a post to the Trash via AJAX.
     *
     * @since 3.1.0
     *
     * @param string $action Action to perform.
     * @phpstan-return never
     */
    function wp_ajax_trash_post($action)
    {
    }
    /**
     * Handles restoring a post from the Trash via AJAX.
     *
     * @since 3.1.0
     *
     * @param string $action Action to perform.
     */
    function wp_ajax_untrash_post($action)
    {
    }
    /**
     * Handles deleting a page via AJAX.
     *
     * @since 3.1.0
     *
     * @param string $action Action to perform.
     */
    function wp_ajax_delete_page($action)
    {
    }
    /**
     * Handles dimming a comment via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_dim_comment()
    {
    }
    /**
     * Handles adding a link category via AJAX.
     *
     * @since 3.1.0
     *
     * @param string $action Action to perform.
     */
    function wp_ajax_add_link_category($action)
    {
    }
    /**
     * Handles adding a tag via AJAX.
     *
     * @since 3.1.0
     */
    function wp_ajax_add_tag()
    {
    }
    /**
     * Handles getting a tagcloud via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_get_tagcloud()
    {
    }
    /**
     * Handles getting comments via AJAX.
     *
     * @since 3.1.0
     *
     * @global int $post_id
     *
     * @param string $action Action to perform.
     */
    function wp_ajax_get_comments($action)
    {
    }
    /**
     * Handles replying to a comment via AJAX.
     *
     * @since 3.1.0
     *
     * @param string $action Action to perform.
     */
    function wp_ajax_replyto_comment($action)
    {
    }
    /**
     * Handles editing a comment via AJAX.
     *
     * @since 3.1.0
     */
    function wp_ajax_edit_comment()
    {
    }
    /**
     * Handles adding a menu item via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_add_menu_item()
    {
    }
    /**
     * Handles adding meta via AJAX.
     *
     * @since 3.1.0
     */
    function wp_ajax_add_meta()
    {
    }
    /**
     * Handles adding a user via AJAX.
     *
     * @since 3.1.0
     *
     * @param string $action Action to perform.
     */
    function wp_ajax_add_user($action)
    {
    }
    /**
     * Handles closed post boxes via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_closed_postboxes()
    {
    }
    /**
     * Handles hidden columns via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_hidden_columns()
    {
    }
    /**
     * Handles updating whether to display the welcome panel via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_update_welcome_panel()
    {
    }
    /**
     * Handles for retrieving menu meta boxes via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_menu_get_metabox()
    {
    }
    /**
     * Handles internal linking via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_wp_link_ajax()
    {
    }
    /**
     * Handles saving menu locations via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_menu_locations_save()
    {
    }
    /**
     * Handles saving the meta box order via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_meta_box_order()
    {
    }
    /**
     * Handles menu quick searching via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_menu_quick_search()
    {
    }
    /**
     * Handles retrieving a permalink via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_get_permalink()
    {
    }
    /**
     * Handles retrieving a sample permalink via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_sample_permalink()
    {
    }
    /**
     * Handles Quick Edit saving a post from a list table via AJAX.
     *
     * @since 3.1.0
     *
     * @global string $mode List table view mode.
     * @phpstan-return never
     */
    function wp_ajax_inline_save()
    {
    }
    /**
     * Handles Quick Edit saving for a term via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_inline_save_tax()
    {
    }
    /**
     * Handles querying posts for the Find Posts modal via AJAX.
     *
     * @see window.findPosts
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_find_posts()
    {
    }
    /**
     * Handles saving the widgets order via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_widgets_order()
    {
    }
    /**
     * Handles saving a widget via AJAX.
     *
     * @since 3.1.0
     *
     * @global array $wp_registered_widgets
     * @global array $wp_registered_widget_controls
     * @global array $wp_registered_widget_updates
     * @phpstan-return never
     */
    function wp_ajax_save_widget()
    {
    }
    /**
     * Handles updating a widget via AJAX.
     *
     * @since 3.9.0
     *
     * @global WP_Customize_Manager $wp_customize
     */
    function wp_ajax_update_widget()
    {
    }
    /**
     * Handles removing inactive widgets via AJAX.
     *
     * @since 4.4.0
     * @phpstan-return never
     */
    function wp_ajax_delete_inactive_widgets()
    {
    }
    /**
     * Handles creating missing image sub-sizes for just uploaded images via AJAX.
     *
     * @since 5.3.0
     * @phpstan-return never
     */
    function wp_ajax_media_create_image_subsizes()
    {
    }
    /**
     * Handles uploading attachments via AJAX.
     *
     * @since 3.3.0
     * @phpstan-return never
     */
    function wp_ajax_upload_attachment()
    {
    }
    /**
     * Handles image editing via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_image_editor()
    {
    }
    /**
     * Handles setting the featured image via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_set_post_thumbnail()
    {
    }
    /**
     * Handles retrieving HTML for the featured image via AJAX.
     *
     * @since 4.6.0
     * @phpstan-return never
     */
    function wp_ajax_get_post_thumbnail_html()
    {
    }
    /**
     * Handles setting the featured image for an attachment via AJAX.
     *
     * @since 4.0.0
     *
     * @see set_post_thumbnail()
     * @phpstan-return never
     */
    function wp_ajax_set_attachment_thumbnail()
    {
    }
    /**
     * Handles formatting a date via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_date_format()
    {
    }
    /**
     * Handles formatting a time via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_time_format()
    {
    }
    /**
     * Handles saving posts from the fullscreen editor via AJAX.
     *
     * @since 3.1.0
     * @deprecated 4.3.0
     * @phpstan-return never
     */
    function wp_ajax_wp_fullscreen_save_post()
    {
    }
    /**
     * Handles removing a post lock via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_wp_remove_post_lock()
    {
    }
    /**
     * Handles dismissing a WordPress pointer via AJAX.
     *
     * @since 3.1.0
     * @phpstan-return never
     */
    function wp_ajax_dismiss_wp_pointer()
    {
    }
    /**
     * Handles getting an attachment via AJAX.
     *
     * @since 3.5.0
     * @phpstan-return never
     */
    function wp_ajax_get_attachment()
    {
    }
    /**
     * Handles querying attachments via AJAX.
     *
     * @since 3.5.0
     * @phpstan-return never
     */
    function wp_ajax_query_attachments()
    {
    }
    /**
     * Handles updating attachment attributes via AJAX.
     *
     * @since 3.5.0
     * @phpstan-return never
     */
    function wp_ajax_save_attachment()
    {
    }
    /**
     * Handles saving backward compatible attachment attributes via AJAX.
     *
     * @since 3.5.0
     * @phpstan-return never
     */
    function wp_ajax_save_attachment_compat()
    {
    }
    /**
     * Handles saving the attachment order via AJAX.
     *
     * @since 3.5.0
     * @phpstan-return never
     */
    function wp_ajax_save_attachment_order()
    {
    }
    /**
     * Handles sending an attachment to the editor via AJAX.
     *
     * Generates the HTML to send an attachment to the editor.
     * Backward compatible with the {@see 'media_send_to_editor'} filter
     * and the chain of filters that follow.
     *
     * @since 3.5.0
     * @phpstan-return never
     */
    function wp_ajax_send_attachment_to_editor()
    {
    }
    /**
     * Handles sending a link to the editor via AJAX.
     *
     * Generates the HTML to send a non-image embed link to the editor.
     *
     * Backward compatible with the following filters:
     * - file_send_to_editor_url
     * - audio_send_to_editor_url
     * - video_send_to_editor_url
     *
     * @since 3.5.0
     *
     * @global WP_Post  $post     Global post object.
     * @global WP_Embed $wp_embed WordPress Embed object.
     * @phpstan-return never
     */
    function wp_ajax_send_link_to_editor()
    {
    }
    /**
     * Handles the Heartbeat API via AJAX.
     *
     * Runs when the user is logged in.
     *
     * @since 3.6.0
     * @phpstan-return never
     */
    function wp_ajax_heartbeat()
    {
    }
    /**
     * Handles getting revision diffs via AJAX.
     *
     * @since 3.6.0
     * @phpstan-return never
     */
    function wp_ajax_get_revision_diffs()
    {
    }
    /**
     * Handles auto-saving the selected color scheme for
     * a user's own profile via AJAX.
     *
     * @since 3.8.0
     *
     * @global array $_wp_admin_css_colors
     * @phpstan-return never
     */
    function wp_ajax_save_user_color_scheme()
    {
    }
    /**
     * Handles getting themes from themes_api() via AJAX.
     *
     * @since 3.9.0
     *
     * @global array $themes_allowedtags
     * @global array $theme_field_defaults
     * @phpstan-return never
     */
    function wp_ajax_query_themes()
    {
    }
    /**
     * Applies [embed] Ajax handlers to a string.
     *
     * @since 4.0.0
     *
     * @global WP_Post    $post          Global post object.
     * @global WP_Embed   $wp_embed      WordPress Embed object.
     * @global WP_Scripts $wp_scripts
     * @global int        $content_width
     * @phpstan-return never
     */
    function wp_ajax_parse_embed()
    {
    }
    /**
     * @since 4.0.0
     *
     * @global WP_Post    $post       Global post object.
     * @global WP_Scripts $wp_scripts
     * @phpstan-return never
     */
    function wp_ajax_parse_media_shortcode()
    {
    }
    /**
     * Handles destroying multiple open sessions for a user via AJAX.
     *
     * @since 4.1.0
     * @phpstan-return never
     */
    function wp_ajax_destroy_sessions()
    {
    }
    /**
     * Handles cropping an image via AJAX.
     *
     * @since 4.3.0
     * @phpstan-return never
     */
    function wp_ajax_crop_image()
    {
    }
    /**
     * Handles generating a password via AJAX.
     *
     * @since 4.4.0
     * @phpstan-return never
     */
    function wp_ajax_generate_password()
    {
    }
    /**
     * Handles generating a password in the no-privilege context via AJAX.
     *
     * @since 5.7.0
     * @phpstan-return never
     */
    function wp_ajax_nopriv_generate_password()
    {
    }
    /**
     * Handles saving the user's WordPress.org username via AJAX.
     *
     * @since 4.4.0
     * @phpstan-return never
     */
    function wp_ajax_save_wporg_username()
    {
    }
    /**
     * Handles installing a theme via AJAX.
     *
     * @since 4.6.0
     *
     * @see Theme_Upgrader
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     * @phpstan-return never
     */
    function wp_ajax_install_theme()
    {
    }
    /**
     * Handles updating a theme via AJAX.
     *
     * @since 4.6.0
     *
     * @see Theme_Upgrader
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     * @phpstan-return never
     */
    function wp_ajax_update_theme()
    {
    }
    /**
     * Handles deleting a theme via AJAX.
     *
     * @since 4.6.0
     *
     * @see delete_theme()
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     * @phpstan-return never
     */
    function wp_ajax_delete_theme()
    {
    }
    /**
     * Handles installing a plugin via AJAX.
     *
     * @since 4.6.0
     *
     * @see Plugin_Upgrader
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     * @phpstan-return never
     */
    function wp_ajax_install_plugin()
    {
    }
    /**
     * Handles activating a plugin via AJAX.
     *
     * @since 6.5.0
     * @phpstan-return never
     */
    function wp_ajax_activate_plugin()
    {
    }
    /**
     * Handles updating a plugin via AJAX.
     *
     * @since 4.2.0
     *
     * @see Plugin_Upgrader
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     * @phpstan-return never
     */
    function wp_ajax_update_plugin()
    {
    }
    /**
     * Handles deleting a plugin via AJAX.
     *
     * @since 4.6.0
     *
     * @see delete_plugins()
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     * @phpstan-return never
     */
    function wp_ajax_delete_plugin()
    {
    }
    /**
     * Handles searching plugins via AJAX.
     *
     * @since 4.6.0
     *
     * @global string $s Search term.
     * @phpstan-return never
     */
    function wp_ajax_search_plugins()
    {
    }
    /**
     * Handles searching plugins to install via AJAX.
     *
     * @since 4.6.0
     * @phpstan-return never
     */
    function wp_ajax_search_install_plugins()
    {
    }
    /**
     * Handles editing a theme or plugin file via AJAX.
     *
     * @since 4.9.0
     *
     * @see wp_edit_theme_plugin_file()
     */
    function wp_ajax_edit_theme_plugin_file()
    {
    }
    /**
     * Handles exporting a user's personal data via AJAX.
     *
     * @since 4.9.6
     * @phpstan-return never
     */
    function wp_ajax_wp_privacy_export_personal_data()
    {
    }
    /**
     * Handles erasing personal data via AJAX.
     *
     * @since 4.9.6
     * @phpstan-return never
     */
    function wp_ajax_wp_privacy_erase_personal_data()
    {
    }
    /**
     * Handles site health checks on server communication via AJAX.
     *
     * @since 5.2.0
     * @deprecated 5.6.0 Use WP_REST_Site_Health_Controller::test_dotorg_communication()
     * @see WP_REST_Site_Health_Controller::test_dotorg_communication()
     * @phpstan-return never
     */
    function wp_ajax_health_check_dotorg_communication()
    {
    }
    /**
     * Handles site health checks on background updates via AJAX.
     *
     * @since 5.2.0
     * @deprecated 5.6.0 Use WP_REST_Site_Health_Controller::test_background_updates()
     * @see WP_REST_Site_Health_Controller::test_background_updates()
     * @phpstan-return never
     */
    function wp_ajax_health_check_background_updates()
    {
    }
    /**
     * Handles site health checks on loopback requests via AJAX.
     *
     * @since 5.2.0
     * @deprecated 5.6.0 Use WP_REST_Site_Health_Controller::test_loopback_requests()
     * @see WP_REST_Site_Health_Controller::test_loopback_requests()
     * @phpstan-return never
     */
    function wp_ajax_health_check_loopback_requests()
    {
    }
    /**
     * Handles site health check to update the result status via AJAX.
     *
     * @since 5.2.0
     * @phpstan-return never
     */
    function wp_ajax_health_check_site_status_result()
    {
    }
    /**
     * Handles site health check to get directories and database sizes via AJAX.
     *
     * @since 5.2.0
     * @deprecated 5.6.0 Use WP_REST_Site_Health_Controller::get_directory_sizes()
     * @see WP_REST_Site_Health_Controller::get_directory_sizes()
     * @phpstan-return never
     */
    function wp_ajax_health_check_get_sizes()
    {
    }
    /**
     * Handles renewing the REST API nonce via AJAX.
     *
     * @since 5.3.0
     * @phpstan-return never
     */
    function wp_ajax_rest_nonce()
    {
    }
    /**
     * Handles enabling or disable plugin and theme auto-updates via AJAX.
     *
     * @since 5.5.0
     * @phpstan-return never
     */
    function wp_ajax_toggle_auto_updates()
    {
    }
    /**
     * Handles sending a password reset link via AJAX.
     *
     * @since 5.7.0
     */
    function wp_ajax_send_password_reset()
    {
    }
    /**
     * Adds a link using values provided in $_POST.
     *
     * @since 2.0.0
     *
     * @return int|WP_Error Value 0 or WP_Error on failure. The link ID on success.
     */
    function add_link()
    {
    }
    /**
     * Updates or inserts a link using values provided in $_POST.
     *
     * @since 2.0.0
     *
     * @param int $link_id Optional. ID of the link to edit. Default 0.
     * @return int|WP_Error Value 0 or WP_Error on failure. The link ID on success.
     */
    function edit_link($link_id = 0)
    {
    }
    /**
     * Retrieves the default link for editing.
     *
     * @since 2.0.0
     *
     * @return stdClass Default link object.
     */
    function get_default_link_to_edit()
    {
    }
    /**
     * Deletes a specified link from the database.
     *
     * @since 2.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $link_id ID of the link to delete.
     * @return true Always true.
     */
    function wp_delete_link($link_id)
    {
    }
    /**
     * Retrieves the link category IDs associated with the link specified.
     *
     * @since 2.1.0
     *
     * @param int $link_id Link ID to look up.
     * @return int[] The IDs of the requested link's categories.
     */
    function wp_get_link_cats($link_id = 0)
    {
    }
    /**
     * Retrieves link data based on its ID.
     *
     * @since 2.0.0
     *
     * @param int|stdClass $link Link ID or object to retrieve.
     * @return object Link object for editing.
     */
    function get_link_to_edit($link)
    {
    }
    /**
     * Inserts a link into the database, or updates an existing link.
     *
     * Runs all the necessary sanitizing, provides default values if arguments are missing,
     * and finally saves the link.
     *
     * @since 2.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array $linkdata {
     *     Elements that make up the link to insert.
     *
     *     @type int    $link_id          Optional. The ID of the existing link if updating.
     *     @type string $link_url         The URL the link points to.
     *     @type string $link_name        The title of the link.
     *     @type string $link_image       Optional. A URL of an image.
     *     @type string $link_target      Optional. The target element for the anchor tag.
     *     @type string $link_description Optional. A short description of the link.
     *     @type string $link_visible     Optional. 'Y' means visible, anything else means not.
     *     @type int    $link_owner       Optional. A user ID.
     *     @type int    $link_rating      Optional. A rating for the link.
     *     @type string $link_rel         Optional. A relationship of the link to you.
     *     @type string $link_notes       Optional. An extended description of or notes on the link.
     *     @type string $link_rss         Optional. A URL of an associated RSS feed.
     *     @type int    $link_category    Optional. The term ID of the link category.
     *                                    If empty, uses default link category.
     * }
     * @param bool  $wp_error Optional. Whether to return a WP_Error object on failure. Default false.
     * @return int|WP_Error Value 0 or WP_Error on failure. The link ID on success.
     * @phpstan-param array{
     *   link_id?: int,
     *   link_url?: string,
     *   link_name?: string,
     *   link_image?: string,
     *   link_target?: string,
     *   link_description?: string,
     *   link_visible?: string,
     *   link_owner?: int,
     *   link_rating?: int,
     *   link_rel?: string,
     *   link_notes?: string,
     *   link_rss?: string,
     *   link_category?: int,
     * } $linkdata
     * @phpstan-return ($wp_error is false ? int<0, max> : int<1, max>|\WP_Error)
     */
    function wp_insert_link($linkdata, $wp_error = \false)
    {
    }
    /**
     * Updates link with the specified link categories.
     *
     * @since 2.1.0
     *
     * @param int   $link_id         ID of the link to update.
     * @param int[] $link_categories Array of link category IDs to add the link to.
     */
    function wp_set_link_cats($link_id = 0, $link_categories = array())
    {
    }
    /**
     * Updates a link in the database.
     *
     * @since 2.0.0
     *
     * @param array $linkdata Link data to update. See wp_insert_link() for accepted arguments.
     * @return int|WP_Error Value 0 or WP_Error on failure. The updated link ID on success.
     * @phpstan-param array{
     *   link_id?: int,
     *   link_url?: string,
     *   link_name?: string,
     *   link_image?: string,
     *   link_target?: string,
     *   link_description?: string,
     *   link_visible?: string,
     *   link_owner?: int,
     *   link_rating?: int,
     *   link_rel?: string,
     *   link_notes?: string,
     *   link_rss?: string,
     *   link_category?: int,
     * } $linkdata See wp_insert_link()
     */
    function wp_update_link($linkdata)
    {
    }
    /**
     * Outputs the 'disabled' message for the WordPress Link Manager.
     *
     * @since 3.5.0
     * @access private
     *
     * @global string $pagenow The filename of the current screen.
     * @phpstan-return void
     */
    function wp_link_manager_disabled_message()
    {
    }
    function PclZipUtilPathReduction($p_dir)
    {
    }
    function PclZipUtilPathInclusion($p_dir, $p_path)
    {
    }
    function PclZipUtilCopyBlock($p_src, $p_dest, $p_size, $p_mode = 0)
    {
    }
    function PclZipUtilRename($p_src, $p_dest)
    {
    }
    function PclZipUtilOptionText($p_option)
    {
    }
    function PclZipUtilTranslateWinPath($p_path, $p_remove_disk_letter = \true)
    {
    }
    /**
     * Returns value of command line params.
     * Exits when a required param is not set.
     *
     * @param string $param
     * @param bool   $required
     * @return mixed
     */
    function get_cli_args($param, $required = \false)
    {
    }
    /**
     * Determines if a comment exists based on author and date.
     *
     * For best performance, use `$timezone = 'gmt'`, which queries a field that is properly indexed. The default value
     * for `$timezone` is 'blog' for legacy reasons.
     *
     * @since 2.0.0
     * @since 4.4.0 Added the `$timezone` parameter.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $comment_author Author of the comment.
     * @param string $comment_date   Date of the comment.
     * @param string $timezone       Timezone. Accepts 'blog' or 'gmt'. Default 'blog'.
     * @return string|null Comment post ID on success.
     * @phpstan-param 'blog'|'gmt' $timezone
     */
    function comment_exists($comment_author, $comment_date, $timezone = 'blog')
    {
    }
    /**
     * Updates a comment with values provided in $_POST.
     *
     * @since 2.0.0
     * @since 5.5.0 A return value was added.
     *
     * @return int|WP_Error The value 1 if the comment was updated, 0 if not updated.
     *                      A WP_Error object on failure.
     */
    function edit_comment()
    {
    }
    /**
     * Returns a WP_Comment object based on comment ID.
     *
     * @since 2.0.0
     *
     * @param int $id ID of comment to retrieve.
     * @return WP_Comment|false Comment if found. False on failure.
     */
    function get_comment_to_edit($id)
    {
    }
    /**
     * Gets the number of pending comments on a post or posts.
     *
     * @since 2.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|int[] $post_id Either a single Post ID or an array of Post IDs
     * @return int|int[] Either a single Posts pending comments as an int or an array of ints keyed on the Post IDs
     */
    function get_pending_comments_num($post_id)
    {
    }
    /**
     * Adds avatars to relevant places in admin.
     *
     * @since 2.5.0
     *
     * @param string $name User name.
     * @return string Avatar with the user name.
     */
    function floated_admin_avatar($name)
    {
    }
    /**
     * Enqueues comment shortcuts jQuery script.
     *
     * @since 2.7.0
     */
    function enqueue_comment_hotkeys_js()
    {
    }
    /**
     * Displays error message at bottom of comments.
     *
     * @param string $msg Error Message. Assumed to contain HTML and be sanitized.
     * @phpstan-return never
     */
    function comment_footer_die($msg)
    {
    }
    /**
     * Retrieves the contributor credits.
     *
     * @since 3.2.0
     * @since 5.6.0 Added the `$version` and `$locale` parameters.
     *
     * @param string $version WordPress version. Defaults to the current version.
     * @param string $locale  WordPress locale. Defaults to the current user's locale.
     * @return array|false A list of all of the contributors, or false on error.
     */
    function wp_credits($version = '', $locale = '')
    {
    }
    /**
     * Retrieves the link to a contributor's WordPress.org profile page.
     *
     * @access private
     * @since 3.2.0
     *
     * @param string $display_name  The contributor's display name (passed by reference).
     * @param string $username      The contributor's username.
     * @param string $profiles      URL to the contributor's WordPress.org profile page.
     */
    function _wp_credits_add_profile_link(&$display_name, $username, $profiles)
    {
    }
    /**
     * Retrieves the link to an external library used in WordPress.
     *
     * @access private
     * @since 3.2.0
     *
     * @param string $data External library data (passed by reference).
     */
    function _wp_credits_build_object_link(&$data)
    {
    }
    /**
     * Displays the title for a given group of contributors.
     *
     * @since 5.3.0
     *
     * @param array $group_data The current contributor group.
     * @phpstan-return void
     */
    function wp_credits_section_title($group_data = array())
    {
    }
    /**
     * Displays a list of contributors for a given group.
     *
     * @since 5.3.0
     *
     * @param array  $credits The credits groups returned from the API.
     * @param string $slug    The current group to display.
     * @phpstan-return void
     */
    function wp_credits_section_list($credits = array(), $slug = '')
    {
    }
    /**
     * Registers dashboard widgets.
     *
     * Handles POST data, sets up filters.
     *
     * @since 2.5.0
     *
     * @global array $wp_registered_widgets
     * @global array $wp_registered_widget_controls
     * @global callable[] $wp_dashboard_control_callbacks
     */
    function wp_dashboard_setup()
    {
    }
    /**
     * Adds a new dashboard widget.
     *
     * @since 2.7.0
     * @since 5.6.0 The `$context` and `$priority` parameters were added.
     *
     * @global callable[] $wp_dashboard_control_callbacks
     *
     * @param string   $widget_id        Widget ID  (used in the 'id' attribute for the widget).
     * @param string   $widget_name      Title of the widget.
     * @param callable $callback         Function that fills the widget with the desired content.
     *                                   The function should echo its output.
     * @param callable $control_callback Optional. Function that outputs controls for the widget. Default null.
     * @param array    $callback_args    Optional. Data that should be set as the $args property of the widget array
     *                                   (which is the second parameter passed to your callback). Default null.
     * @param string   $context          Optional. The context within the screen where the box should display.
     *                                   Accepts 'normal', 'side', 'column3', or 'column4'. Default 'normal'.
     * @param string   $priority         Optional. The priority within the context where the box should show.
     *                                   Accepts 'high', 'core', 'default', or 'low'. Default 'core'.
     * @phpstan-param 'normal'|'side'|'column3'|'column4' $context
     * @phpstan-param 'high'|'core'|'default'|'low' $priority
     */
    function wp_add_dashboard_widget($widget_id, $widget_name, $callback, $control_callback = \null, $callback_args = \null, $context = 'normal', $priority = 'core')
    {
    }
    /**
     * Outputs controls for the current dashboard widget.
     *
     * @access private
     * @since 2.7.0
     *
     * @param mixed $dashboard
     * @param array $meta_box
     */
    function _wp_dashboard_control_callback($dashboard, $meta_box)
    {
    }
    /**
     * Displays the dashboard.
     *
     * @since 2.5.0
     */
    function wp_dashboard()
    {
    }
    /**
     * Dashboard widget that displays some basic stats about the site.
     *
     * Formerly 'Right Now'. A streamlined 'At a Glance' as of 3.8.
     *
     * @since 2.7.0
     */
    function wp_dashboard_right_now()
    {
    }
    /**
     * @since 3.1.0
     */
    function wp_network_dashboard_right_now()
    {
    }
    /**
     * Displays the Quick Draft widget.
     *
     * @since 3.8.0
     *
     * @global int $post_ID
     *
     * @param string|false $error_msg Optional. Error message. Default false.
     * @phpstan-return void
     */
    function wp_dashboard_quick_press($error_msg = \false)
    {
    }
    /**
     * Show recent drafts of the user on the dashboard.
     *
     * @since 2.7.0
     *
     * @param WP_Post[]|false $drafts Optional. Array of posts to display. Default false.
     * @phpstan-return void
     */
    function wp_dashboard_recent_drafts($drafts = \false)
    {
    }
    /**
     * Outputs a row for the Recent Comments widget.
     *
     * @access private
     * @since 2.7.0
     *
     * @global WP_Comment $comment Global comment object.
     *
     * @param WP_Comment $comment   The current comment.
     * @param bool       $show_date Optional. Whether to display the date.
     */
    function _wp_dashboard_recent_comments_row(&$comment, $show_date = \true)
    {
    }
    /**
     * Outputs the Activity widget.
     *
     * Callback function for {@see 'dashboard_activity'}.
     *
     * @since 3.8.0
     */
    function wp_dashboard_site_activity()
    {
    }
    /**
     * Generates Publishing Soon and Recently Published sections.
     *
     * @since 3.8.0
     *
     * @param array $args {
     *     An array of query and display arguments.
     *
     *     @type int    $max     Number of posts to display.
     *     @type string $status  Post status.
     *     @type string $order   Designates ascending ('ASC') or descending ('DESC') order.
     *     @type string $title   Section title.
     *     @type string $id      The container id.
     * }
     * @return bool False if no posts were found. True otherwise.
     * @phpstan-param array{
     *   max?: int,
     *   status?: string,
     *   order?: string,
     *   title?: string,
     *   id?: string,
     * } $args
     */
    function wp_dashboard_recent_posts($args)
    {
    }
    /**
     * Show Comments section.
     *
     * @since 3.8.0
     *
     * @param int $total_items Optional. Number of comments to query. Default 5.
     * @return bool False if no comments were found. True otherwise.
     */
    function wp_dashboard_recent_comments($total_items = 5)
    {
    }
    /**
     * Display generic dashboard RSS widget feed.
     *
     * @since 2.5.0
     *
     * @param string $widget_id
     */
    function wp_dashboard_rss_output($widget_id)
    {
    }
    /**
     * Checks to see if all of the feed url in $check_urls are cached.
     *
     * If $check_urls is empty, look for the rss feed url found in the dashboard
     * widget options of $widget_id. If cached, call $callback, a function that
     * echoes out output for this widget. If not cache, echo a "Loading..." stub
     * which is later replaced by Ajax call (see top of /wp-admin/index.php)
     *
     * @since 2.5.0
     * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
     *              by adding it to the function signature.
     *
     * @param string   $widget_id  The widget ID.
     * @param callable $callback   The callback function used to display each feed.
     * @param array    $check_urls RSS feeds.
     * @param mixed    ...$args    Optional additional parameters to pass to the callback function.
     * @return bool True on success, false on failure.
     */
    function wp_dashboard_cached_rss_widget($widget_id, $callback, $check_urls = array(), ...$args)
    {
    }
    /**
     * Calls widget control callback.
     *
     * @since 2.5.0
     *
     * @global callable[] $wp_dashboard_control_callbacks
     *
     * @param int|false $widget_control_id Optional. Registered widget ID. Default false.
     */
    function wp_dashboard_trigger_widget_control($widget_control_id = \false)
    {
    }
    /**
     * Sets up the RSS dashboard widget control and $args to be used as input to wp_widget_rss_form().
     *
     * Handles POST data from RSS-type widgets.
     *
     * @since 2.5.0
     *
     * @param string $widget_id
     * @param array  $form_inputs
     */
    function wp_dashboard_rss_control($widget_id, $form_inputs = array())
    {
    }
    /**
     * Renders the Events and News dashboard widget.
     *
     * @since 4.8.0
     */
    function wp_dashboard_events_news()
    {
    }
    /**
     * Prints the markup for the Community Events section of the Events and News Dashboard widget.
     *
     * @since 4.8.0
     */
    function wp_print_community_events_markup()
    {
    }
    /**
     * Renders the events templates for the Event and News widget.
     *
     * @since 4.8.0
     */
    function wp_print_community_events_templates()
    {
    }
    /**
     * 'WordPress Events and News' dashboard widget.
     *
     * @since 2.7.0
     * @since 4.8.0 Removed popular plugins feed.
     */
    function wp_dashboard_primary()
    {
    }
    /**
     * Displays the WordPress events and news feeds.
     *
     * @since 3.8.0
     * @since 4.8.0 Removed popular plugins feed.
     *
     * @param string $widget_id Widget ID.
     * @param array  $feeds     Array of RSS feeds.
     */
    function wp_dashboard_primary_output($widget_id, $feeds)
    {
    }
    /**
     * Displays file upload quota on dashboard.
     *
     * Runs on the {@see 'activity_box_end'} hook in wp_dashboard_right_now().
     *
     * @since 3.0.0
     *
     * @return true|void True if not multisite, user can't upload files, or the space check option is disabled.
     */
    function wp_dashboard_quota()
    {
    }
    /**
     * Displays the browser update nag.
     *
     * @since 3.2.0
     * @since 5.8.0 Added a special message for Internet Explorer users.
     *
     * @global bool $is_IE
     */
    function wp_dashboard_browser_nag()
    {
    }
    /**
     * Adds an additional class to the browser nag if the current version is insecure.
     *
     * @since 3.2.0
     *
     * @param string[] $classes Array of meta box classes.
     * @return string[] Modified array of meta box classes.
     */
    function dashboard_browser_nag_class($classes)
    {
    }
    /**
     * Checks if the user needs a browser update.
     *
     * @since 3.2.0
     *
     * @return array|false Array of browser data on success, false on failure.
     */
    function wp_check_browser_version()
    {
    }
    /**
     * Displays the PHP update nag.
     *
     * @since 5.1.0
     * @phpstan-return void
     */
    function wp_dashboard_php_nag()
    {
    }
    /**
     * Adds an additional class to the PHP nag if the current version is insecure.
     *
     * @since 5.1.0
     *
     * @param string[] $classes Array of meta box classes.
     * @return string[] Modified array of meta box classes.
     */
    function dashboard_php_nag_class($classes)
    {
    }
    /**
     * Displays the Site Health Status widget.
     *
     * @since 5.4.0
     */
    function wp_dashboard_site_health()
    {
    }
    /**
     * Outputs empty dashboard widget to be populated by JS later.
     *
     * Usable by plugins.
     *
     * @since 2.5.0
     */
    function wp_dashboard_empty()
    {
    }
    /**
     * Displays a welcome panel to introduce users to WordPress.
     *
     * @since 3.3.0
     * @since 5.9.0 Send users to the Site Editor if the active theme is block-based.
     */
    function wp_welcome_panel()
    {
    }
    /**
     * @since 2.1.0
     * @deprecated 2.1.0 Use wp_editor()
     * @see wp_editor()
     */
    function tinymce_include()
    {
    }
    /**
     * Unused Admin function.
     *
     * @since 2.0.0
     * @deprecated 2.5.0
     *
     */
    function documentation_link()
    {
    }
    /**
     * Calculates the new dimensions for a downsampled image.
     *
     * @since 2.0.0
     * @deprecated 3.0.0 Use wp_constrain_dimensions()
     * @see wp_constrain_dimensions()
     *
     * @param int $width Current width of the image
     * @param int $height Current height of the image
     * @param int $wmax Maximum wanted width
     * @param int $hmax Maximum wanted height
     * @return array Shrunk dimensions (width, height).
     */
    function wp_shrink_dimensions($width, $height, $wmax = 128, $hmax = 96)
    {
    }
    /**
     * Calculated the new dimensions for a downsampled image.
     *
     * @since 2.0.0
     * @deprecated 3.5.0 Use wp_constrain_dimensions()
     * @see wp_constrain_dimensions()
     *
     * @param int $width Current width of the image
     * @param int $height Current height of the image
     * @return array Shrunk dimensions (width, height).
     */
    function get_udims($width, $height)
    {
    }
    /**
     * Legacy function used to generate the categories checklist control.
     *
     * @since 0.71
     * @deprecated 2.6.0 Use wp_category_checklist()
     * @see wp_category_checklist()
     *
     * @global int $post_ID
     *
     * @param int   $default_category Unused.
     * @param int   $category_parent  Unused.
     * @param array $popular_ids      Unused.
     */
    function dropdown_categories($default_category = 0, $category_parent = 0, $popular_ids = array())
    {
    }
    /**
     * Legacy function used to generate a link categories checklist control.
     *
     * @since 2.1.0
     * @deprecated 2.6.0 Use wp_link_category_checklist()
     * @see wp_link_category_checklist()
     *
     * @global int $link_id
     *
     * @param int $default_link_category Unused.
     */
    function dropdown_link_categories($default_link_category = 0)
    {
    }
    /**
     * Get the real filesystem path to a file to edit within the admin.
     *
     * @since 1.5.0
     * @deprecated 2.9.0
     * @uses WP_CONTENT_DIR Full filesystem path to the wp-content directory.
     *
     * @param string $file Filesystem path relative to the wp-content directory.
     * @return string Full filesystem path to edit.
     */
    function get_real_file_to_edit($file)
    {
    }
    /**
     * Legacy function used for generating a categories drop-down control.
     *
     * @since 1.2.0
     * @deprecated 3.0.0 Use wp_dropdown_categories()
     * @see wp_dropdown_categories()
     *
     * @param int $current_cat     Optional. ID of the current category. Default 0.
     * @param int $current_parent  Optional. Current parent category ID. Default 0.
     * @param int $category_parent Optional. Parent ID to retrieve categories for. Default 0.
     * @param int $level           Optional. Number of levels deep to display. Default 0.
     * @param array $categories    Optional. Categories to include in the control. Default 0.
     * @return void|false Void on success, false if no categories were found.
     */
    function wp_dropdown_cats($current_cat = 0, $current_parent = 0, $category_parent = 0, $level = 0, $categories = 0)
    {
    }
    /**
     * Register a setting and its sanitization callback
     *
     * @since 2.7.0
     * @deprecated 3.0.0 Use register_setting()
     * @see register_setting()
     *
     * @param string   $option_group      A settings group name. Should correspond to an allowed option key name.
     *                                    Default allowed option key names include 'general', 'discussion', 'media',
     *                                    'reading', 'writing', and 'options'.
     * @param string   $option_name       The name of an option to sanitize and save.
     * @param callable $sanitize_callback Optional. A callback function that sanitizes the option's value.
     */
    function add_option_update_handler($option_group, $option_name, $sanitize_callback = '')
    {
    }
    /**
     * Unregister a setting
     *
     * @since 2.7.0
     * @deprecated 3.0.0 Use unregister_setting()
     * @see unregister_setting()
     *
     * @param string   $option_group      The settings group name used during registration.
     * @param string   $option_name       The name of the option to unregister.
     * @param callable $sanitize_callback Optional. Deprecated.
     */
    function remove_option_update_handler($option_group, $option_name, $sanitize_callback = '')
    {
    }
    /**
     * Determines the language to use for CodePress syntax highlighting.
     *
     * @since 2.8.0
     * @deprecated 3.0.0
     *
     * @param string $filename
     */
    function codepress_get_lang($filename)
    {
    }
    /**
     * Adds JavaScript required to make CodePress work on the theme/plugin file editors.
     *
     * @since 2.8.0
     * @deprecated 3.0.0
     */
    function codepress_footer_js()
    {
    }
    /**
     * Determine whether to use CodePress.
     *
     * @since 2.8.0
     * @deprecated 3.0.0
     */
    function use_codepress()
    {
    }
    /**
     * Get all user IDs.
     *
     * @deprecated 3.1.0 Use get_users()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return array List of user IDs.
     */
    function get_author_user_ids()
    {
    }
    /**
     * Gets author users who can edit posts.
     *
     * @deprecated 3.1.0 Use get_users()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $user_id User ID.
     * @return array|false List of editable authors. False if no editable users.
     */
    function get_editable_authors($user_id)
    {
    }
    /**
     * Gets the IDs of any users who can edit posts.
     *
     * @deprecated 3.1.0 Use get_users()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int  $user_id       User ID.
     * @param bool $exclude_zeros Optional. Whether to exclude zeroes. Default true.
     * @return array Array of editable user IDs, empty array otherwise.
     */
    function get_editable_user_ids($user_id, $exclude_zeros = \true, $post_type = 'post')
    {
    }
    /**
     * Gets all users who are not authors.
     *
     * @deprecated 3.1.0 Use get_users()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function get_nonauthor_user_ids()
    {
    }
    /**
     * Retrieves editable posts from other users.
     *
     * @since 2.3.0
     * @deprecated 3.1.0 Use get_posts()
     * @see get_posts()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $user_id User ID to not retrieve posts from.
     * @param string $type    Optional. Post type to retrieve. Accepts 'draft', 'pending' or 'any' (all).
     *                        Default 'any'.
     * @return array List of posts from others.
     * @phpstan-param 'draft'|'pending'|'any' $type
     */
    function get_others_unpublished_posts($user_id, $type = 'any')
    {
    }
    /**
     * Retrieve drafts from other users.
     *
     * @deprecated 3.1.0 Use get_posts()
     * @see get_posts()
     *
     * @param int $user_id User ID.
     * @return array List of drafts from other users.
     */
    function get_others_drafts($user_id)
    {
    }
    /**
     * Retrieve pending review posts from other users.
     *
     * @deprecated 3.1.0 Use get_posts()
     * @see get_posts()
     *
     * @param int $user_id User ID.
     * @return array List of posts with pending review post type from other users.
     */
    function get_others_pending($user_id)
    {
    }
    /**
     * Output the QuickPress dashboard widget.
     *
     * @since 3.0.0
     * @deprecated 3.2.0 Use wp_dashboard_quick_press()
     * @see wp_dashboard_quick_press()
     */
    function wp_dashboard_quick_press_output()
    {
    }
    /**
     * Outputs the TinyMCE editor.
     *
     * @since 2.7.0
     * @deprecated 3.3.0 Use wp_editor()
     * @see wp_editor()
     */
    function wp_tiny_mce($teeny = \false, $settings = \false)
    {
    }
    /**
     * Preloads TinyMCE dialogs.
     *
     * @deprecated 3.3.0 Use wp_editor()
     * @see wp_editor()
     */
    function wp_preload_dialogs()
    {
    }
    /**
     * Prints TinyMCE editor JS.
     *
     * @deprecated 3.3.0 Use wp_editor()
     * @see wp_editor()
     */
    function wp_print_editor_js()
    {
    }
    /**
     * Handles quicktags.
     *
     * @deprecated 3.3.0 Use wp_editor()
     * @see wp_editor()
     */
    function wp_quicktags()
    {
    }
    /**
     * Returns the screen layout options.
     *
     * @since 2.8.0
     * @deprecated 3.3.0 WP_Screen::render_screen_layout()
     * @see WP_Screen::render_screen_layout()
     */
    function screen_layout($screen)
    {
    }
    /**
     * Returns the screen's per-page options.
     *
     * @since 2.8.0
     * @deprecated 3.3.0 Use WP_Screen::render_per_page_options()
     * @see WP_Screen::render_per_page_options()
     */
    function screen_options($screen)
    {
    }
    /**
     * Renders the screen's help.
     *
     * @since 2.7.0
     * @deprecated 3.3.0 Use WP_Screen::render_screen_meta()
     * @see WP_Screen::render_screen_meta()
     */
    function screen_meta($screen)
    {
    }
    /**
     * Favorite actions were deprecated in version 3.2. Use the admin bar instead.
     *
     * @since 2.7.0
     * @deprecated 3.2.0 Use WP_Admin_Bar
     * @see WP_Admin_Bar
     */
    function favorite_actions()
    {
    }
    /**
     * Handles uploading an image.
     *
     * @deprecated 3.3.0 Use wp_media_upload_handler()
     * @see wp_media_upload_handler()
     *
     * @return null|string
     */
    function media_upload_image()
    {
    }
    /**
     * Handles uploading an audio file.
     *
     * @deprecated 3.3.0 Use wp_media_upload_handler()
     * @see wp_media_upload_handler()
     *
     * @return null|string
     */
    function media_upload_audio()
    {
    }
    /**
     * Handles uploading a video file.
     *
     * @deprecated 3.3.0 Use wp_media_upload_handler()
     * @see wp_media_upload_handler()
     *
     * @return null|string
     */
    function media_upload_video()
    {
    }
    /**
     * Handles uploading a generic file.
     *
     * @deprecated 3.3.0 Use wp_media_upload_handler()
     * @see wp_media_upload_handler()
     *
     * @return null|string
     */
    function media_upload_file()
    {
    }
    /**
     * Handles retrieving the insert-from-URL form for an image.
     *
     * @deprecated 3.3.0 Use wp_media_insert_url_form()
     * @see wp_media_insert_url_form()
     *
     * @return string
     */
    function type_url_form_image()
    {
    }
    /**
     * Handles retrieving the insert-from-URL form for an audio file.
     *
     * @deprecated 3.3.0 Use wp_media_insert_url_form()
     * @see wp_media_insert_url_form()
     *
     * @return string
     */
    function type_url_form_audio()
    {
    }
    /**
     * Handles retrieving the insert-from-URL form for a video file.
     *
     * @deprecated 3.3.0 Use wp_media_insert_url_form()
     * @see wp_media_insert_url_form()
     *
     * @return string
     */
    function type_url_form_video()
    {
    }
    /**
     * Handles retrieving the insert-from-URL form for a generic file.
     *
     * @deprecated 3.3.0 Use wp_media_insert_url_form()
     * @see wp_media_insert_url_form()
     *
     * @return string
     */
    function type_url_form_file()
    {
    }
    /**
     * Add contextual help text for a page.
     *
     * Creates an 'Overview' help tab.
     *
     * @since 2.7.0
     * @deprecated 3.3.0 Use WP_Screen::add_help_tab()
     * @see WP_Screen::add_help_tab()
     *
     * @param string    $screen The handle for the screen to add help to. This is usually
     *                          the hook name returned by the `add_*_page()` functions.
     * @param string    $help   The content of an 'Overview' help tab.
     */
    function add_contextual_help($screen, $help)
    {
    }
    /**
     * Get the allowed themes for the current site.
     *
     * @since 3.0.0
     * @deprecated 3.4.0 Use wp_get_themes()
     * @see wp_get_themes()
     *
     * @return WP_Theme[] Array of WP_Theme objects keyed by their name.
     */
    function get_allowed_themes()
    {
    }
    /**
     * Retrieves a list of broken themes.
     *
     * @since 1.5.0
     * @deprecated 3.4.0 Use wp_get_themes()
     * @see wp_get_themes()
     *
     * @return array
     */
    function get_broken_themes()
    {
    }
    /**
     * Retrieves information on the current active theme.
     *
     * @since 2.0.0
     * @deprecated 3.4.0 Use wp_get_theme()
     * @see wp_get_theme()
     *
     * @return WP_Theme
     */
    function current_theme_info()
    {
    }
    /**
     * This was once used to display an 'Insert into Post' button.
     *
     * Now it is deprecated and stubbed.
     *
     * @deprecated 3.5.0
     */
    function _insert_into_post_button($type)
    {
    }
    /**
     * This was once used to display a media button.
     *
     * Now it is deprecated and stubbed.
     *
     * @deprecated 3.5.0
     */
    function _media_button($title, $icon, $type, $id)
    {
    }
    /**
     * Gets an existing post and format it for editing.
     *
     * @since 2.0.0
     * @deprecated 3.5.0 Use get_post()
     * @see get_post()
     *
     * @param int $id
     * @return WP_Post
     */
    function get_post_to_edit($id)
    {
    }
    /**
     * Gets the default page information to use.
     *
     * @since 2.5.0
     * @deprecated 3.5.0 Use get_default_post_to_edit()
     * @see get_default_post_to_edit()
     *
     * @return WP_Post Post object containing all the default post data as attributes
     */
    function get_default_page_to_edit()
    {
    }
    /**
     * This was once used to create a thumbnail from an Image given a maximum side size.
     *
     * @since 1.2.0
     * @deprecated 3.5.0 Use image_resize()
     * @see image_resize()
     *
     * @param mixed $file Filename of the original image, Or attachment ID.
     * @param int $max_side Maximum length of a single side for the thumbnail.
     * @param mixed $deprecated Never used.
     * @return string Thumbnail path on success, Error string on failure.
     */
    function wp_create_thumbnail($file, $max_side, $deprecated = '')
    {
    }
    /**
     * This was once used to display a meta box for the nav menu theme locations.
     *
     * Deprecated in favor of a 'Manage Locations' tab added to nav menus management screen.
     *
     * @since 3.0.0
     * @deprecated 3.6.0
     */
    function wp_nav_menu_locations_meta_box()
    {
    }
    /**
     * This was once used to kick-off the Core Updater.
     *
     * Deprecated in favor of instantiating a Core_Upgrader instance directly,
     * and calling the 'upgrade' method.
     *
     * @since 2.7.0
     * @deprecated 3.7.0 Use Core_Upgrader
     * @see Core_Upgrader
     */
    function wp_update_core($current, $feedback = '')
    {
    }
    /**
     * This was once used to kick-off the Plugin Updater.
     *
     * Deprecated in favor of instantiating a Plugin_Upgrader instance directly,
     * and calling the 'upgrade' method.
     * Unused since 2.8.0.
     *
     * @since 2.5.0
     * @deprecated 3.7.0 Use Plugin_Upgrader
     * @see Plugin_Upgrader
     */
    function wp_update_plugin($plugin, $feedback = '')
    {
    }
    /**
     * This was once used to kick-off the Theme Updater.
     *
     * Deprecated in favor of instantiating a Theme_Upgrader instance directly,
     * and calling the 'upgrade' method.
     * Unused since 2.8.0.
     *
     * @since 2.7.0
     * @deprecated 3.7.0 Use Theme_Upgrader
     * @see Theme_Upgrader
     */
    function wp_update_theme($theme, $feedback = '')
    {
    }
    /**
     * This was once used to display attachment links. Now it is deprecated and stubbed.
     *
     * @since 2.0.0
     * @deprecated 3.7.0
     *
     * @param int|bool $id
     */
    function the_attachment_links($id = \false)
    {
    }
    /**
     * Displays a screen icon.
     *
     * @since 2.7.0
     * @deprecated 3.8.0
     */
    function screen_icon()
    {
    }
    /**
     * Retrieves the screen icon (no longer used in 3.8+).
     *
     * @since 3.2.0
     * @deprecated 3.8.0
     *
     * @return string An HTML comment explaining that icons are no longer used.
     */
    function get_screen_icon()
    {
    }
    /**
     * Deprecated dashboard widget controls.
     *
     * @since 2.5.0
     * @deprecated 3.8.0
     */
    function wp_dashboard_incoming_links_output()
    {
    }
    /**
     * Deprecated dashboard secondary output.
     *
     * @deprecated 3.8.0
     */
    function wp_dashboard_secondary_output()
    {
    }
    /**
     * Deprecated dashboard widget controls.
     *
     * @since 2.7.0
     * @deprecated 3.8.0
     */
    function wp_dashboard_incoming_links()
    {
    }
    /**
     * Deprecated dashboard incoming links control.
     *
     * @deprecated 3.8.0
     */
    function wp_dashboard_incoming_links_control()
    {
    }
    /**
     * Deprecated dashboard plugins control.
     *
     * @deprecated 3.8.0
     */
    function wp_dashboard_plugins()
    {
    }
    /**
     * Deprecated dashboard primary control.
     *
     * @deprecated 3.8.0
     */
    function wp_dashboard_primary_control()
    {
    }
    /**
     * Deprecated dashboard recent comments control.
     *
     * @deprecated 3.8.0
     */
    function wp_dashboard_recent_comments_control()
    {
    }
    /**
     * Deprecated dashboard secondary section.
     *
     * @deprecated 3.8.0
     */
    function wp_dashboard_secondary()
    {
    }
    /**
     * Deprecated dashboard secondary control.
     *
     * @deprecated 3.8.0
     */
    function wp_dashboard_secondary_control()
    {
    }
    /**
     * Display plugins text for the WordPress news widget.
     *
     * @since 2.5.0
     * @deprecated 4.8.0
     *
     * @param string $rss  The RSS feed URL.
     * @param array  $args Array of arguments for this RSS feed.
     */
    function wp_dashboard_plugins_output($rss, $args = array())
    {
    }
    /**
     * This was once used to move child posts to a new parent.
     *
     * @since 2.3.0
     * @deprecated 3.9.0
     * @access private
     *
     * @param int $old_ID
     * @param int $new_ID
     */
    function _relocate_children($old_ID, $new_ID)
    {
    }
    /**
     * Add a top-level menu page in the 'objects' section.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 2.7.0
     *
     * @deprecated 4.5.0 Use add_menu_page()
     * @see add_menu_page()
     * @global int $_wp_last_object_menu
     *
     * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string   $menu_title The text to be used for the menu.
     * @param string   $capability The capability required for this menu to be displayed to the user.
     * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
     * @param callable $callback   Optional. The function to be called to output the content for this page.
     * @param string   $icon_url   Optional. The URL to the icon to be used for this menu.
     * @return string The resulting page's hook_suffix.
     */
    function add_object_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $icon_url = '')
    {
    }
    /**
     * Add a top-level menu page in the 'utility' section.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 2.7.0
     *
     * @deprecated 4.5.0 Use add_menu_page()
     * @see add_menu_page()
     * @global int $_wp_last_utility_menu
     *
     * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string   $menu_title The text to be used for the menu.
     * @param string   $capability The capability required for this menu to be displayed to the user.
     * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
     * @param callable $callback   Optional. The function to be called to output the content for this page.
     * @param string   $icon_url   Optional. The URL to the icon to be used for this menu.
     * @return string The resulting page's hook_suffix.
     */
    function add_utility_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $icon_url = '')
    {
    }
    /**
     * Disables autocomplete on the 'post' form (Add/Edit Post screens) for WebKit browsers,
     * as they disregard the autocomplete setting on the editor textarea. That can break the editor
     * when the user navigates to it with the browser's Back button. See #28037
     *
     * Replaced with wp_page_reload_on_back_button_js() that also fixes this problem.
     *
     * @since 4.0.0
     * @deprecated 4.6.0
     *
     * @link https://core.trac.wordpress.org/ticket/35852
     *
     * @global bool $is_safari
     * @global bool $is_chrome
     */
    function post_form_autocomplete_off()
    {
    }
    /**
     * Display JavaScript on the page.
     *
     * @since 3.5.0
     * @deprecated 4.9.0
     */
    function options_permalink_add_js()
    {
    }
    /**
     * Was used to add options for the privacy requests screens before they were separate files.
     *
     * @since 4.9.8
     * @access private
     * @deprecated 5.3.0
     */
    function _wp_privacy_requests_screen_options()
    {
    }
    /**
     * Was used to filter input from media_upload_form_handler() and to assign a default
     * post_title from the file name if none supplied.
     *
     * @since 2.5.0
     * @deprecated 6.0.0
     *
     * @param array $post       The WP_Post attachment object converted to an array.
     * @param array $attachment An array of attachment metadata.
     * @return array Attachment post object converted to an array.
     */
    function image_attachment_fields_to_save($post, $attachment)
    {
    }
    /**
     * Generates the WXR export file for download.
     *
     * Default behavior is to export all content, however, note that post content will only
     * be exported for post types with the `can_export` argument enabled. Any posts with the
     * 'auto-draft' status will be skipped.
     *
     * @since 2.1.0
     * @since 5.7.0 Added the `post_modified` and `post_modified_gmt` fields to the export file.
     *
     * @global wpdb    $wpdb WordPress database abstraction object.
     * @global WP_Post $post Global post object.
     *
     * @param array $args {
     *     Optional. Arguments for generating the WXR export file for download. Default empty array.
     *
     *     @type string $content    Type of content to export. If set, only the post content of this post type
     *                              will be exported. Accepts 'all', 'post', 'page', 'attachment', or a defined
     *                              custom post. If an invalid custom post type is supplied, every post type for
     *                              which `can_export` is enabled will be exported instead. If a valid custom post
     *                              type is supplied but `can_export` is disabled, then 'posts' will be exported
     *                              instead. When 'all' is supplied, only post types with `can_export` enabled will
     *                              be exported. Default 'all'.
     *     @type string $author     Author to export content for. Only used when `$content` is 'post', 'page', or
     *                              'attachment'. Accepts false (all) or a specific author ID. Default false (all).
     *     @type string $category   Category (slug) to export content for. Used only when `$content` is 'post'. If
     *                              set, only post content assigned to `$category` will be exported. Accepts false
     *                              or a specific category slug. Default is false (all categories).
     *     @type string $start_date Start date to export content from. Expected date format is 'Y-m-d'. Used only
     *                              when `$content` is 'post', 'page' or 'attachment'. Default false (since the
     *                              beginning of time).
     *     @type string $end_date   End date to export content to. Expected date format is 'Y-m-d'. Used only when
     *                              `$content` is 'post', 'page' or 'attachment'. Default false (latest publish date).
     *     @type string $status     Post status to export posts for. Used only when `$content` is 'post' or 'page'.
     *                              Accepts false (all statuses except 'auto-draft'), or a specific status, i.e.
     *                              'publish', 'pending', 'draft', 'auto-draft', 'future', 'private', 'inherit', or
     *                              'trash'. Default false (all statuses except 'auto-draft').
     * }
     * @phpstan-param array{
     *   content?: string,
     *   author?: string,
     *   category?: string,
     *   start_date?: string,
     *   end_date?: string,
     *   status?: string,
     * } $args
     */
    function export_wp($args = array())
    {
    }
    /**
     * Gets the description for standard WordPress theme files.
     *
     * @since 1.5.0
     *
     * @global array $wp_file_descriptions Theme file descriptions.
     * @global array $allowed_files        List of allowed files.
     *
     * @param string $file Filesystem path or filename.
     * @return string Description of file from $wp_file_descriptions or basename of $file if description doesn't exist.
     *                Appends 'Page Template' to basename of $file if the file is a page template.
     */
    function get_file_description($file)
    {
    }
    /**
     * Gets the absolute filesystem path to the root of the WordPress installation.
     *
     * @since 1.5.0
     *
     * @return string Full filesystem path to the root of the WordPress installation.
     */
    function get_home_path()
    {
    }
    /**
     * Returns a listing of all files in the specified folder and all subdirectories up to 100 levels deep.
     *
     * The depth of the recursiveness can be controlled by the $levels param.
     *
     * @since 2.6.0
     * @since 4.9.0 Added the `$exclusions` parameter.
     * @since 6.3.0 Added the `$include_hidden` parameter.
     *
     * @param string   $folder         Optional. Full path to folder. Default empty.
     * @param int      $levels         Optional. Levels of folders to follow, Default 100 (PHP Loop limit).
     * @param string[] $exclusions     Optional. List of folders and files to skip.
     * @param bool     $include_hidden Optional. Whether to include details of hidden ("." prefixed) files.
     *                                 Default false.
     * @return string[]|false Array of files on success, false on failure.
     */
    function list_files($folder = '', $levels = 100, $exclusions = array(), $include_hidden = \false)
    {
    }
    /**
     * Gets the list of file extensions that are editable in plugins.
     *
     * @since 4.9.0
     *
     * @param string $plugin Path to the plugin file relative to the plugins directory.
     * @return string[] Array of editable file extensions.
     */
    function wp_get_plugin_file_editable_extensions($plugin)
    {
    }
    /**
     * Gets the list of file extensions that are editable for a given theme.
     *
     * @since 4.9.0
     *
     * @param WP_Theme $theme Theme object.
     * @return string[] Array of editable file extensions.
     */
    function wp_get_theme_file_editable_extensions($theme)
    {
    }
    /**
     * Prints file editor templates (for plugins and themes).
     *
     * @since 4.9.0
     */
    function wp_print_file_editor_templates()
    {
    }
    /**
     * Attempts to edit a file for a theme or plugin.
     *
     * When editing a PHP file, loopback requests will be made to the admin and the homepage
     * to attempt to see if there is a fatal error introduced. If so, the PHP change will be
     * reverted.
     *
     * @since 4.9.0
     *
     * @param string[] $args {
     *     Args. Note that all of the arg values are already unslashed. They are, however,
     *     coming straight from `$_POST` and are not validated or sanitized in any way.
     *
     *     @type string $file       Relative path to file.
     *     @type string $plugin     Path to the plugin file relative to the plugins directory.
     *     @type string $theme      Theme being edited.
     *     @type string $newcontent New content for the file.
     *     @type string $nonce      Nonce.
     * }
     * @return true|WP_Error True on success or `WP_Error` on failure.
     * @phpstan-param array{
     *   file?: string,
     *   plugin?: string,
     *   theme?: string,
     *   newcontent?: string,
     *   nonce?: string,
     * } $args
     */
    function wp_edit_theme_plugin_file($args)
    {
    }
    /**
     * Returns a filename of a temporary unique file.
     *
     * Please note that the calling function must delete or move the file.
     *
     * The filename is based off the passed parameter or defaults to the current unix timestamp,
     * while the directory can either be passed as well, or by leaving it blank, default to a writable
     * temporary directory.
     *
     * @since 2.6.0
     *
     * @param string $filename Optional. Filename to base the Unique file off. Default empty.
     * @param string $dir      Optional. Directory to store the file in. Default empty.
     * @return string A writable filename.
     */
    function wp_tempnam($filename = '', $dir = '')
    {
    }
    /**
     * Makes sure that the file that was requested to be edited is allowed to be edited.
     *
     * Function will die if you are not allowed to edit the file.
     *
     * @since 1.5.0
     *
     * @param string   $file          File the user is attempting to edit.
     * @param string[] $allowed_files Optional. Array of allowed files to edit.
     *                                `$file` must match an entry exactly.
     * @return string|void Returns the file name on success, dies on failure.
     */
    function validate_file_to_edit($file, $allowed_files = array())
    {
    }
    /**
     * Handles PHP uploads in WordPress.
     *
     * Sanitizes file names, checks extensions for mime type, and moves the file
     * to the appropriate directory within the uploads directory.
     *
     * @access private
     * @since 4.0.0
     *
     * @see wp_handle_upload_error
     *
     * @param array       $file      {
     *     Reference to a single element from `$_FILES`. Call the function once for each uploaded file.
     *
     *     @type string $name     The original name of the file on the client machine.
     *     @type string $type     The mime type of the file, if the browser provided this information.
     *     @type string $tmp_name The temporary filename of the file in which the uploaded file was stored on the server.
     *     @type int    $size     The size, in bytes, of the uploaded file.
     *     @type int    $error    The error code associated with this file upload.
     * }
     * @param array|false $overrides {
     *     An array of override parameters for this file, or boolean false if none are provided.
     *
     *     @type callable $upload_error_handler     Function to call when there is an error during the upload process.
     *                                              See {@see wp_handle_upload_error()}.
     *     @type callable $unique_filename_callback Function to call when determining a unique file name for the file.
     *                                              See {@see wp_unique_filename()}.
     *     @type string[] $upload_error_strings     The strings that describe the error indicated in
     *                                              `$_FILES[{form field}]['error']`.
     *     @type bool     $test_form                Whether to test that the `$_POST['action']` parameter is as expected.
     *     @type bool     $test_size                Whether to test that the file size is greater than zero bytes.
     *     @type bool     $test_type                Whether to test that the mime type of the file is as expected.
     *     @type string[] $mimes                    Array of allowed mime types keyed by their file extension regex.
     * }
     * @param string      $time      Time formatted in 'yyyy/mm'.
     * @param string      $action    Expected value for `$_POST['action']`.
     * @return array {
     *     On success, returns an associative array of file attributes.
     *     On failure, returns `$overrides['upload_error_handler']( &$file, $message )`
     *     or `array( 'error' => $message )`.
     *
     *     @type string $file Filename of the newly-uploaded file.
     *     @type string $url  URL of the newly-uploaded file.
     *     @type string $type Mime type of the newly-uploaded file.
     * }
     * @phpstan-param array{
     *   name?: string,
     *   type?: string,
     *   tmp_name?: string,
     *   size?: int,
     *   error?: int,
     * } $file
     * @phpstan-param false|array{
     *   upload_error_handler?: callable,
     *   unique_filename_callback?: callable,
     *   upload_error_strings?: string[],
     *   test_form?: bool,
     *   test_size?: bool,
     *   test_type?: bool,
     *   mimes?: string[],
     * } $overrides
     * @phpstan-return array{
     *   file: string,
     *   url: string,
     *   type: string,
     * }
     */
    function _wp_handle_upload(&$file, $overrides, $time, $action)
    {
    }
    /**
     * Wrapper for _wp_handle_upload().
     *
     * Passes the {@see 'wp_handle_upload'} action.
     *
     * @since 2.0.0
     *
     * @see _wp_handle_upload()
     *
     * @param array       $file      Reference to a single element of `$_FILES`.
     *                               Call the function once for each uploaded file.
     *                               See _wp_handle_upload() for accepted values.
     * @param array|false $overrides Optional. An associative array of names => values
     *                               to override default variables. Default false.
     *                               See _wp_handle_upload() for accepted values.
     * @param string|null $time      Optional. Time formatted in 'yyyy/mm'. Default null.
     * @return array See _wp_handle_upload() for return value.
     * @phpstan-param array{
     *   name?: string,
     *   type?: string,
     *   tmp_name?: string,
     *   size?: int,
     *   error?: int,
     * } $file See _wp_handle_upload()
     * @phpstan-param false|array{
     *   upload_error_handler?: callable,
     *   unique_filename_callback?: callable,
     *   upload_error_strings?: string[],
     *   test_form?: bool,
     *   test_size?: bool,
     *   test_type?: bool,
     *   mimes?: string[],
     * } $overrides See _wp_handle_upload()
     */
    function wp_handle_upload(&$file, $overrides = \false, $time = \null)
    {
    }
    /**
     * Wrapper for _wp_handle_upload().
     *
     * Passes the {@see 'wp_handle_sideload'} action.
     *
     * @since 2.6.0
     *
     * @see _wp_handle_upload()
     *
     * @param array       $file      Reference to a single element of `$_FILES`.
     *                               Call the function once for each uploaded file.
     *                               See _wp_handle_upload() for accepted values.
     * @param array|false $overrides Optional. An associative array of names => values
     *                               to override default variables. Default false.
     *                               See _wp_handle_upload() for accepted values.
     * @param string|null $time      Optional. Time formatted in 'yyyy/mm'. Default null.
     * @return array See _wp_handle_upload() for return value.
     * @phpstan-param array{
     *   name?: string,
     *   type?: string,
     *   tmp_name?: string,
     *   size?: int,
     *   error?: int,
     * } $file See _wp_handle_upload()
     * @phpstan-param false|array{
     *   upload_error_handler?: callable,
     *   unique_filename_callback?: callable,
     *   upload_error_strings?: string[],
     *   test_form?: bool,
     *   test_size?: bool,
     *   test_type?: bool,
     *   mimes?: string[],
     * } $overrides See _wp_handle_upload()
     */
    function wp_handle_sideload(&$file, $overrides = \false, $time = \null)
    {
    }
    /**
     * Downloads a URL to a local temporary file using the WordPress HTTP API.
     *
     * Please note that the calling function must delete or move the file.
     *
     * @since 2.5.0
     * @since 5.2.0 Signature Verification with SoftFail was added.
     * @since 5.9.0 Support for Content-Disposition filename was added.
     *
     * @param string $url                    The URL of the file to download.
     * @param int    $timeout                The timeout for the request to download the file.
     *                                       Default 300 seconds.
     * @param bool   $signature_verification Whether to perform Signature Verification.
     *                                       Default false.
     * @return string|WP_Error Filename on success, WP_Error on failure.
     */
    function download_url($url, $timeout = 300, $signature_verification = \false)
    {
    }
    /**
     * Calculates and compares the MD5 of a file to its expected value.
     *
     * @since 3.7.0
     *
     * @param string $filename     The filename to check the MD5 of.
     * @param string $expected_md5 The expected MD5 of the file, either a base64-encoded raw md5,
     *                             or a hex-encoded md5.
     * @return bool|WP_Error True on success, false when the MD5 format is unknown/unexpected,
     *                       WP_Error on failure.
     */
    function verify_file_md5($filename, $expected_md5)
    {
    }
    /**
     * Verifies the contents of a file against its ED25519 signature.
     *
     * @since 5.2.0
     *
     * @param string       $filename            The file to validate.
     * @param string|array $signatures          A Signature provided for the file.
     * @param string|false $filename_for_errors Optional. A friendly filename for errors.
     * @return bool|WP_Error True on success, false if verification not attempted,
     *                       or WP_Error describing an error condition.
     */
    function verify_file_signature($filename, $signatures, $filename_for_errors = \false)
    {
    }
    /**
     * Retrieves the list of signing keys trusted by WordPress.
     *
     * @since 5.2.0
     *
     * @return string[] Array of base64-encoded signing keys.
     */
    function wp_trusted_keys()
    {
    }
    /**
     * Determines whether the given file is a valid ZIP file.
     *
     * This function does not test to ensure that a file exists. Non-existent files
     * are not valid ZIPs, so those will also return false.
     *
     * @since 6.4.4
     *
     * @param string $file Full path to the ZIP file.
     * @return bool Whether the file is a valid ZIP file.
     */
    function wp_zip_file_is_valid($file)
    {
    }
    /**
     * Unzips a specified ZIP file to a location on the filesystem via the WordPress
     * Filesystem Abstraction.
     *
     * Assumes that WP_Filesystem() has already been called and set up. Does not extract
     * a root-level __MACOSX directory, if present.
     *
     * Attempts to increase the PHP memory limit to 256M before uncompressing. However,
     * the most memory required shouldn't be much larger than the archive itself.
     *
     * @since 2.5.0
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     *
     * @param string $file Full path and filename of ZIP archive.
     * @param string $to   Full path on the filesystem to extract archive to.
     * @return true|WP_Error True on success, WP_Error on failure.
     */
    function unzip_file($file, $to)
    {
    }
    /**
     * Attempts to unzip an archive using the ZipArchive class.
     *
     * This function should not be called directly, use `unzip_file()` instead.
     *
     * Assumes that WP_Filesystem() has already been called and set up.
     *
     * @since 3.0.0
     * @access private
     *
     * @see unzip_file()
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     *
     * @param string   $file        Full path and filename of ZIP archive.
     * @param string   $to          Full path on the filesystem to extract archive to.
     * @param string[] $needed_dirs A partial list of required folders needed to be created.
     * @return true|WP_Error True on success, WP_Error on failure.
     */
    function _unzip_file_ziparchive($file, $to, $needed_dirs = array())
    {
    }
    /**
     * Attempts to unzip an archive using the PclZip library.
     *
     * This function should not be called directly, use `unzip_file()` instead.
     *
     * Assumes that WP_Filesystem() has already been called and set up.
     *
     * @since 3.0.0
     * @access private
     *
     * @see unzip_file()
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     *
     * @param string   $file        Full path and filename of ZIP archive.
     * @param string   $to          Full path on the filesystem to extract archive to.
     * @param string[] $needed_dirs A partial list of required folders needed to be created.
     * @return true|WP_Error True on success, WP_Error on failure.
     */
    function _unzip_file_pclzip($file, $to, $needed_dirs = array())
    {
    }
    /**
     * Copies a directory from one location to another via the WordPress Filesystem
     * Abstraction.
     *
     * Assumes that WP_Filesystem() has already been called and setup.
     *
     * @since 2.5.0
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     *
     * @param string   $from      Source directory.
     * @param string   $to        Destination directory.
     * @param string[] $skip_list An array of files/folders to skip copying.
     * @return true|WP_Error True on success, WP_Error on failure.
     */
    function copy_dir($from, $to, $skip_list = array())
    {
    }
    /**
     * Moves a directory from one location to another.
     *
     * Recursively invalidates OPcache on success.
     *
     * If the renaming failed, falls back to copy_dir().
     *
     * Assumes that WP_Filesystem() has already been called and setup.
     *
     * This function is not designed to merge directories, copy_dir() should be used instead.
     *
     * @since 6.2.0
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     *
     * @param string $from      Source directory.
     * @param string $to        Destination directory.
     * @param bool   $overwrite Optional. Whether to overwrite the destination directory if it exists.
     *                          Default false.
     * @return true|WP_Error True on success, WP_Error on failure.
     */
    function move_dir($from, $to, $overwrite = \false)
    {
    }
    /**
     * Initializes and connects the WordPress Filesystem Abstraction classes.
     *
     * This function will include the chosen transport and attempt connecting.
     *
     * Plugins may add extra transports, And force WordPress to use them by returning
     * the filename via the {@see 'filesystem_method_file'} filter.
     *
     * @since 2.5.0
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     *
     * @param array|false  $args                         Optional. Connection args, These are passed
     *                                                   directly to the `WP_Filesystem_*()` classes.
     *                                                   Default false.
     * @param string|false $context                      Optional. Context for get_filesystem_method().
     *                                                   Default false.
     * @param bool         $allow_relaxed_file_ownership Optional. Whether to allow Group/World writable.
     *                                                   Default false.
     * @return bool|null True on success, false on failure,
     *                   null if the filesystem method class file does not exist.
     */
    function WP_Filesystem($args = \false, $context = \false, $allow_relaxed_file_ownership = \false)
    {
    }
    /**
     * Determines which method to use for reading, writing, modifying, or deleting
     * files on the filesystem.
     *
     * The priority of the transports are: Direct, SSH2, FTP PHP Extension, FTP Sockets
     * (Via Sockets class, or `fsockopen()`). Valid values for these are: 'direct', 'ssh2',
     * 'ftpext' or 'ftpsockets'.
     *
     * The return value can be overridden by defining the `FS_METHOD` constant in `wp-config.php`,
     * or filtering via {@see 'filesystem_method'}.
     *
     * @link https://developer.wordpress.org/advanced-administration/wordpress/wp-config/#wordpress-upgrade-constants
     *
     * Plugins may define a custom transport handler, See WP_Filesystem().
     *
     * @since 2.5.0
     *
     * @global callable $_wp_filesystem_direct_method
     *
     * @param array  $args                         Optional. Connection details. Default empty array.
     * @param string $context                      Optional. Full path to the directory that is tested
     *                                             for being writable. Default empty.
     * @param bool   $allow_relaxed_file_ownership Optional. Whether to allow Group/World writable.
     *                                             Default false.
     * @return string The transport to use, see description for valid return values.
     */
    function get_filesystem_method($args = array(), $context = '', $allow_relaxed_file_ownership = \false)
    {
    }
    /**
     * Displays a form to the user to request for their FTP/SSH details in order
     * to connect to the filesystem.
     *
     * All chosen/entered details are saved, excluding the password.
     *
     * Hostnames may be in the form of hostname:portnumber (eg: wordpress.org:2467)
     * to specify an alternate FTP/SSH port.
     *
     * Plugins may override this form by returning true|false via the {@see 'request_filesystem_credentials'} filter.
     *
     * @since 2.5.0
     * @since 4.6.0 The `$context` parameter default changed from `false` to an empty string.
     *
     * @global string $pagenow The filename of the current screen.
     *
     * @param string        $form_post                    The URL to post the form to.
     * @param string        $type                         Optional. Chosen type of filesystem. Default empty.
     * @param bool|WP_Error $error                        Optional. Whether the current request has failed
     *                                                    to connect, or an error object. Default false.
     * @param string        $context                      Optional. Full path to the directory that is tested
     *                                                    for being writable. Default empty.
     * @param array         $extra_fields                 Optional. Extra `POST` fields to be checked
     *                                                    for inclusion in the post. Default null.
     * @param bool          $allow_relaxed_file_ownership Optional. Whether to allow Group/World writable.
     *                                                    Default false.
     * @return bool|array True if no filesystem credentials are required,
     *                    false if they are required but have not been provided,
     *                    array of credentials if they are required and have been provided.
     */
    function request_filesystem_credentials($form_post, $type = '', $error = \false, $context = '', $extra_fields = \null, $allow_relaxed_file_ownership = \false)
    {
    }
    /**
     * Prints the filesystem credentials modal when needed.
     *
     * @since 4.2.0
     * @phpstan-return void
     */
    function wp_print_request_filesystem_credentials_modal()
    {
    }
    /**
     * Attempts to clear the opcode cache for an individual PHP file.
     *
     * This function can be called safely without having to check the file extension
     * or availability of the OPcache extension.
     *
     * Whether or not invalidation is possible is cached to improve performance.
     *
     * @since 5.5.0
     *
     * @link https://www.php.net/manual/en/function.opcache-invalidate.php
     *
     * @param string $filepath Path to the file, including extension, for which the opcode cache is to be cleared.
     * @param bool   $force    Invalidate even if the modification time is not newer than the file in cache.
     *                         Default false.
     * @return bool True if opcache was invalidated for `$filepath`, or there was nothing to invalidate.
     *              False if opcache invalidation is not available, or is disabled via filter.
     */
    function wp_opcache_invalidate($filepath, $force = \false)
    {
    }
    /**
     * Attempts to clear the opcode cache for a directory of files.
     *
     * @since 6.2.0
     *
     * @see wp_opcache_invalidate()
     * @link https://www.php.net/manual/en/function.opcache-invalidate.php
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     *
     * @param string $dir The path to the directory for which the opcode cache is to be cleared.
     * @phpstan-return void
     */
    function wp_opcache_invalidate_directory($dir)
    {
    }
    /**
     * Loads the WP image-editing interface.
     *
     * @since 2.9.0
     *
     * @param int          $post_id Attachment post ID.
     * @param false|object $msg     Optional. Message to display for image editor updates or errors.
     *                              Default false.
     */
    function wp_image_editor($post_id, $msg = \false)
    {
    }
    /**
     * Streams image in WP_Image_Editor to browser.
     *
     * @since 2.9.0
     *
     * @param WP_Image_Editor $image         The image editor instance.
     * @param string          $mime_type     The mime type of the image.
     * @param int             $attachment_id The image's attachment post ID.
     * @return bool True on success, false on failure.
     */
    function wp_stream_image($image, $mime_type, $attachment_id)
    {
    }
    /**
     * Saves image to file.
     *
     * @since 2.9.0
     * @since 3.5.0 The `$image` parameter expects a `WP_Image_Editor` instance.
     * @since 6.0.0 The `$filesize` value was added to the returned array.
     *
     * @param string          $filename  Name of the file to be saved.
     * @param WP_Image_Editor $image     The image editor instance.
     * @param string          $mime_type The mime type of the image.
     * @param int             $post_id   Attachment post ID.
     * @return array|WP_Error|bool {
     *     Array on success or WP_Error if the file failed to save.
     *     When called with a deprecated value for the `$image` parameter,
     *     i.e. a non-`WP_Image_Editor` image resource or `GdImage` instance,
     *     the function will return true on success, false on failure.
     *
     *     @type string $path      Path to the image file.
     *     @type string $file      Name of the image file.
     *     @type int    $width     Image width.
     *     @type int    $height    Image height.
     *     @type string $mime-type The mime type of the image.
     *     @type int    $filesize  File size of the image.
     * }
     * @phpstan-return \WP_Error|bool|array{
     *   path: string,
     *   file: string,
     *   width: int,
     *   height: int,
     *   mime-type: string,
     *   filesize: int,
     * }
     */
    function wp_save_image_file($filename, $image, $mime_type, $post_id)
    {
    }
    /**
     * Image preview ratio. Internal use only.
     *
     * @since 2.9.0
     *
     * @ignore
     * @param int $w Image width in pixels.
     * @param int $h Image height in pixels.
     * @return float|int Image preview ratio.
     */
    function _image_get_preview_ratio($w, $h)
    {
    }
    /**
     * Returns an image resource. Internal use only.
     *
     * @since 2.9.0
     * @deprecated 3.5.0 Use WP_Image_Editor::rotate()
     * @see WP_Image_Editor::rotate()
     *
     * @ignore
     * @param resource|GdImage  $img   Image resource.
     * @param float|int         $angle Image rotation angle, in degrees.
     * @return resource|GdImage|false GD image resource or GdImage instance, false otherwise.
     */
    function _rotate_image_resource($img, $angle)
    {
    }
    /**
     * Flips an image resource. Internal use only.
     *
     * @since 2.9.0
     * @deprecated 3.5.0 Use WP_Image_Editor::flip()
     * @see WP_Image_Editor::flip()
     *
     * @ignore
     * @param resource|GdImage $img  Image resource or GdImage instance.
     * @param bool             $horz Whether to flip horizontally.
     * @param bool             $vert Whether to flip vertically.
     * @return resource|GdImage (maybe) flipped image resource or GdImage instance.
     */
    function _flip_image_resource($img, $horz, $vert)
    {
    }
    /**
     * Crops an image resource. Internal use only.
     *
     * @since 2.9.0
     *
     * @ignore
     * @param resource|GdImage $img Image resource or GdImage instance.
     * @param float            $x   Source point x-coordinate.
     * @param float            $y   Source point y-coordinate.
     * @param float            $w   Source width.
     * @param float            $h   Source height.
     * @return resource|GdImage (maybe) cropped image resource or GdImage instance.
     */
    function _crop_image_resource($img, $x, $y, $w, $h)
    {
    }
    /**
     * Performs group of changes on Editor specified.
     *
     * @since 2.9.0
     *
     * @param WP_Image_Editor $image   WP_Image_Editor instance.
     * @param array           $changes Array of change operations.
     * @return WP_Image_Editor WP_Image_Editor instance with changes applied.
     */
    function image_edit_apply_changes($image, $changes)
    {
    }
    /**
     * Streams image in post to browser, along with enqueued changes
     * in `$_REQUEST['history']`.
     *
     * @since 2.9.0
     *
     * @param int $post_id Attachment post ID.
     * @return bool True on success, false on failure.
     */
    function stream_preview_image($post_id)
    {
    }
    /**
     * Restores the metadata for a given attachment.
     *
     * @since 2.9.0
     *
     * @param int $post_id Attachment post ID.
     * @return stdClass Image restoration message object.
     */
    function wp_restore_image($post_id)
    {
    }
    /**
     * Saves image to post, along with enqueued changes
     * in `$_REQUEST['history']`.
     *
     * @since 2.9.0
     *
     * @param int $post_id Attachment post ID.
     * @return stdClass
     */
    function wp_save_image($post_id)
    {
    }
    /**
     * Crops an image to a given size.
     *
     * @since 2.1.0
     *
     * @param string|int   $src      The source file or Attachment ID.
     * @param int          $src_x    The start x position to crop from.
     * @param int          $src_y    The start y position to crop from.
     * @param int          $src_w    The width to crop.
     * @param int          $src_h    The height to crop.
     * @param int          $dst_w    The destination width.
     * @param int          $dst_h    The destination height.
     * @param bool|false   $src_abs  Optional. If the source crop points are absolute.
     * @param string|false $dst_file Optional. The destination file to write to.
     * @return string|WP_Error New filepath on success, WP_Error on failure.
     */
    function wp_crop_image($src, $src_x, $src_y, $src_w, $src_h, $dst_w, $dst_h, $src_abs = \false, $dst_file = \false)
    {
    }
    /**
     * Compare the existing image sub-sizes (as saved in the attachment meta)
     * to the currently registered image sub-sizes, and return the difference.
     *
     * Registered sub-sizes that are larger than the image are skipped.
     *
     * @since 5.3.0
     *
     * @param int $attachment_id The image attachment post ID.
     * @return array[] Associative array of arrays of image sub-size information for
     *                 missing image sizes, keyed by image size name.
     */
    function wp_get_missing_image_subsizes($attachment_id)
    {
    }
    /**
     * If any of the currently registered image sub-sizes are missing,
     * create them and update the image meta data.
     *
     * @since 5.3.0
     *
     * @param int $attachment_id The image attachment post ID.
     * @return array|WP_Error The updated image meta data array or WP_Error object
     *                        if both the image meta and the attached file are missing.
     */
    function wp_update_image_subsizes($attachment_id)
    {
    }
    /**
     * Updates the attached file and image meta data when the original image was edited.
     *
     * @since 5.3.0
     * @since 6.0.0 The `$filesize` value was added to the returned array.
     * @access private
     *
     * @param array  $saved_data    The data returned from WP_Image_Editor after successfully saving an image.
     * @param string $original_file Path to the original file.
     * @param array  $image_meta    The image meta data.
     * @param int    $attachment_id The attachment post ID.
     * @return array The updated image meta data.
     */
    function _wp_image_meta_replace_original($saved_data, $original_file, $image_meta, $attachment_id)
    {
    }
    /**
     * Creates image sub-sizes, adds the new data to the image meta `sizes` array, and updates the image metadata.
     *
     * Intended for use after an image is uploaded. Saves/updates the image metadata after each
     * sub-size is created. If there was an error, it is added to the returned image metadata array.
     *
     * @since 5.3.0
     *
     * @param string $file          Full path to the image file.
     * @param int    $attachment_id Attachment ID to process.
     * @return array The image attachment meta data.
     */
    function wp_create_image_subsizes($file, $attachment_id)
    {
    }
    /**
     * Low-level function to create image sub-sizes.
     *
     * Updates the image meta after each sub-size is created.
     * Errors are stored in the returned image metadata array.
     *
     * @since 5.3.0
     * @access private
     *
     * @param array  $new_sizes     Array defining what sizes to create.
     * @param string $file          Full path to the image file.
     * @param array  $image_meta    The attachment meta data array.
     * @param int    $attachment_id Attachment ID to process.
     * @return array The attachment meta data with updated `sizes` array. Includes an array of errors encountered while resizing.
     */
    function _wp_make_subsizes($new_sizes, $file, $image_meta, $attachment_id)
    {
    }
    /**
     * Copy parent attachment properties to newly cropped image.
     *
     * @since 6.5.0
     *
     * @param string $cropped              Path to the cropped image file.
     * @param int    $parent_attachment_id Parent file Attachment ID.
     * @param string $context              Control calling the function.
     * @return array Properties of attachment.
     */
    function wp_copy_parent_attachment_properties($cropped, $parent_attachment_id, $context = '')
    {
    }
    /**
     * Generates attachment meta data and create image sub-sizes for images.
     *
     * @since 2.1.0
     * @since 6.0.0 The `$filesize` value was added to the returned array.
     * @since 6.7.0 The 'image/heic' mime type is supported.
     *
     * @param int    $attachment_id Attachment ID to process.
     * @param string $file          Filepath of the attached image.
     * @return array Metadata for attachment.
     */
    function wp_generate_attachment_metadata($attachment_id, $file)
    {
    }
    /**
     * Converts a fraction string to a decimal.
     *
     * @since 2.5.0
     *
     * @param string $str Fraction string.
     * @return int|float Returns calculated fraction or integer 0 on invalid input.
     */
    function wp_exif_frac2dec($str)
    {
    }
    /**
     * Converts the exif date format to a unix timestamp.
     *
     * @since 2.5.0
     *
     * @param string $str A date string expected to be in Exif format (Y:m:d H:i:s).
     * @return int|false The unix timestamp, or false on failure.
     */
    function wp_exif_date2ts($str)
    {
    }
    /**
     * Gets extended image metadata, exif or iptc as available.
     *
     * Retrieves the EXIF metadata aperture, credit, camera, caption, copyright, iso
     * created_timestamp, focal_length, shutter_speed, and title.
     *
     * The IPTC metadata that is retrieved is APP13, credit, byline, created date
     * and time, caption, copyright, and title. Also includes FNumber, Model,
     * DateTimeDigitized, FocalLength, ISOSpeedRatings, and ExposureTime.
     *
     * @todo Try other exif libraries if available.
     * @since 2.5.0
     *
     * @param string $file
     * @return array|false Image metadata array on success, false on failure.
     */
    function wp_read_image_metadata($file)
    {
    }
    /**
     * Validates that file is an image.
     *
     * @since 2.5.0
     *
     * @param string $path File path to test if valid image.
     * @return bool True if valid image, false if not valid image.
     */
    function file_is_valid_image($path)
    {
    }
    /**
     * Validates that file is suitable for displaying within a web page.
     *
     * @since 2.5.0
     *
     * @param string $path File path to test.
     * @return bool True if suitable, false if not suitable.
     */
    function file_is_displayable_image($path)
    {
    }
    /**
     * Loads an image resource for editing.
     *
     * @since 2.9.0
     *
     * @param int          $attachment_id Attachment ID.
     * @param string       $mime_type     Image mime type.
     * @param string|int[] $size          Optional. Image size. Accepts any registered image size name, or an array
     *                                    of width and height values in pixels (in that order). Default 'full'.
     * @return resource|GdImage|false The resulting image resource or GdImage instance on success,
     *                                false on failure.
     */
    function load_image_to_edit($attachment_id, $mime_type, $size = 'full')
    {
    }
    /**
     * Retrieves the path or URL of an attachment's attached file.
     *
     * If the attached file is not present on the local filesystem (usually due to replication plugins),
     * then the URL of the file is returned if `allow_url_fopen` is supported.
     *
     * @since 3.4.0
     * @access private
     *
     * @param int          $attachment_id Attachment ID.
     * @param string|int[] $size          Optional. Image size. Accepts any registered image size name, or an array
     *                                    of width and height values in pixels (in that order). Default 'full'.
     * @return string|false File path or URL on success, false on failure.
     */
    function _load_image_to_edit_path($attachment_id, $size = 'full')
    {
    }
    /**
     * Copies an existing image file.
     *
     * @since 3.4.0
     * @access private
     *
     * @param int $attachment_id Attachment ID.
     * @return string|false New file path on success, false on failure.
     */
    function _copy_image_file($attachment_id)
    {
    }
    /**
     * Retrieves the list of importers.
     *
     * @since 2.0.0
     *
     * @global array $wp_importers
     * @return array
     */
    function get_importers()
    {
    }
    /**
     * Sorts a multidimensional array by first member of each top level member.
     *
     * Used by uasort() as a callback, should not be used directly.
     *
     * @since 2.9.0
     * @access private
     *
     * @param array $a
     * @param array $b
     * @return int
     */
    function _usort_by_first_member($a, $b)
    {
    }
    /**
     * Registers importer for WordPress.
     *
     * @since 2.0.0
     *
     * @global array $wp_importers
     *
     * @param string   $id          Importer tag. Used to uniquely identify importer.
     * @param string   $name        Importer name and title.
     * @param string   $description Importer description.
     * @param callable $callback    Callback to run.
     * @return void|WP_Error Void on success. WP_Error when $callback is WP_Error.
     */
    function register_importer($id, $name, $description, $callback)
    {
    }
    /**
     * Cleanup importer.
     *
     * Removes attachment based on ID.
     *
     * @since 2.0.0
     *
     * @param string $id Importer ID.
     */
    function wp_import_cleanup($id)
    {
    }
    /**
     * Handles importer uploading and adds attachment.
     *
     * @since 2.0.0
     *
     * @return array Uploaded file's details on success, error message on failure.
     */
    function wp_import_handle_upload()
    {
    }
    /**
     * Returns a list from WordPress.org of popular importer plugins.
     *
     * @since 3.5.0
     *
     * @return array Importers with metadata for each.
     */
    function wp_get_popular_importers()
    {
    }
    /**
     * Fetches an instance of a WP_List_Table class.
     *
     * @since 3.1.0
     *
     * @global string $hook_suffix
     *
     * @param string $class_name The type of the list table, which is the class name.
     * @param array  $args       Optional. Arguments to pass to the class. Accepts 'screen'.
     * @return WP_List_Table|false List table object on success, false if the class does not exist.
     * @phpstan-template T of string
     * @phpstan-param T $class_name
     * @phpstan-param array{screen?: string} $args
     * @phpstan-return ($class_name is 'WP_Posts_List_Table'|'WP_Media_List_Table'|'WP_Terms_List_Table'|'WP_Users_List_Table'|'WP_Comments_List_Table'|'WP_Post_Comments_List_Table'|'WP_Links_List_Table'|'WP_Plugin_Install_List_Table'|'WP_Themes_List_Table'|'WP_Theme_Install_List_Table'|'WP_Plugins_List_Table'|'WP_Application_Passwords_List_Table'|'WP_MS_Sites_List_Table'|'WP_MS_Users_List_Table'|'WP_MS_Themes_List_Table'|'WP_Privacy_Data_Export_Requests_List_Table'|'WP_Privacy_Data_Removal_Requests_List_Table' ? new<T> : false)
     */
    function _get_list_table($class_name, $args = array())
    {
    }
    /**
     * Register column headers for a particular screen.
     *
     * @see get_column_headers(), print_column_headers(), get_hidden_columns()
     *
     * @since 2.7.0
     *
     * @param string    $screen The handle for the screen to register column headers for. This is
     *                          usually the hook name returned by the `add_*_page()` functions.
     * @param string[] $columns An array of columns with column IDs as the keys and translated
     *                          column names as the values.
     */
    function register_column_headers($screen, $columns)
    {
    }
    /**
     * Prints column headers for a particular screen.
     *
     * @since 2.7.0
     *
     * @param string|WP_Screen $screen  The screen hook name or screen object.
     * @param bool             $with_id Whether to set the ID attribute or not.
     */
    function print_column_headers($screen, $with_id = \true)
    {
    }
    /**
     * Defines the default media upload tabs.
     *
     * @since 2.5.0
     *
     * @return string[] Default tabs.
     */
    function media_upload_tabs()
    {
    }
    /**
     * Adds the gallery tab back to the tabs array if post has image attachments.
     *
     * @since 2.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array $tabs
     * @return array $tabs with gallery if post has image attachment
     */
    function update_gallery_tab($tabs)
    {
    }
    /**
     * Outputs the legacy media upload tabs UI.
     *
     * @since 2.5.0
     *
     * @global string $redir_tab
     */
    function the_media_upload_tabs()
    {
    }
    /**
     * Retrieves the image HTML to send to the editor.
     *
     * @since 2.5.0
     *
     * @param int          $id      Image attachment ID.
     * @param string       $caption Image caption.
     * @param string       $title   Image title attribute.
     * @param string       $align   Image CSS alignment property.
     * @param string       $url     Optional. Image src URL. Default empty.
     * @param bool|string  $rel     Optional. Value for rel attribute or whether to add a default value. Default false.
     * @param string|int[] $size    Optional. Image size. Accepts any registered image size name, or an array of
     *                              width and height values in pixels (in that order). Default 'medium'.
     * @param string       $alt     Optional. Image alt attribute. Default empty.
     * @return string The HTML output to insert into the editor.
     */
    function get_image_send_to_editor($id, $caption, $title, $align, $url = '', $rel = \false, $size = 'medium', $alt = '')
    {
    }
    /**
     * Adds image shortcode with caption to editor.
     *
     * @since 2.6.0
     *
     * @param string  $html    The image HTML markup to send.
     * @param int     $id      Image attachment ID.
     * @param string  $caption Image caption.
     * @param string  $title   Image title attribute (not used).
     * @param string  $align   Image CSS alignment property.
     * @param string  $url     Image source URL (not used).
     * @param string  $size    Image size (not used).
     * @param string  $alt     Image `alt` attribute (not used).
     * @return string The image HTML markup with caption shortcode.
     */
    function image_add_caption($html, $id, $caption, $title, $align, $url, $size, $alt = '')
    {
    }
    /**
     * Private preg_replace callback used in image_add_caption().
     *
     * @access private
     * @since 3.4.0
     *
     * @param array $matches Single regex match.
     * @return string Cleaned up HTML for caption.
     */
    function _cleanup_image_add_caption($matches)
    {
    }
    /**
     * Adds image HTML to editor.
     *
     * @since 2.5.0
     *
     * @param string $html
     * @phpstan-return never
     */
    function media_send_to_editor($html)
    {
    }
    /**
     * Saves a file submitted from a POST request and create an attachment post for it.
     *
     * @since 2.5.0
     *
     * @param string $file_id   Index of the `$_FILES` array that the file was sent.
     * @param int    $post_id   The post ID of a post to attach the media item to. Required, but can
     *                          be set to 0, creating a media item that has no relationship to a post.
     * @param array  $post_data Optional. Overwrite some of the attachment.
     * @param array  $overrides Optional. Override the wp_handle_upload() behavior.
     * @return int|WP_Error ID of the attachment or a WP_Error object on failure.
     */
    function media_handle_upload($file_id, $post_id, $post_data = array(), $overrides = array('test_form' => \false))
    {
    }
    /**
     * Handles a side-loaded file in the same way as an uploaded file is handled by media_handle_upload().
     *
     * @since 2.6.0
     * @since 5.3.0 The `$post_id` parameter was made optional.
     *
     * @param string[] $file_array Array that represents a `$_FILES` upload array.
     * @param int      $post_id    Optional. The post ID the media is associated with.
     * @param string   $desc       Optional. Description of the side-loaded file. Default null.
     * @param array    $post_data  Optional. Post data to override. Default empty array.
     * @return int|WP_Error The ID of the attachment or a WP_Error on failure.
     */
    function media_handle_sideload($file_array, $post_id = 0, $desc = \null, $post_data = array())
    {
    }
    /**
     * Outputs the iframe to display the media upload page.
     *
     * @since 2.5.0
     * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
     *              by adding it to the function signature.
     *
     * @global string $body_id
     *
     * @param callable $content_func Function that outputs the content.
     * @param mixed    ...$args      Optional additional parameters to pass to the callback function when it's called.
     */
    function wp_iframe($content_func, ...$args)
    {
    }
    /**
     * Adds the media button to the editor.
     *
     * @since 2.5.0
     *
     * @global int $post_ID
     *
     * @param string $editor_id
     */
    function media_buttons($editor_id = 'content')
    {
    }
    /**
     * Retrieves the upload iframe source URL.
     *
     * @since 3.0.0
     *
     * @global int $post_ID
     *
     * @param string $type    Media type.
     * @param int    $post_id Post ID.
     * @param string $tab     Media upload tab.
     * @return string Upload iframe source URL.
     */
    function get_upload_iframe_src($type = \null, $post_id = \null, $tab = \null)
    {
    }
    /**
     * Handles form submissions for the legacy media uploader.
     *
     * @since 2.5.0
     *
     * @return null|array|void Array of error messages keyed by attachment ID, null or void on success.
     */
    function media_upload_form_handler()
    {
    }
    /**
     * Handles the process of uploading media.
     *
     * @since 2.5.0
     *
     * @return null|string
     */
    function wp_media_upload_handler()
    {
    }
    /**
     * Downloads an image from the specified URL, saves it as an attachment, and optionally attaches it to a post.
     *
     * @since 2.6.0
     * @since 4.2.0 Introduced the `$return_type` parameter.
     * @since 4.8.0 Introduced the 'id' option for the `$return_type` parameter.
     * @since 5.3.0 The `$post_id` parameter was made optional.
     * @since 5.4.0 The original URL of the attachment is stored in the `_source_url`
     *              post meta value.
     * @since 5.8.0 Added 'webp' to the default list of allowed file extensions.
     *
     * @param string $file        The URL of the image to download.
     * @param int    $post_id     Optional. The post ID the media is to be associated with.
     * @param string $desc        Optional. Description of the image.
     * @param string $return_type Optional. Accepts 'html' (image tag html) or 'src' (URL),
     *                            or 'id' (attachment ID). Default 'html'.
     * @return string|int|WP_Error Populated HTML img tag, attachment ID, or attachment source
     *                             on success, WP_Error object otherwise.
     */
    function media_sideload_image($file, $post_id = 0, $desc = \null, $return_type = 'html')
    {
    }
    /**
     * Retrieves the legacy media uploader form in an iframe.
     *
     * @since 2.5.0
     *
     * @return string|null
     */
    function media_upload_gallery()
    {
    }
    /**
     * Retrieves the legacy media library form in an iframe.
     *
     * @since 2.5.0
     *
     * @return string|null
     */
    function media_upload_library()
    {
    }
    /**
     * Retrieves HTML for the image alignment radio buttons with the specified one checked.
     *
     * @since 2.7.0
     *
     * @param WP_Post $post
     * @param string  $checked
     * @return string
     */
    function image_align_input_fields($post, $checked = '')
    {
    }
    /**
     * Retrieves HTML for the size radio buttons with the specified one checked.
     *
     * @since 2.7.0
     *
     * @param WP_Post     $post
     * @param bool|string $check
     * @return array
     */
    function image_size_input_fields($post, $check = '')
    {
    }
    /**
     * Retrieves HTML for the Link URL buttons with the default link type as specified.
     *
     * @since 2.7.0
     *
     * @param WP_Post $post
     * @param string  $url_type
     * @return string
     */
    function image_link_input_fields($post, $url_type = '')
    {
    }
    /**
     * Outputs a textarea element for inputting an attachment caption.
     *
     * @since 3.4.0
     *
     * @param WP_Post $edit_post Attachment WP_Post object.
     * @return string HTML markup for the textarea element.
     */
    function wp_caption_input_textarea($edit_post)
    {
    }
    /**
     * Retrieves the image attachment fields to edit form fields.
     *
     * @since 2.5.0
     *
     * @param array  $form_fields
     * @param object $post
     * @return array
     */
    function image_attachment_fields_to_edit($form_fields, $post)
    {
    }
    /**
     * Retrieves the single non-image attachment fields to edit form fields.
     *
     * @since 2.5.0
     *
     * @param array   $form_fields An array of attachment form fields.
     * @param WP_Post $post        The WP_Post attachment object.
     * @return array Filtered attachment form fields.
     */
    function media_single_attachment_fields_to_edit($form_fields, $post)
    {
    }
    /**
     * Retrieves the post non-image attachment fields to edit form fields.
     *
     * @since 2.8.0
     *
     * @param array   $form_fields An array of attachment form fields.
     * @param WP_Post $post        The WP_Post attachment object.
     * @return array Filtered attachment form fields.
     */
    function media_post_single_attachment_fields_to_edit($form_fields, $post)
    {
    }
    /**
     * Retrieves the media element HTML to send to the editor.
     *
     * @since 2.5.0
     *
     * @param string  $html
     * @param int     $attachment_id
     * @param array   $attachment
     * @return string
     */
    function image_media_send_to_editor($html, $attachment_id, $attachment)
    {
    }
    /**
     * Retrieves the attachment fields to edit form fields.
     *
     * @since 2.5.0
     *
     * @param WP_Post $post
     * @param array   $errors
     * @return array
     */
    function get_attachment_fields_to_edit($post, $errors = \null)
    {
    }
    /**
     * Retrieves HTML for media items of post gallery.
     *
     * The HTML markup retrieved will be created for the progress of SWF Upload
     * component. Will also create link for showing and hiding the form to modify
     * the image attachment.
     *
     * @since 2.5.0
     *
     * @global WP_Query $wp_the_query WordPress Query object.
     *
     * @param int   $post_id Post ID.
     * @param array $errors  Errors for attachment, if any.
     * @return string HTML content for media items of post gallery.
     */
    function get_media_items($post_id, $errors)
    {
    }
    /**
     * Retrieves HTML form for modifying the image attachment.
     *
     * @since 2.5.0
     *
     * @global string $redir_tab
     *
     * @param int          $attachment_id Attachment ID for modification.
     * @param string|array $args          Optional. Override defaults.
     * @return string HTML form for attachment.
     */
    function get_media_item($attachment_id, $args = \null)
    {
    }
    /**
     * @since 3.5.0
     *
     * @param int   $attachment_id
     * @param array $args
     * @return array
     */
    function get_compat_media_markup($attachment_id, $args = \null)
    {
    }
    /**
     * Outputs the legacy media upload header.
     *
     * @since 2.5.0
     */
    function media_upload_header()
    {
    }
    /**
     * Outputs the legacy media upload form.
     *
     * @since 2.5.0
     *
     * @global string $type
     * @global string $tab
     *
     * @param array $errors
     * @phpstan-return void
     */
    function media_upload_form($errors = \null)
    {
    }
    /**
     * Outputs the legacy media upload form for a given media type.
     *
     * @since 2.5.0
     *
     * @param string       $type
     * @param array        $errors
     * @param int|WP_Error $id
     */
    function media_upload_type_form($type = 'file', $errors = \null, $id = \null)
    {
    }
    /**
     * Outputs the legacy media upload form for external media.
     *
     * @since 2.7.0
     *
     * @param string  $type
     * @param object  $errors
     * @param int     $id
     */
    function media_upload_type_url_form($type = \null, $errors = \null, $id = \null)
    {
    }
    /**
     * Adds gallery form to upload iframe.
     *
     * @since 2.5.0
     *
     * @global string $redir_tab
     * @global string $type
     * @global string $tab
     *
     * @param array $errors
     */
    function media_upload_gallery_form($errors)
    {
    }
    /**
     * Outputs the legacy media upload form for the media library.
     *
     * @since 2.5.0
     *
     * @global wpdb      $wpdb            WordPress database abstraction object.
     * @global WP_Query  $wp_query        WordPress Query object.
     * @global WP_Locale $wp_locale       WordPress date and time locale object.
     * @global string    $type
     * @global string    $tab
     * @global array     $post_mime_types
     *
     * @param array $errors
     */
    function media_upload_library_form($errors)
    {
    }
    /**
     * Creates the form for external url.
     *
     * @since 2.7.0
     *
     * @param string $default_view
     * @return string HTML content of the form.
     */
    function wp_media_insert_url_form($default_view = 'image')
    {
    }
    /**
     * Displays the multi-file uploader message.
     *
     * @since 2.6.0
     *
     * @global int $post_ID
     */
    function media_upload_flash_bypass()
    {
    }
    /**
     * Displays the browser's built-in uploader message.
     *
     * @since 2.6.0
     */
    function media_upload_html_bypass()
    {
    }
    /**
     * Used to display a "After a file has been uploaded..." help message.
     *
     * @since 3.3.0
     */
    function media_upload_text_after()
    {
    }
    /**
     * Displays the checkbox to scale images.
     *
     * @since 3.3.0
     */
    function media_upload_max_image_resize()
    {
    }
    /**
     * Displays the out of storage quota message in Multisite.
     *
     * @since 3.5.0
     */
    function multisite_over_quota_message()
    {
    }
    /**
     * Displays the image and editor in the post editor
     *
     * @since 3.5.0
     *
     * @param WP_Post $post A post object.
     */
    function edit_form_image_editor($post)
    {
    }
    /**
     * Displays non-editable attachment metadata in the publish meta box.
     *
     * @since 3.5.0
     */
    function attachment_submitbox_metadata()
    {
    }
    /**
     * Parses ID3v2, ID3v1, and getID3 comments to extract usable data.
     *
     * @since 3.6.0
     *
     * @param array $metadata An existing array with data.
     * @param array $data Data supplied by ID3 tags.
     */
    function wp_add_id3_tag_data(&$metadata, $data)
    {
    }
    /**
     * Retrieves metadata from a video file's ID3 tags.
     *
     * @since 3.6.0
     *
     * @param string $file Path to file.
     * @return array|false Returns array of metadata, if found.
     */
    function wp_read_video_metadata($file)
    {
    }
    /**
     * Retrieves metadata from an audio file's ID3 tags.
     *
     * @since 3.6.0
     *
     * @param string $file Path to file.
     * @return array|false Returns array of metadata, if found.
     */
    function wp_read_audio_metadata($file)
    {
    }
    /**
     * Parses creation date from media metadata.
     *
     * The getID3 library doesn't have a standard method for getting creation dates,
     * so the location of this data can vary based on the MIME type.
     *
     * @since 4.9.0
     *
     * @link https://github.com/JamesHeinrich/getID3/blob/master/structure.txt
     *
     * @param array $metadata The metadata returned by getID3::analyze().
     * @return int|false A UNIX timestamp for the media's creation date if available
     *                   or a boolean FALSE if a timestamp could not be determined.
     */
    function wp_get_media_creation_timestamp($metadata)
    {
    }
    /**
     * Encapsulates the logic for Attach/Detach actions.
     *
     * @since 4.2.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $parent_id Attachment parent ID.
     * @param string $action    Optional. Attach/detach action. Accepts 'attach' or 'detach'.
     *                          Default 'attach'.
     * @phpstan-param 'attach'|'detach' $action
     * @phpstan-return void
     */
    function wp_media_attach_action($parent_id, $action = 'attach')
    {
    }
    /**
     * Adds a CSS class to a string.
     *
     * @since 2.7.0
     *
     * @param string $class_to_add The CSS class to add.
     * @param string $classes      The string to add the CSS class to.
     * @return string The string with the CSS class added.
     */
    function add_cssclass($class_to_add, $classes)
    {
    }
    /**
     * Adds CSS classes for top-level administration menu items.
     *
     * The list of added classes includes `.menu-top-first` and `.menu-top-last`.
     *
     * @since 2.7.0
     *
     * @param array $menu The array of administration menu items.
     * @return array The array of administration menu items with the CSS classes added.
     */
    function add_menu_classes($menu)
    {
    }
    /**
     * @global array $menu_order
     * @global array $default_menu_order
     *
     * @param array $a
     * @param array $b
     * @return int
     */
    function sort_menu($a, $b)
    {
    }
    /**
     * Displays post submit form fields.
     *
     * @since 2.7.0
     *
     * @global string $action
     *
     * @param WP_Post $post Current post object.
     * @param array   $args {
     *     Array of arguments for building the post submit meta box.
     *
     *     @type string   $id       Meta box 'id' attribute.
     *     @type string   $title    Meta box title.
     *     @type callable $callback Meta box display callback.
     *     @type array    $args     Extra meta box arguments.
     * }
     * @phpstan-param array{
     *   id?: string,
     *   title?: string,
     *   callback?: callable,
     *   args?: array,
     * } $args
     */
    function post_submit_meta_box($post, $args = array())
    {
    }
    /**
     * Displays attachment submit form fields.
     *
     * @since 3.5.0
     *
     * @param WP_Post $post Current post object.
     */
    function attachment_submit_meta_box($post)
    {
    }
    /**
     * Displays post format form elements.
     *
     * @since 3.1.0
     *
     * @param WP_Post $post Current post object.
     * @param array   $box {
     *     Post formats meta box arguments.
     *
     *     @type string   $id       Meta box 'id' attribute.
     *     @type string   $title    Meta box title.
     *     @type callable $callback Meta box display callback.
     *     @type array    $args     Extra meta box arguments.
     * }
     * @phpstan-param array{
     *   id?: string,
     *   title?: string,
     *   callback?: callable,
     *   args?: array,
     * } $box
     */
    function post_format_meta_box($post, $box)
    {
    }
    /**
     * Displays post tags form fields.
     *
     * @since 2.6.0
     *
     * @todo Create taxonomy-agnostic wrapper for this.
     *
     * @param WP_Post $post Current post object.
     * @param array   $box {
     *     Tags meta box arguments.
     *
     *     @type string   $id       Meta box 'id' attribute.
     *     @type string   $title    Meta box title.
     *     @type callable $callback Meta box display callback.
     *     @type array    $args {
     *         Extra meta box arguments.
     *
     *         @type string $taxonomy Taxonomy. Default 'post_tag'.
     *     }
     * }
     * @phpstan-param array{
     *   id?: string,
     *   title?: string,
     *   callback?: callable,
     *   args?: array{
     *     taxonomy?: string,
     *   },
     * } $box
     */
    function post_tags_meta_box($post, $box)
    {
    }
    /**
     * Displays post categories form fields.
     *
     * @since 2.6.0
     *
     * @todo Create taxonomy-agnostic wrapper for this.
     *
     * @param WP_Post $post Current post object.
     * @param array   $box {
     *     Categories meta box arguments.
     *
     *     @type string   $id       Meta box 'id' attribute.
     *     @type string   $title    Meta box title.
     *     @type callable $callback Meta box display callback.
     *     @type array    $args {
     *         Extra meta box arguments.
     *
     *         @type string $taxonomy Taxonomy. Default 'category'.
     *     }
     * }
     * @phpstan-param array{
     *   id?: string,
     *   title?: string,
     *   callback?: callable,
     *   args?: array{
     *     taxonomy?: string,
     *   },
     * } $box
     */
    function post_categories_meta_box($post, $box)
    {
    }
    /**
     * Displays post excerpt form fields.
     *
     * @since 2.6.0
     *
     * @param WP_Post $post Current post object.
     */
    function post_excerpt_meta_box($post)
    {
    }
    /**
     * Displays trackback links form fields.
     *
     * @since 2.6.0
     *
     * @param WP_Post $post Current post object.
     */
    function post_trackback_meta_box($post)
    {
    }
    /**
     * Displays custom fields form fields.
     *
     * @since 2.6.0
     *
     * @param WP_Post $post Current post object.
     */
    function post_custom_meta_box($post)
    {
    }
    /**
     * Displays comments status form fields.
     *
     * @since 2.6.0
     *
     * @param WP_Post $post Current post object.
     */
    function post_comment_status_meta_box($post)
    {
    }
    /**
     * Displays comments for post table header
     *
     * @since 3.0.0
     *
     * @param array $result Table header rows.
     * @return array
     */
    function post_comment_meta_box_thead($result)
    {
    }
    /**
     * Displays comments for post.
     *
     * @since 2.8.0
     *
     * @param WP_Post $post Current post object.
     */
    function post_comment_meta_box($post)
    {
    }
    /**
     * Displays slug form fields.
     *
     * @since 2.6.0
     *
     * @param WP_Post $post Current post object.
     */
    function post_slug_meta_box($post)
    {
    }
    /**
     * Displays form field with list of authors.
     *
     * @since 2.6.0
     *
     * @global int $user_ID
     *
     * @param WP_Post $post Current post object.
     */
    function post_author_meta_box($post)
    {
    }
    /**
     * Displays list of revisions.
     *
     * @since 2.6.0
     *
     * @param WP_Post $post Current post object.
     */
    function post_revisions_meta_box($post)
    {
    }
    /**
     * Displays page attributes form fields.
     *
     * @since 2.7.0
     *
     * @param WP_Post $post Current post object.
     */
    function page_attributes_meta_box($post)
    {
    }
    /**
     * Displays link create form fields.
     *
     * @since 2.7.0
     *
     * @param object $link Current link object.
     */
    function link_submit_meta_box($link)
    {
    }
    /**
     * Displays link categories form fields.
     *
     * @since 2.6.0
     *
     * @param object $link Current link object.
     */
    function link_categories_meta_box($link)
    {
    }
    /**
     * Displays form fields for changing link target.
     *
     * @since 2.6.0
     *
     * @param object $link Current link object.
     */
    function link_target_meta_box($link)
    {
    }
    /**
     * Displays 'checked' checkboxes attribute for XFN microformat options.
     *
     * @since 1.0.1
     *
     * @global object $link Current link object.
     *
     * @param string $xfn_relationship XFN relationship category. Possible values are:
     *                                 'friendship', 'physical', 'professional',
     *                                 'geographical', 'family', 'romantic', 'identity'.
     * @param string $xfn_value        Optional. The XFN value to mark as checked
     *                                 if it matches the current link's relationship.
     *                                 Default empty string.
     * @param mixed  $deprecated       Deprecated. Not used.
     */
    function xfn_check($xfn_relationship, $xfn_value = '', $deprecated = '')
    {
    }
    /**
     * Displays XFN form fields.
     *
     * @since 2.6.0
     *
     * @param object $link Current link object.
     */
    function link_xfn_meta_box($link)
    {
    }
    /**
     * Displays advanced link options form fields.
     *
     * @since 2.6.0
     *
     * @param object $link Current link object.
     */
    function link_advanced_meta_box($link)
    {
    }
    /**
     * Displays post thumbnail meta box.
     *
     * @since 2.9.0
     *
     * @param WP_Post $post Current post object.
     */
    function post_thumbnail_meta_box($post)
    {
    }
    /**
     * Displays fields for ID3 data.
     *
     * @since 3.9.0
     *
     * @param WP_Post $post Current post object.
     */
    function attachment_id3_data_meta_box($post)
    {
    }
    /**
     * Registers the default post meta boxes, and runs the `do_meta_boxes` actions.
     *
     * @since 5.0.0
     *
     * @param WP_Post $post The post object that these meta boxes are being generated for.
     */
    function register_and_do_post_meta_boxes($post)
    {
    }
    /**
     * Returns whether the server is running Apache with the mod_rewrite module loaded.
     *
     * @since 2.0.0
     *
     * @return bool Whether the server is running Apache with the mod_rewrite module loaded.
     */
    function got_mod_rewrite()
    {
    }
    /**
     * Returns whether the server supports URL rewriting.
     *
     * Detects Apache's mod_rewrite, IIS 7.0+ permalink support, and nginx.
     *
     * @since 3.7.0
     *
     * @global bool $is_nginx
     * @global bool $is_caddy
     *
     * @return bool Whether the server supports URL rewriting.
     */
    function got_url_rewrite()
    {
    }
    /**
     * Extracts strings from between the BEGIN and END markers in the .htaccess file.
     *
     * @since 1.5.0
     *
     * @param string $filename Filename to extract the strings from.
     * @param string $marker   The marker to extract the strings from.
     * @return string[] An array of strings from a file (.htaccess) from between BEGIN and END markers.
     */
    function extract_from_markers($filename, $marker)
    {
    }
    /**
     * Inserts an array of strings into a file (.htaccess), placing it between
     * BEGIN and END markers.
     *
     * Replaces existing marked info. Retains surrounding
     * data. Creates file if none exists.
     *
     * @since 1.5.0
     *
     * @param string       $filename  Filename to alter.
     * @param string       $marker    The marker to alter.
     * @param array|string $insertion The new content to insert.
     * @return bool True on write success, false on failure.
     */
    function insert_with_markers($filename, $marker, $insertion)
    {
    }
    /**
     * Updates the htaccess file with the current rules if it is writable.
     *
     * Always writes to the file if it exists and is writable to ensure that we
     * blank out old rules.
     *
     * @since 1.5.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @return bool|null True on write success, false on failure. Null in multisite.
     */
    function save_mod_rewrite_rules()
    {
    }
    /**
     * Updates the IIS web.config file with the current rules if it is writable.
     * If the permalinks do not require rewrite rules then the rules are deleted from the web.config file.
     *
     * @since 2.8.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @return bool|null True on write success, false on failure. Null in multisite.
     */
    function iis7_save_url_rewrite_rules()
    {
    }
    /**
     * Updates the "recently-edited" file for the plugin or theme file editor.
     *
     * @since 1.5.0
     *
     * @param string $file
     */
    function update_recently_edited($file)
    {
    }
    /**
     * Makes a tree structure for the theme file editor's file list.
     *
     * @since 4.9.0
     * @access private
     *
     * @param array $allowed_files List of theme file paths.
     * @return array Tree structure for listing theme files.
     */
    function wp_make_theme_file_tree($allowed_files)
    {
    }
    /**
     * Outputs the formatted file list for the theme file editor.
     *
     * @since 4.9.0
     * @access private
     *
     * @global string $relative_file Name of the file being edited relative to the
     *                               theme directory.
     * @global string $stylesheet    The stylesheet name of the theme being edited.
     *
     * @param array|string $tree  List of file/folder paths, or filename.
     * @param int          $level The aria-level for the current iteration.
     * @param int          $size  The aria-setsize for the current iteration.
     * @param int          $index The aria-posinset for the current iteration.
     */
    function wp_print_theme_file_tree($tree, $level = 2, $size = 1, $index = 1)
    {
    }
    /**
     * Makes a tree structure for the plugin file editor's file list.
     *
     * @since 4.9.0
     * @access private
     *
     * @param array $plugin_editable_files List of plugin file paths.
     * @return array Tree structure for listing plugin files.
     */
    function wp_make_plugin_file_tree($plugin_editable_files)
    {
    }
    /**
     * Outputs the formatted file list for the plugin file editor.
     *
     * @since 4.9.0
     * @access private
     *
     * @param array|string $tree  List of file/folder paths, or filename.
     * @param string       $label Name of file or folder to print.
     * @param int          $level The aria-level for the current iteration.
     * @param int          $size  The aria-setsize for the current iteration.
     * @param int          $index The aria-posinset for the current iteration.
     */
    function wp_print_plugin_file_tree($tree, $label = '', $level = 2, $size = 1, $index = 1)
    {
    }
    /**
     * Flushes rewrite rules if `siteurl`, `home` or `page_on_front` changed.
     *
     * @since 2.1.0
     *
     * @param string $old_value
     * @param string $value
     * @phpstan-return void
     */
    function update_home_siteurl($old_value, $value)
    {
    }
    /**
     * Resets global variables based on `$_GET` and `$_POST`.
     *
     * This function resets global variables based on the names passed
     * in the `$vars` array to the value of `$_POST[$var]` or `$_GET[$var]` or an
     * empty string if neither is defined.
     *
     * @since 2.0.0
     *
     * @param array $vars An array of globals to reset.
     */
    function wp_reset_vars($vars)
    {
    }
    /**
     * Displays the given administration message.
     *
     * @since 2.1.0
     *
     * @param string|WP_Error $message
     */
    function show_message($message)
    {
    }
    /**
     * @since 2.8.0
     *
     * @param string $content
     * @return array
     */
    function wp_doc_link_parse($content)
    {
    }
    /**
     * Saves option for number of rows when listing posts, pages, comments, etc.
     *
     * @since 2.8.0
     * @phpstan-return void
     */
    function set_screen_options()
    {
    }
    /**
     * Checks if rewrite rule for WordPress already exists in the IIS 7+ configuration file.
     *
     * @since 2.8.0
     *
     * @param string $filename The file path to the configuration file.
     * @return bool
     */
    function iis7_rewrite_rule_exists($filename)
    {
    }
    /**
     * Deletes WordPress rewrite rule from web.config file if it exists there.
     *
     * @since 2.8.0
     *
     * @param string $filename Name of the configuration file.
     * @return bool
     */
    function iis7_delete_rewrite_rule($filename)
    {
    }
    /**
     * Adds WordPress rewrite rule to the IIS 7+ configuration file.
     *
     * @since 2.8.0
     *
     * @param string $filename     The file path to the configuration file.
     * @param string $rewrite_rule The XML fragment with URL Rewrite rule.
     * @return bool
     */
    function iis7_add_rewrite_rule($filename, $rewrite_rule)
    {
    }
    /**
     * Saves the XML document into a file.
     *
     * @since 2.8.0
     *
     * @param DOMDocument $doc
     * @param string      $filename
     */
    function saveDomDocument($doc, $filename)
    {
    }
    /**
     * Displays the default admin color scheme picker (Used in user-edit.php).
     *
     * @since 3.0.0
     *
     * @global array $_wp_admin_css_colors
     *
     * @param int $user_id User ID.
     */
    function admin_color_scheme_picker($user_id)
    {
    }
    /**
     *
     * @global array $_wp_admin_css_colors
     */
    function wp_color_scheme_settings()
    {
    }
    /**
     * Displays the viewport meta in the admin.
     *
     * @since 5.5.0
     * @phpstan-return void
     */
    function wp_admin_viewport_meta()
    {
    }
    /**
     * Adds viewport meta for mobile in Customizer.
     *
     * Hooked to the {@see 'admin_viewport_meta'} filter.
     *
     * @since 5.5.0
     *
     * @param string $viewport_meta The viewport meta.
     * @return string Filtered viewport meta.
     */
    function _customizer_mobile_viewport_meta($viewport_meta)
    {
    }
    /**
     * Checks lock status for posts displayed on the Posts screen.
     *
     * @since 3.6.0
     *
     * @param array  $response  The Heartbeat response.
     * @param array  $data      The $_POST data sent.
     * @param string $screen_id The screen ID.
     * @return array The Heartbeat response.
     */
    function wp_check_locked_posts($response, $data, $screen_id)
    {
    }
    /**
     * Checks lock status on the New/Edit Post screen and refresh the lock.
     *
     * @since 3.6.0
     *
     * @param array  $response  The Heartbeat response.
     * @param array  $data      The $_POST data sent.
     * @param string $screen_id The screen ID.
     * @return array The Heartbeat response.
     */
    function wp_refresh_post_lock($response, $data, $screen_id)
    {
    }
    /**
     * Checks nonce expiration on the New/Edit Post screen and refresh if needed.
     *
     * @since 3.6.0
     *
     * @param array  $response  The Heartbeat response.
     * @param array  $data      The $_POST data sent.
     * @param string $screen_id The screen ID.
     * @return array The Heartbeat response.
     */
    function wp_refresh_post_nonces($response, $data, $screen_id)
    {
    }
    /**
     * Refresh nonces used with meta boxes in the block editor.
     *
     * @since 6.1.0
     *
     * @param array  $response  The Heartbeat response.
     * @param array  $data      The $_POST data sent.
     * @return array The Heartbeat response.
     */
    function wp_refresh_metabox_loader_nonces($response, $data)
    {
    }
    /**
     * Adds the latest Heartbeat and REST API nonce to the Heartbeat response.
     *
     * @since 5.0.0
     *
     * @param array $response The Heartbeat response.
     * @return array The Heartbeat response.
     */
    function wp_refresh_heartbeat_nonces($response)
    {
    }
    /**
     * Disables suspension of Heartbeat on the Add/Edit Post screens.
     *
     * @since 3.8.0
     *
     * @global string $pagenow The filename of the current screen.
     *
     * @param array $settings An array of Heartbeat settings.
     * @return array Filtered Heartbeat settings.
     */
    function wp_heartbeat_set_suspension($settings)
    {
    }
    /**
     * Performs autosave with heartbeat.
     *
     * @since 3.9.0
     *
     * @param array $response The Heartbeat response.
     * @param array $data     The $_POST data sent.
     * @return array The Heartbeat response.
     */
    function heartbeat_autosave($response, $data)
    {
    }
    /**
     * Removes single-use URL parameters and create canonical link based on new URL.
     *
     * Removes specific query string parameters from a URL, create the canonical link,
     * put it in the admin header, and change the current URL to match.
     *
     * @since 4.2.0
     * @phpstan-return void
     */
    function wp_admin_canonical_url()
    {
    }
    /**
     * Sends a referrer policy header so referrers are not sent externally from administration screens.
     *
     * @since 4.9.0
     */
    function wp_admin_headers()
    {
    }
    /**
     * Outputs JS that reloads the page if the user navigated to it with the Back or Forward button.
     *
     * Used on the Edit Post and Add New Post screens. Needed to ensure the page is not loaded from browser cache,
     * so the post title and editor content are the last saved versions. Ideally this script should run first in the head.
     *
     * @since 4.6.0
     */
    function wp_page_reload_on_back_button_js()
    {
    }
    /**
     * Sends a confirmation request email when a change of site admin email address is attempted.
     *
     * The new site admin address will not become active until confirmed.
     *
     * @since 3.0.0
     * @since 4.9.0 This function was moved from wp-admin/includes/ms.php so it's no longer Multisite specific.
     *
     * @param string $old_value The old site admin email address.
     * @param string $value     The proposed new site admin email address.
     * @phpstan-return void
     */
    function update_option_new_admin_email($old_value, $value)
    {
    }
    /**
     * Appends '(Draft)' to draft page titles in the privacy page dropdown
     * so that unpublished content is obvious.
     *
     * @since 4.9.8
     * @access private
     *
     * @param string  $title Page title.
     * @param WP_Post $page  Page data object.
     * @return string Page title.
     */
    function _wp_privacy_settings_filter_draft_page_titles($title, $page)
    {
    }
    /**
     * Checks if the user needs to update PHP.
     *
     * @since 5.1.0
     * @since 5.1.1 Added the {@see 'wp_is_php_version_acceptable'} filter.
     *
     * @return array|false {
     *     Array of PHP version data. False on failure.
     *
     *     @type string $recommended_version The PHP version recommended by WordPress.
     *     @type string $minimum_version     The minimum required PHP version.
     *     @type bool   $is_supported        Whether the PHP version is actively supported.
     *     @type bool   $is_secure           Whether the PHP version receives security updates.
     *     @type bool   $is_acceptable       Whether the PHP version is still acceptable or warnings
     *                                       should be shown and an update recommended.
     * }
     * @phpstan-return false|array{
     *   recommended_version: string,
     *   minimum_version: string,
     *   is_supported: bool,
     *   is_secure: bool,
     *   is_acceptable: bool,
     * }
     */
    function wp_check_php_version()
    {
    }
    /**
     * Outputs the WPMU menu.
     *
     * @deprecated 3.0.0
     */
    function wpmu_menu()
    {
    }
    /**
     * Determines if the available space defined by the admin has been exceeded by the user.
     *
     * @deprecated 3.0.0 Use is_upload_space_available()
     * @see is_upload_space_available()
     */
    function wpmu_checkAvailableSpace()
    {
    }
    /**
     * WPMU options.
     *
     * @deprecated 3.0.0
     */
    function mu_options($options)
    {
    }
    /**
     * Deprecated functionality for activating a network-only plugin.
     *
     * @deprecated 3.0.0 Use activate_plugin()
     * @see activate_plugin()
     */
    function activate_sitewide_plugin()
    {
    }
    /**
     * Deprecated functionality for deactivating a network-only plugin.
     *
     * @deprecated 3.0.0 Use deactivate_plugin()
     * @see deactivate_plugin()
     */
    function deactivate_sitewide_plugin($plugin = \false)
    {
    }
    /**
     * Deprecated functionality for determining if the current plugin is network-only.
     *
     * @deprecated 3.0.0 Use is_network_only_plugin()
     * @see is_network_only_plugin()
     */
    function is_wpmu_sitewide_plugin($file)
    {
    }
    /**
     * Deprecated functionality for getting themes network-enabled themes.
     *
     * @deprecated 3.4.0 Use WP_Theme::get_allowed_on_network()
     * @see WP_Theme::get_allowed_on_network()
     */
    function get_site_allowed_themes()
    {
    }
    /**
     * Deprecated functionality for getting themes allowed on a specific site.
     *
     * @deprecated 3.4.0 Use WP_Theme::get_allowed_on_site()
     * @see WP_Theme::get_allowed_on_site()
     */
    function wpmu_get_blog_allowedthemes($blog_id = 0)
    {
    }
    /**
     * Deprecated functionality for determining whether a file is deprecated.
     *
     * @deprecated 3.5.0
     */
    function ms_deprecated_blogs_file()
    {
    }
    /**
     * Install global terms.
     *
     * @since 3.0.0
     * @since 6.1.0 This function no longer does anything.
     * @deprecated 6.1.0
     */
    function install_global_terms()
    {
    }
    /**
     * Synchronizes category and post tag slugs when global terms are enabled.
     *
     * @since 3.0.0
     * @since 6.1.0 This function no longer does anything.
     * @deprecated 6.1.0
     *
     * @param WP_Term|array $term     The term.
     * @param string        $taxonomy The taxonomy for `$term`.
     * @return WP_Term|array Always returns `$term`.
     */
    function sync_category_tag_slugs($term, $taxonomy)
    {
    }
    /**
     * Determines whether uploaded file exceeds space quota.
     *
     * @since 3.0.0
     *
     * @param array $file An element from the `$_FILES` array for a given file.
     * @return array The `$_FILES` array element with 'error' key set if file exceeds quota. 'error' is empty otherwise.
     */
    function check_upload_size($file)
    {
    }
    /**
     * Deletes a site.
     *
     * @since 3.0.0
     * @since 5.1.0 Use wp_delete_site() internally to delete the site row from the database.
     *
     * @param int  $blog_id Site ID.
     * @param bool $drop    True if site's database tables should be dropped. Default false.
     */
    function wpmu_delete_blog($blog_id, $drop = \false)
    {
    }
    /**
     * Deletes a user and all of their posts from the network.
     *
     * This function:
     *
     * - Deletes all posts (of all post types) authored by the user on all sites on the network
     * - Deletes all links owned by the user on all sites on the network
     * - Removes the user from all sites on the network
     * - Deletes the user from the database
     *
     * @since 3.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $id The user ID.
     * @return bool True if the user was deleted, false otherwise.
     */
    function wpmu_delete_user($id)
    {
    }
    /**
     * Checks whether a site has used its allotted upload space.
     *
     * @since MU (3.0.0)
     *
     * @param bool $display_message Optional. If set to true and the quota is exceeded,
     *                              a warning message is displayed. Default true.
     * @return bool True if user is over upload space quota, otherwise false.
     */
    function upload_is_user_over_quota($display_message = \true)
    {
    }
    /**
     * Displays the amount of disk space used by the current site. Not used in core.
     *
     * @since MU (3.0.0)
     */
    function display_space_usage()
    {
    }
    /**
     * Gets the remaining upload space for this site.
     *
     * @since MU (3.0.0)
     *
     * @param int $size Current max size in bytes.
     * @return int Max size in bytes.
     */
    function fix_import_form_size($size)
    {
    }
    /**
     * Displays the site upload space quota setting form on the Edit Site Settings screen.
     *
     * @since 3.0.0
     *
     * @param int $id The ID of the site to display the setting for.
     */
    function upload_space_setting($id)
    {
    }
    /**
     * Cleans the user cache for a specific user.
     *
     * @since 3.0.0
     *
     * @param int $id The user ID.
     * @return int|false The ID of the refreshed user or false if the user does not exist.
     */
    function refresh_user_details($id)
    {
    }
    /**
     * Returns the language for a language code.
     *
     * @since 3.0.0
     *
     * @param string $code Optional. The two-letter language code. Default empty.
     * @return string The language corresponding to $code if it exists. If it does not exist,
     *                then the first two letters of $code is returned.
     */
    function format_code_lang($code = '')
    {
    }
    /**
     * Displays an access denied message when a user tries to view a site's dashboard they
     * do not have access to.
     *
     * @since 3.2.0
     * @access private
     * @phpstan-return void
     */
    function _access_denied_splash()
    {
    }
    /**
     * Checks if the current user has permissions to import new users.
     *
     * @since 3.0.0
     *
     * @param string $permission A permission to be checked. Currently not used.
     * @return bool True if the user has proper permissions, false if they do not.
     */
    function check_import_new_users($permission)
    {
    }
    /**
     * Generates and displays a drop-down of available languages.
     *
     * @since 3.0.0
     *
     * @param string[] $lang_files Optional. An array of the language files. Default empty array.
     * @param string   $current    Optional. The current language code. Default empty.
     */
    function mu_dropdown_languages($lang_files = array(), $current = '')
    {
    }
    /**
     * Displays an admin notice to upgrade all sites after a core upgrade.
     *
     * @since 3.0.0
     *
     * @global int    $wp_db_version WordPress database version.
     * @global string $pagenow       The filename of the current screen.
     *
     * @return void|false Void on success. False if the current user is not a super admin.
     */
    function site_admin_notice()
    {
    }
    /**
     * Avoids a collision between a site slug and a permalink slug.
     *
     * In a subdirectory installation this will make sure that a site and a post do not use the
     * same subdirectory by checking for a site with the same name as a new post.
     *
     * @since 3.0.0
     *
     * @param array $data    An array of post data.
     * @param array $postarr An array of posts. Not currently used.
     * @return array The new array of post data after checking for collisions.
     */
    function avoid_blog_page_permalink_collision($data, $postarr)
    {
    }
    /**
     * Handles the display of choosing a user's primary site.
     *
     * This displays the user's primary site and allows the user to choose
     * which site is primary.
     *
     * @since 3.0.0
     */
    function choose_primary_blog()
    {
    }
    /**
     * Determines whether or not this network from this page can be edited.
     *
     * By default editing of network is restricted to the Network Admin for that `$network_id`.
     * This function allows for this to be overridden.
     *
     * @since 3.1.0
     *
     * @param int $network_id The network ID to check.
     * @return bool True if network can be edited, false otherwise.
     */
    function can_edit_network($network_id)
    {
    }
    /**
     * Prints thickbox image paths for Network Admin.
     *
     * @since 3.1.0
     *
     * @access private
     */
    function _thickbox_path_admin_subfolder()
    {
    }
    /**
     * @param array $users
     * @return bool
     */
    function confirm_delete_users($users)
    {
    }
    /**
     * Prints JavaScript in the header on the Network Settings screen.
     *
     * @since 4.1.0
     */
    function network_settings_add_js()
    {
    }
    /**
     * Outputs the HTML for a network's "Edit Site" tabular interface.
     *
     * @since 4.6.0
     *
     * @global string $pagenow The filename of the current screen.
     *
     * @param array $args {
     *     Optional. Array or string of Query parameters. Default empty array.
     *
     *     @type int    $blog_id  The site ID. Default is the current site.
     *     @type array  $links    The tabs to include with (label|url|cap) keys.
     *     @type string $selected The ID of the selected link.
     * }
     * @phpstan-param array{
     *   blog_id?: int,
     *   links?: array,
     *   selected?: string,
     * } $args
     */
    function network_edit_site_nav($args = array())
    {
    }
    /**
     * Returns the arguments for the help tab on the Edit Site screens.
     *
     * @since 4.9.0
     *
     * @return array Help tab arguments.
     */
    function get_site_screen_help_tab_args()
    {
    }
    /**
     * Returns the content for the help sidebar on the Edit Site screens.
     *
     * @since 4.9.0
     *
     * @return string Help sidebar content.
     */
    function get_site_screen_help_sidebar_content()
    {
    }
    /**
     * Prints the appropriate response to a menu quick search.
     *
     * @since 3.0.0
     *
     * @param array $request The unsanitized request values.
     * @phpstan-return void
     */
    function _wp_ajax_menu_quick_search($request = array())
    {
    }
    /**
     * Register nav menu meta boxes and advanced menu items.
     *
     * @since 3.0.0
     */
    function wp_nav_menu_setup()
    {
    }
    /**
     * Limit the amount of meta boxes to pages, posts, links, and categories for first time users.
     *
     * @since 3.0.0
     *
     * @global array $wp_meta_boxes Global meta box state.
     * @phpstan-return void
     */
    function wp_initial_nav_menu_meta_boxes()
    {
    }
    /**
     * Creates meta boxes for any post type menu item..
     *
     * @since 3.0.0
     * @phpstan-return void
     */
    function wp_nav_menu_post_type_meta_boxes()
    {
    }
    /**
     * Creates meta boxes for any taxonomy menu item.
     *
     * @since 3.0.0
     * @phpstan-return void
     */
    function wp_nav_menu_taxonomy_meta_boxes()
    {
    }
    /**
     * Check whether to disable the Menu Locations meta box submit button and inputs.
     *
     * @since 3.6.0
     * @since 5.3.1 The `$display` parameter was added.
     *
     * @global bool $one_theme_location_no_menus to determine if no menus exist
     *
     * @param int|string $nav_menu_selected_id ID, name, or slug of the currently selected menu.
     * @param bool       $display              Whether to display or just return the string.
     * @return string|false Disabled attribute if at least one menu exists, false if not.
     */
    function wp_nav_menu_disabled_check($nav_menu_selected_id, $display = \true)
    {
    }
    /**
     * Displays a meta box for the custom links menu item.
     *
     * @since 3.0.0
     *
     * @global int        $_nav_menu_placeholder
     * @global int|string $nav_menu_selected_id
     */
    function wp_nav_menu_item_link_meta_box()
    {
    }
    /**
     * Displays a meta box for a post type menu item.
     *
     * @since 3.0.0
     *
     * @global int        $_nav_menu_placeholder
     * @global int|string $nav_menu_selected_id
     *
     * @param string $data_object Not used.
     * @param array  $box {
     *     Post type menu item meta box arguments.
     *
     *     @type string       $id       Meta box 'id' attribute.
     *     @type string       $title    Meta box title.
     *     @type callable     $callback Meta box display callback.
     *     @type WP_Post_Type $args     Extra meta box arguments (the post type object for this meta box).
     * }
     * @phpstan-param array{
     *   id?: string,
     *   title?: string,
     *   callback?: callable,
     *   args?: WP_Post_Type,
     * } $box
     * @phpstan-return void
     */
    function wp_nav_menu_item_post_type_meta_box($data_object, $box)
    {
    }
    /**
     * Displays a meta box for a taxonomy menu item.
     *
     * @since 3.0.0
     *
     * @global int|string $nav_menu_selected_id
     *
     * @param string $data_object Not used.
     * @param array  $box {
     *     Taxonomy menu item meta box arguments.
     *
     *     @type string   $id       Meta box 'id' attribute.
     *     @type string   $title    Meta box title.
     *     @type callable $callback Meta box display callback.
     *     @type object   $args     Extra meta box arguments (the taxonomy object for this meta box).
     * }
     * @phpstan-param array{
     *   id?: string,
     *   title?: string,
     *   callback?: callable,
     *   args?: object,
     * } $box
     * @phpstan-return void
     */
    function wp_nav_menu_item_taxonomy_meta_box($data_object, $box)
    {
    }
    /**
     * Save posted nav menu item data.
     *
     * @since 3.0.0
     *
     * @param int     $menu_id   The menu ID for which to save this item. Value of 0 makes a draft, orphaned menu item. Default 0.
     * @param array[] $menu_data The unsanitized POSTed menu item data.
     * @return int[] The database IDs of the items saved
     */
    function wp_save_nav_menu_items($menu_id = 0, $menu_data = array())
    {
    }
    /**
     * Adds custom arguments to some of the meta box object types.
     *
     * @since 3.0.0
     *
     * @access private
     *
     * @param object $data_object The post type or taxonomy meta-object.
     * @return object The post type or taxonomy object.
     */
    function _wp_nav_menu_meta_box_object($data_object = \null)
    {
    }
    /**
     * Returns the menu formatted to edit.
     *
     * @since 3.0.0
     *
     * @param int $menu_id Optional. The ID of the menu to format. Default 0.
     * @return string|WP_Error The menu formatted to edit or error object on failure.
     */
    function wp_get_nav_menu_to_edit($menu_id = 0)
    {
    }
    /**
     * Returns the columns for the nav menus page.
     *
     * @since 3.0.0
     *
     * @return string[] Array of column titles keyed by their column name.
     */
    function wp_nav_menu_manage_columns()
    {
    }
    /**
     * Deletes orphaned draft menu items
     *
     * @access private
     * @since 3.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function _wp_delete_orphaned_draft_menu_items()
    {
    }
    /**
     * Saves nav menu items.
     *
     * @since 3.6.0
     *
     * @param int|string $nav_menu_selected_id    ID, slug, or name of the currently-selected menu.
     * @param string     $nav_menu_selected_title Title of the currently-selected menu.
     * @return string[] The menu updated messages.
     */
    function wp_nav_menu_update_menu_items($nav_menu_selected_id, $nav_menu_selected_title)
    {
    }
    /**
     * If a JSON blob of navigation menu data is in POST data, expand it and inject
     * it into `$_POST` to avoid PHP `max_input_vars` limitations. See #14134.
     *
     * @ignore
     * @since 4.5.3
     * @access private
     * @phpstan-return void
     */
    function _wp_expand_nav_menu_post_data()
    {
    }
    /**
     * Check for an existing network.
     *
     * @since 3.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return string|false Base domain if network exists, otherwise false.
     */
    function network_domain_check()
    {
    }
    /**
     * Allow subdomain installation
     *
     * @since 3.0.0
     * @return bool Whether subdomain installation is allowed
     */
    function allow_subdomain_install()
    {
    }
    /**
     * Allow subdirectory installation.
     *
     * @since 3.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return bool Whether subdirectory installation is allowed
     */
    function allow_subdirectory_install()
    {
    }
    /**
     * Get base domain of network.
     *
     * @since 3.0.0
     * @return string Base domain.
     */
    function get_clean_basedomain()
    {
    }
    /**
     * Prints step 1 for Network installation process.
     *
     * @todo Realistically, step 1 should be a welcome screen explaining what a Network is and such.
     *       Navigating to Tools > Network should not be a sudden "Welcome to a new install process!
     *       Fill this out and click here." See also contextual help todo.
     *
     * @since 3.0.0
     *
     * @global bool $is_apache
     *
     * @param false|WP_Error $errors Optional. Error object. Default false.
     */
    function network_step1($errors = \false)
    {
    }
    /**
     * Prints step 2 for Network installation process.
     *
     * @since 3.0.0
     *
     * @global wpdb $wpdb     WordPress database abstraction object.
     * @global bool $is_nginx Whether the server software is Nginx or something else.
     *
     * @param false|WP_Error $errors Optional. Error object. Default false.
     */
    function network_step2($errors = \false)
    {
    }
    /**
     * Output JavaScript to toggle display of additional settings if avatars are disabled.
     *
     * @since 4.2.0
     */
    function options_discussion_add_js()
    {
    }
    /**
     * Display JavaScript on the page.
     *
     * @since 3.5.0
     */
    function options_general_add_js()
    {
    }
    /**
     * Display JavaScript on the page.
     *
     * @since 3.5.0
     */
    function options_reading_add_js()
    {
    }
    /**
     * Render the site charset setting.
     *
     * @since 3.5.0
     */
    function options_reading_blog_charset()
    {
    }
    /**
     * Retrieves plugin installer pages from the WordPress.org Plugins API.
     *
     * It is possible for a plugin to override the Plugin API result with three
     * filters. Assume this is for plugins, which can extend on the Plugin Info to
     * offer more choices. This is very powerful and must be used with care when
     * overriding the filters.
     *
     * The first filter, {@see 'plugins_api_args'}, is for the args and gives the action
     * as the second parameter. The hook for {@see 'plugins_api_args'} must ensure that
     * an object is returned.
     *
     * The second filter, {@see 'plugins_api'}, allows a plugin to override the WordPress.org
     * Plugin Installation API entirely. If `$action` is 'query_plugins' or 'plugin_information',
     * an object MUST be passed. If `$action` is 'hot_tags', an array MUST be passed.
     *
     * Finally, the third filter, {@see 'plugins_api_result'}, makes it possible to filter the
     * response object or array, depending on the `$action` type.
     *
     * Supported arguments per action:
     *
     * | Argument Name        | query_plugins | plugin_information | hot_tags |
     * | -------------------- | :-----------: | :----------------: | :------: |
     * | `$slug`              | No            |  Yes               | No       |
     * | `$per_page`          | Yes           |  No                | No       |
     * | `$page`              | Yes           |  No                | No       |
     * | `$number`            | No            |  No                | Yes      |
     * | `$search`            | Yes           |  No                | No       |
     * | `$tag`               | Yes           |  No                | No       |
     * | `$author`            | Yes           |  No                | No       |
     * | `$user`              | Yes           |  No                | No       |
     * | `$browse`            | Yes           |  No                | No       |
     * | `$locale`            | Yes           |  Yes               | No       |
     * | `$installed_plugins` | Yes           |  No                | No       |
     * | `$is_ssl`            | Yes           |  Yes               | No       |
     * | `$fields`            | Yes           |  Yes               | No       |
     *
     * @since 2.7.0
     *
     * @param string       $action API action to perform: 'query_plugins', 'plugin_information',
     *                             or 'hot_tags'.
     * @param array|object $args   {
     *     Optional. Array or object of arguments to serialize for the Plugin Info API.
     *
     *     @type string  $slug              The plugin slug. Default empty.
     *     @type int     $per_page          Number of plugins per page. Default 24.
     *     @type int     $page              Number of current page. Default 1.
     *     @type int     $number            Number of tags or categories to be queried.
     *     @type string  $search            A search term. Default empty.
     *     @type string  $tag               Tag to filter plugins. Default empty.
     *     @type string  $author            Username of an plugin author to filter plugins. Default empty.
     *     @type string  $user              Username to query for their favorites. Default empty.
     *     @type string  $browse            Browse view: 'popular', 'new', 'beta', 'recommended'.
     *     @type string  $locale            Locale to provide context-sensitive results. Default is the value
     *                                      of get_locale().
     *     @type string  $installed_plugins Installed plugins to provide context-sensitive results.
     *     @type bool    $is_ssl            Whether links should be returned with https or not. Default false.
     *     @type array   $fields            {
     *         Array of fields which should or should not be returned.
     *
     *         @type bool $short_description Whether to return the plugin short description. Default true.
     *         @type bool $description       Whether to return the plugin full description. Default false.
     *         @type bool $sections          Whether to return the plugin readme sections: description, installation,
     *                                       FAQ, screenshots, other notes, and changelog. Default false.
     *         @type bool $tested            Whether to return the 'Compatible up to' value. Default true.
     *         @type bool $requires          Whether to return the required WordPress version. Default true.
     *         @type bool $requires_php      Whether to return the required PHP version. Default true.
     *         @type bool $rating            Whether to return the rating in percent and total number of ratings.
     *                                       Default true.
     *         @type bool $ratings           Whether to return the number of rating for each star (1-5). Default true.
     *         @type bool $downloaded        Whether to return the download count. Default true.
     *         @type bool $downloadlink      Whether to return the download link for the package. Default true.
     *         @type bool $last_updated      Whether to return the date of the last update. Default true.
     *         @type bool $added             Whether to return the date when the plugin was added to the wordpress.org
     *                                       repository. Default true.
     *         @type bool $tags              Whether to return the assigned tags. Default true.
     *         @type bool $compatibility     Whether to return the WordPress compatibility list. Default true.
     *         @type bool $homepage          Whether to return the plugin homepage link. Default true.
     *         @type bool $versions          Whether to return the list of all available versions. Default false.
     *         @type bool $donate_link       Whether to return the donation link. Default true.
     *         @type bool $reviews           Whether to return the plugin reviews. Default false.
     *         @type bool $banners           Whether to return the banner images links. Default false.
     *         @type bool $icons             Whether to return the icon links. Default false.
     *         @type bool $active_installs   Whether to return the number of active installations. Default false.
     *         @type bool $contributors      Whether to return the list of contributors. Default false.
     *     }
     * }
     * @return object|array|WP_Error Response object or array on success, WP_Error on failure. See the
     *         {@link https://developer.wordpress.org/reference/functions/plugins_api/ function reference article}
     *         for more information on the make-up of possible return values depending on the value of `$action`.
     * @phpstan-param 'query_plugins'|'plugin_information'|'hot_tags' $action
     * @phpstan-param object|array{
     *   slug?: string,
     *   per_page?: int,
     *   page?: int,
     *   number?: int,
     *   search?: string,
     *   tag?: string,
     *   author?: string,
     *   user?: string,
     *   browse?: string,
     *   locale?: string,
     *   installed_plugins?: string,
     *   is_ssl?: bool,
     *   fields?: array{
     *     short_description?: bool,
     *     description?: bool,
     *     sections?: bool,
     *     tested?: bool,
     *     requires?: bool,
     *     requires_php?: bool,
     *     rating?: bool,
     *     ratings?: bool,
     *     downloaded?: bool,
     *     downloadlink?: bool,
     *     last_updated?: bool,
     *     added?: bool,
     *     tags?: bool,
     *     compatibility?: bool,
     *     homepage?: bool,
     *     versions?: bool,
     *     donate_link?: bool,
     *     reviews?: bool,
     *     banners?: bool,
     *     icons?: bool,
     *     active_installs?: bool,
     *     contributors?: bool,
     *   },
     * } $args
     */
    function plugins_api($action, $args = array())
    {
    }
    /**
     * Retrieves popular WordPress plugin tags.
     *
     * @since 2.7.0
     *
     * @param array $args
     * @return array|WP_Error
     */
    function install_popular_tags($args = array())
    {
    }
    /**
     * Displays the Featured tab of Add Plugins screen.
     *
     * @since 2.7.0
     */
    function install_dashboard()
    {
    }
    /**
     * Displays a search form for searching plugins.
     *
     * @since 2.7.0
     * @since 4.6.0 The `$type_selector` parameter was deprecated.
     *
     * @param bool $deprecated Not used.
     */
    function install_search_form($deprecated = \true)
    {
    }
    /**
     * Displays a form to upload plugins from zip files.
     *
     * @since 2.8.0
     */
    function install_plugins_upload()
    {
    }
    /**
     * Shows a username form for the favorites page.
     *
     * @since 3.5.0
     */
    function install_plugins_favorites_form()
    {
    }
    /**
     * Displays plugin content based on plugin list.
     *
     * @since 2.7.0
     *
     * @global WP_List_Table $wp_list_table
     * @phpstan-return void
     */
    function display_plugins_table()
    {
    }
    /**
     * Determines the status we can perform on a plugin.
     *
     * @since 3.0.0
     *
     * @param array|object $api  Data about the plugin retrieved from the API.
     * @param bool         $loop Optional. Disable further loops. Default false.
     * @return array {
     *     Plugin installation status data.
     *
     *     @type string $status  Status of a plugin. Could be one of 'install', 'update_available', 'latest_installed' or 'newer_installed'.
     *     @type string $url     Plugin installation URL.
     *     @type string $version The most recent version of the plugin.
     *     @type string $file    Plugin filename relative to the plugins directory.
     * }
     * @phpstan-return array{
     *   status: string,
     *   url: string,
     *   version: string,
     *   file: string,
     * }
     */
    function install_plugin_install_status($api, $loop = \false)
    {
    }
    /**
     * Displays plugin information in dialog box form.
     *
     * @since 2.7.0
     *
     * @global string $tab
     * @phpstan-return void
     */
    function install_plugin_information()
    {
    }
    /**
     * Gets the markup for the plugin install action button.
     *
     * @since 6.5.0
     *
     * @param string       $name           Plugin name.
     * @param array|object $data           {
     *     An array or object of plugin data. Can be retrieved from the API.
     *
     *     @type string   $slug             The plugin slug.
     *     @type string[] $requires_plugins An array of plugin dependency slugs.
     *     @type string   $version          The plugin's version string. Used when getting the install status.
     * }
     * @param bool         $compatible_php   The result of a PHP compatibility check.
     * @param bool         $compatible_wp    The result of a WP compatibility check.
     * @return string The markup for the dependency row button. An empty string if the user does not have capabilities.
     * @phpstan-param object|array{
     *   slug?: string,
     *   requires_plugins?: string[],
     *   version?: string,
     * } $data
     */
    function wp_get_plugin_action_button($name, $data, $compatible_php, $compatible_wp)
    {
    }
    /**
     * Parses the plugin contents to retrieve plugin's metadata.
     *
     * All plugin headers must be on their own line. Plugin description must not have
     * any newlines, otherwise only parts of the description will be displayed.
     * The below is formatted for printing.
     *
     *     /*
     *     Plugin Name: Name of the plugin.
     *     Plugin URI: The home page of the plugin.
     *     Description: Plugin description.
     *     Author: Plugin author's name.
     *     Author URI: Link to the author's website.
     *     Version: Plugin version.
     *     Text Domain: Optional. Unique identifier, should be same as the one used in
     *          load_plugin_textdomain().
     *     Domain Path: Optional. Only useful if the translations are located in a
     *          folder above the plugin's base path. For example, if .mo files are
     *          located in the locale folder then Domain Path will be "/locale/" and
     *          must have the first slash. Defaults to the base folder the plugin is
     *          located in.
     *     Network: Optional. Specify "Network: true" to require that a plugin is activated
     *          across all sites in an installation. This will prevent a plugin from being
     *          activated on a single site when Multisite is enabled.
     *     Requires at least: Optional. Specify the minimum required WordPress version.
     *     Requires PHP: Optional. Specify the minimum required PHP version.
     *     * / # Remove the space to close comment.
     *
     * The first 8 KB of the file will be pulled in and if the plugin data is not
     * within that first 8 KB, then the plugin author should correct their plugin
     * and move the plugin data headers to the top.
     *
     * The plugin file is assumed to have permissions to allow for scripts to read
     * the file. This is not checked however and the file is only opened for
     * reading.
     *
     * @since 1.5.0
     * @since 5.3.0 Added support for `Requires at least` and `Requires PHP` headers.
     * @since 5.8.0 Added support for `Update URI` header.
     * @since 6.5.0 Added support for `Requires Plugins` header.
     *
     * @param string $plugin_file Absolute path to the main plugin file.
     * @param bool   $markup      Optional. If the returned data should have HTML markup applied.
     *                            Default true.
     * @param bool   $translate   Optional. If the returned data should be translated. Default true.
     * @return array {
     *     Plugin data. Values will be empty if not supplied by the plugin.
     *
     *     @type string $Name            Name of the plugin. Should be unique.
     *     @type string $PluginURI       Plugin URI.
     *     @type string $Version         Plugin version.
     *     @type string $Description     Plugin description.
     *     @type string $Author          Plugin author's name.
     *     @type string $AuthorURI       Plugin author's website address (if set).
     *     @type string $TextDomain      Plugin textdomain.
     *     @type string $DomainPath      Plugin's relative directory path to .mo files.
     *     @type bool   $Network         Whether the plugin can only be activated network-wide.
     *     @type string $RequiresWP      Minimum required version of WordPress.
     *     @type string $RequiresPHP     Minimum required version of PHP.
     *     @type string $UpdateURI       ID of the plugin for update purposes, should be a URI.
     *     @type string $RequiresPlugins Comma separated list of dot org plugin slugs.
     *     @type string $Title           Title of the plugin and link to the plugin's site (if set).
     *     @type string $AuthorName      Plugin author's name.
     * }
     * @phpstan-return array{
     *   Name: string,
     *   PluginURI: string,
     *   Version: string,
     *   Description: string,
     *   Author: string,
     *   AuthorURI: string,
     *   TextDomain: string,
     *   DomainPath: string,
     *   Network: bool,
     *   RequiresWP: string,
     *   RequiresPHP: string,
     *   UpdateURI: string,
     *   RequiresPlugins: string,
     *   Title: string,
     *   AuthorName: string,
     * }
     */
    function get_plugin_data($plugin_file, $markup = \true, $translate = \true)
    {
    }
    /**
     * Sanitizes plugin data, optionally adds markup, optionally translates.
     *
     * @since 2.7.0
     *
     * @see get_plugin_data()
     *
     * @access private
     *
     * @param string $plugin_file Path to the main plugin file.
     * @param array  $plugin_data An array of plugin data. See get_plugin_data().
     * @param bool   $markup      Optional. If the returned data should have HTML markup applied.
     *                            Default true.
     * @param bool   $translate   Optional. If the returned data should be translated. Default true.
     * @return array Plugin data. Values will be empty if not supplied by the plugin.
     *               See get_plugin_data() for the list of possible values.
     */
    function _get_plugin_data_markup_translate($plugin_file, $plugin_data, $markup = \true, $translate = \true)
    {
    }
    /**
     * Gets a list of a plugin's files.
     *
     * @since 2.8.0
     *
     * @param string $plugin Path to the plugin file relative to the plugins directory.
     * @return string[] Array of file names relative to the plugin root.
     */
    function get_plugin_files($plugin)
    {
    }
    /**
     * Checks the plugins directory and retrieve all plugin files with plugin data.
     *
     * WordPress only supports plugin files in the base plugins directory
     * (wp-content/plugins) and in one directory above the plugins directory
     * (wp-content/plugins/my-plugin). The file it looks for has the plugin data
     * and must be found in those two locations. It is recommended to keep your
     * plugin files in their own directories.
     *
     * The file with the plugin data is the file that will be included and therefore
     * needs to have the main execution for the plugin. This does not mean
     * everything must be contained in the file and it is recommended that the file
     * be split for maintainability. Keep everything in one file for extreme
     * optimization purposes.
     *
     * @since 1.5.0
     *
     * @param string $plugin_folder Optional. Relative path to single plugin folder.
     * @return array[] Array of arrays of plugin data, keyed by plugin file name. See get_plugin_data().
     */
    function get_plugins($plugin_folder = '')
    {
    }
    /**
     * Checks the mu-plugins directory and retrieve all mu-plugin files with any plugin data.
     *
     * WordPress only includes mu-plugin files in the base mu-plugins directory (wp-content/mu-plugins).
     *
     * @since 3.0.0
     * @return array[] Array of arrays of mu-plugin data, keyed by plugin file name. See get_plugin_data().
     */
    function get_mu_plugins()
    {
    }
    /**
     * Declares a callback to sort array by a 'Name' key.
     *
     * @since 3.1.0
     *
     * @access private
     *
     * @param array $a array with 'Name' key.
     * @param array $b array with 'Name' key.
     * @return int Return 0 or 1 based on two string comparison.
     */
    function _sort_uname_callback($a, $b)
    {
    }
    /**
     * Checks the wp-content directory and retrieve all drop-ins with any plugin data.
     *
     * @since 3.0.0
     * @return array[] Array of arrays of dropin plugin data, keyed by plugin file name. See get_plugin_data().
     */
    function get_dropins()
    {
    }
    /**
     * Returns drop-in plugins that WordPress uses.
     *
     * Includes Multisite drop-ins only when is_multisite()
     *
     * @since 3.0.0
     *
     * @return array[] {
     *     Key is file name. The value is an array of data about the drop-in.
     *
     *     @type array ...$0 {
     *         Data about the drop-in.
     *
     *         @type string      $0 The purpose of the drop-in.
     *         @type string|true $1 Name of the constant that must be true for the drop-in
     *                              to be used, or true if no constant is required.
     *     }
     * }
     * @phpstan-return array<int|string, array{
     *   0: string,
     *   1: string|true,
     * }>
     */
    function _get_dropins()
    {
    }
    /**
     * Determines whether a plugin is active.
     *
     * Only plugins installed in the plugins/ folder can be active.
     *
     * Plugins in the mu-plugins/ folder can't be "activated," so this function will
     * return false for those plugins.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.5.0
     *
     * @param string $plugin Path to the plugin file relative to the plugins directory.
     * @return bool True, if in the active plugins list. False, not in the list.
     */
    function is_plugin_active($plugin)
    {
    }
    /**
     * Determines whether the plugin is inactive.
     *
     * Reverse of is_plugin_active(). Used as a callback.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 3.1.0
     *
     * @see is_plugin_active()
     *
     * @param string $plugin Path to the plugin file relative to the plugins directory.
     * @return bool True if inactive. False if active.
     */
    function is_plugin_inactive($plugin)
    {
    }
    /**
     * Determines whether the plugin is active for the entire network.
     *
     * Only plugins installed in the plugins/ folder can be active.
     *
     * Plugins in the mu-plugins/ folder can't be "activated," so this function will
     * return false for those plugins.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 3.0.0
     *
     * @param string $plugin Path to the plugin file relative to the plugins directory.
     * @return bool True if active for the network, otherwise false.
     */
    function is_plugin_active_for_network($plugin)
    {
    }
    /**
     * Checks for "Network: true" in the plugin header to see if this should
     * be activated only as a network wide plugin. The plugin would also work
     * when Multisite is not enabled.
     *
     * Checks for "Site Wide Only: true" for backward compatibility.
     *
     * @since 3.0.0
     *
     * @param string $plugin Path to the plugin file relative to the plugins directory.
     * @return bool True if plugin is network only, false otherwise.
     */
    function is_network_only_plugin($plugin)
    {
    }
    /**
     * Attempts activation of plugin in a "sandbox" and redirects on success.
     *
     * A plugin that is already activated will not attempt to be activated again.
     *
     * The way it works is by setting the redirection to the error before trying to
     * include the plugin file. If the plugin fails, then the redirection will not
     * be overwritten with the success message. Also, the options will not be
     * updated and the activation hook will not be called on plugin error.
     *
     * It should be noted that in no way the below code will actually prevent errors
     * within the file. The code should not be used elsewhere to replicate the
     * "sandbox", which uses redirection to work.
     * {@source 13 1}
     *
     * If any errors are found or text is outputted, then it will be captured to
     * ensure that the success redirection will update the error redirection.
     *
     * @since 2.5.0
     * @since 5.2.0 Test for WordPress version and PHP version compatibility.
     *
     * @param string $plugin       Path to the plugin file relative to the plugins directory.
     * @param string $redirect     Optional. URL to redirect to.
     * @param bool   $network_wide Optional. Whether to enable the plugin for all sites in the network
     *                             or just the current site. Multisite only. Default false.
     * @param bool   $silent       Optional. Whether to prevent calling activation hooks. Default false.
     * @return null|WP_Error Null on success, WP_Error on invalid file.
     */
    function activate_plugin($plugin, $redirect = '', $network_wide = \false, $silent = \false)
    {
    }
    /**
     * Deactivates a single plugin or multiple plugins.
     *
     * The deactivation hook is disabled by the plugin upgrader by using the $silent
     * parameter.
     *
     * @since 2.5.0
     *
     * @param string|string[] $plugins      Single plugin or list of plugins to deactivate.
     * @param bool            $silent       Prevent calling deactivation hooks. Default false.
     * @param bool|null       $network_wide Whether to deactivate the plugin for all sites in the network.
     *                                      A value of null will deactivate plugins for both the network
     *                                      and the current site. Multisite only. Default null.
     */
    function deactivate_plugins($plugins, $silent = \false, $network_wide = \null)
    {
    }
    /**
     * Activates multiple plugins.
     *
     * When WP_Error is returned, it does not mean that one of the plugins had
     * errors. It means that one or more of the plugin file paths were invalid.
     *
     * The execution will be halted as soon as one of the plugins has an error.
     *
     * @since 2.6.0
     *
     * @param string|string[] $plugins      Single plugin or list of plugins to activate.
     * @param string          $redirect     Redirect to page after successful activation.
     * @param bool            $network_wide Whether to enable the plugin for all sites in the network.
     *                                      Default false.
     * @param bool            $silent       Prevent calling activation hooks. Default false.
     * @return true|WP_Error True when finished or WP_Error if there were errors during a plugin activation.
     */
    function activate_plugins($plugins, $redirect = '', $network_wide = \false, $silent = \false)
    {
    }
    /**
     * Removes directory and files of a plugin for a list of plugins.
     *
     * @since 2.6.0
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     *
     * @param string[] $plugins    List of plugin paths to delete, relative to the plugins directory.
     * @param string   $deprecated Not used.
     * @return bool|null|WP_Error True on success, false if `$plugins` is empty, `WP_Error` on failure.
     *                            `null` if filesystem credentials are required to proceed.
     */
    function delete_plugins($plugins, $deprecated = '')
    {
    }
    /**
     * Validates active plugins.
     *
     * Validate all active plugins, deactivates invalid and
     * returns an array of deactivated ones.
     *
     * @since 2.5.0
     * @return WP_Error[] Array of plugin errors keyed by plugin file name.
     */
    function validate_active_plugins()
    {
    }
    /**
     * Validates the plugin path.
     *
     * Checks that the main plugin file exists and is a valid plugin. See validate_file().
     *
     * @since 2.5.0
     *
     * @param string $plugin Path to the plugin file relative to the plugins directory.
     * @return int|WP_Error 0 on success, WP_Error on failure.
     */
    function validate_plugin($plugin)
    {
    }
    /**
     * Validates the plugin requirements for WordPress version and PHP version.
     *
     * Uses the information from `Requires at least`, `Requires PHP` and `Requires Plugins` headers
     * defined in the plugin's main PHP file.
     *
     * @since 5.2.0
     * @since 5.3.0 Added support for reading the headers from the plugin's
     *              main PHP file, with `readme.txt` as a fallback.
     * @since 5.8.0 Removed support for using `readme.txt` as a fallback.
     * @since 6.5.0 Added support for the 'Requires Plugins' header.
     *
     * @param string $plugin Path to the plugin file relative to the plugins directory.
     * @return true|WP_Error True if requirements are met, WP_Error on failure.
     */
    function validate_plugin_requirements($plugin)
    {
    }
    /**
     * Determines whether the plugin can be uninstalled.
     *
     * @since 2.7.0
     *
     * @param string $plugin Path to the plugin file relative to the plugins directory.
     * @return bool Whether plugin can be uninstalled.
     */
    function is_uninstallable_plugin($plugin)
    {
    }
    /**
     * Uninstalls a single plugin.
     *
     * Calls the uninstall hook, if it is available.
     *
     * @since 2.7.0
     *
     * @param string $plugin Path to the plugin file relative to the plugins directory.
     * @return true|void True if a plugin's uninstall.php file has been found and included.
     *                   Void otherwise.
     */
    function uninstall_plugin($plugin)
    {
    }
    /**
     * Adds a top-level menu page.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 1.5.0
     *
     * @global array $menu
     * @global array $admin_page_hooks
     * @global array $_registered_pages
     * @global array $_parent_pages
     *
     * @param string    $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string    $menu_title The text to be used for the menu.
     * @param string    $capability The capability required for this menu to be displayed to the user.
     * @param string    $menu_slug  The slug name to refer to this menu by. Should be unique for this menu page and only
     *                              include lowercase alphanumeric, dashes, and underscores characters to be compatible
     *                              with sanitize_key().
     * @param callable  $callback   Optional. The function to be called to output the content for this page.
     * @param string    $icon_url   Optional. The URL to the icon to be used for this menu.
     *                              * Pass a base64-encoded SVG using a data URI, which will be colored to match
     *                                the color scheme. This should begin with 'data:image/svg+xml;base64,'.
     *                              * Pass the name of a Dashicons helper class to use a font icon,
     *                                e.g. 'dashicons-chart-pie'.
     *                              * Pass 'none' to leave div.wp-menu-image empty so an icon can be added via CSS.
     * @param int|float $position   Optional. The position in the menu order this item should appear.
     * @return string The resulting page's hook_suffix.
     */
    function add_menu_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $icon_url = '', $position = \null)
    {
    }
    /**
     * Adds a submenu page.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 1.5.0
     * @since 5.3.0 Added the `$position` parameter.
     *
     * @global array $submenu
     * @global array $menu
     * @global array $_wp_real_parent_file
     * @global bool  $_wp_submenu_nopriv
     * @global array $_registered_pages
     * @global array $_parent_pages
     *
     * @param string    $parent_slug The slug name for the parent menu (or the file name of a standard
     *                               WordPress admin page).
     * @param string    $page_title  The text to be displayed in the title tags of the page when the menu
     *                               is selected.
     * @param string    $menu_title  The text to be used for the menu.
     * @param string    $capability  The capability required for this menu to be displayed to the user.
     * @param string    $menu_slug   The slug name to refer to this menu by. Should be unique for this menu
     *                               and only include lowercase alphanumeric, dashes, and underscores characters
     *                               to be compatible with sanitize_key().
     * @param callable  $callback    Optional. The function to be called to output the content for this page.
     * @param int|float $position    Optional. The position in the menu order this item should appear.
     * @return string|false The resulting page's hook_suffix, or false if the user does not have the capability required.
     * @phpstan-param ''|callable $callback
     */
    function add_submenu_page($parent_slug, $page_title, $menu_title, $capability, $menu_slug, $callback = '', $position = \null)
    {
    }
    /**
     * Adds a submenu page to the Tools main menu.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 1.5.0
     * @since 5.3.0 Added the `$position` parameter.
     *
     * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string   $menu_title The text to be used for the menu.
     * @param string   $capability The capability required for this menu to be displayed to the user.
     * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
     * @param callable $callback   Optional. The function to be called to output the content for this page.
     * @param int      $position   Optional. The position in the menu order this item should appear.
     * @return string|false The resulting page's hook_suffix, or false if the user does not have the capability required.
     */
    function add_management_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $position = \null)
    {
    }
    /**
     * Adds a submenu page to the Settings main menu.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 1.5.0
     * @since 5.3.0 Added the `$position` parameter.
     *
     * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string   $menu_title The text to be used for the menu.
     * @param string   $capability The capability required for this menu to be displayed to the user.
     * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
     * @param callable $callback   Optional. The function to be called to output the content for this page.
     * @param int      $position   Optional. The position in the menu order this item should appear.
     * @return string|false The resulting page's hook_suffix, or false if the user does not have the capability required.
     */
    function add_options_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $position = \null)
    {
    }
    /**
     * Adds a submenu page to the Appearance main menu.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 2.0.0
     * @since 5.3.0 Added the `$position` parameter.
     *
     * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string   $menu_title The text to be used for the menu.
     * @param string   $capability The capability required for this menu to be displayed to the user.
     * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
     * @param callable $callback   Optional. The function to be called to output the content for this page.
     * @param int      $position   Optional. The position in the menu order this item should appear.
     * @return string|false The resulting page's hook_suffix, or false if the user does not have the capability required.
     */
    function add_theme_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $position = \null)
    {
    }
    /**
     * Adds a submenu page to the Plugins main menu.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 3.0.0
     * @since 5.3.0 Added the `$position` parameter.
     *
     * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string   $menu_title The text to be used for the menu.
     * @param string   $capability The capability required for this menu to be displayed to the user.
     * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
     * @param callable $callback   Optional. The function to be called to output the content for this page.
     * @param int      $position   Optional. The position in the menu order this item should appear.
     * @return string|false The resulting page's hook_suffix, or false if the user does not have the capability required.
     */
    function add_plugins_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $position = \null)
    {
    }
    /**
     * Adds a submenu page to the Users/Profile main menu.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 2.1.3
     * @since 5.3.0 Added the `$position` parameter.
     *
     * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string   $menu_title The text to be used for the menu.
     * @param string   $capability The capability required for this menu to be displayed to the user.
     * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
     * @param callable $callback   Optional. The function to be called to output the content for this page.
     * @param int      $position   Optional. The position in the menu order this item should appear.
     * @return string|false The resulting page's hook_suffix, or false if the user does not have the capability required.
     */
    function add_users_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $position = \null)
    {
    }
    /**
     * Adds a submenu page to the Dashboard main menu.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 2.7.0
     * @since 5.3.0 Added the `$position` parameter.
     *
     * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string   $menu_title The text to be used for the menu.
     * @param string   $capability The capability required for this menu to be displayed to the user.
     * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
     * @param callable $callback   Optional. The function to be called to output the content for this page.
     * @param int      $position   Optional. The position in the menu order this item should appear.
     * @return string|false The resulting page's hook_suffix, or false if the user does not have the capability required.
     */
    function add_dashboard_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $position = \null)
    {
    }
    /**
     * Adds a submenu page to the Posts main menu.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 2.7.0
     * @since 5.3.0 Added the `$position` parameter.
     *
     * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string   $menu_title The text to be used for the menu.
     * @param string   $capability The capability required for this menu to be displayed to the user.
     * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
     * @param callable $callback   Optional. The function to be called to output the content for this page.
     * @param int      $position   Optional. The position in the menu order this item should appear.
     * @return string|false The resulting page's hook_suffix, or false if the user does not have the capability required.
     */
    function add_posts_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $position = \null)
    {
    }
    /**
     * Adds a submenu page to the Media main menu.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 2.7.0
     * @since 5.3.0 Added the `$position` parameter.
     *
     * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string   $menu_title The text to be used for the menu.
     * @param string   $capability The capability required for this menu to be displayed to the user.
     * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
     * @param callable $callback   Optional. The function to be called to output the content for this page.
     * @param int      $position   Optional. The position in the menu order this item should appear.
     * @return string|false The resulting page's hook_suffix, or false if the user does not have the capability required.
     */
    function add_media_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $position = \null)
    {
    }
    /**
     * Adds a submenu page to the Links main menu.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 2.7.0
     * @since 5.3.0 Added the `$position` parameter.
     *
     * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string   $menu_title The text to be used for the menu.
     * @param string   $capability The capability required for this menu to be displayed to the user.
     * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
     * @param callable $callback   Optional. The function to be called to output the content for this page.
     * @param int      $position   Optional. The position in the menu order this item should appear.
     * @return string|false The resulting page's hook_suffix, or false if the user does not have the capability required.
     */
    function add_links_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $position = \null)
    {
    }
    /**
     * Adds a submenu page to the Pages main menu.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 2.7.0
     * @since 5.3.0 Added the `$position` parameter.
     *
     * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string   $menu_title The text to be used for the menu.
     * @param string   $capability The capability required for this menu to be displayed to the user.
     * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
     * @param callable $callback   Optional. The function to be called to output the content for this page.
     * @param int      $position   Optional. The position in the menu order this item should appear.
     * @return string|false The resulting page's hook_suffix, or false if the user does not have the capability required.
     */
    function add_pages_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $position = \null)
    {
    }
    /**
     * Adds a submenu page to the Comments main menu.
     *
     * This function takes a capability which will be used to determine whether
     * or not a page is included in the menu.
     *
     * The function which is hooked in to handle the output of the page must check
     * that the user has the required capability as well.
     *
     * @since 2.7.0
     * @since 5.3.0 Added the `$position` parameter.
     *
     * @param string   $page_title The text to be displayed in the title tags of the page when the menu is selected.
     * @param string   $menu_title The text to be used for the menu.
     * @param string   $capability The capability required for this menu to be displayed to the user.
     * @param string   $menu_slug  The slug name to refer to this menu by (should be unique for this menu).
     * @param callable $callback   Optional. The function to be called to output the content for this page.
     * @param int      $position   Optional. The position in the menu order this item should appear.
     * @return string|false The resulting page's hook_suffix, or false if the user does not have the capability required.
     */
    function add_comments_page($page_title, $menu_title, $capability, $menu_slug, $callback = '', $position = \null)
    {
    }
    /**
     * Removes a top-level admin menu.
     *
     * Example usage:
     *
     *  - `remove_menu_page( 'tools.php' )`
     *  - `remove_menu_page( 'plugin_menu_slug' )`
     *
     * @since 3.1.0
     *
     * @global array $menu
     *
     * @param string $menu_slug The slug of the menu.
     * @return array|false The removed menu on success, false if not found.
     */
    function remove_menu_page($menu_slug)
    {
    }
    /**
     * Removes an admin submenu.
     *
     * Example usage:
     *
     *  - `remove_submenu_page( 'themes.php', 'nav-menus.php' )`
     *  - `remove_submenu_page( 'tools.php', 'plugin_submenu_slug' )`
     *  - `remove_submenu_page( 'plugin_menu_slug', 'plugin_submenu_slug' )`
     *
     * @since 3.1.0
     *
     * @global array $submenu
     *
     * @param string $menu_slug    The slug for the parent menu.
     * @param string $submenu_slug The slug of the submenu.
     * @return array|false The removed submenu on success, false if not found.
     */
    function remove_submenu_page($menu_slug, $submenu_slug)
    {
    }
    /**
     * Gets the URL to access a particular menu page based on the slug it was registered with.
     *
     * If the slug hasn't been registered properly, no URL will be returned.
     *
     * @since 3.0.0
     *
     * @global array $_parent_pages
     *
     * @param string $menu_slug The slug name to refer to this menu by (should be unique for this menu).
     * @param bool   $display   Optional. Whether or not to display the URL. Default true.
     * @return string The menu page URL.
     */
    function menu_page_url($menu_slug, $display = \true)
    {
    }
    /**
     * Gets the parent file of the current admin page.
     *
     * @since 1.5.0
     *
     * @global string $parent_file
     * @global array  $menu
     * @global array  $submenu
     * @global string $pagenow              The filename of the current screen.
     * @global string $typenow              The post type of the current screen.
     * @global string $plugin_page
     * @global array  $_wp_real_parent_file
     * @global array  $_wp_menu_nopriv
     * @global array  $_wp_submenu_nopriv
     *
     * @param string $parent_page Optional. The slug name for the parent menu (or the file name
     *                            of a standard WordPress admin page). Default empty string.
     * @return string The parent file of the current admin page.
     */
    function get_admin_page_parent($parent_page = '')
    {
    }
    /**
     * Gets the title of the current admin page.
     *
     * @since 1.5.0
     *
     * @global string $title       The title of the current screen.
     * @global array  $menu
     * @global array  $submenu
     * @global string $pagenow     The filename of the current screen.
     * @global string $typenow     The post type of the current screen.
     * @global string $plugin_page
     *
     * @return string The title of the current admin page.
     */
    function get_admin_page_title()
    {
    }
    /**
     * Gets the hook attached to the administrative page of a plugin.
     *
     * @since 1.5.0
     *
     * @param string $plugin_page The slug name of the plugin page.
     * @param string $parent_page The slug name for the parent menu (or the file name of a standard
     *                            WordPress admin page).
     * @return string|null Hook attached to the plugin page, null otherwise.
     */
    function get_plugin_page_hook($plugin_page, $parent_page)
    {
    }
    /**
     * Gets the hook name for the administrative page of a plugin.
     *
     * @since 1.5.0
     *
     * @global array $admin_page_hooks
     *
     * @param string $plugin_page The slug name of the plugin page.
     * @param string $parent_page The slug name for the parent menu (or the file name of a standard
     *                            WordPress admin page).
     * @return string Hook name for the plugin page.
     */
    function get_plugin_page_hookname($plugin_page, $parent_page)
    {
    }
    /**
     * Determines whether the current user can access the current admin page.
     *
     * @since 1.5.0
     *
     * @global string $pagenow            The filename of the current screen.
     * @global array  $menu
     * @global array  $submenu
     * @global array  $_wp_menu_nopriv
     * @global array  $_wp_submenu_nopriv
     * @global string $plugin_page
     * @global array  $_registered_pages
     *
     * @return bool True if the current user can access the admin page, false otherwise.
     */
    function user_can_access_admin_page()
    {
    }
    /**
     * Refreshes the value of the allowed options list available via the 'allowed_options' hook.
     *
     * See the {@see 'allowed_options'} filter.
     *
     * @since 2.7.0
     * @since 5.5.0 `$new_whitelist_options` was renamed to `$new_allowed_options`.
     *              Please consider writing more inclusive code.
     *
     * @global array $new_allowed_options
     *
     * @param array $options
     * @return array
     */
    function option_update_filter($options)
    {
    }
    /**
     * Adds an array of options to the list of allowed options.
     *
     * @since 5.5.0
     *
     * @global array $allowed_options
     *
     * @param array        $new_options
     * @param string|array $options
     * @return array
     */
    function add_allowed_options($new_options, $options = '')
    {
    }
    /**
     * Removes a list of options from the allowed options list.
     *
     * @since 5.5.0
     *
     * @global array $allowed_options
     *
     * @param array        $del_options
     * @param string|array $options
     * @return array
     */
    function remove_allowed_options($del_options, $options = '')
    {
    }
    /**
     * Outputs nonce, action, and option_page fields for a settings page.
     *
     * @since 2.7.0
     *
     * @param string $option_group A settings group name. This should match the group name
     *                             used in register_setting().
     */
    function settings_fields($option_group)
    {
    }
    /**
     * Clears the plugins cache used by get_plugins() and by default, the plugin updates cache.
     *
     * @since 3.7.0
     *
     * @param bool $clear_update_cache Whether to clear the plugin updates cache. Default true.
     */
    function wp_clean_plugins_cache($clear_update_cache = \true)
    {
    }
    /**
     * Loads a given plugin attempt to generate errors.
     *
     * @since 3.0.0
     * @since 4.4.0 Function was moved into the `wp-admin/includes/plugin.php` file.
     *
     * @param string $plugin Path to the plugin file relative to the plugins directory.
     */
    function plugin_sandbox_scrape($plugin)
    {
    }
    /**
     * Declares a helper function for adding content to the Privacy Policy Guide.
     *
     * Plugins and themes should suggest text for inclusion in the site's privacy policy.
     * The suggested text should contain information about any functionality that affects user privacy,
     * and will be shown on the Privacy Policy Guide screen.
     *
     * A plugin or theme can use this function multiple times as long as it will help to better present
     * the suggested policy content. For example modular plugins such as WooCommerse or Jetpack
     * can add or remove suggested content depending on the modules/extensions that are enabled.
     * For more information see the Plugin Handbook:
     * https://developer.wordpress.org/plugins/privacy/suggesting-text-for-the-site-privacy-policy/.
     *
     * The HTML contents of the `$policy_text` supports use of a specialized `.privacy-policy-tutorial`
     * CSS class which can be used to provide supplemental information. Any content contained within
     * HTML elements that have the `.privacy-policy-tutorial` CSS class applied will be omitted
     * from the clipboard when the section content is copied.
     *
     * Intended for use with the `'admin_init'` action.
     *
     * @since 4.9.6
     *
     * @param string $plugin_name The name of the plugin or theme that is suggesting content
     *                            for the site's privacy policy.
     * @param string $policy_text The suggested content for inclusion in the policy.
     * @phpstan-return void
     */
    function wp_add_privacy_policy_content($plugin_name, $policy_text)
    {
    }
    /**
     * Determines whether a plugin is technically active but was paused while
     * loading.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 5.2.0
     *
     * @global WP_Paused_Extensions_Storage $_paused_plugins
     *
     * @param string $plugin Path to the plugin file relative to the plugins directory.
     * @return bool True, if in the list of paused plugins. False, if not in the list.
     */
    function is_plugin_paused($plugin)
    {
    }
    /**
     * Gets the error that was recorded for a paused plugin.
     *
     * @since 5.2.0
     *
     * @global WP_Paused_Extensions_Storage $_paused_plugins
     *
     * @param string $plugin Path to the plugin file relative to the plugins directory.
     * @return array|false Array of error information as returned by `error_get_last()`,
     *                     or false if none was recorded.
     */
    function wp_get_plugin_error($plugin)
    {
    }
    /**
     * Tries to resume a single plugin.
     *
     * If a redirect was provided, we first ensure the plugin does not throw fatal
     * errors anymore.
     *
     * The way it works is by setting the redirection to the error before trying to
     * include the plugin file. If the plugin fails, then the redirection will not
     * be overwritten with the success message and the plugin will not be resumed.
     *
     * @since 5.2.0
     *
     * @param string $plugin   Single plugin to resume.
     * @param string $redirect Optional. URL to redirect to. Default empty string.
     * @return true|WP_Error True on success, false if `$plugin` was not paused,
     *                       `WP_Error` on failure.
     */
    function resume_plugin($plugin, $redirect = '')
    {
    }
    /**
     * Renders an admin notice in case some plugins have been paused due to errors.
     *
     * @since 5.2.0
     *
     * @global string                       $pagenow         The filename of the current screen.
     * @global WP_Paused_Extensions_Storage $_paused_plugins
     * @phpstan-return void
     */
    function paused_plugins_notice()
    {
    }
    /**
     * Renders an admin notice when a plugin was deactivated during an update.
     *
     * Displays an admin notice in case a plugin has been deactivated during an
     * upgrade due to incompatibility with the current version of WordPress.
     *
     * @since 5.8.0
     * @access private
     *
     * @global string $pagenow    The filename of the current screen.
     * @global string $wp_version The WordPress version string.
     * @phpstan-return void
     */
    function deactivated_plugins_notice()
    {
    }
    /**
     * Renames `$_POST` data from form names to DB post columns.
     *
     * Manipulates `$_POST` directly.
     *
     * @since 2.6.0
     *
     * @param bool       $update    Whether the post already exists.
     * @param array|null $post_data Optional. The array of post data to process.
     *                              Defaults to the `$_POST` superglobal.
     * @return array|WP_Error Array of post data on success, WP_Error on failure.
     */
    function _wp_translate_postdata($update = \false, $post_data = \null)
    {
    }
    /**
     * Returns only allowed post data fields.
     *
     * @since 5.0.1
     *
     * @param array|WP_Error|null $post_data The array of post data to process, or an error object.
     *                                       Defaults to the `$_POST` superglobal.
     * @return array|WP_Error Array of post data on success, WP_Error on failure.
     */
    function _wp_get_allowed_postdata($post_data = \null)
    {
    }
    /**
     * Updates an existing post with values provided in `$_POST`.
     *
     * If post data is passed as an argument, it is treated as an array of data
     * keyed appropriately for turning into a post object.
     *
     * If post data is not passed, the `$_POST` global variable is used instead.
     *
     * @since 1.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array|null $post_data Optional. The array of post data to process.
     *                              Defaults to the `$_POST` superglobal.
     * @return int Post ID.
     */
    function edit_post($post_data = \null)
    {
    }
    /**
     * Processes the post data for the bulk editing of posts.
     *
     * Updates all bulk edited posts/pages, adding (but not removing) tags and
     * categories. Skips pages when they would be their own parent or child.
     *
     * @since 2.7.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array|null $post_data Optional. The array of post data to process.
     *                              Defaults to the `$_POST` superglobal.
     * @return array
     */
    function bulk_edit_posts($post_data = \null)
    {
    }
    /**
     * Returns default post information to use when populating the "Write Post" form.
     *
     * @since 2.0.0
     *
     * @param string $post_type    Optional. A post type string. Default 'post'.
     * @param bool   $create_in_db Optional. Whether to insert the post into database. Default false.
     * @return WP_Post Post object containing all the default post data as attributes
     */
    function get_default_post_to_edit($post_type = 'post', $create_in_db = \false)
    {
    }
    /**
     * Determines if a post exists based on title, content, date and type.
     *
     * @since 2.0.0
     * @since 5.2.0 Added the `$type` parameter.
     * @since 5.8.0 Added the `$status` parameter.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $title   Post title.
     * @param string $content Optional. Post content.
     * @param string $date    Optional. Post date.
     * @param string $type    Optional. Post type.
     * @param string $status  Optional. Post status.
     * @return int Post ID if post exists, 0 otherwise.
     */
    function post_exists($title, $content = '', $date = '', $type = '', $status = '')
    {
    }
    /**
     * Creates a new post from the "Write Post" form using `$_POST` information.
     *
     * @since 2.1.0
     *
     * @global WP_User $current_user
     *
     * @return int|WP_Error Post ID on success, WP_Error on failure.
     */
    function wp_write_post()
    {
    }
    /**
     * Calls wp_write_post() and handles the errors.
     *
     * @since 2.0.0
     *
     * @return int|void Post ID on success, void on failure.
     */
    function write_post()
    {
    }
    /**
     * Adds post meta data defined in the `$_POST` superglobal for a post with given ID.
     *
     * @since 1.2.0
     *
     * @param int $post_id
     * @return int|bool
     */
    function add_meta($post_id)
    {
    }
    /**
     * Deletes post meta data by meta ID.
     *
     * @since 1.2.0
     *
     * @param int $mid
     * @return bool
     */
    function delete_meta($mid)
    {
    }
    /**
     * Returns a list of previously defined keys.
     *
     * @since 1.2.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return string[] Array of meta key names.
     */
    function get_meta_keys()
    {
    }
    /**
     * Returns post meta data by meta ID.
     *
     * @since 2.1.0
     *
     * @param int $mid
     * @return object|bool
     */
    function get_post_meta_by_id($mid)
    {
    }
    /**
     * Returns meta data for the given post ID.
     *
     * @since 1.2.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $post_id A post ID.
     * @return array[] {
     *     Array of meta data arrays for the given post ID.
     *
     *     @type array ...$0 {
     *         Associative array of meta data.
     *
     *         @type string $meta_key   Meta key.
     *         @type mixed  $meta_value Meta value.
     *         @type string $meta_id    Meta ID as a numeric string.
     *         @type string $post_id    Post ID as a numeric string.
     *     }
     * }
     * @phpstan-return array<int|string, array{
     *   meta_key: string,
     *   meta_value: mixed,
     *   meta_id: string,
     *   post_id: string,
     * }>
     */
    function has_meta($post_id)
    {
    }
    /**
     * Updates post meta data by meta ID.
     *
     * @since 1.2.0
     *
     * @param int    $meta_id    Meta ID.
     * @param string $meta_key   Meta key. Expect slashed.
     * @param string $meta_value Meta value. Expect slashed.
     * @return bool
     */
    function update_meta($meta_id, $meta_key, $meta_value)
    {
    }
    /**
     * Replaces hrefs of attachment anchors with up-to-date permalinks.
     *
     * @since 2.3.0
     * @access private
     *
     * @param int|WP_Post $post Post ID or post object.
     * @return void|int|WP_Error Void if nothing fixed. 0 or WP_Error on update failure. The post ID on update success.
     */
    function _fix_attachment_links($post)
    {
    }
    /**
     * Returns all the possible statuses for a post type.
     *
     * @since 2.5.0
     *
     * @param string $type The post_type you want the statuses for. Default 'post'.
     * @return string[] An array of all the statuses for the supplied post type.
     */
    function get_available_post_statuses($type = 'post')
    {
    }
    /**
     * Runs the query to fetch the posts for listing on the edit posts page.
     *
     * @since 2.5.0
     *
     * @param array|false $q Optional. Array of query variables to use to build the query.
     *                       Defaults to the `$_GET` superglobal.
     * @return array
     */
    function wp_edit_posts_query($q = \false)
    {
    }
    /**
     * Returns the query variables for the current attachments request.
     *
     * @since 4.2.0
     *
     * @param array|false $q Optional. Array of query variables to use to build the query.
     *                       Defaults to the `$_GET` superglobal.
     * @return array The parsed query vars.
     */
    function wp_edit_attachments_query_vars($q = \false)
    {
    }
    /**
     * Executes a query for attachments. An array of WP_Query arguments
     * can be passed in, which will override the arguments set by this function.
     *
     * @since 2.5.0
     *
     * @param array|false $q Optional. Array of query variables to use to build the query.
     *                       Defaults to the `$_GET` superglobal.
     * @return array
     */
    function wp_edit_attachments_query($q = \false)
    {
    }
    /**
     * Returns the list of classes to be used by a meta box.
     *
     * @since 2.5.0
     *
     * @param string $box_id    Meta box ID (used in the 'id' attribute for the meta box).
     * @param string $screen_id The screen on which the meta box is shown.
     * @return string Space-separated string of class names.
     */
    function postbox_classes($box_id, $screen_id)
    {
    }
    /**
     * Returns a sample permalink based on the post name.
     *
     * @since 2.5.0
     *
     * @param int|WP_Post $post  Post ID or post object.
     * @param string|null $title Optional. Title to override the post's current title
     *                           when generating the post name. Default null.
     * @param string|null $name  Optional. Name to override the post name. Default null.
     * @return array {
     *     Array containing the sample permalink with placeholder for the post name, and the post name.
     *
     *     @type string $0 The permalink with placeholder for the post name.
     *     @type string $1 The post name.
     * }
     * @phpstan-return array{
     *   0: string,
     *   1: string,
     * }
     */
    function get_sample_permalink($post, $title = \null, $name = \null)
    {
    }
    /**
     * Returns the HTML of the sample permalink slug editor.
     *
     * @since 2.5.0
     *
     * @param int|WP_Post $post      Post ID or post object.
     * @param string|null $new_title Optional. New title. Default null.
     * @param string|null $new_slug  Optional. New slug. Default null.
     * @return string The HTML of the sample permalink slug editor.
     */
    function get_sample_permalink_html($post, $new_title = \null, $new_slug = \null)
    {
    }
    /**
     * Returns HTML for the post thumbnail meta box.
     *
     * @since 2.9.0
     *
     * @param int|null         $thumbnail_id Optional. Thumbnail attachment ID. Default null.
     * @param int|WP_Post|null $post         Optional. The post ID or object associated
     *                                       with the thumbnail. Defaults to global $post.
     * @return string The post thumbnail HTML.
     */
    function _wp_post_thumbnail_html($thumbnail_id = \null, $post = \null)
    {
    }
    /**
     * Determines whether the post is currently being edited by another user.
     *
     * @since 2.5.0
     *
     * @param int|WP_Post $post ID or object of the post to check for editing.
     * @return int|false ID of the user with lock. False if the post does not exist, post is not locked,
     *                   the user with lock does not exist, or the post is locked by current user.
     */
    function wp_check_post_lock($post)
    {
    }
    /**
     * Marks the post as currently being edited by the current user.
     *
     * @since 2.5.0
     *
     * @param int|WP_Post $post ID or object of the post being edited.
     * @return array|false {
     *     Array of the lock time and user ID. False if the post does not exist, or there
     *     is no current user.
     *
     *     @type int $0 The current time as a Unix timestamp.
     *     @type int $1 The ID of the current user.
     * }
     * @phpstan-return false|array{
     *   0: int,
     *   1: int,
     * }
     */
    function wp_set_post_lock($post)
    {
    }
    /**
     * Outputs the HTML for the notice to say that someone else is editing or has taken over editing of this post.
     *
     * @since 2.8.5
     * @phpstan-return void
     */
    function _admin_notice_post_locked()
    {
    }
    /**
     * Creates autosave data for the specified post from `$_POST` data.
     *
     * @since 2.6.0
     *
     * @param array|int $post_data Associative array containing the post data, or integer post ID.
     *                             If a numeric post ID is provided, will use the `$_POST` superglobal.
     * @return int|WP_Error The autosave revision ID. WP_Error or 0 on error.
     */
    function wp_create_post_autosave($post_data)
    {
    }
    /**
     * Autosaves the revisioned meta fields.
     *
     * Iterates through the revisioned meta fields and checks each to see if they are set,
     * and have a changed value. If so, the meta value is saved and attached to the autosave.
     *
     * @since 6.4.0
     *
     * @param array $new_autosave The new post data being autosaved.
     */
    function wp_autosave_post_revisioned_meta_fields($new_autosave)
    {
    }
    /**
     * Saves a draft or manually autosaves for the purpose of showing a post preview.
     *
     * @since 2.7.0
     *
     * @return string URL to redirect to show the preview.
     */
    function post_preview()
    {
    }
    /**
     * Saves a post submitted with XHR.
     *
     * Intended for use with heartbeat and autosave.js
     *
     * @since 3.9.0
     *
     * @param array $post_data Associative array of the submitted post data.
     * @return mixed The value 0 or WP_Error on failure. The saved post ID on success.
     *               The ID can be the draft post_id or the autosave revision post_id.
     */
    function wp_autosave($post_data)
    {
    }
    /**
     * Redirects to previous page.
     *
     * @since 2.7.0
     *
     * @param int $post_id Optional. Post ID.
     * @phpstan-return never
     */
    function redirect_post($post_id = '')
    {
    }
    /**
     * Sanitizes POST values from a checkbox taxonomy metabox.
     *
     * @since 5.1.0
     *
     * @param string $taxonomy The taxonomy name.
     * @param array  $terms    Raw term data from the 'tax_input' field.
     * @return int[] Array of sanitized term IDs.
     */
    function taxonomy_meta_box_sanitize_cb_checkboxes($taxonomy, $terms)
    {
    }
    /**
     * Sanitizes POST values from an input taxonomy metabox.
     *
     * @since 5.1.0
     *
     * @param string       $taxonomy The taxonomy name.
     * @param array|string $terms    Raw term data from the 'tax_input' field.
     * @return array
     */
    function taxonomy_meta_box_sanitize_cb_input($taxonomy, $terms)
    {
    }
    /**
     * Prepares server-registered blocks for the block editor.
     *
     * Returns an associative array of registered block data keyed by block name. Data includes properties
     * of a block relevant for client registration.
     *
     * @since 5.0.0
     * @since 6.3.0 Added `selectors` field.
     * @since 6.4.0 Added `block_hooks` field.
     *
     * @return array An associative array of registered block data.
     */
    function get_block_editor_server_block_settings()
    {
    }
    /**
     * Renders the meta boxes forms.
     *
     * @since 5.0.0
     *
     * @global WP_Post   $post           Global post object.
     * @global WP_Screen $current_screen WordPress current screen object.
     * @global array     $wp_meta_boxes  Global meta box state.
     */
    function the_block_editor_meta_boxes()
    {
    }
    /**
     * Renders the hidden form required for the meta boxes form.
     *
     * @since 5.0.0
     *
     * @param WP_Post $post Current post object.
     */
    function the_block_editor_meta_box_post_form_hidden_fields($post)
    {
    }
    /**
     * Disables block editor for wp_navigation type posts so they can be managed via the UI.
     *
     * @since 5.9.0
     * @access private
     *
     * @param bool   $value Whether the CPT supports block editor or not.
     * @param string $post_type Post type.
     * @return bool Whether the block editor should be disabled or not.
     */
    function _disable_block_editor_for_navigation_post_type($value, $post_type)
    {
    }
    /**
     * This callback disables the content editor for wp_navigation type posts.
     * Content editor cannot handle wp_navigation type posts correctly.
     * We cannot disable the "editor" feature in the wp_navigation's CPT definition
     * because it disables the ability to save navigation blocks via REST API.
     *
     * @since 5.9.0
     * @access private
     *
     * @param WP_Post $post An instance of WP_Post class.
     * @phpstan-return void
     */
    function _disable_content_editor_for_navigation_post_type($post)
    {
    }
    /**
     * This callback enables content editor for wp_navigation type posts.
     * We need to enable it back because we disable it to hide
     * the content editor for wp_navigation type posts.
     *
     * @since 5.9.0
     * @access private
     *
     * @see _disable_content_editor_for_navigation_post_type
     *
     * @param WP_Post $post An instance of WP_Post class.
     * @phpstan-return void
     */
    function _enable_content_editor_for_navigation_post_type($post)
    {
    }
    /**
     * Resend an existing request and return the result.
     *
     * @since 4.9.6
     * @access private
     *
     * @param int $request_id Request ID.
     * @return true|WP_Error Returns true if sending the email was successful, or a WP_Error object.
     */
    function _wp_privacy_resend_request($request_id)
    {
    }
    /**
     * Marks a request as completed by the admin and logs the current timestamp.
     *
     * @since 4.9.6
     * @access private
     *
     * @param int $request_id Request ID.
     * @return int|WP_Error Request ID on success, or a WP_Error on failure.
     */
    function _wp_privacy_completed_request($request_id)
    {
    }
    /**
     * Handle list table actions.
     *
     * @since 4.9.6
     * @access private
     */
    function _wp_personal_data_handle_actions()
    {
    }
    /**
     * Cleans up failed and expired requests before displaying the list table.
     *
     * @since 4.9.6
     * @access private
     */
    function _wp_personal_data_cleanup_requests()
    {
    }
    /**
     * Generate a single group for the personal data export report.
     *
     * @since 4.9.6
     * @since 5.4.0 Added the `$group_id` and `$groups_count` parameters.
     *
     * @param array  $group_data {
     *     The group data to render.
     *
     *     @type string $group_label  The user-facing heading for the group, e.g. 'Comments'.
     *     @type array  $items        {
     *         An array of group items.
     *
     *         @type array  $group_item_data  {
     *             An array of name-value pairs for the item.
     *
     *             @type string $name   The user-facing name of an item name-value pair, e.g. 'IP Address'.
     *             @type string $value  The user-facing value of an item data pair, e.g. '50.60.70.0'.
     *         }
     *     }
     * }
     * @param string $group_id     The group identifier.
     * @param int    $groups_count The number of all groups
     * @return string The HTML for this group and its items.
     * @phpstan-param array{
     *   group_label?: string,
     *   items?: array{
     *     group_item_data: array{
     *       name: string,
     *       value: string,
     *     },
     *   },
     * } $group_data
     */
    function wp_privacy_generate_personal_data_export_group_html($group_data, $group_id = '', $groups_count = 1)
    {
    }
    /**
     * Generate the personal data export file.
     *
     * @since 4.9.6
     *
     * @param int $request_id The export request ID.
     */
    function wp_privacy_generate_personal_data_export_file($request_id)
    {
    }
    /**
     * Send an email to the user with a link to the personal data export file
     *
     * @since 4.9.6
     *
     * @param int $request_id The request ID for this personal data export.
     * @return true|WP_Error True on success or `WP_Error` on failure.
     */
    function wp_privacy_send_personal_data_export_email($request_id)
    {
    }
    /**
     * Intercept personal data exporter page Ajax responses in order to assemble the personal data export file.
     *
     * @since 4.9.6
     *
     * @see 'wp_privacy_personal_data_export_page'
     *
     * @param array  $response        The response from the personal data exporter for the given page.
     * @param int    $exporter_index  The index of the personal data exporter. Begins at 1.
     * @param string $email_address   The email address of the user whose personal data this is.
     * @param int    $page            The page of personal data for this exporter. Begins at 1.
     * @param int    $request_id      The request ID for this personal data export.
     * @param bool   $send_as_email   Whether the final results of the export should be emailed to the user.
     * @param string $exporter_key    The slug (key) of the exporter.
     * @return array The filtered response.
     */
    function wp_privacy_process_personal_data_export_page($response, $exporter_index, $email_address, $page, $request_id, $send_as_email, $exporter_key)
    {
    }
    /**
     * Mark erasure requests as completed after processing is finished.
     *
     * This intercepts the Ajax responses to personal data eraser page requests, and
     * monitors the status of a request. Once all of the processing has finished, the
     * request is marked as completed.
     *
     * @since 4.9.6
     *
     * @see 'wp_privacy_personal_data_erasure_page'
     *
     * @param array  $response      The response from the personal data eraser for
     *                              the given page.
     * @param int    $eraser_index  The index of the personal data eraser. Begins
     *                              at 1.
     * @param string $email_address The email address of the user whose personal
     *                              data this is.
     * @param int    $page          The page of personal data for this eraser.
     *                              Begins at 1.
     * @param int    $request_id    The request ID for this personal data erasure.
     * @return array The filtered response.
     */
    function wp_privacy_process_personal_data_erasure_page($response, $eraser_index, $email_address, $page, $request_id)
    {
    }
    /**
     * Get the revision UI diff.
     *
     * @since 3.6.0
     *
     * @param WP_Post|int $post         The post object or post ID.
     * @param int         $compare_from The revision ID to compare from.
     * @param int         $compare_to   The revision ID to come to.
     * @return array|false Associative array of a post's revisioned fields and their diffs.
     *                     Or, false on failure.
     */
    function wp_get_revision_ui_diff($post, $compare_from, $compare_to)
    {
    }
    /**
     * Prepare revisions for JavaScript.
     *
     * @since 3.6.0
     *
     * @param WP_Post|int $post                 The post object or post ID.
     * @param int         $selected_revision_id The selected revision ID.
     * @param int         $from                 Optional. The revision ID to compare from.
     * @return array An associative array of revision data and related settings.
     */
    function wp_prepare_revisions_for_js($post, $selected_revision_id, $from = \null)
    {
    }
    /**
     * Print JavaScript templates required for the revisions experience.
     *
     * @since 4.1.0
     *
     * @global WP_Post $post Global post object.
     */
    function wp_print_revision_templates()
    {
    }
    /**
     * Retrieve the SQL for creating database tables.
     *
     * @since 3.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $scope   Optional. The tables for which to retrieve SQL. Can be all, global, ms_global, or blog tables. Defaults to all.
     * @param int    $blog_id Optional. The site ID for which to retrieve SQL. Default is the current site ID.
     * @return string The SQL needed to create the requested tables.
     */
    function wp_get_db_schema($scope = 'all', $blog_id = \null)
    {
    }
    /**
     * Create WordPress options and set the default values.
     *
     * @since 1.5.0
     * @since 5.1.0 The $options parameter has been added.
     *
     * @global wpdb $wpdb                  WordPress database abstraction object.
     * @global int  $wp_db_version         WordPress database version.
     * @global int  $wp_current_db_version The old (current) database version.
     *
     * @param array $options Optional. Custom option $key => $value pairs to use. Default empty array.
     */
    function populate_options(array $options = array())
    {
    }
    /**
     * Execute WordPress role creation for the various WordPress versions.
     *
     * @since 2.0.0
     */
    function populate_roles()
    {
    }
    /**
     * Create the roles for WordPress 2.0
     *
     * @since 2.0.0
     */
    function populate_roles_160()
    {
    }
    /**
     * Create and modify WordPress roles for WordPress 2.1.
     *
     * @since 2.1.0
     */
    function populate_roles_210()
    {
    }
    /**
     * Create and modify WordPress roles for WordPress 2.3.
     *
     * @since 2.3.0
     */
    function populate_roles_230()
    {
    }
    /**
     * Create and modify WordPress roles for WordPress 2.5.
     *
     * @since 2.5.0
     */
    function populate_roles_250()
    {
    }
    /**
     * Create and modify WordPress roles for WordPress 2.6.
     *
     * @since 2.6.0
     */
    function populate_roles_260()
    {
    }
    /**
     * Create and modify WordPress roles for WordPress 2.7.
     *
     * @since 2.7.0
     */
    function populate_roles_270()
    {
    }
    /**
     * Create and modify WordPress roles for WordPress 2.8.
     *
     * @since 2.8.0
     */
    function populate_roles_280()
    {
    }
    /**
     * Create and modify WordPress roles for WordPress 3.0.
     *
     * @since 3.0.0
     */
    function populate_roles_300()
    {
    }
    /**
     * Install Network.
     *
     * @since 3.0.0
     */
    function install_network()
    {
    }
    /**
     * Populate network settings.
     *
     * @since 3.0.0
     *
     * @global wpdb       $wpdb         WordPress database abstraction object.
     * @global object     $current_site
     * @global WP_Rewrite $wp_rewrite   WordPress rewrite component.
     *
     * @param int    $network_id        ID of network to populate.
     * @param string $domain            The domain name for the network. Example: "example.com".
     * @param string $email             Email address for the network administrator.
     * @param string $site_name         The name of the network.
     * @param string $path              Optional. The path to append to the network's domain name. Default '/'.
     * @param bool   $subdomain_install Optional. Whether the network is a subdomain installation or a subdirectory installation.
     *                                  Default false, meaning the network is a subdirectory installation.
     * @return true|WP_Error True on success, or WP_Error on warning (with the installation otherwise successful,
     *                       so the error code must be checked) or failure.
     */
    function populate_network($network_id = 1, $domain = '', $email = '', $site_name = '', $path = '/', $subdomain_install = \false)
    {
    }
    /**
     * Creates WordPress network meta and sets the default values.
     *
     * @since 5.1.0
     *
     * @global wpdb $wpdb          WordPress database abstraction object.
     * @global int  $wp_db_version WordPress database version.
     *
     * @param int   $network_id Network ID to populate meta for.
     * @param array $meta       Optional. Custom meta $key => $value pairs to use. Default empty array.
     */
    function populate_network_meta($network_id, array $meta = array())
    {
    }
    /**
     * Creates WordPress site meta and sets the default values.
     *
     * @since 5.1.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int   $site_id Site ID to populate meta for.
     * @param array $meta    Optional. Custom meta $key => $value pairs to use. Default empty array.
     * @phpstan-return void
     */
    function populate_site_meta($site_id, array $meta = array())
    {
    }
    /**
     * Get the column headers for a screen
     *
     * @since 2.7.0
     *
     * @param string|WP_Screen $screen The screen you want the headers for
     * @return string[] The column header labels keyed by column ID.
     */
    function get_column_headers($screen)
    {
    }
    /**
     * Get a list of hidden columns.
     *
     * @since 2.7.0
     *
     * @param string|WP_Screen $screen The screen you want the hidden columns for
     * @return string[] Array of IDs of hidden columns.
     */
    function get_hidden_columns($screen)
    {
    }
    /**
     * Prints the meta box preferences for screen meta.
     *
     * @since 2.7.0
     *
     * @global array $wp_meta_boxes Global meta box state.
     *
     * @param WP_Screen $screen
     * @phpstan-return void
     */
    function meta_box_prefs($screen)
    {
    }
    /**
     * Gets an array of IDs of hidden meta boxes.
     *
     * @since 2.7.0
     *
     * @param string|WP_Screen $screen Screen identifier
     * @return string[] IDs of hidden meta boxes.
     */
    function get_hidden_meta_boxes($screen)
    {
    }
    /**
     * Register and configure an admin screen option
     *
     * @since 3.1.0
     *
     * @param string $option An option name.
     * @param mixed  $args   Option-dependent arguments.
     * @phpstan-return void
     */
    function add_screen_option($option, $args = array())
    {
    }
    /**
     * Get the current screen object
     *
     * @since 3.1.0
     *
     * @global WP_Screen $current_screen WordPress current screen object.
     *
     * @return WP_Screen|null Current screen object or null when screen not defined.
     */
    function get_current_screen()
    {
    }
    /**
     * Set the current screen object
     *
     * @since 3.0.0
     *
     * @param string|WP_Screen $hook_name Optional. The hook name (also known as the hook suffix) used to determine the screen,
     *                                    or an existing screen object.
     */
    function set_current_screen($hook_name = '')
    {
    }
    /**
     * Checks whether a category exists.
     *
     * @since 2.0.0
     *
     * @see term_exists()
     *
     * @param int|string $cat_name        Category name.
     * @param int        $category_parent Optional. ID of parent category.
     * @return string|null Returns the category ID as a numeric string if the pairing exists, null if not.
     */
    function category_exists($cat_name, $category_parent = \null)
    {
    }
    /**
     * Gets category object for given ID and 'edit' filter context.
     *
     * @since 2.0.0
     *
     * @param int $id
     * @return object
     */
    function get_category_to_edit($id)
    {
    }
    /**
     * Adds a new category to the database if it does not already exist.
     *
     * @since 2.0.0
     *
     * @param int|string $cat_name        Category name.
     * @param int        $category_parent Optional. ID of parent category.
     * @return int|WP_Error
     */
    function wp_create_category($cat_name, $category_parent = 0)
    {
    }
    /**
     * Creates categories for the given post.
     *
     * @since 2.0.0
     *
     * @param string[] $categories Array of category names to create.
     * @param int      $post_id    Optional. The post ID. Default empty.
     * @return int[] Array of IDs of categories assigned to the given post.
     */
    function wp_create_categories($categories, $post_id = '')
    {
    }
    /**
     * Updates an existing Category or creates a new Category.
     *
     * @since 2.0.0
     * @since 2.5.0 $wp_error parameter was added.
     * @since 3.0.0 The 'taxonomy' argument was added.
     *
     * @param array $catarr {
     *     Array of arguments for inserting a new category.
     *
     *     @type int        $cat_ID               Category ID. A non-zero value updates an existing category.
     *                                            Default 0.
     *     @type string     $taxonomy             Taxonomy slug. Default 'category'.
     *     @type string     $cat_name             Category name. Default empty.
     *     @type string     $category_description Category description. Default empty.
     *     @type string     $category_nicename    Category nice (display) name. Default empty.
     *     @type int|string $category_parent      Category parent ID. Default empty.
     * }
     * @param bool  $wp_error Optional. Default false.
     * @return int|WP_Error The ID number of the new or updated Category on success. Zero or a WP_Error on failure,
     *                      depending on param `$wp_error`.
     * @phpstan-param array{
     *   cat_ID?: int,
     *   taxonomy?: string,
     *   cat_name?: string,
     *   category_description?: string,
     *   category_nicename?: string,
     *   category_parent?: int|string,
     * } $catarr
     * @phpstan-return ($wp_error is false ? int<0, max> : int<1, max>|\WP_Error)
     */
    function wp_insert_category($catarr, $wp_error = \false)
    {
    }
    /**
     * Aliases wp_insert_category() with minimal args.
     *
     * If you want to update only some fields of an existing category, call this
     * function with only the new values set inside $catarr.
     *
     * @since 2.0.0
     *
     * @param array $catarr The 'cat_ID' value is required. All other keys are optional.
     * @return int|false The ID number of the new or updated Category on success. Zero or FALSE on failure.
     */
    function wp_update_category($catarr)
    {
    }
    /**
     * Checks whether a post tag with a given name exists.
     *
     * @since 2.3.0
     *
     * @param int|string $tag_name
     * @return mixed Returns null if the term does not exist.
     *               Returns an array of the term ID and the term taxonomy ID if the pairing exists.
     *               Returns 0 if term ID 0 is passed to the function.
     * @phpstan-return ($tag_name is 0 ? 0 : ($tag_name is '' ? null : array{term_id: string, term_taxonomy_id: string}|null))
     */
    function tag_exists($tag_name)
    {
    }
    /**
     * Adds a new tag to the database if it does not already exist.
     *
     * @since 2.3.0
     *
     * @param int|string $tag_name
     * @return array|WP_Error
     */
    function wp_create_tag($tag_name)
    {
    }
    /**
     * Gets comma-separated list of tags available to edit.
     *
     * @since 2.3.0
     *
     * @param int    $post_id
     * @param string $taxonomy Optional. The taxonomy for which to retrieve terms. Default 'post_tag'.
     * @return string|false|WP_Error
     */
    function get_tags_to_edit($post_id, $taxonomy = 'post_tag')
    {
    }
    /**
     * Gets comma-separated list of terms available to edit for the given post ID.
     *
     * @since 2.8.0
     *
     * @param int    $post_id
     * @param string $taxonomy Optional. The taxonomy for which to retrieve terms. Default 'post_tag'.
     * @return string|false|WP_Error
     */
    function get_terms_to_edit($post_id, $taxonomy = 'post_tag')
    {
    }
    /**
     * Adds a new term to the database if it does not already exist.
     *
     * @since 2.8.0
     *
     * @param string $tag_name The term name.
     * @param string $taxonomy Optional. The taxonomy within which to create the term. Default 'post_tag'.
     * @return array|WP_Error
     */
    function wp_create_term($tag_name, $taxonomy = 'post_tag')
    {
    }
    /**
     * Outputs an unordered list of checkbox input elements labeled with category names.
     *
     * @since 2.5.1
     *
     * @see wp_terms_checklist()
     *
     * @param int         $post_id              Optional. Post to generate a categories checklist for. Default 0.
     *                                          $selected_cats must not be an array. Default 0.
     * @param int         $descendants_and_self Optional. ID of the category to output along with its descendants.
     *                                          Default 0.
     * @param int[]|false $selected_cats        Optional. Array of category IDs to mark as checked. Default false.
     * @param int[]|false $popular_cats         Optional. Array of category IDs to receive the "popular-category" class.
     *                                          Default false.
     * @param Walker      $walker               Optional. Walker object to use to build the output.
     *                                          Default is a Walker_Category_Checklist instance.
     * @param bool        $checked_ontop        Optional. Whether to move checked items out of the hierarchy and to
     *                                          the top of the list. Default true.
     */
    function wp_category_checklist($post_id = 0, $descendants_and_self = 0, $selected_cats = \false, $popular_cats = \false, $walker = \null, $checked_ontop = \true)
    {
    }
    /**
     * Outputs an unordered list of checkbox input elements labelled with term names.
     *
     * Taxonomy-independent version of wp_category_checklist().
     *
     * @since 3.0.0
     * @since 4.4.0 Introduced the `$echo` argument.
     *
     * @param int          $post_id Optional. Post ID. Default 0.
     * @param array|string $args {
     *     Optional. Array or string of arguments for generating a terms checklist. Default empty array.
     *
     *     @type int    $descendants_and_self ID of the category to output along with its descendants.
     *                                        Default 0.
     *     @type int[]  $selected_cats        Array of category IDs to mark as checked. Default false.
     *     @type int[]  $popular_cats         Array of category IDs to receive the "popular-category" class.
     *                                        Default false.
     *     @type Walker $walker               Walker object to use to build the output. Default empty which
     *                                        results in a Walker_Category_Checklist instance being used.
     *     @type string $taxonomy             Taxonomy to generate the checklist for. Default 'category'.
     *     @type bool   $checked_ontop        Whether to move checked items out of the hierarchy and to
     *                                        the top of the list. Default true.
     *     @type bool   $echo                 Whether to echo the generated markup. False to return the markup instead
     *                                        of echoing it. Default true.
     * }
     * @return string HTML list of input elements.
     * @phpstan-param array{
     *   descendants_and_self?: int,
     *   selected_cats?: int[],
     *   popular_cats?: int[],
     *   walker?: Walker,
     *   taxonomy?: string,
     *   checked_ontop?: bool,
     *   echo?: bool,
     * } $args
     */
    function wp_terms_checklist($post_id = 0, $args = array())
    {
    }
    /**
     * Retrieves a list of the most popular terms from the specified taxonomy.
     *
     * If the `$display` argument is true then the elements for a list of checkbox
     * `<input>` elements labelled with the names of the selected terms is output.
     * If the `$post_ID` global is not empty then the terms associated with that
     * post will be marked as checked.
     *
     * @since 2.5.0
     *
     * @param string $taxonomy     Taxonomy to retrieve terms from.
     * @param int    $default_term Optional. Not used.
     * @param int    $number       Optional. Number of terms to retrieve. Default 10.
     * @param bool   $display      Optional. Whether to display the list as well. Default true.
     * @return int[] Array of popular term IDs.
     */
    function wp_popular_terms_checklist($taxonomy, $default_term = 0, $number = 10, $display = \true)
    {
    }
    /**
     * Outputs a link category checklist element.
     *
     * @since 2.5.1
     *
     * @param int $link_id Optional. The link ID. Default 0.
     * @phpstan-return void
     */
    function wp_link_category_checklist($link_id = 0)
    {
    }
    /**
     * Adds hidden fields with the data for use in the inline editor for posts and pages.
     *
     * @since 2.7.0
     *
     * @param WP_Post $post Post object.
     * @phpstan-return void
     */
    function get_inline_data($post)
    {
    }
    /**
     * Outputs the in-line comment reply-to form in the Comments list table.
     *
     * @since 2.7.0
     *
     * @global WP_List_Table $wp_list_table
     *
     * @param int    $position  Optional. The value of the 'position' input field. Default 1.
     * @param bool   $checkbox  Optional. The value of the 'checkbox' input field. Default false.
     * @param string $mode      Optional. If set to 'single', will use WP_Post_Comments_List_Table,
     *                          otherwise WP_Comments_List_Table. Default 'single'.
     * @param bool   $table_row Optional. Whether to use a table instead of a div element. Default true.
     * @phpstan-return void
     */
    function wp_comment_reply($position = 1, $checkbox = \false, $mode = 'single', $table_row = \true)
    {
    }
    /**
     * Outputs 'undo move to Trash' text for comments.
     *
     * @since 2.9.0
     */
    function wp_comment_trashnotice()
    {
    }
    /**
     * Outputs a post's public meta data in the Custom Fields meta box.
     *
     * @since 1.2.0
     *
     * @param array[] $meta An array of meta data arrays keyed on 'meta_key' and 'meta_value'.
     * @phpstan-return void
     */
    function list_meta($meta)
    {
    }
    /**
     * Outputs a single row of public meta data in the Custom Fields meta box.
     *
     * @since 2.5.0
     *
     * @param array $entry An array of meta data keyed on 'meta_key' and 'meta_value'.
     * @param int   $count Reference to the row number.
     * @return string A single row of public meta data.
     */
    function _list_meta_row($entry, &$count)
    {
    }
    /**
     * Prints the form in the Custom Fields meta box.
     *
     * @since 1.2.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param WP_Post $post Optional. The post being edited.
     */
    function meta_form($post = \null)
    {
    }
    /**
     * Prints out HTML form date elements for editing post or comment publish date.
     *
     * @since 0.71
     * @since 4.4.0 Converted to use get_comment() instead of the global `$comment`.
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     *
     * @param int|bool $edit      Accepts 1|true for editing the date, 0|false for adding the date.
     * @param int|bool $for_post  Accepts 1|true for applying the date to a post, 0|false for a comment.
     * @param int      $tab_index The tabindex attribute to add. Default 0.
     * @param int|bool $multi     Optional. Whether the additional fields and buttons should be added.
     *                            Default 0|false.
     * @phpstan-return void
     */
    function touch_time($edit = 1, $for_post = 1, $tab_index = 0, $multi = 0)
    {
    }
    /**
     * Prints out option HTML elements for the page templates drop-down.
     *
     * @since 1.5.0
     * @since 4.7.0 Added the `$post_type` parameter.
     *
     * @param string $default_template Optional. The template file name. Default empty.
     * @param string $post_type        Optional. Post type to get templates for. Default 'page'.
     */
    function page_template_dropdown($default_template = '', $post_type = 'page')
    {
    }
    /**
     * Prints out option HTML elements for the page parents drop-down.
     *
     * @since 1.5.0
     * @since 4.4.0 `$post` argument was added.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int         $default_page Optional. The default page ID to be pre-selected. Default 0.
     * @param int         $parent_page  Optional. The parent page ID. Default 0.
     * @param int         $level        Optional. Page depth level. Default 0.
     * @param int|WP_Post $post         Post ID or WP_Post object.
     * @return void|false Void on success, false if the page has no children.
     */
    function parent_dropdown($default_page = 0, $parent_page = 0, $level = 0, $post = \null)
    {
    }
    /**
     * Prints out option HTML elements for role selectors.
     *
     * @since 2.1.0
     *
     * @param string $selected Slug for the role that should be already selected.
     */
    function wp_dropdown_roles($selected = '')
    {
    }
    /**
     * Outputs the form used by the importers to accept the data to be imported.
     *
     * @since 2.0.0
     *
     * @param string $action The action attribute for the form.
     */
    function wp_import_upload_form($action)
    {
    }
    /**
     * Adds a meta box to one or more screens.
     *
     * @since 2.5.0
     * @since 4.4.0 The `$screen` parameter now accepts an array of screen IDs.
     *
     * @global array $wp_meta_boxes Global meta box state.
     *
     * @param string                 $id            Meta box ID (used in the 'id' attribute for the meta box).
     * @param string                 $title         Title of the meta box.
     * @param callable               $callback      Function that fills the box with the desired content.
     *                                              The function should echo its output.
     * @param string|array|WP_Screen $screen        Optional. The screen or screens on which to show the box
     *                                              (such as a post type, 'link', or 'comment'). Accepts a single
     *                                              screen ID, WP_Screen object, or array of screen IDs. Default
     *                                              is the current screen.  If you have used add_menu_page() or
     *                                              add_submenu_page() to create a new screen (and hence screen_id),
     *                                              make sure your menu slug conforms to the limits of sanitize_key()
     *                                              otherwise the 'screen' menu may not correctly render on your page.
     * @param string                 $context       Optional. The context within the screen where the box
     *                                              should display. Available contexts vary from screen to
     *                                              screen. Post edit screen contexts include 'normal', 'side',
     *                                              and 'advanced'. Comments screen contexts include 'normal'
     *                                              and 'side'. Menus meta boxes (accordion sections) all use
     *                                              the 'side' context. Global default is 'advanced'.
     * @param string                 $priority      Optional. The priority within the context where the box should show.
     *                                              Accepts 'high', 'core', 'default', or 'low'. Default 'default'.
     * @param array                  $callback_args Optional. Data that should be set as the $args property
     *                                              of the box array (which is the second parameter passed
     *                                              to your callback). Default null.
     * @phpstan-param 'high'|'core'|'default'|'low' $priority
     * @phpstan-return void
     */
    function add_meta_box($id, $title, $callback, $screen = \null, $context = 'advanced', $priority = 'default', $callback_args = \null)
    {
    }
    /**
     * Renders a "fake" meta box with an information message,
     * shown on the block editor, when an incompatible meta box is found.
     *
     * @since 5.0.0
     *
     * @param mixed $data_object The data object being rendered on this screen.
     * @param array $box         {
     *     Custom formats meta box arguments.
     *
     *     @type string   $id           Meta box 'id' attribute.
     *     @type string   $title        Meta box title.
     *     @type callable $old_callback The original callback for this meta box.
     *     @type array    $args         Extra meta box arguments.
     * }
     * @phpstan-param array{
     *   id?: string,
     *   title?: string,
     *   old_callback?: callable,
     *   args?: array,
     * } $box
     */
    function do_block_editor_incompatible_meta_box($data_object, $box)
    {
    }
    /**
     * Internal helper function to find the plugin from a meta box callback.
     *
     * @since 5.0.0
     *
     * @access private
     *
     * @param callable $callback The callback function to check.
     * @return array|null The plugin that the callback belongs to, or null if it doesn't belong to a plugin.
     */
    function _get_plugin_from_callback($callback)
    {
    }
    /**
     * Meta-Box template function.
     *
     * @since 2.5.0
     *
     * @global array $wp_meta_boxes Global meta box state.
     *
     * @param string|WP_Screen $screen      The screen identifier. If you have used add_menu_page() or
     *                                      add_submenu_page() to create a new screen (and hence screen_id)
     *                                      make sure your menu slug conforms to the limits of sanitize_key()
     *                                      otherwise the 'screen' menu may not correctly render on your page.
     * @param string           $context     The screen context for which to display meta boxes.
     * @param mixed            $data_object Gets passed to the meta box callback function as the first parameter.
     *                                      Often this is the object that's the focus of the current screen,
     *                                      for example a `WP_Post` or `WP_Comment` object.
     * @return int Number of meta_boxes.
     */
    function do_meta_boxes($screen, $context, $data_object)
    {
    }
    /**
     * Removes a meta box from one or more screens.
     *
     * @since 2.6.0
     * @since 4.4.0 The `$screen` parameter now accepts an array of screen IDs.
     *
     * @global array $wp_meta_boxes Global meta box state.
     *
     * @param string                 $id      Meta box ID (used in the 'id' attribute for the meta box).
     * @param string|array|WP_Screen $screen  The screen or screens on which the meta box is shown (such as a
     *                                        post type, 'link', or 'comment'). Accepts a single screen ID,
     *                                        WP_Screen object, or array of screen IDs.
     * @param string                 $context The context within the screen where the box is set to display.
     *                                        Contexts vary from screen to screen. Post edit screen contexts
     *                                        include 'normal', 'side', and 'advanced'. Comments screen contexts
     *                                        include 'normal' and 'side'. Menus meta boxes (accordion sections)
     *                                        all use the 'side' context.
     * @phpstan-return void
     */
    function remove_meta_box($id, $screen, $context)
    {
    }
    /**
     * Meta Box Accordion Template Function.
     *
     * Largely made up of abstracted code from do_meta_boxes(), this
     * function serves to build meta boxes as list items for display as
     * a collapsible accordion.
     *
     * @since 3.6.0
     *
     * @uses global $wp_meta_boxes Used to retrieve registered meta boxes.
     *
     * @param string|object $screen      The screen identifier.
     * @param string        $context     The screen context for which to display accordion sections.
     * @param mixed         $data_object Gets passed to the section callback function as the first parameter.
     * @return int Number of meta boxes as accordion sections.
     */
    function do_accordion_sections($screen, $context, $data_object)
    {
    }
    /**
     * Adds a new section to a settings page.
     *
     * Part of the Settings API. Use this to define new settings sections for an admin page.
     * Show settings sections in your admin page callback function with do_settings_sections().
     * Add settings fields to your section with add_settings_field().
     *
     * The $callback argument should be the name of a function that echoes out any
     * content you want to show at the top of the settings section before the actual
     * fields. It can output nothing if you want.
     *
     * @since 2.7.0
     * @since 6.1.0 Added an `$args` parameter for the section's HTML wrapper and class name.
     *
     * @global array $wp_settings_sections Storage array of all settings sections added to admin pages.
     *
     * @param string   $id       Slug-name to identify the section. Used in the 'id' attribute of tags.
     * @param string   $title    Formatted title of the section. Shown as the heading for the section.
     * @param callable $callback Function that echos out any content at the top of the section (between heading and fields).
     * @param string   $page     The slug-name of the settings page on which to show the section. Built-in pages include
     *                           'general', 'reading', 'writing', 'discussion', 'media', etc. Create your own using
     *                           add_options_page();
     * @param array    $args     {
     *     Arguments used to create the settings section.
     *
     *     @type string $before_section HTML content to prepend to the section's HTML output.
     *                                  Receives the section's class name as `%s`. Default empty.
     *     @type string $after_section  HTML content to append to the section's HTML output. Default empty.
     *     @type string $section_class  The class name to use for the section. Default empty.
     * }
     * @phpstan-param array{
     *   before_section?: string,
     *   after_section?: string,
     *   section_class?: string,
     * } $args
     */
    function add_settings_section($id, $title, $callback, $page, $args = array())
    {
    }
    /**
     * Adds a new field to a section of a settings page.
     *
     * Part of the Settings API. Use this to define a settings field that will show
     * as part of a settings section inside a settings page. The fields are shown using
     * do_settings_fields() in do_settings_sections().
     *
     * The $callback argument should be the name of a function that echoes out the
     * HTML input tags for this setting field. Use get_option() to retrieve existing
     * values to show.
     *
     * @since 2.7.0
     * @since 4.2.0 The `$class` argument was added.
     *
     * @global array $wp_settings_fields Storage array of settings fields and info about their pages/sections.
     *
     * @param string   $id       Slug-name to identify the field. Used in the 'id' attribute of tags.
     * @param string   $title    Formatted title of the field. Shown as the label for the field
     *                           during output.
     * @param callable $callback Function that fills the field with the desired form inputs. The
     *                           function should echo its output.
     * @param string   $page     The slug-name of the settings page on which to show the section
     *                           (general, reading, writing, ...).
     * @param string   $section  Optional. The slug-name of the section of the settings page
     *                           in which to show the box. Default 'default'.
     * @param array    $args {
     *     Optional. Extra arguments that get passed to the callback function.
     *
     *     @type string $label_for When supplied, the setting title will be wrapped
     *                             in a `<label>` element, its `for` attribute populated
     *                             with this value.
     *     @type string $class     CSS Class to be added to the `<tr>` element when the
     *                             field is output.
     * }
     * @phpstan-param array{
     *   label_for?: string,
     *   class?: string,
     * } $args
     */
    function add_settings_field($id, $title, $callback, $page, $section = 'default', $args = array())
    {
    }
    /**
     * Prints out all settings sections added to a particular settings page.
     *
     * Part of the Settings API. Use this in a settings page callback function
     * to output all the sections and fields that were added to that $page with
     * add_settings_section() and add_settings_field()
     *
     * @global array $wp_settings_sections Storage array of all settings sections added to admin pages.
     * @global array $wp_settings_fields Storage array of settings fields and info about their pages/sections.
     * @since 2.7.0
     *
     * @param string $page The slug name of the page whose settings sections you want to output.
     * @phpstan-return void
     */
    function do_settings_sections($page)
    {
    }
    /**
     * Prints out the settings fields for a particular settings section.
     *
     * Part of the Settings API. Use this in a settings page to output
     * a specific section. Should normally be called by do_settings_sections()
     * rather than directly.
     *
     * @global array $wp_settings_fields Storage array of settings fields and their pages/sections.
     *
     * @since 2.7.0
     *
     * @param string $page Slug title of the admin page whose settings fields you want to show.
     * @param string $section Slug title of the settings section whose fields you want to show.
     * @phpstan-return void
     */
    function do_settings_fields($page, $section)
    {
    }
    /**
     * Registers a settings error to be displayed to the user.
     *
     * Part of the Settings API. Use this to show messages to users about settings validation
     * problems, missing settings or anything else.
     *
     * Settings errors should be added inside the $sanitize_callback function defined in
     * register_setting() for a given setting to give feedback about the submission.
     *
     * By default messages will show immediately after the submission that generated the error.
     * Additional calls to settings_errors() can be used to show errors even when the settings
     * page is first accessed.
     *
     * @since 3.0.0
     * @since 5.3.0 Added `warning` and `info` as possible values for `$type`.
     *
     * @global array[] $wp_settings_errors Storage array of errors registered during this pageload
     *
     * @param string $setting Slug title of the setting to which this error applies.
     * @param string $code    Slug-name to identify the error. Used as part of 'id' attribute in HTML output.
     * @param string $message The formatted message text to display to the user (will be shown inside styled
     *                        `<div>` and `<p>` tags).
     * @param string $type    Optional. Message type, controls HTML class. Possible values include 'error',
     *                        'success', 'warning', 'info'. Default 'error'.
     */
    function add_settings_error($setting, $code, $message, $type = 'error')
    {
    }
    /**
     * Fetches settings errors registered by add_settings_error().
     *
     * Checks the $wp_settings_errors array for any errors declared during the current
     * pageload and returns them.
     *
     * If changes were just submitted ($_GET['settings-updated']) and settings errors were saved
     * to the 'settings_errors' transient then those errors will be returned instead. This
     * is used to pass errors back across pageloads.
     *
     * Use the $sanitize argument to manually re-sanitize the option before returning errors.
     * This is useful if you have errors or notices you want to show even when the user
     * hasn't submitted data (i.e. when they first load an options page, or in the {@see 'admin_notices'}
     * action hook).
     *
     * @since 3.0.0
     *
     * @global array[] $wp_settings_errors Storage array of errors registered during this pageload
     *
     * @param string $setting  Optional. Slug title of a specific setting whose errors you want.
     * @param bool   $sanitize Optional. Whether to re-sanitize the setting value before returning errors.
     * @return array[] {
     *     Array of settings error arrays.
     *
     *     @type array ...$0 {
     *         Associative array of setting error data.
     *
     *         @type string $setting Slug title of the setting to which this error applies.
     *         @type string $code    Slug-name to identify the error. Used as part of 'id' attribute in HTML output.
     *         @type string $message The formatted message text to display to the user (will be shown inside styled
     *                               `<div>` and `<p>` tags).
     *         @type string $type    Optional. Message type, controls HTML class. Possible values include 'error',
     *                               'success', 'warning', 'info'. Default 'error'.
     *     }
     * }
     * @phpstan-return array<int|string, array{
     *   setting: string,
     *   code: string,
     *   message: string,
     *   type: string,
     * }>
     */
    function get_settings_errors($setting = '', $sanitize = \false)
    {
    }
    /**
     * Displays settings errors registered by add_settings_error().
     *
     * Part of the Settings API. Outputs a div for each error retrieved by
     * get_settings_errors().
     *
     * This is called automatically after a settings page based on the
     * Settings API is submitted. Errors should be added during the validation
     * callback function for a setting defined in register_setting().
     *
     * The $sanitize option is passed into get_settings_errors() and will
     * re-run the setting sanitization
     * on its current value.
     *
     * The $hide_on_update option will cause errors to only show when the settings
     * page is first loaded. if the user has already saved new values it will be
     * hidden to avoid repeating messages already shown in the default error
     * reporting after submission. This is useful to show general errors like
     * missing settings when the user arrives at the settings page.
     *
     * @since 3.0.0
     * @since 5.3.0 Legacy `error` and `updated` CSS classes are mapped to
     *              `notice-error` and `notice-success`.
     *
     * @param string $setting        Optional slug title of a specific setting whose errors you want.
     * @param bool   $sanitize       Whether to re-sanitize the setting value before returning errors.
     * @param bool   $hide_on_update If set to true errors will not be shown if the settings page has
     *                               already been submitted.
     * @phpstan-return void
     */
    function settings_errors($setting = '', $sanitize = \false, $hide_on_update = \false)
    {
    }
    /**
     * Outputs the modal window used for attaching media to posts or pages in the media-listing screen.
     *
     * @since 2.7.0
     *
     * @param string $found_action Optional. The value of the 'found_action' input field. Default empty string.
     */
    function find_posts_div($found_action = '')
    {
    }
    /**
     * Displays the post password.
     *
     * The password is passed through esc_attr() to ensure that it is safe for placing in an HTML attribute.
     *
     * @since 2.7.0
     */
    function the_post_password()
    {
    }
    /**
     * Gets the post title.
     *
     * The post title is fetched and if it is blank then a default string is
     * returned.
     *
     * @since 2.7.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return string The post title if set.
     */
    function _draft_or_post_title($post = 0)
    {
    }
    /**
     * Displays the search query.
     *
     * A simple wrapper to display the "s" parameter in a `GET` URI. This function
     * should only be used when the_search_query() cannot.
     *
     * @since 2.7.0
     */
    function _admin_search_query()
    {
    }
    /**
     * Generic Iframe header for use with Thickbox.
     *
     * @since 2.7.0
     *
     * @global string    $hook_suffix
     * @global string    $admin_body_class
     * @global string    $body_id
     * @global WP_Locale $wp_locale        WordPress date and time locale object.
     *
     * @param string $title      Optional. Title of the Iframe page. Default empty.
     * @param bool   $deprecated Not used.
     */
    function iframe_header($title = '', $deprecated = \false)
    {
    }
    /**
     * Generic Iframe footer for use with Thickbox.
     *
     * @since 2.7.0
     */
    function iframe_footer()
    {
    }
    /**
     * Echoes or returns the post states as HTML.
     *
     * @since 2.7.0
     * @since 5.3.0 Added the `$display` parameter and a return value.
     *
     * @see get_post_states()
     *
     * @param WP_Post $post    The post to retrieve states for.
     * @param bool    $display Optional. Whether to display the post states as an HTML string.
     *                         Default true.
     * @return string Post states string.
     */
    function _post_states($post, $display = \true)
    {
    }
    /**
     * Retrieves an array of post states from a post.
     *
     * @since 5.3.0
     *
     * @param WP_Post $post The post to retrieve states for.
     * @return string[] Array of post state labels keyed by their state.
     */
    function get_post_states($post)
    {
    }
    /**
     * Outputs the attachment media states as HTML.
     *
     * @since 3.2.0
     * @since 5.6.0 Added the `$display` parameter and a return value.
     *
     * @param WP_Post $post    The attachment post to retrieve states for.
     * @param bool    $display Optional. Whether to display the post states as an HTML string.
     *                         Default true.
     * @return string Media states string.
     */
    function _media_states($post, $display = \true)
    {
    }
    /**
     * Retrieves an array of media states from an attachment.
     *
     * @since 5.6.0
     *
     * @param WP_Post $post The attachment to retrieve states for.
     * @return string[] Array of media state labels keyed by their state.
     */
    function get_media_states($post)
    {
    }
    /**
     * Tests support for compressing JavaScript from PHP.
     *
     * Outputs JavaScript that tests if compression from PHP works as expected
     * and sets an option with the result. Has no effect when the current user
     * is not an administrator. To run the test again the option 'can_compress_scripts'
     * has to be deleted.
     *
     * @since 2.8.0
     */
    function compression_test()
    {
    }
    /**
     * Echoes a submit button, with provided text and appropriate class(es).
     *
     * @since 3.1.0
     *
     * @see get_submit_button()
     *
     * @param string       $text             Optional. The text of the button. Defaults to 'Save Changes'.
     * @param string       $type             Optional. The type and CSS class(es) of the button. Core values
     *                                       include 'primary', 'small', and 'large'. Default 'primary'.
     * @param string       $name             Optional. The HTML name of the submit button. If no `id` attribute
     *                                       is given in the `$other_attributes` parameter, `$name` will be used
     *                                       as the button's `id`. Default 'submit'.
     * @param bool         $wrap             Optional. True if the output button should be wrapped in a paragraph tag,
     *                                       false otherwise. Default true.
     * @param array|string $other_attributes Optional. Other attributes that should be output with the button,
     *                                       mapping attributes to their values, e.g. `array( 'id' => 'search-submit' )`.
     *                                       These key/value attribute pairs will be output as `attribute="value"`,
     *                                       where attribute is the key. Attributes can also be provided as a string,
     *                                       e.g. `id="search-submit"`, though the array format is generally preferred.
     *                                       Default empty string.
     */
    function submit_button($text = '', $type = 'primary', $name = 'submit', $wrap = \true, $other_attributes = '')
    {
    }
    /**
     * Returns a submit button, with provided text and appropriate class.
     *
     * @since 3.1.0
     *
     * @param string       $text             Optional. The text of the button. Defaults to 'Save Changes'.
     * @param string       $type             Optional. The type and CSS class(es) of the button. Core values
     *                                       include 'primary', 'small', and 'large'. Default 'primary large'.
     * @param string       $name             Optional. The HTML name of the submit button. If no `id` attribute
     *                                       is given in the `$other_attributes` parameter, `$name` will be used
     *                                       as the button's `id`. Default 'submit'.
     * @param bool         $wrap             Optional. True if the output button should be wrapped in a paragraph tag,
     *                                       false otherwise. Default true.
     * @param array|string $other_attributes Optional. Other attributes that should be output with the button,
     *                                       mapping attributes to their values, e.g. `array( 'id' => 'search-submit' )`.
     *                                       These key/value attribute pairs will be output as `attribute="value"`,
     *                                       where attribute is the key. Attributes can also be provided as a string,
     *                                       e.g. `id="search-submit"`, though the array format is generally preferred.
     *                                       Default empty string.
     * @return string Submit button HTML.
     */
    function get_submit_button($text = '', $type = 'primary large', $name = 'submit', $wrap = \true, $other_attributes = '')
    {
    }
    /**
     * Prints out the beginning of the admin HTML header.
     *
     * @global bool $is_IE
     */
    function _wp_admin_html_begin()
    {
    }
    /**
     * Converts a screen string to a screen object.
     *
     * @since 3.0.0
     *
     * @param string $hook_name The hook name (also known as the hook suffix) used to determine the screen.
     * @return WP_Screen Screen object.
     */
    function convert_to_screen($hook_name)
    {
    }
    /**
     * Outputs the HTML for restoring the post data from DOM storage
     *
     * @since 3.6.0
     * @access private
     */
    function _local_storage_notice()
    {
    }
    /**
     * Outputs a HTML element with a star rating for a given rating.
     *
     * Outputs a HTML element with the star rating exposed on a 0..5 scale in
     * half star increments (ie. 1, 1.5, 2 stars). Optionally, if specified, the
     * number of ratings may also be displayed by passing the $number parameter.
     *
     * @since 3.8.0
     * @since 4.4.0 Introduced the `echo` parameter.
     *
     * @param array $args {
     *     Optional. Array of star ratings arguments.
     *
     *     @type int|float $rating The rating to display, expressed in either a 0.5 rating increment,
     *                             or percentage. Default 0.
     *     @type string    $type   Format that the $rating is in. Valid values are 'rating' (default),
     *                             or, 'percent'. Default 'rating'.
     *     @type int       $number The number of ratings that makes up this rating. Default 0.
     *     @type bool      $echo   Whether to echo the generated markup. False to return the markup instead
     *                             of echoing it. Default true.
     * }
     * @return string Star rating HTML.
     * @phpstan-param array{
     *   rating?: int|float,
     *   type?: string,
     *   number?: int,
     *   echo?: bool,
     * } $args
     */
    function wp_star_rating($args = array())
    {
    }
    /**
     * Outputs a notice when editing the page for posts (internal use only).
     *
     * @ignore
     * @since 4.2.0
     */
    function _wp_posts_page_notice()
    {
    }
    /**
     * Outputs a notice when editing the page for posts in the block editor (internal use only).
     *
     * @ignore
     * @since 5.8.0
     */
    function _wp_block_editor_posts_page_notice()
    {
    }
    /**
     * Retrieves the list of WordPress theme features (aka theme tags).
     *
     * @since 2.8.0
     *
     * @deprecated 3.1.0 Use get_theme_feature_list() instead.
     *
     * @return array
     */
    function install_themes_feature_list()
    {
    }
    /**
     * Displays search form for searching themes.
     *
     * @since 2.8.0
     *
     * @param bool $type_selector
     */
    function install_theme_search_form($type_selector = \true)
    {
    }
    /**
     * Displays tags filter for themes.
     *
     * @since 2.8.0
     */
    function install_themes_dashboard()
    {
    }
    /**
     * Displays a form to upload themes from zip files.
     *
     * @since 2.8.0
     */
    function install_themes_upload()
    {
    }
    /**
     * Prints a theme on the Install Themes pages.
     *
     * @deprecated 3.4.0
     *
     * @global WP_Theme_Install_List_Table $wp_list_table
     *
     * @param object $theme
     */
    function display_theme($theme)
    {
    }
    /**
     * Displays theme content based on theme list.
     *
     * @since 2.8.0
     *
     * @global WP_Theme_Install_List_Table $wp_list_table
     */
    function display_themes()
    {
    }
    /**
     * Displays theme information in dialog box form.
     *
     * @since 2.8.0
     *
     * @global WP_Theme_Install_List_Table $wp_list_table
     * @phpstan-return never
     */
    function install_theme_information()
    {
    }
    /**
     * Removes a theme.
     *
     * @since 2.8.0
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     *
     * @param string $stylesheet Stylesheet of the theme to delete.
     * @param string $redirect   Redirect to page when complete.
     * @return bool|null|WP_Error True on success, false if `$stylesheet` is empty, WP_Error on failure.
     *                            Null if filesystem credentials are required to proceed.
     */
    function delete_theme($stylesheet, $redirect = '')
    {
    }
    /**
     * Gets the page templates available in this theme.
     *
     * @since 1.5.0
     * @since 4.7.0 Added the `$post_type` parameter.
     *
     * @param WP_Post|null $post      Optional. The post being edited, provided for context.
     * @param string       $post_type Optional. Post type to get the templates for. Default 'page'.
     * @return string[] Array of template file names keyed by the template header name.
     */
    function get_page_templates($post = \null, $post_type = 'page')
    {
    }
    /**
     * Tidies a filename for url display by the theme file editor.
     *
     * @since 2.9.0
     * @access private
     *
     * @param string $fullpath Full path to the theme file
     * @param string $containingfolder Path of the theme parent folder
     * @return string
     */
    function _get_template_edit_filename($fullpath, $containingfolder)
    {
    }
    /**
     * Check if there is an update for a theme available.
     *
     * Will display link, if there is an update available.
     *
     * @since 2.7.0
     *
     * @see get_theme_update_available()
     *
     * @param WP_Theme $theme Theme data object.
     */
    function theme_update_available($theme)
    {
    }
    /**
     * Retrieves the update link if there is a theme update available.
     *
     * Will return a link if there is an update available.
     *
     * @since 3.8.0
     *
     * @param WP_Theme $theme WP_Theme object.
     * @return string|false HTML for the update link, or false if invalid info was passed.
     */
    function get_theme_update_available($theme)
    {
    }
    /**
     * Retrieves list of WordPress theme features (aka theme tags).
     *
     * @since 3.1.0
     * @since 3.2.0 Added 'Gray' color and 'Featured Image Header', 'Featured Images',
     *              'Full Width Template', and 'Post Formats' features.
     * @since 3.5.0 Added 'Flexible Header' feature.
     * @since 3.8.0 Renamed 'Width' filter to 'Layout'.
     * @since 3.8.0 Renamed 'Fixed Width' and 'Flexible Width' options
     *              to 'Fixed Layout' and 'Fluid Layout'.
     * @since 3.8.0 Added 'Accessibility Ready' feature and 'Responsive Layout' option.
     * @since 3.9.0 Combined 'Layout' and 'Columns' filters.
     * @since 4.6.0 Removed 'Colors' filter.
     * @since 4.6.0 Added 'Grid Layout' option.
     *              Removed 'Fixed Layout', 'Fluid Layout', and 'Responsive Layout' options.
     * @since 4.6.0 Added 'Custom Logo' and 'Footer Widgets' features.
     *              Removed 'Blavatar' feature.
     * @since 4.6.0 Added 'Blog', 'E-Commerce', 'Education', 'Entertainment', 'Food & Drink',
     *              'Holiday', 'News', 'Photography', and 'Portfolio' subjects.
     *              Removed 'Photoblogging' and 'Seasonal' subjects.
     * @since 4.9.0 Reordered the filters from 'Layout', 'Features', 'Subject'
     *              to 'Subject', 'Features', 'Layout'.
     * @since 4.9.0 Removed 'BuddyPress', 'Custom Menu', 'Flexible Header',
     *              'Front Page Posting', 'Microformats', 'RTL Language Support',
     *              'Threaded Comments', and 'Translation Ready' features.
     * @since 5.5.0 Added 'Block Editor Patterns', 'Block Editor Styles',
     *              and 'Full Site Editing' features.
     * @since 5.5.0 Added 'Wide Blocks' layout option.
     * @since 5.8.1 Added 'Template Editing' feature.
     * @since 6.1.1 Replaced 'Full Site Editing' feature name with 'Site Editor'.
     * @since 6.2.0 Added 'Style Variations' feature.
     *
     * @param bool $api Optional. Whether try to fetch tags from the WordPress.org API. Defaults to true.
     * @return array Array of features keyed by category with translations keyed by slug.
     */
    function get_theme_feature_list($api = \true)
    {
    }
    /**
     * Retrieves theme installer pages from the WordPress.org Themes API.
     *
     * It is possible for a theme to override the Themes API result with three
     * filters. Assume this is for themes, which can extend on the Theme Info to
     * offer more choices. This is very powerful and must be used with care, when
     * overriding the filters.
     *
     * The first filter, {@see 'themes_api_args'}, is for the args and gives the action
     * as the second parameter. The hook for {@see 'themes_api_args'} must ensure that
     * an object is returned.
     *
     * The second filter, {@see 'themes_api'}, allows a plugin to override the WordPress.org
     * Theme API entirely. If `$action` is 'query_themes', 'theme_information', or 'feature_list',
     * an object MUST be passed. If `$action` is 'hot_tags', an array should be passed.
     *
     * Finally, the third filter, {@see 'themes_api_result'}, makes it possible to filter the
     * response object or array, depending on the `$action` type.
     *
     * Supported arguments per action:
     *
     * | Argument Name      | 'query_themes' | 'theme_information' | 'hot_tags' | 'feature_list'   |
     * | -------------------| :------------: | :-----------------: | :--------: | :--------------: |
     * | `$slug`            | No             |  Yes                | No         | No               |
     * | `$per_page`        | Yes            |  No                 | No         | No               |
     * | `$page`            | Yes            |  No                 | No         | No               |
     * | `$number`          | No             |  No                 | Yes        | No               |
     * | `$search`          | Yes            |  No                 | No         | No               |
     * | `$tag`             | Yes            |  No                 | No         | No               |
     * | `$author`          | Yes            |  No                 | No         | No               |
     * | `$user`            | Yes            |  No                 | No         | No               |
     * | `$browse`          | Yes            |  No                 | No         | No               |
     * | `$locale`          | Yes            |  Yes                | No         | No               |
     * | `$fields`          | Yes            |  Yes                | No         | No               |
     *
     * @since 2.8.0
     *
     * @param string       $action API action to perform: Accepts 'query_themes', 'theme_information',
     *                             'hot_tags' or 'feature_list'.
     * @param array|object $args   {
     *     Optional. Array or object of arguments to serialize for the Themes API. Default empty array.
     *
     *     @type string  $slug     The theme slug. Default empty.
     *     @type int     $per_page Number of themes per page. Default 24.
     *     @type int     $page     Number of current page. Default 1.
     *     @type int     $number   Number of tags to be queried.
     *     @type string  $search   A search term. Default empty.
     *     @type string  $tag      Tag to filter themes. Default empty.
     *     @type string  $author   Username of an author to filter themes. Default empty.
     *     @type string  $user     Username to query for their favorites. Default empty.
     *     @type string  $browse   Browse view: 'featured', 'popular', 'updated', 'favorites'.
     *     @type string  $locale   Locale to provide context-sensitive results. Default is the value of get_locale().
     *     @type array   $fields   {
     *         Array of fields which should or should not be returned.
     *
     *         @type bool $description        Whether to return the theme full description. Default false.
     *         @type bool $sections           Whether to return the theme readme sections: description, installation,
     *                                        FAQ, screenshots, other notes, and changelog. Default false.
     *         @type bool $rating             Whether to return the rating in percent and total number of ratings.
     *                                        Default false.
     *         @type bool $ratings            Whether to return the number of rating for each star (1-5). Default false.
     *         @type bool $downloaded         Whether to return the download count. Default false.
     *         @type bool $downloadlink       Whether to return the download link for the package. Default false.
     *         @type bool $last_updated       Whether to return the date of the last update. Default false.
     *         @type bool $tags               Whether to return the assigned tags. Default false.
     *         @type bool $homepage           Whether to return the theme homepage link. Default false.
     *         @type bool $screenshots        Whether to return the screenshots. Default false.
     *         @type int  $screenshot_count   Number of screenshots to return. Default 1.
     *         @type bool $screenshot_url     Whether to return the URL of the first screenshot. Default false.
     *         @type bool $photon_screenshots Whether to return the screenshots via Photon. Default false.
     *         @type bool $template           Whether to return the slug of the parent theme. Default false.
     *         @type bool $parent             Whether to return the slug, name and homepage of the parent theme. Default false.
     *         @type bool $versions           Whether to return the list of all available versions. Default false.
     *         @type bool $theme_url          Whether to return theme's URL. Default false.
     *         @type bool $extended_author    Whether to return nicename or nicename and display name. Default false.
     *     }
     * }
     * @return object|array|WP_Error Response object or array on success, WP_Error on failure. See the
     *         {@link https://developer.wordpress.org/reference/functions/themes_api/ function reference article}
     *         for more information on the make-up of possible return objects depending on the value of `$action`.
     * @phpstan-param 'query_themes'|'theme_information'|'hot_tags'|'feature_list' $action
     * @phpstan-param object|array{
     *   slug?: string,
     *   per_page?: int,
     *   page?: int,
     *   number?: int,
     *   search?: string,
     *   tag?: string,
     *   author?: string,
     *   user?: string,
     *   browse?: string,
     *   locale?: string,
     *   fields?: array{
     *     description?: bool,
     *     sections?: bool,
     *     rating?: bool,
     *     ratings?: bool,
     *     downloaded?: bool,
     *     downloadlink?: bool,
     *     last_updated?: bool,
     *     tags?: bool,
     *     homepage?: bool,
     *     screenshots?: bool,
     *     screenshot_count?: int,
     *     screenshot_url?: bool,
     *     photon_screenshots?: bool,
     *     template?: bool,
     *     parent?: bool,
     *     versions?: bool,
     *     theme_url?: bool,
     *     extended_author?: bool,
     *   },
     * } $args
     */
    function themes_api($action, $args = array())
    {
    }
    /**
     * Prepares themes for JavaScript.
     *
     * @since 3.8.0
     *
     * @param WP_Theme[] $themes Optional. Array of theme objects to prepare.
     *                           Defaults to all allowed themes.
     *
     * @return array An associative array of theme data, sorted by name.
     */
    function wp_prepare_themes_for_js($themes = \null)
    {
    }
    /**
     * Prints JS templates for the theme-browsing UI in the Customizer.
     *
     * @since 4.2.0
     */
    function customize_themes_print_templates()
    {
    }
    /**
     * Determines whether a theme is technically active but was paused while
     * loading.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 5.2.0
     *
     * @global WP_Paused_Extensions_Storage $_paused_themes
     *
     * @param string $theme Path to the theme directory relative to the themes directory.
     * @return bool True, if in the list of paused themes. False, not in the list.
     */
    function is_theme_paused($theme)
    {
    }
    /**
     * Gets the error that was recorded for a paused theme.
     *
     * @since 5.2.0
     *
     * @global WP_Paused_Extensions_Storage $_paused_themes
     *
     * @param string $theme Path to the theme directory relative to the themes
     *                      directory.
     * @return array|false Array of error information as it was returned by
     *                     `error_get_last()`, or false if none was recorded.
     */
    function wp_get_theme_error($theme)
    {
    }
    /**
     * Tries to resume a single theme.
     *
     * If a redirect was provided and a functions.php file was found, we first ensure that
     * functions.php file does not throw fatal errors anymore.
     *
     * The way it works is by setting the redirection to the error before trying to
     * include the file. If the theme fails, then the redirection will not be overwritten
     * with the success message and the theme will not be resumed.
     *
     * @since 5.2.0
     *
     * @global string $wp_stylesheet_path Path to current theme's stylesheet directory.
     * @global string $wp_template_path   Path to current theme's template directory.
     *
     * @param string $theme    Single theme to resume.
     * @param string $redirect Optional. URL to redirect to. Default empty string.
     * @return bool|WP_Error True on success, false if `$theme` was not paused,
     *                       `WP_Error` on failure.
     */
    function resume_theme($theme, $redirect = '')
    {
    }
    /**
     * Renders an admin notice in case some themes have been paused due to errors.
     *
     * @since 5.2.0
     *
     * @global string                       $pagenow        The filename of the current screen.
     * @global WP_Paused_Extensions_Storage $_paused_themes
     * @phpstan-return void
     */
    function paused_themes_notice()
    {
    }
    /**
     * Retrieve translations from WordPress Translation API.
     *
     * @since 4.0.0
     *
     * @param string       $type Type of translations. Accepts 'plugins', 'themes', 'core'.
     * @param array|object $args Translation API arguments. Optional.
     * @return array|WP_Error {
     *     On success an associative array of translations, WP_Error on failure.
     *
     *     @type array $translations {
     *         List of translations, each an array of data.
     *
     *         @type array ...$0 {
     *             @type string   $language     Language code.
     *             @type string   $version      WordPress version.
     *             @type string   $updated      Date the translation was last updated, in MySQL datetime format.
     *             @type string   $english_name English name of the language.
     *             @type string   $native_name  Native name of the language.
     *             @type string   $package      URL to download the translation package.
     *             @type string[] $iso          Array of ISO language codes.
     *             @type array    $strings      Array of translated strings used in the installation process.
     *         }
     *     }
     * }
     * @phpstan-return \WP_Error|array{
     *   translations: array<array-key, array{
     *       language: string,
     *       version: string,
     *       updated: string,
     *       english_name: string,
     *       native_name: string,
     *       package: string,
     *       iso: string[],
     *       strings: array,
     *   }>,
     * }
     */
    function translations_api($type, $args = \null)
    {
    }
    /**
     * Get available translations from the WordPress.org API.
     *
     * @since 4.0.0
     *
     * @see translations_api()
     *
     * @return array {
     *     Array of translations keyed by the language code, each an associative array of data.
     *     If the API response results in an error, an empty array will be returned.
     *
     *     @type array ...$0 {
     *         @type string   $language     Language code.
     *         @type string   $version      WordPress version.
     *         @type string   $updated      Date the translation was last updated, in MySQL datetime format.
     *         @type string   $english_name English name of the language.
     *         @type string   $native_name  Native name of the language.
     *         @type string   $package      URL to download the translation package.
     *         @type string[] $iso          Array of ISO language codes.
     *         @type array    $strings      Array of translated strings used in the installation process.
     *     }
     * }
     * @phpstan-return array<int|string, array{
     *   language: string,
     *   version: string,
     *   updated: string,
     *   english_name: string,
     *   native_name: string,
     *   package: string,
     *   iso: string[],
     *   strings: array,
     * }>
     */
    function wp_get_available_translations()
    {
    }
    /**
     * Output the select form for the language selection on the installation screen.
     *
     * @since 4.0.0
     *
     * @global string $wp_local_package Locale code of the package.
     *
     * @param array[] $languages Array of available languages (populated via the Translation API).
     */
    function wp_install_language_form($languages)
    {
    }
    /**
     * Download a language pack.
     *
     * @since 4.0.0
     *
     * @see wp_get_available_translations()
     *
     * @param string $download Language code to download.
     * @return string|false Returns the language code if successfully downloaded
     *                      (or already installed), or false on failure.
     */
    function wp_download_language_pack($download)
    {
    }
    /**
     * Check if WordPress has access to the filesystem without asking for
     * credentials.
     *
     * @since 4.0.0
     *
     * @return bool Returns true on success, false on failure.
     */
    function wp_can_install_language_pack()
    {
    }
    /**
     * Upgrades the core of WordPress.
     *
     * This will create a .maintenance file at the base of the WordPress directory
     * to ensure that people can not access the website, when the files are being
     * copied to their locations.
     *
     * The files in the `$_old_files` list will be removed and the new files
     * copied from the zip file after the database is upgraded.
     *
     * The files in the `$_new_bundled_files` list will be added to the installation
     * if the version is greater than or equal to the old version being upgraded.
     *
     * The steps for the upgrader for after the new release is downloaded and
     * unzipped is:
     *   1. Test unzipped location for select files to ensure that unzipped worked.
     *   2. Create the .maintenance file in current WordPress base.
     *   3. Copy new WordPress directory over old WordPress files.
     *   4. Upgrade WordPress to new version.
     *     4.1. Copy all files/folders other than wp-content
     *     4.2. Copy any language files to WP_LANG_DIR (which may differ from WP_CONTENT_DIR
     *     4.3. Copy any new bundled themes/plugins to their respective locations
     *   5. Delete new WordPress directory path.
     *   6. Delete .maintenance file.
     *   7. Remove old files.
     *   8. Delete 'update_core' option.
     *
     * There are several areas of failure. For instance if PHP times out before step
     * 6, then you will not be able to access any portion of your site. Also, since
     * the upgrade will not continue where it left off, you will not be able to
     * automatically remove old files and remove the 'update_core' option. This
     * isn't that bad.
     *
     * If the copy of the new WordPress over the old fails, then the worse is that
     * the new WordPress directory will remain.
     *
     * If it is assumed that every file will be copied over, including plugins and
     * themes, then if you edit the default theme, you should rename it, so that
     * your changes remain.
     *
     * @since 2.7.0
     *
     * @global WP_Filesystem_Base $wp_filesystem          WordPress filesystem subclass.
     * @global array              $_old_files
     * @global array              $_old_requests_files
     * @global array              $_new_bundled_files
     * @global wpdb               $wpdb                   WordPress database abstraction object.
     * @global string             $wp_version
     * @global string             $required_php_version
     * @global string             $required_mysql_version
     *
     * @param string $from New release unzipped path.
     * @param string $to   Path to old WordPress installation.
     * @return string|WP_Error New WordPress version on success, WP_Error on failure.
     */
    function update_core($from, $to)
    {
    }
    /**
     * Preloads old Requests classes and interfaces.
     *
     * This function preloads the old Requests code into memory before the
     * upgrade process deletes the files. Why? Requests code is loaded into
     * memory via an autoloader, meaning when a class or interface is needed
     * If a request is in process, Requests could attempt to access code. If
     * the file is not there, a fatal error could occur. If the file was
     * replaced, the new code is not compatible with the old, resulting in
     * a fatal error. Preloading ensures the code is in memory before the
     * code is updated.
     *
     * @since 6.2.0
     *
     * @global array              $_old_requests_files Requests files to be preloaded.
     * @global WP_Filesystem_Base $wp_filesystem       WordPress filesystem subclass.
     * @global string             $wp_version          The WordPress version string.
     *
     * @param string $to Path to old WordPress installation.
     * @phpstan-return void
     */
    function _preload_old_requests_classes_and_interfaces($to)
    {
    }
    /**
     * Redirect to the About WordPress page after a successful upgrade.
     *
     * This function is only needed when the existing installation is older than 3.4.0.
     *
     * @since 3.3.0
     *
     * @global string $wp_version The WordPress version string.
     * @global string $pagenow    The filename of the current screen.
     * @global string $action
     *
     * @param string $new_version
     * @phpstan-return void
     */
    function _redirect_to_about_wordpress($new_version)
    {
    }
    /**
     * Cleans up Genericons example files.
     *
     * @since 4.2.2
     *
     * @global array              $wp_theme_directories
     * @global WP_Filesystem_Base $wp_filesystem
     */
    function _upgrade_422_remove_genericons()
    {
    }
    /**
     * Recursively find Genericons example files in a given folder.
     *
     * @ignore
     * @since 4.2.2
     *
     * @param string $directory Directory path. Expects trailingslashed.
     * @return array
     */
    function _upgrade_422_find_genericons_files_in_folder($directory)
    {
    }
    /**
     * @ignore
     * @since 4.4.0
     */
    function _upgrade_440_force_deactivate_incompatible_plugins()
    {
    }
    /**
     * @access private
     * @ignore
     * @since 5.8.0
     * @since 5.9.0 The minimum compatible version of Gutenberg is 11.9.
     * @since 6.1.1 The minimum compatible version of Gutenberg is 14.1.
     * @since 6.4.0 The minimum compatible version of Gutenberg is 16.5.
     * @since 6.5.0 The minimum compatible version of Gutenberg is 17.6.
     */
    function _upgrade_core_deactivate_incompatible_plugins()
    {
    }
    /**
     * Selects the first update version from the update_core option.
     *
     * @since 2.7.0
     *
     * @return object|array|false The response from the API on success, false on failure.
     */
    function get_preferred_from_update_core()
    {
    }
    /**
     * Gets available core updates.
     *
     * @since 2.7.0
     *
     * @param array $options Set $options['dismissed'] to true to show dismissed upgrades too,
     *                       set $options['available'] to false to skip not-dismissed updates.
     * @return array|false Array of the update objects on success, false on failure.
     */
    function get_core_updates($options = array())
    {
    }
    /**
     * Gets the best available (and enabled) Auto-Update for WordPress core.
     *
     * If there's 1.2.3 and 1.3 on offer, it'll choose 1.3 if the installation allows it, else, 1.2.3.
     *
     * @since 3.7.0
     *
     * @return object|false The core update offering on success, false on failure.
     */
    function find_core_auto_update()
    {
    }
    /**
     * Gets and caches the checksums for the given version of WordPress.
     *
     * @since 3.7.0
     *
     * @param string $version Version string to query.
     * @param string $locale  Locale to query.
     * @return array|false An array of checksums on success, false on failure.
     */
    function get_core_checksums($version, $locale)
    {
    }
    /**
     * Dismisses core update.
     *
     * @since 2.7.0
     *
     * @param object $update
     * @return bool
     */
    function dismiss_core_update($update)
    {
    }
    /**
     * Undismisses core update.
     *
     * @since 2.7.0
     *
     * @param string $version
     * @param string $locale
     * @return bool
     */
    function undismiss_core_update($version, $locale)
    {
    }
    /**
     * Finds the available update for WordPress core.
     *
     * @since 2.7.0
     *
     * @param string $version Version string to find the update for.
     * @param string $locale  Locale to find the update for.
     * @return object|false The core update offering on success, false on failure.
     */
    function find_core_update($version, $locale)
    {
    }
    /**
     * Returns core update footer message.
     *
     * @since 2.3.0
     *
     * @param string $msg
     * @return string
     */
    function core_update_footer($msg = '')
    {
    }
    /**
     * Returns core update notification message.
     *
     * @since 2.3.0
     *
     * @global string $pagenow The filename of the current screen.
     * @return void|false
     */
    function update_nag()
    {
    }
    /**
     * Displays WordPress version and active theme in the 'At a Glance' dashboard widget.
     *
     * @since 2.5.0
     */
    function update_right_now_message()
    {
    }
    /**
     * Retrieves plugins with updates available.
     *
     * @since 2.9.0
     *
     * @return array
     */
    function get_plugin_updates()
    {
    }
    /**
     * Adds a callback to display update information for plugins with updates available.
     *
     * @since 2.9.0
     * @phpstan-return void
     */
    function wp_plugin_update_rows()
    {
    }
    /**
     * Displays update information for a plugin.
     *
     * @since 2.3.0
     *
     * @param string $file        Plugin basename.
     * @param array  $plugin_data Plugin information.
     * @return void|false
     */
    function wp_plugin_update_row($file, $plugin_data)
    {
    }
    /**
     * Retrieves themes with updates available.
     *
     * @since 2.9.0
     *
     * @return array
     */
    function get_theme_updates()
    {
    }
    /**
     * Adds a callback to display update information for themes with updates available.
     *
     * @since 3.1.0
     * @phpstan-return void
     */
    function wp_theme_update_rows()
    {
    }
    /**
     * Displays update information for a theme.
     *
     * @since 3.1.0
     *
     * @param string   $theme_key Theme stylesheet.
     * @param WP_Theme $theme     Theme object.
     * @return void|false
     */
    function wp_theme_update_row($theme_key, $theme)
    {
    }
    /**
     * Displays maintenance nag HTML message.
     *
     * @since 2.7.0
     *
     * @global int $upgrading
     *
     * @return void|false
     */
    function maintenance_nag()
    {
    }
    /**
     * Prints the JavaScript templates for update admin notices.
     *
     * @since 4.6.0
     *
     * Template takes one argument with four values:
     *
     *     param {object} data {
     *         Arguments for admin notice.
     *
     *         @type string id        ID of the notice.
     *         @type string className Class names for the notice.
     *         @type string message   The notice's message.
     *         @type string type      The type of update the notice is for. Either 'plugin' or 'theme'.
     *     }
     */
    function wp_print_admin_notice_templates()
    {
    }
    /**
     * Prints the JavaScript templates for update and deletion rows in list tables.
     *
     * @since 4.6.0
     *
     * The update template takes one argument with four values:
     *
     *     param {object} data {
     *         Arguments for the update row
     *
     *         @type string slug    Plugin slug.
     *         @type string plugin  Plugin base name.
     *         @type string colspan The number of table columns this row spans.
     *         @type string content The row content.
     *     }
     *
     * The delete template takes one argument with four values:
     *
     *     param {object} data {
     *         Arguments for the update row
     *
     *         @type string slug    Plugin slug.
     *         @type string plugin  Plugin base name.
     *         @type string name    Plugin name.
     *         @type string colspan The number of table columns this row spans.
     *     }
     */
    function wp_print_update_row_templates()
    {
    }
    /**
     * Displays a notice when the user is in recovery mode.
     *
     * @since 5.2.0
     * @phpstan-return void
     */
    function wp_recovery_mode_nag()
    {
    }
    /**
     * Checks whether auto-updates are enabled.
     *
     * @since 5.5.0
     *
     * @param string $type The type of update being checked: Either 'theme' or 'plugin'.
     * @return bool True if auto-updates are enabled for `$type`, false otherwise.
     * @phpstan-param 'theme'|'plugin' $type
     */
    function wp_is_auto_update_enabled_for_type($type)
    {
    }
    /**
     * Checks whether auto-updates are forced for an item.
     *
     * @since 5.6.0
     *
     * @param string    $type   The type of update being checked: Either 'theme' or 'plugin'.
     * @param bool|null $update Whether to update. The value of null is internally used
     *                          to detect whether nothing has hooked into this filter.
     * @param object    $item   The update offer.
     * @return bool True if auto-updates are forced for `$item`, false otherwise.
     * @phpstan-param 'theme'|'plugin' $type
     */
    function wp_is_auto_update_forced_for_item($type, $update, $item)
    {
    }
    /**
     * Determines the appropriate auto-update message to be displayed.
     *
     * @since 5.5.0
     *
     * @return string The update message to be shown.
     */
    function wp_get_auto_update_message()
    {
    }
    /**
     * Installs the site.
     *
     * Runs the required functions to set up and populate the database,
     * including primary admin user and initial options.
     *
     * @since 2.1.0
     *
     * @param string $blog_title    Site title.
     * @param string $user_name     User's username.
     * @param string $user_email    User's email.
     * @param bool   $is_public     Whether the site is public.
     * @param string $deprecated    Optional. Not used.
     * @param string $user_password Optional. User's chosen password. Default empty (random password).
     * @param string $language      Optional. Language chosen. Default empty.
     * @return array {
     *     Data for the newly installed site.
     *
     *     @type string $url              The URL of the site.
     *     @type int    $user_id          The ID of the site owner.
     *     @type string $password         The password of the site owner, if their user account didn't already exist.
     *     @type string $password_message The explanatory message regarding the password.
     * }
     * @phpstan-return array{
     *   url: string,
     *   user_id: int,
     *   password: string,
     *   password_message: string,
     * }
     */
    function wp_install($blog_title, $user_name, $user_email, $is_public, $deprecated = '', $user_password = '', $language = '')
    {
    }
    /**
     * Creates the initial content for a newly-installed site.
     *
     * Adds the default "Uncategorized" category, the first post (with comment),
     * first page, and default widgets for default theme for the current version.
     *
     * @since 2.1.0
     *
     * @global wpdb       $wpdb         WordPress database abstraction object.
     * @global WP_Rewrite $wp_rewrite   WordPress rewrite component.
     * @global string     $table_prefix The database table prefix.
     *
     * @param int $user_id User ID.
     */
    function wp_install_defaults($user_id)
    {
    }
    /**
     * Maybe enable pretty permalinks on installation.
     *
     * If after enabling pretty permalinks don't work, fallback to query-string permalinks.
     *
     * @since 4.2.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @return bool Whether pretty permalinks are enabled. False otherwise.
     */
    function wp_install_maybe_enable_pretty_permalinks()
    {
    }
    /**
     * Notifies the site admin that the installation of WordPress is complete.
     *
     * Sends an email to the new administrator that the installation is complete
     * and provides them with a record of their login credentials.
     *
     * @since 2.1.0
     *
     * @param string $blog_title Site title.
     * @param string $blog_url   Site URL.
     * @param int    $user_id    Administrator's user ID.
     * @param string $password   Administrator's password. Note that a placeholder message is
     *                           usually passed instead of the actual password.
     */
    function wp_new_blog_notification($blog_title, $blog_url, $user_id, $password)
    {
    }
    /**
     * Runs WordPress Upgrade functions.
     *
     * Upgrades the database if needed during a site update.
     *
     * @since 2.1.0
     *
     * @global int $wp_current_db_version The old (current) database version.
     * @global int $wp_db_version         The new database version.
     * @phpstan-return void
     */
    function wp_upgrade()
    {
    }
    /**
     * Functions to be called in installation and upgrade scripts.
     *
     * Contains conditional checks to determine which upgrade scripts to run,
     * based on database version and WP version being updated-to.
     *
     * @ignore
     * @since 1.0.1
     *
     * @global int $wp_current_db_version The old (current) database version.
     * @global int $wp_db_version         The new database version.
     * @phpstan-return void
     */
    function upgrade_all()
    {
    }
    /**
     * Execute changes made in WordPress 1.0.
     *
     * @ignore
     * @since 1.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function upgrade_100()
    {
    }
    /**
     * Execute changes made in WordPress 1.0.1.
     *
     * @ignore
     * @since 1.0.1
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function upgrade_101()
    {
    }
    /**
     * Execute changes made in WordPress 1.2.
     *
     * @ignore
     * @since 1.2.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function upgrade_110()
    {
    }
    /**
     * Execute changes made in WordPress 1.5.
     *
     * @ignore
     * @since 1.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function upgrade_130()
    {
    }
    /**
     * Execute changes made in WordPress 2.0.
     *
     * @ignore
     * @since 2.0.0
     *
     * @global wpdb $wpdb                  WordPress database abstraction object.
     * @global int  $wp_current_db_version The old (current) database version.
     */
    function upgrade_160()
    {
    }
    /**
     * Execute changes made in WordPress 2.1.
     *
     * @ignore
     * @since 2.1.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function upgrade_210()
    {
    }
    /**
     * Execute changes made in WordPress 2.3.
     *
     * @ignore
     * @since 2.3.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function upgrade_230()
    {
    }
    /**
     * Remove old options from the database.
     *
     * @ignore
     * @since 2.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function upgrade_230_options_table()
    {
    }
    /**
     * Remove old categories, link2cat, and post2cat database tables.
     *
     * @ignore
     * @since 2.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function upgrade_230_old_tables()
    {
    }
    /**
     * Upgrade old slugs made in version 2.2.
     *
     * @ignore
     * @since 2.2.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function upgrade_old_slugs()
    {
    }
    /**
     * Execute changes made in WordPress 2.5.0.
     *
     * @ignore
     * @since 2.5.0
     *
     * @global int $wp_current_db_version The old (current) database version.
     */
    function upgrade_250()
    {
    }
    /**
     * Execute changes made in WordPress 2.5.2.
     *
     * @ignore
     * @since 2.5.2
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function upgrade_252()
    {
    }
    /**
     * Execute changes made in WordPress 2.6.
     *
     * @ignore
     * @since 2.6.0
     *
     * @global int $wp_current_db_version The old (current) database version.
     */
    function upgrade_260()
    {
    }
    /**
     * Execute changes made in WordPress 2.7.
     *
     * @ignore
     * @since 2.7.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function upgrade_270()
    {
    }
    /**
     * Execute changes made in WordPress 2.8.
     *
     * @ignore
     * @since 2.8.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function upgrade_280()
    {
    }
    /**
     * Execute changes made in WordPress 2.9.
     *
     * @ignore
     * @since 2.9.0
     *
     * @global int $wp_current_db_version The old (current) database version.
     */
    function upgrade_290()
    {
    }
    /**
     * Execute changes made in WordPress 3.0.
     *
     * @ignore
     * @since 3.0.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function upgrade_300()
    {
    }
    /**
     * Execute changes made in WordPress 3.3.
     *
     * @ignore
     * @since 3.3.0
     *
     * @global int   $wp_current_db_version The old (current) database version.
     * @global wpdb  $wpdb                  WordPress database abstraction object.
     * @global array $wp_registered_widgets
     * @global array $sidebars_widgets
     * @phpstan-return void
     */
    function upgrade_330()
    {
    }
    /**
     * Execute changes made in WordPress 3.4.
     *
     * @ignore
     * @since 3.4.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function upgrade_340()
    {
    }
    /**
     * Execute changes made in WordPress 3.5.
     *
     * @ignore
     * @since 3.5.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function upgrade_350()
    {
    }
    /**
     * Execute changes made in WordPress 3.7.
     *
     * @ignore
     * @since 3.7.0
     *
     * @global int $wp_current_db_version The old (current) database version.
     */
    function upgrade_370()
    {
    }
    /**
     * Execute changes made in WordPress 3.7.2.
     *
     * @ignore
     * @since 3.7.2
     *
     * @global int $wp_current_db_version The old (current) database version.
     */
    function upgrade_372()
    {
    }
    /**
     * Execute changes made in WordPress 3.8.0.
     *
     * @ignore
     * @since 3.8.0
     *
     * @global int $wp_current_db_version The old (current) database version.
     */
    function upgrade_380()
    {
    }
    /**
     * Execute changes made in WordPress 4.0.0.
     *
     * @ignore
     * @since 4.0.0
     *
     * @global int $wp_current_db_version The old (current) database version.
     */
    function upgrade_400()
    {
    }
    /**
     * Execute changes made in WordPress 4.2.0.
     *
     * @ignore
     * @since 4.2.0
     */
    function upgrade_420()
    {
    }
    /**
     * Executes changes made in WordPress 4.3.0.
     *
     * @ignore
     * @since 4.3.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function upgrade_430()
    {
    }
    /**
     * Executes comments changes made in WordPress 4.3.0.
     *
     * @ignore
     * @since 4.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     * @phpstan-return void
     */
    function upgrade_430_fix_comments()
    {
    }
    /**
     * Executes changes made in WordPress 4.3.1.
     *
     * @ignore
     * @since 4.3.1
     */
    function upgrade_431()
    {
    }
    /**
     * Executes changes made in WordPress 4.4.0.
     *
     * @ignore
     * @since 4.4.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function upgrade_440()
    {
    }
    /**
     * Executes changes made in WordPress 4.5.0.
     *
     * @ignore
     * @since 4.5.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function upgrade_450()
    {
    }
    /**
     * Executes changes made in WordPress 4.6.0.
     *
     * @ignore
     * @since 4.6.0
     *
     * @global int $wp_current_db_version The old (current) database version.
     */
    function upgrade_460()
    {
    }
    /**
     * Executes changes made in WordPress 5.0.0.
     *
     * @ignore
     * @since 5.0.0
     * @deprecated 5.1.0
     */
    function upgrade_500()
    {
    }
    /**
     * Executes changes made in WordPress 5.1.0.
     *
     * @ignore
     * @since 5.1.0
     */
    function upgrade_510()
    {
    }
    /**
     * Executes changes made in WordPress 5.3.0.
     *
     * @ignore
     * @since 5.3.0
     */
    function upgrade_530()
    {
    }
    /**
     * Executes changes made in WordPress 5.5.0.
     *
     * @ignore
     * @since 5.5.0
     *
     * @global int $wp_current_db_version The old (current) database version.
     */
    function upgrade_550()
    {
    }
    /**
     * Executes changes made in WordPress 5.6.0.
     *
     * @ignore
     * @since 5.6.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function upgrade_560()
    {
    }
    /**
     * Executes changes made in WordPress 5.9.0.
     *
     * @ignore
     * @since 5.9.0
     *
     * @global int $wp_current_db_version The old (current) database version.
     */
    function upgrade_590()
    {
    }
    /**
     * Executes changes made in WordPress 6.0.0.
     *
     * @ignore
     * @since 6.0.0
     *
     * @global int $wp_current_db_version The old (current) database version.
     */
    function upgrade_600()
    {
    }
    /**
     * Executes changes made in WordPress 6.3.0.
     *
     * @ignore
     * @since 6.3.0
     *
     * @global int $wp_current_db_version The old (current) database version.
     */
    function upgrade_630()
    {
    }
    /**
     * Executes changes made in WordPress 6.4.0.
     *
     * @ignore
     * @since 6.4.0
     *
     * @global int $wp_current_db_version The old (current) database version.
     */
    function upgrade_640()
    {
    }
    /**
     * Executes changes made in WordPress 6.5.0.
     *
     * @ignore
     * @since 6.5.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function upgrade_650()
    {
    }
    /**
     * Executes changes made in WordPress 6.7.0.
     *
     * @ignore
     * @since 6.7.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     */
    function upgrade_670()
    {
    }
    /**
     * Executes network-level upgrade routines.
     *
     * @since 3.0.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function upgrade_network()
    {
    }
    /**
     * Creates a table in the database, if it doesn't already exist.
     *
     * This method checks for an existing database table and creates a new one if it's not
     * already present. It doesn't rely on MySQL's "IF NOT EXISTS" statement, but chooses
     * to query all tables first and then run the SQL statement creating the table.
     *
     * @since 1.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $table_name Database table name.
     * @param string $create_ddl SQL statement to create table.
     * @return bool True on success or if the table already exists. False on failure.
     */
    function maybe_create_table($table_name, $create_ddl)
    {
    }
    /**
     * Drops a specified index from a table.
     *
     * @since 1.0.1
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $table Database table name.
     * @param string $index Index name to drop.
     * @return true True, when finished.
     */
    function drop_index($table, $index)
    {
    }
    /**
     * Adds an index to a specified table.
     *
     * @since 1.0.1
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $table Database table name.
     * @param string $index Database table index column.
     * @return true True, when done with execution.
     */
    function add_clean_index($table, $index)
    {
    }
    /**
     * Adds column to a database table, if it doesn't already exist.
     *
     * @since 1.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $table_name  Database table name.
     * @param string $column_name Table column name.
     * @param string $create_ddl  SQL statement to add column.
     * @return bool True on success or if the column already exists. False on failure.
     */
    function maybe_add_column($table_name, $column_name, $create_ddl)
    {
    }
    /**
     * If a table only contains utf8 or utf8mb4 columns, convert it to utf8mb4.
     *
     * @since 4.2.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $table The table to convert.
     * @return bool True if the table was converted, false if it wasn't.
     */
    function maybe_convert_table_to_utf8mb4($table)
    {
    }
    /**
     * Retrieve all options as it was for 1.2.
     *
     * @since 1.2.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return stdClass List of options.
     */
    function get_alloptions_110()
    {
    }
    /**
     * Utility version of get_option that is private to installation/upgrade.
     *
     * @ignore
     * @since 1.5.1
     * @access private
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $setting Option name.
     * @return mixed
     */
    function __get_option($setting)
    {
    }
    /**
     * Filters for content to remove unnecessary slashes.
     *
     * @since 1.5.0
     *
     * @param string $content The content to modify.
     * @return string The de-slashed content.
     */
    function deslash($content)
    {
    }
    /**
     * Modifies the database based on specified SQL statements.
     *
     * Useful for creating new tables and updating existing tables to a new structure.
     *
     * @since 1.5.0
     * @since 6.1.0 Ignores display width for integer data types on MySQL 8.0.17 or later,
     *              to match MySQL behavior. Note: This does not affect MariaDB.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string[]|string $queries Optional. The query to run. Can be multiple queries
     *                                 in an array, or a string of queries separated by
     *                                 semicolons. Default empty string.
     * @param bool            $execute Optional. Whether or not to execute the query right away.
     *                                 Default true.
     * @return array Strings containing the results of the various update queries.
     */
    function dbDelta($queries = '', $execute = \true)
    {
    }
    /**
     * Updates the database tables to a new schema.
     *
     * By default, updates all the tables to use the latest defined schema, but can also
     * be used to update a specific set of tables in wp_get_db_schema().
     *
     * @since 1.5.0
     *
     * @uses dbDelta
     *
     * @param string $tables Optional. Which set of tables to update. Default is 'all'.
     */
    function make_db_current($tables = 'all')
    {
    }
    /**
     * Updates the database tables to a new schema, but without displaying results.
     *
     * By default, updates all the tables to use the latest defined schema, but can
     * also be used to update a specific set of tables in wp_get_db_schema().
     *
     * @since 1.5.0
     *
     * @see make_db_current()
     *
     * @param string $tables Optional. Which set of tables to update. Default is 'all'.
     */
    function make_db_current_silent($tables = 'all')
    {
    }
    /**
     * Creates a site theme from an existing theme.
     *
     * {@internal Missing Long Description}}
     *
     * @since 1.5.0
     *
     * @param string $theme_name The name of the theme.
     * @param string $template   The directory name of the theme.
     * @return bool
     */
    function make_site_theme_from_oldschool($theme_name, $template)
    {
    }
    /**
     * Creates a site theme from the default theme.
     *
     * {@internal Missing Long Description}}
     *
     * @since 1.5.0
     *
     * @param string $theme_name The name of the theme.
     * @param string $template   The directory name of the theme.
     * @return void|false
     */
    function make_site_theme_from_default($theme_name, $template)
    {
    }
    /**
     * Creates a site theme.
     *
     * {@internal Missing Long Description}}
     *
     * @since 1.5.0
     *
     * @return string|false
     */
    function make_site_theme()
    {
    }
    /**
     * Translate user level to user role name.
     *
     * @since 2.0.0
     *
     * @param int $level User level.
     * @return string User role name.
     */
    function translate_level_to_role($level)
    {
    }
    /**
     * Checks the version of the installed MySQL binary.
     *
     * @since 2.1.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function wp_check_mysql_version()
    {
    }
    /**
     * Disables the Automattic widgets plugin, which was merged into core.
     *
     * @since 2.2.0
     */
    function maybe_disable_automattic_widgets()
    {
    }
    /**
     * Disables the Link Manager on upgrade if, at the time of upgrade, no links exist in the DB.
     *
     * @since 3.5.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function maybe_disable_link_manager()
    {
    }
    /**
     * Runs before the schema is upgraded.
     *
     * @since 2.9.0
     *
     * @global int  $wp_current_db_version The old (current) database version.
     * @global wpdb $wpdb                  WordPress database abstraction object.
     */
    function pre_schema_upgrade()
    {
    }
    /**
     * Determine if global tables should be upgraded.
     *
     * This function performs a series of checks to ensure the environment allows
     * for the safe upgrading of global WordPress database tables. It is necessary
     * because global tables will commonly grow to millions of rows on large
     * installations, and the ability to control their upgrade routines can be
     * critical to the operation of large networks.
     *
     * In a future iteration, this function may use `wp_is_large_network()` to more-
     * intelligently prevent global table upgrades. Until then, we make sure
     * WordPress is on the main site of the main network, to avoid running queries
     * more than once in multi-site or multi-network environments.
     *
     * @since 4.3.0
     *
     * @return bool Whether to run the upgrade routines on global tables.
     */
    function wp_should_upgrade_global_tables()
    {
    }
    /**
     * Creates a new user from the "Users" form using $_POST information.
     *
     * @since 2.0.0
     *
     * @return int|WP_Error WP_Error or User ID.
     */
    function add_user()
    {
    }
    /**
     * Edit user settings based on contents of $_POST
     *
     * Used on user-edit.php and profile.php to manage and process user options, passwords etc.
     *
     * @since 2.0.0
     *
     * @param int $user_id Optional. User ID.
     * @return int|WP_Error User ID of the updated user or WP_Error on failure.
     */
    function edit_user($user_id = 0)
    {
    }
    /**
     * Fetch a filtered list of user roles that the current user is
     * allowed to edit.
     *
     * Simple function whose main purpose is to allow filtering of the
     * list of roles in the $wp_roles object so that plugins can remove
     * inappropriate ones depending on the situation or user making edits.
     * Specifically because without filtering anyone with the edit_users
     * capability can edit others to be administrators, even if they are
     * only editors or authors. This filter allows admins to delegate
     * user management.
     *
     * @since 2.8.0
     *
     * @return array[] Array of arrays containing role information.
     */
    function get_editable_roles()
    {
    }
    /**
     * Retrieve user data and filter it.
     *
     * @since 2.0.5
     *
     * @param int $user_id User ID.
     * @return WP_User|false WP_User object on success, false on failure.
     */
    function get_user_to_edit($user_id)
    {
    }
    /**
     * Retrieve the user's drafts.
     *
     * @since 2.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $user_id User ID.
     * @return array
     */
    function get_users_drafts($user_id)
    {
    }
    /**
     * Delete user and optionally reassign posts and links to another user.
     *
     * Note that on a Multisite installation the user only gets removed from the site
     * and does not get deleted from the database.
     *
     * If the `$reassign` parameter is not assigned to a user ID, then all posts will
     * be deleted of that user. The action {@see 'delete_user'} that is passed the user ID
     * being deleted will be run after the posts are either reassigned or deleted.
     * The user meta will also be deleted that are for that user ID.
     *
     * @since 2.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $id       User ID.
     * @param int $reassign Optional. Reassign posts and links to new User ID.
     * @return bool True when finished.
     */
    function wp_delete_user($id, $reassign = \null)
    {
    }
    /**
     * Remove all capabilities from user.
     *
     * @since 2.1.0
     *
     * @param int $id User ID.
     */
    function wp_revoke_user($id)
    {
    }
    /**
     * @since 2.8.0
     *
     * @global int $user_ID
     *
     * @param false $errors Deprecated.
     * @phpstan-return void
     */
    function default_password_nag_handler($errors = \false)
    {
    }
    /**
     * @since 2.8.0
     *
     * @param int     $user_ID
     * @param WP_User $old_data
     * @phpstan-return void
     */
    function default_password_nag_edit_user($user_ID, $old_data)
    {
    }
    /**
     * @since 2.8.0
     *
     * @global string $pagenow The filename of the current screen.
     * @phpstan-return void
     */
    function default_password_nag()
    {
    }
    /**
     * @since 3.5.0
     * @access private
     */
    function delete_users_add_js()
    {
    }
    /**
     * Optional SSL preference that can be turned on by hooking to the 'personal_options' action.
     *
     * See the {@see 'personal_options'} action.
     *
     * @since 2.7.0
     *
     * @param WP_User $user User data object.
     */
    function use_ssl_preference($user)
    {
    }
    /**
     * @since MU (3.0.0)
     *
     * @param string $text
     * @return string
     */
    function admin_created_user_email($text)
    {
    }
    /**
     * Checks if the Authorize Application Password request is valid.
     *
     * @since 5.6.0
     * @since 6.2.0 Allow insecure HTTP connections for the local environment.
     * @since 6.3.2 Validates the success and reject URLs to prevent `javascript` pseudo protocol from being executed.
     *
     * @param array   $request {
     *     The array of request data. All arguments are optional and may be empty.
     *
     *     @type string $app_name    The suggested name of the application.
     *     @type string $app_id      A UUID provided by the application to uniquely identify it.
     *     @type string $success_url The URL the user will be redirected to after approving the application.
     *     @type string $reject_url  The URL the user will be redirected to after rejecting the application.
     * }
     * @param WP_User $user The user authorizing the application.
     * @return true|WP_Error True if the request is valid, a WP_Error object contains errors if not.
     * @phpstan-param array{
     *   app_name?: string,
     *   app_id?: string,
     *   success_url?: string,
     *   reject_url?: string,
     * } $request
     */
    function wp_is_authorize_application_password_request_valid($request, $user)
    {
    }
    /**
     * Validates the redirect URL protocol scheme. The protocol can be anything except `http` and `javascript`.
     *
     * @since 6.3.2
     *
     * @param string $url The redirect URL to be validated.
     * @return true|WP_Error True if the redirect URL is valid, a WP_Error object otherwise.
     */
    function wp_is_authorize_application_redirect_url_valid($url)
    {
    }
    /**
     * Display list of the available widgets.
     *
     * @since 2.5.0
     *
     * @global array $wp_registered_widgets
     * @global array $wp_registered_widget_controls
     */
    function wp_list_widgets()
    {
    }
    /**
     * Callback to sort array by a 'name' key.
     *
     * @since 3.1.0
     * @access private
     *
     * @param array $a First array.
     * @param array $b Second array.
     * @return int
     */
    function _sort_name_callback($a, $b)
    {
    }
    /**
     * Show the widgets and their settings for a sidebar.
     * Used in the admin widget config screen.
     *
     * @since 2.5.0
     *
     * @param string $sidebar      Sidebar ID.
     * @param string $sidebar_name Optional. Sidebar name. Default empty.
     */
    function wp_list_widget_controls($sidebar, $sidebar_name = '')
    {
    }
    /**
     * Retrieves the widget control arguments.
     *
     * @since 2.5.0
     *
     * @global array $wp_registered_widgets
     *
     * @param array $params
     * @return array
     */
    function wp_list_widget_controls_dynamic_sidebar($params)
    {
    }
    /**
     * @global array $wp_registered_widgets
     *
     * @param string $id_base
     * @return int
     */
    function next_widget_id_number($id_base)
    {
    }
    /**
     * Meta widget used to display the control form for a widget.
     *
     * Called from dynamic_sidebar().
     *
     * @since 2.5.0
     *
     * @global array $wp_registered_widgets
     * @global array $wp_registered_widget_controls
     * @global array $sidebars_widgets
     *
     * @param array $sidebar_args
     * @return array
     */
    function wp_widget_control($sidebar_args)
    {
    }
    /**
     * @param string $classes
     * @return string
     */
    function wp_widgets_access_body_class($classes)
    {
    }
    /**
     * Display installation header.
     *
     * @since 2.5.0
     *
     * @param string $body_classes
     */
    function display_header($body_classes = '')
    {
    }
    /**
     * Displays installer setup form.
     *
     * @since 2.8.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string|null $error
     */
    function display_setup_form($error = \null)
    {
    }
    /**
     * Starts a new XML tag.
     *
     * Callback function for xml_set_element_handler().
     *
     * @since 0.71
     * @access private
     *
     * @global array $names
     * @global array $urls
     * @global array $targets
     * @global array $descriptions
     * @global array $feeds
     *
     * @param resource $parser   XML Parser resource.
     * @param string   $tag_name XML element name.
     * @param array    $attrs    XML element attributes.
     */
    function startElement($parser, $tag_name, $attrs)
    {
    }
    /**
     * Ends a new XML tag.
     *
     * Callback function for xml_set_element_handler().
     *
     * @since 0.71
     * @access private
     *
     * @param resource $parser   XML Parser resource.
     * @param string   $tag_name XML tag name.
     */
    function endElement($parser, $tag_name)
    {
    }
    /**
     * Display menu.
     *
     * @access private
     * @since 2.7.0
     *
     * @global string $self
     * @global string $parent_file
     * @global string $submenu_file
     * @global string $plugin_page
     * @global string $typenow      The post type of the current screen.
     *
     * @param array $menu
     * @param array $submenu
     * @param bool  $submenu_as_parent
     */
    function _wp_menu_output($menu, $submenu, $submenu_as_parent = \true)
    {
    }
    /**
     * Adds the 'Theme File Editor' menu item to the bottom of the Appearance (non-block themes)
     * or Tools (block themes) menu.
     *
     * @access private
     * @since 3.0.0
     * @since 5.9.0 Renamed 'Theme Editor' to 'Theme File Editor'.
     *              Relocates to Tools for block themes.
     */
    function _add_themes_utility_last()
    {
    }
    /**
     * Adds the 'Plugin File Editor' menu item after the 'Themes File Editor' in Tools
     * for block themes.
     *
     * @access private
     * @since 5.9.0
     * @phpstan-return void
     */
    function _add_plugin_file_editor_to_tools()
    {
    }
    /**
     * @global int $_wp_nav_menu_max_depth
     *
     * @param string $classes
     * @return string
     */
    function wp_nav_menu_max_depth($classes)
    {
    }
    function wp_load_press_this()
    {
    }
    /**
     * Display setup wp-config.php file header.
     *
     * @ignore
     * @since 2.3.0
     *
     * @param string|string[] $body_classes Class attribute values for the body tag.
     */
    function setup_config_display_header($body_classes = array())
    {
    }
    /**
     * Returns the JavaScript template used to display the auto-update setting for a theme.
     *
     * @since 5.5.0
     *
     * @return string The template for displaying the auto-update setting link.
     */
    function wp_theme_auto_update_setting_template()
    {
    }
    /**
     * Lists available core updates.
     *
     * @since 2.7.0
     *
     * @global string $wp_local_package Locale code of the package.
     * @global wpdb   $wpdb             WordPress database abstraction object.
     *
     * @param object $update
     */
    function list_core_update($update)
    {
    }
    /**
     * Display dismissed updates.
     *
     * @since 2.7.0
     */
    function dismissed_updates()
    {
    }
    /**
     * Display upgrade WordPress for downloading latest or upgrading automatically form.
     *
     * @since 2.7.0
     */
    function core_upgrade_preamble()
    {
    }
    /**
     * Display WordPress auto-updates settings.
     *
     * @since 5.6.0
     */
    function core_auto_updates_settings()
    {
    }
    /**
     * Display the upgrade plugins form.
     *
     * @since 2.9.0
     * @phpstan-return void
     */
    function list_plugin_updates()
    {
    }
    /**
     * Display the upgrade themes form.
     *
     * @since 2.9.0
     * @phpstan-return void
     */
    function list_theme_updates()
    {
    }
    /**
     * Display the update translations form.
     *
     * @since 3.7.0
     * @phpstan-return void
     */
    function list_translation_updates()
    {
    }
    /**
     * Upgrades WordPress core display.
     *
     * @since 2.7.0
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     *
     * @param bool $reinstall
     * @phpstan-return void
     */
    function do_core_upgrade($reinstall = \false)
    {
    }
    /**
     * Dismiss a core update.
     *
     * @since 2.7.0
     * @phpstan-return void
     */
    function do_dismiss_core_update()
    {
    }
    /**
     * Undismiss a core update.
     *
     * @since 2.7.0
     * @phpstan-return void
     */
    function do_undismiss_core_update()
    {
    }
    /**
     * Retrieves the cron lock.
     *
     * Returns the uncached `doing_cron` transient.
     *
     * @ignore
     * @since 3.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return string|int|false Value of the `doing_cron` transient, 0|false otherwise.
     */
    function _get_cron_lock()
    {
    }
    /**
     * Instantiates the admin bar object and set it up as a global for access elsewhere.
     *
     * UNHOOKING THIS FUNCTION WILL NOT PROPERLY REMOVE THE ADMIN BAR.
     * For that, use show_admin_bar(false) or the {@see 'show_admin_bar'} filter.
     *
     * @since 3.1.0
     * @access private
     *
     * @global WP_Admin_Bar $wp_admin_bar
     *
     * @return bool Whether the admin bar was successfully initialized.
     */
    function _wp_admin_bar_init()
    {
    }
    /**
     * Renders the admin bar to the page based on the $wp_admin_bar->menu member var.
     *
     * This is called very early on the {@see 'wp_body_open'} action so that it will render
     * before anything else being added to the page body.
     *
     * For backward compatibility with themes not using the 'wp_body_open' action,
     * the function is also called late on {@see 'wp_footer'}.
     *
     * It includes the {@see 'admin_bar_menu'} action which should be used to hook in and
     * add new menus to the admin bar. This also gives you access to the `$post` global,
     * among others.
     *
     * @since 3.1.0
     * @since 5.4.0 Called on 'wp_body_open' action first, with 'wp_footer' as a fallback.
     *
     * @global WP_Admin_Bar $wp_admin_bar
     * @phpstan-return void
     */
    function wp_admin_bar_render()
    {
    }
    /**
     * Adds the WordPress logo menu.
     *
     * @since 3.3.0
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     */
    function wp_admin_bar_wp_menu($wp_admin_bar)
    {
    }
    /**
     * Adds the sidebar toggle button.
     *
     * @since 3.8.0
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     */
    function wp_admin_bar_sidebar_toggle($wp_admin_bar)
    {
    }
    /**
     * Adds the "My Account" item.
     *
     * @since 3.3.0
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_my_account_item($wp_admin_bar)
    {
    }
    /**
     * Adds the "My Account" submenu items.
     *
     * @since 3.1.0
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_my_account_menu($wp_admin_bar)
    {
    }
    /**
     * Adds the "Site Name" menu.
     *
     * @since 3.3.0
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_site_menu($wp_admin_bar)
    {
    }
    /**
     * Adds the "Edit site" link to the Toolbar.
     *
     * @since 5.9.0
     * @since 6.3.0 Added `$_wp_current_template_id` global for editing of current template directly from the admin bar.
     * @since 6.6.0 Added the `canvas` query arg to the Site Editor link.
     *
     * @global string $_wp_current_template_id
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_edit_site_menu($wp_admin_bar)
    {
    }
    /**
     * Adds the "Customize" link to the Toolbar.
     *
     * @since 4.3.0
     *
     * @global WP_Customize_Manager $wp_customize
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_customize_menu($wp_admin_bar)
    {
    }
    /**
     * Adds the "My Sites/[Site Name]" menu and all submenus.
     *
     * @since 3.1.0
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_my_sites_menu($wp_admin_bar)
    {
    }
    /**
     * Provides a shortlink.
     *
     * @since 3.1.0
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_shortlink_menu($wp_admin_bar)
    {
    }
    /**
     * Provides an edit link for posts and terms.
     *
     * @since 3.1.0
     * @since 5.5.0 Added a "View Post" link on Comments screen for a single post.
     *
     * @global WP_Term  $tag
     * @global WP_Query $wp_the_query WordPress Query object.
     * @global int      $user_id      The ID of the user being edited. Not to be confused with the
     *                                global $user_ID, which contains the ID of the current user.
     * @global int      $post_id      The ID of the post when editing comments for a single post.
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_edit_menu($wp_admin_bar)
    {
    }
    /**
     * Adds "Add New" menu.
     *
     * @since 3.1.0
     * @since 6.5.0 Added a New Site link for network installations.
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_new_content_menu($wp_admin_bar)
    {
    }
    /**
     * Adds edit comments link with awaiting moderation count bubble.
     *
     * @since 3.1.0
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_comments_menu($wp_admin_bar)
    {
    }
    /**
     * Adds appearance submenu items to the "Site Name" menu.
     *
     * @since 3.1.0
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_appearance_menu($wp_admin_bar)
    {
    }
    /**
     * Provides an update link if theme/plugin/core updates are available.
     *
     * @since 3.1.0
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_updates_menu($wp_admin_bar)
    {
    }
    /**
     * Adds search form.
     *
     * @since 3.3.0
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_search_menu($wp_admin_bar)
    {
    }
    /**
     * Adds a link to exit recovery mode when Recovery Mode is active.
     *
     * @since 5.2.0
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     * @phpstan-return void
     */
    function wp_admin_bar_recovery_mode_menu($wp_admin_bar)
    {
    }
    /**
     * Adds secondary menus.
     *
     * @since 3.3.0
     *
     * @param WP_Admin_Bar $wp_admin_bar The WP_Admin_Bar instance.
     */
    function wp_admin_bar_add_secondary_groups($wp_admin_bar)
    {
    }
    /**
     * Enqueues inline style to hide the admin bar when printing.
     *
     * @since 6.4.0
     * @phpstan-return void
     */
    function wp_enqueue_admin_bar_header_styles()
    {
    }
    /**
     * Enqueues inline bump styles to make room for the admin bar.
     *
     * @since 6.4.0
     * @phpstan-return void
     */
    function wp_enqueue_admin_bar_bump_styles()
    {
    }
    /**
     * Sets the display status of the admin bar.
     *
     * This can be called immediately upon plugin load. It does not need to be called
     * from a function hooked to the {@see 'init'} action.
     *
     * @since 3.1.0
     *
     * @global bool $show_admin_bar
     *
     * @param bool $show Whether to allow the admin bar to show.
     */
    function show_admin_bar($show)
    {
    }
    /**
     * Determines whether the admin bar should be showing.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 3.1.0
     *
     * @global bool   $show_admin_bar
     * @global string $pagenow        The filename of the current screen.
     *
     * @return bool Whether the admin bar should be showing.
     */
    function is_admin_bar_showing()
    {
    }
    /**
     * Retrieves the admin bar display preference of a user.
     *
     * @since 3.1.0
     * @access private
     *
     * @param string $context Context of this preference check. Defaults to 'front'. The 'admin'
     *                        preference is no longer used.
     * @param int    $user    Optional. ID of the user to check, defaults to 0 for current user.
     * @return bool Whether the admin bar should be showing for this user.
     */
    function _get_admin_bar_pref($context = 'front', $user = 0)
    {
    }
    /**
     * Retrieves the author of the current post.
     *
     * @since 1.5.0
     * @since 6.3.0 Returns an empty string if the author's display name is unknown.
     *
     * @global WP_User $authordata The current author's data.
     *
     * @param string $deprecated Deprecated.
     * @return string The author's display name, empty string if unknown.
     */
    function get_the_author($deprecated = '')
    {
    }
    /**
     * Displays the name of the author of the current post.
     *
     * The behavior of this function is based off of old functionality predating
     * get_the_author(). This function is not deprecated, but is designed to echo
     * the value from get_the_author() and as an result of any old theme that might
     * still use the old behavior will also pass the value from get_the_author().
     *
     * The normal, expected behavior of this function is to echo the author and not
     * return it. However, backward compatibility has to be maintained.
     *
     * @since 0.71
     *
     * @see get_the_author()
     * @link https://developer.wordpress.org/reference/functions/the_author/
     *
     * @param string $deprecated      Deprecated.
     * @param bool   $deprecated_echo Deprecated. Use get_the_author(). Echo the string or return it.
     * @return string The author's display name, from get_the_author().
     */
    function the_author($deprecated = '', $deprecated_echo = \true)
    {
    }
    /**
     * Retrieves the author who last edited the current post.
     *
     * @since 2.8.0
     *
     * @return string|void The author's display name, empty string if unknown.
     */
    function get_the_modified_author()
    {
    }
    /**
     * Displays the name of the author who last edited the current post,
     * if the author's ID is available.
     *
     * @since 2.8.0
     *
     * @see get_the_author()
     */
    function the_modified_author()
    {
    }
    /**
     * Retrieves the requested data of the author of the current post.
     *
     * Valid values for the `$field` parameter include:
     *
     * - admin_color
     * - aim
     * - comment_shortcuts
     * - description
     * - display_name
     * - first_name
     * - ID
     * - jabber
     * - last_name
     * - nickname
     * - plugins_last_view
     * - plugins_per_page
     * - rich_editing
     * - syntax_highlighting
     * - user_activation_key
     * - user_description
     * - user_email
     * - user_firstname
     * - user_lastname
     * - user_level
     * - user_login
     * - user_nicename
     * - user_pass
     * - user_registered
     * - user_status
     * - user_url
     * - yim
     *
     * @since 2.8.0
     *
     * @global WP_User $authordata The current author's data.
     *
     * @param string    $field   Optional. The user field to retrieve. Default empty.
     * @param int|false $user_id Optional. User ID. Defaults to the current post author.
     * @return string The author's field from the current author's DB object, otherwise an empty string.
     */
    function get_the_author_meta($field = '', $user_id = \false)
    {
    }
    /**
     * Outputs the field from the user's DB object. Defaults to current post's author.
     *
     * @since 2.8.0
     *
     * @param string    $field   Selects the field of the users record. See get_the_author_meta()
     *                           for the list of possible fields.
     * @param int|false $user_id Optional. User ID. Defaults to the current post author.
     *
     * @see get_the_author_meta()
     */
    function the_author_meta($field = '', $user_id = \false)
    {
    }
    /**
     * Retrieves either author's link or author's name.
     *
     * If the author has a home page set, return an HTML link, otherwise just return
     * the author's name.
     *
     * @since 3.0.0
     *
     * @global WP_User $authordata The current author's data.
     *
     * @return string An HTML link if the author's URL exists in user meta,
     *                otherwise the result of get_the_author().
     */
    function get_the_author_link()
    {
    }
    /**
     * Displays either author's link or author's name.
     *
     * If the author has a home page set, echo an HTML link, otherwise just echo the
     * author's name.
     *
     * @link https://developer.wordpress.org/reference/functions/the_author_link/
     *
     * @since 2.1.0
     */
    function the_author_link()
    {
    }
    /**
     * Retrieves the number of posts by the author of the current post.
     *
     * @since 1.5.0
     *
     * @return int The number of posts by the author.
     */
    function get_the_author_posts()
    {
    }
    /**
     * Displays the number of posts by the author of the current post.
     *
     * @link https://developer.wordpress.org/reference/functions/the_author_posts/
     * @since 0.71
     */
    function the_author_posts()
    {
    }
    /**
     * Retrieves an HTML link to the author page of the current post's author.
     *
     * Returns an HTML-formatted link using get_author_posts_url().
     *
     * @since 4.4.0
     *
     * @global WP_User $authordata The current author's data.
     *
     * @return string An HTML link to the author page, or an empty string if $authordata is not set.
     */
    function get_the_author_posts_link()
    {
    }
    /**
     * Displays an HTML link to the author page of the current post's author.
     *
     * @since 1.2.0
     * @since 4.4.0 Converted into a wrapper for get_the_author_posts_link()
     *
     * @param string $deprecated Unused.
     */
    function the_author_posts_link($deprecated = '')
    {
    }
    /**
     * Retrieves the URL to the author page for the user with the ID provided.
     *
     * @since 2.1.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param int    $author_id       Author ID.
     * @param string $author_nicename Optional. The author's nicename (slug). Default empty.
     * @return string The URL to the author's page.
     */
    function get_author_posts_url($author_id, $author_nicename = '')
    {
    }
    /**
     * Lists all the authors of the site, with several options available.
     *
     * @link https://developer.wordpress.org/reference/functions/wp_list_authors/
     *
     * @since 1.2.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string|array $args {
     *     Optional. Array or string of default arguments.
     *
     *     @type string       $orderby       How to sort the authors. Accepts 'nicename', 'email', 'url', 'registered',
     *                                       'user_nicename', 'user_email', 'user_url', 'user_registered', 'name',
     *                                       'display_name', 'post_count', 'ID', 'meta_value', 'user_login'. Default 'name'.
     *     @type string       $order         Sorting direction for $orderby. Accepts 'ASC', 'DESC'. Default 'ASC'.
     *     @type int          $number        Maximum authors to return or display. Default empty (all authors).
     *     @type bool         $optioncount   Show the count in parenthesis next to the author's name. Default false.
     *     @type bool         $exclude_admin Whether to exclude the 'admin' account, if it exists. Default true.
     *     @type bool         $show_fullname Whether to show the author's full name. Default false.
     *     @type bool         $hide_empty    Whether to hide any authors with no posts. Default true.
     *     @type string       $feed          If not empty, show a link to the author's feed and use this text as the alt
     *                                       parameter of the link. Default empty.
     *     @type string       $feed_image    If not empty, show a link to the author's feed and use this image URL as
     *                                       clickable anchor. Default empty.
     *     @type string       $feed_type     The feed type to link to. Possible values include 'rss2', 'atom'.
     *                                       Default is the value of get_default_feed().
     *     @type bool         $echo          Whether to output the result or instead return it. Default true.
     *     @type string       $style         If 'list', each author is wrapped in an `<li>` element, otherwise the authors
     *                                       will be separated by commas.
     *     @type bool         $html          Whether to list the items in HTML form or plaintext. Default true.
     *     @type int[]|string $exclude       Array or comma/space-separated list of author IDs to exclude. Default empty.
     *     @type int[]|string $include       Array or comma/space-separated list of author IDs to include. Default empty.
     * }
     * @return void|string Void if 'echo' argument is true, list of authors if 'echo' is false.
     * @phpstan-param array{
     *   orderby?: string,
     *   order?: string,
     *   number?: int,
     *   optioncount?: bool,
     *   exclude_admin?: bool,
     *   show_fullname?: bool,
     *   hide_empty?: bool,
     *   feed?: string,
     *   feed_image?: string,
     *   feed_type?: string,
     *   echo?: bool,
     *   style?: string,
     *   html?: bool,
     *   exclude?: int[]|string,
     *   include?: int[]|string,
     * } $args
     */
    function wp_list_authors($args = '')
    {
    }
    /**
     * Determines whether this site has more than one author.
     *
     * Checks to see if more than one author has published posts.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 3.2.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return bool Whether or not we have more than one author
     */
    function is_multi_author()
    {
    }
    /**
     * Helper function to clear the cache for number of authors.
     *
     * @since 3.2.0
     * @access private
     */
    function __clear_multi_author_cache()
    {
    }
    /**
     * Registers a new block bindings source.
     *
     * Registering a source consists of defining a **name** for that source and a callback function specifying
     * how to get a value from that source and pass it to a block attribute.
     *
     * Once a source is registered, any block that supports the Block Bindings API can use a value
     * from that source by setting its `metadata.bindings` attribute to a value that refers to the source.
     *
     * Note that `register_block_bindings_source()` should be called from a handler attached to the `init` hook.
     *
     *
     * ## Example
     *
     * ### Registering a source
     *
     * First, you need to define a function that will be used to get the value from the source.
     *
     *     function my_plugin_get_custom_source_value( array $source_args, $block_instance, string $attribute_name ) {
     *       // Your custom logic to get the value from the source.
     *       // For example, you can use the `$source_args` to look up a value in a custom table or get it from an external API.
     *       $value = $source_args['key'];
     *
     *       return "The value passed to the block is: $value"
     *     }
     *
     * The `$source_args` will contain the arguments passed to the source in the block's
     * `metadata.bindings` attribute. See the example in the "Usage in a block" section below.
     *
     *     function my_plugin_register_block_bindings_sources() {
     *       register_block_bindings_source( 'my-plugin/my-custom-source', array(
     *         'label'              => __( 'My Custom Source', 'my-plugin' ),
     *         'get_value_callback' => 'my_plugin_get_custom_source_value',
     *       ) );
     *     }
     *     add_action( 'init', 'my_plugin_register_block_bindings_sources' );
     *
     * ### Usage in a block
     *
     * In a block's `metadata.bindings` attribute, you can specify the source and
     * its arguments. Such a block will use the source to override the block
     * attribute's value. For example:
     *
     *     <!-- wp:paragraph {
     *       "metadata": {
     *         "bindings": {
     *           "content": {
     *             "source": "my-plugin/my-custom-source",
     *             "args": {
     *               "key": "you can pass any custom arguments here"
     *             }
     *           }
     *         }
     *       }
     *     } -->
     *     <p>Fallback text that gets replaced.</p>
     *     <!-- /wp:paragraph -->
     *
     * @since 6.5.0
     *
     * @param string $source_name       The name of the source. It must be a string containing a namespace prefix, i.e.
     *                                  `my-plugin/my-custom-source`. It must only contain lowercase alphanumeric
     *                                  characters, the forward slash `/` and dashes.
     * @param array  $source_properties {
     *     The array of arguments that are used to register a source.
     *
     *     @type string   $label              The label of the source.
     *     @type callable $get_value_callback A callback executed when the source is processed during block rendering.
     *                                        The callback should have the following signature:
     *
     *                                        `function( $source_args, $block_instance, $attribute_name ): mixed`
     *                                            - @param array    $source_args    Array containing source arguments
     *                                                                              used to look up the override value,
     *                                                                              i.e. {"key": "foo"}.
     *                                            - @param WP_Block $block_instance The block instance.
     *                                            - @param string   $attribute_name The name of an attribute.
     *                                        The callback has a mixed return type; it may return a string to override
     *                                        the block's original value, null, false to remove an attribute, etc.
     *     @type string[] $uses_context       Optional. Array of values to add to block `uses_context` needed by the source.
     * }
     * @return WP_Block_Bindings_Source|false Source when the registration was successful, or `false` on failure.
     * @phpstan-param array{
     *   label?: string,
     *   get_value_callback?: callable,
     *   uses_context?: string[],
     * } $source_properties
     */
    function register_block_bindings_source(string $source_name, array $source_properties)
    {
    }
    /**
     * Unregisters a block bindings source.
     *
     * @since 6.5.0
     *
     * @param string $source_name Block bindings source name including namespace.
     * @return WP_Block_Bindings_Source|false The unregistered block bindings source on success and `false` otherwise.
     */
    function unregister_block_bindings_source(string $source_name)
    {
    }
    /**
     * Retrieves the list of all registered block bindings sources.
     *
     * @since 6.5.0
     *
     * @return WP_Block_Bindings_Source[] The array of registered block bindings sources.
     */
    function get_all_registered_block_bindings_sources()
    {
    }
    /**
     * Retrieves a registered block bindings source.
     *
     * @since 6.5.0
     *
     * @param string $source_name The name of the source.
     * @return WP_Block_Bindings_Source|null The registered block bindings source, or `null` if it is not registered.
     */
    function get_block_bindings_source(string $source_name)
    {
    }
    /**
     * Gets value for the Pattern Overrides source.
     *
     * @since 6.5.0
     * @access private
     *
     * @param array    $source_args    Array containing source arguments used to look up the override value.
     *                                 Example: array( "key" => "foo" ).
     * @param WP_Block $block_instance The block instance.
     * @param string   $attribute_name The name of the target attribute.
     * @return mixed The value computed for the source.
     */
    function _block_bindings_pattern_overrides_get_value(array $source_args, $block_instance, string $attribute_name)
    {
    }
    /**
     * Registers Pattern Overrides source in the Block Bindings registry.
     *
     * @since 6.5.0
     * @access private
     */
    function _register_block_bindings_pattern_overrides_source()
    {
    }
    /**
     * Gets value for Post Meta source.
     *
     * @since 6.5.0
     * @access private
     *
     * @param array    $source_args    Array containing source arguments used to look up the override value.
     *                                 Example: array( "key" => "foo" ).
     * @param WP_Block $block_instance The block instance.
     * @return mixed The value computed for the source.
     */
    function _block_bindings_post_meta_get_value(array $source_args, $block_instance)
    {
    }
    /**
     * Registers Post Meta source in the block bindings registry.
     *
     * @since 6.5.0
     * @access private
     */
    function _register_block_bindings_post_meta_source()
    {
    }
    /**
     * Returns the list of default categories for block types.
     *
     * @since 5.8.0
     * @since 6.3.0 Reusable Blocks renamed to Patterns.
     *
     * @return array[] Array of categories for block types.
     */
    function get_default_block_categories()
    {
    }
    /**
     * Returns all the categories for block types that will be shown in the block editor.
     *
     * @since 5.0.0
     * @since 5.8.0 It is possible to pass the block editor context as param.
     *
     * @param WP_Post|WP_Block_Editor_Context $post_or_block_editor_context The current post object or
     *                                                                      the block editor context.
     *
     * @return array[] Array of categories for block types.
     */
    function get_block_categories($post_or_block_editor_context)
    {
    }
    /**
     * Gets the list of allowed block types to use in the block editor.
     *
     * @since 5.8.0
     *
     * @param WP_Block_Editor_Context $block_editor_context The current block editor context.
     *
     * @return bool|string[] Array of block type slugs, or boolean to enable/disable all.
     */
    function get_allowed_block_types($block_editor_context)
    {
    }
    /**
     * Returns the default block editor settings.
     *
     * @since 5.8.0
     *
     * @return array The default block editor settings.
     */
    function get_default_block_editor_settings()
    {
    }
    /**
     * Returns the block editor settings needed to use the Legacy Widget block which
     * is not registered by default.
     *
     * @since 5.8.0
     *
     * @return array Settings to be used with get_block_editor_settings().
     */
    function get_legacy_widget_block_editor_settings()
    {
    }
    /**
     * Collect the block editor assets that need to be loaded into the editor's iframe.
     *
     * @since 6.0.0
     * @access private
     *
     * @global WP_Styles  $wp_styles  The WP_Styles current instance.
     * @global WP_Scripts $wp_scripts The WP_Scripts current instance.
     *
     * @return array {
     *     The block editor assets.
     *
     *     @type string|false $styles  String containing the HTML for styles.
     *     @type string|false $scripts String containing the HTML for scripts.
     * }
     * @phpstan-return array{
     *   styles: string|false,
     *   scripts: string|false,
     * }
     */
    function _wp_get_iframed_editor_assets()
    {
    }
    /**
     * Finds the first occurrence of a specific block in an array of blocks.
     *
     * @since 6.3.0
     *
     * @param array  $blocks     Array of blocks.
     * @param string $block_name Name of the block to find.
     * @return array Found block, or empty array if none found.
     */
    function wp_get_first_block($blocks, $block_name)
    {
    }
    /**
     * Retrieves Post Content block attributes from the current post template.
     *
     * @since 6.3.0
     * @since 6.4.0 Return null if there is no post content block.
     * @access private
     *
     * @global int $post_ID
     *
     * @return array|null Post Content block attributes array or null if Post Content block doesn't exist.
     */
    function wp_get_post_content_block_attributes()
    {
    }
    /**
     * Returns the contextualized block editor settings for a selected editor context.
     *
     * @since 5.8.0
     *
     * @param array                   $custom_settings      Custom settings to use with the given editor type.
     * @param WP_Block_Editor_Context $block_editor_context The current block editor context.
     *
     * @return array The contextualized block editor settings.
     */
    function get_block_editor_settings(array $custom_settings, $block_editor_context)
    {
    }
    /**
     * Preloads common data used with the block editor by specifying an array of
     * REST API paths that will be preloaded for a given block editor context.
     *
     * @since 5.8.0
     *
     * @global WP_Post    $post       Global post object.
     * @global WP_Scripts $wp_scripts The WP_Scripts object for printing scripts.
     * @global WP_Styles  $wp_styles  The WP_Styles object for printing styles.
     *
     * @param (string|string[])[]     $preload_paths        List of paths to preload.
     * @param WP_Block_Editor_Context $block_editor_context The current block editor context.
     * @phpstan-return void
     */
    function block_editor_rest_api_preload(array $preload_paths, $block_editor_context)
    {
    }
    /**
     * Creates an array of theme styles to load into the block editor.
     *
     * @since 5.8.0
     *
     * @global array $editor_styles
     *
     * @return array An array of theme styles for the block editor.
     */
    function get_block_editor_theme_styles()
    {
    }
    /**
     * Returns the classic theme supports settings for block editor.
     *
     * @since 6.2.0
     * @since 6.6.0 Add support for 'editor-spacing-sizes' theme support.
     *
     * @return array The classic theme supports settings.
     */
    function get_classic_theme_supports_block_editor_settings()
    {
    }
    /**
     * Registers the core block patterns and categories.
     *
     * @since 5.5.0
     * @since 6.3.0 Added source to core block patterns.
     * @access private
     */
    function _register_core_block_patterns_and_categories()
    {
    }
    /**
     * Normalize the pattern properties to camelCase.
     *
     * The API's format is snake_case, `register_block_pattern()` expects camelCase.
     *
     * @since 6.2.0
     * @access private
     *
     * @param array $pattern Pattern as returned from the Pattern Directory API.
     * @return array Normalized pattern.
     */
    function wp_normalize_remote_block_pattern($pattern)
    {
    }
    /**
     * Register Core's official patterns from wordpress.org/patterns.
     *
     * @since 5.8.0
     * @since 5.9.0 The $current_screen argument was removed.
     * @since 6.2.0 Normalize the pattern from the API (snake_case) to the
     *              format expected by `register_block_pattern` (camelCase).
     * @since 6.3.0 Add 'pattern-directory/core' to the pattern's 'source'.
     *
     * @param WP_Screen $deprecated Unused. Formerly the screen that the current request was triggered from.
     * @phpstan-return void
     */
    function _load_remote_block_patterns($deprecated = \null)
    {
    }
    /**
     * Register `Featured` (category) patterns from wordpress.org/patterns.
     *
     * @since 5.9.0
     * @since 6.2.0 Normalized the pattern from the API (snake_case) to the
     *              format expected by `register_block_pattern()` (camelCase).
     * @since 6.3.0 Add 'pattern-directory/featured' to the pattern's 'source'.
     * @phpstan-return void
     */
    function _load_remote_featured_patterns()
    {
    }
    /**
     * Registers patterns from Pattern Directory provided by a theme's
     * `theme.json` file.
     *
     * @since 6.0.0
     * @since 6.2.0 Normalized the pattern from the API (snake_case) to the
     *              format expected by `register_block_pattern()` (camelCase).
     * @since 6.3.0 Add 'pattern-directory/theme' to the pattern's 'source'.
     * @access private
     * @phpstan-return void
     */
    function _register_remote_theme_patterns()
    {
    }
    /**
     * Register any patterns that the active theme may provide under its
     * `./patterns/` directory.
     *
     * @since 6.0.0
     * @since 6.1.0 The `postTypes` property was added.
     * @since 6.2.0 The `templateTypes` property was added.
     * @since 6.4.0 Uses the `WP_Theme::get_block_patterns` method.
     * @access private
     * @phpstan-return void
     */
    function _register_theme_block_patterns()
    {
    }
    /**
     * Registers the align block attribute for block types that support it.
     *
     * @since 5.6.0
     * @access private
     *
     * @param WP_Block_Type $block_type Block Type.
     */
    function wp_register_alignment_support($block_type)
    {
    }
    /**
     * Adds CSS classes for block alignment to the incoming attributes array.
     * This will be applied to the block markup in the front-end.
     *
     * @since 5.6.0
     * @access private
     *
     * @param WP_Block_Type $block_type       Block Type.
     * @param array         $block_attributes Block attributes.
     * @return array Block alignment CSS classes and inline styles.
     */
    function wp_apply_alignment_support($block_type, $block_attributes)
    {
    }
    /**
     * Registers the style block attribute for block types that support it.
     *
     * @since 6.4.0
     * @access private
     *
     * @param WP_Block_Type $block_type Block Type.
     * @phpstan-return void
     */
    function wp_register_background_support($block_type)
    {
    }
    /**
     * Renders the background styles to the block wrapper.
     * This block support uses the `render_block` hook to ensure that
     * it is also applied to non-server-rendered blocks.
     *
     * @since 6.4.0
     * @since 6.5.0 Added support for `backgroundPosition` and `backgroundRepeat` output.
     * @since 6.6.0 Removed requirement for `backgroundImage.source`. A file/url is the default.
     * @since 6.7.0 Added support for `backgroundAttachment` output.
     *
     * @access private
     *
     * @param  string $block_content Rendered block content.
     * @param  array  $block         Block object.
     * @return string Filtered block content.
     */
    function wp_render_background_support($block_content, $block)
    {
    }
    /**
     * Determines the block style variation names within a CSS class string.
     *
     * @since 6.6.0
     *
     * @param string $class_string CSS class string to look for a variation in.
     *
     * @return array|null The block style variation name if found.
     */
    function wp_get_block_style_variation_name_from_class($class_string)
    {
    }
    /**
     * Recursively resolves any `ref` values within a block style variation's data.
     *
     * @since 6.6.0
     * @access private
     *
     * @param array $variation_data Reference to the variation data being processed.
     * @param array $theme_json     Theme.json data to retrieve referenced values from.
     */
    function wp_resolve_block_style_variation_ref_values(&$variation_data, $theme_json)
    {
    }
    /**
     * Render the block style variation's styles.
     *
     * In the case of nested blocks with variations applied, we want the parent
     * variation's styles to be rendered before their descendants. This solves the
     * issue of a block type being styled in both the parent and descendant: we want
     * the descendant style to take priority, and this is done by loading it after,
     * in the DOM order. This is why the variation stylesheet generation is in a
     * different filter.
     *
     * @since 6.6.0
     * @access private
     *
     * @param array $parsed_block The parsed block.
     *
     * @return array The parsed block with block style variation classname added.
     */
    function wp_render_block_style_variation_support_styles($parsed_block)
    {
    }
    /**
     * Ensure the variation block support class name generated and added to
     * block attributes in the `render_block_data` filter gets applied to the
     * block's markup.
     *
     * @see wp_render_block_style_variation_support_styles
     *
     * @since 6.6.0
     * @access private
     *
     * @param  string $block_content Rendered block content.
     * @param  array  $block         Block object.
     *
     * @return string                Filtered block content.
     */
    function wp_render_block_style_variation_class_name($block_content, $block)
    {
    }
    /**
     * Enqueues styles for block style variations.
     *
     * @since 6.6.0
     * @access private
     */
    function wp_enqueue_block_style_variation_styles()
    {
    }
    /**
     * Registers block style variations read in from theme.json partials.
     *
     * @since 6.6.0
     * @access private
     *
     * @param array $variations Shared block style variations.
     * @phpstan-return void
     */
    function wp_register_block_style_variations_from_theme_json_partials($variations)
    {
    }
    /**
     * Registers the style attribute used by the border feature if needed for block
     * types that support borders.
     *
     * @since 5.8.0
     * @since 6.1.0 Improved conditional blocks optimization.
     * @access private
     *
     * @param WP_Block_Type $block_type Block Type.
     */
    function wp_register_border_support($block_type)
    {
    }
    /**
     * Adds CSS classes and inline styles for border styles to the incoming
     * attributes array. This will be applied to the block markup in the front-end.
     *
     * @since 5.8.0
     * @since 6.1.0 Implemented the style engine to generate CSS and classnames.
     * @access private
     *
     * @param WP_Block_Type $block_type       Block type.
     * @param array         $block_attributes Block attributes.
     * @return array Border CSS classes and inline styles.
     */
    function wp_apply_border_support($block_type, $block_attributes)
    {
    }
    /**
     * Checks whether the current block type supports the border feature requested.
     *
     * If the `__experimentalBorder` support flag is a boolean `true` all border
     * support features are available. Otherwise, the specific feature's support
     * flag nested under `experimentalBorder` must be enabled for the feature
     * to be opted into.
     *
     * @since 5.8.0
     * @access private
     *
     * @param WP_Block_Type $block_type    Block type to check for support.
     * @param string        $feature       Name of the feature to check support for.
     * @param mixed         $default_value Fallback value for feature support, defaults to false.
     * @return bool Whether the feature is supported.
     */
    function wp_has_border_feature_support($block_type, $feature, $default_value = \false)
    {
    }
    /**
     * Registers the style and colors block attributes for block types that support it.
     *
     * @since 5.6.0
     * @since 6.1.0 Improved $color_support assignment optimization.
     * @access private
     *
     * @param WP_Block_Type $block_type Block Type.
     */
    function wp_register_colors_support($block_type)
    {
    }
    /**
     * Adds CSS classes and inline styles for colors to the incoming attributes array.
     * This will be applied to the block markup in the front-end.
     *
     * @since 5.6.0
     * @since 6.1.0 Implemented the style engine to generate CSS and classnames.
     * @access private
     *
     * @param  WP_Block_Type $block_type       Block type.
     * @param  array         $block_attributes Block attributes.
     *
     * @return array Colors CSS classes and inline styles.
     */
    function wp_apply_colors_support($block_type, $block_attributes)
    {
    }
    /**
     * Registers the custom classname block attribute for block types that support it.
     *
     * @since 5.6.0
     * @access private
     *
     * @param WP_Block_Type $block_type Block Type.
     */
    function wp_register_custom_classname_support($block_type)
    {
    }
    /**
     * Adds the custom classnames to the output.
     *
     * @since 5.6.0
     * @access private
     *
     * @param  WP_Block_Type $block_type       Block Type.
     * @param  array         $block_attributes Block attributes.
     *
     * @return array Block CSS classes and inline styles.
     */
    function wp_apply_custom_classname_support($block_type, $block_attributes)
    {
    }
    /**
     * Registers the style block attribute for block types that support it.
     *
     * @since 5.9.0
     * @access private
     *
     * @param WP_Block_Type $block_type Block Type.
     * @phpstan-return void
     */
    function wp_register_dimensions_support($block_type)
    {
    }
    /**
     * Adds CSS classes for block dimensions to the incoming attributes array.
     * This will be applied to the block markup in the front-end.
     *
     * @since 5.9.0
     * @since 6.2.0 Added `minHeight` support.
     * @access private
     *
     * @param WP_Block_Type $block_type       Block Type.
     * @param array         $block_attributes Block attributes.
     * @return array Block dimensions CSS classes and inline styles.
     */
    function wp_apply_dimensions_support($block_type, $block_attributes)
    {
    }
    /**
     * Renders server-side dimensions styles to the block wrapper.
     * This block support uses the `render_block` hook to ensure that
     * it is also applied to non-server-rendered blocks.
     *
     * @since 6.5.0
     * @access private
     *
     * @param  string $block_content Rendered block content.
     * @param  array  $block         Block object.
     * @return string                Filtered block content.
     */
    function wp_render_dimensions_support($block_content, $block)
    {
    }
    /**
     * Gets the elements class names.
     *
     * @since 6.0.0
     * @access private
     *
     * @param array $block Block object.
     * @return string The unique class name.
     */
    function wp_get_elements_class_name($block)
    {
    }
    /**
     * Determines whether an elements class name should be added to the block.
     *
     * @since 6.6.0
     * @access private
     *
     * @param  array $block   Block object.
     * @param  array $options Per element type options e.g. whether to skip serialization.
     * @return boolean Whether the block needs an elements class name.
     */
    function wp_should_add_elements_class_name($block, $options)
    {
    }
    /**
     * Render the elements stylesheet and adds elements class name to block as required.
     *
     * In the case of nested blocks we want the parent element styles to be rendered before their descendants.
     * This solves the issue of an element (e.g.: link color) being styled in both the parent and a descendant:
     * we want the descendant style to take priority, and this is done by loading it after, in DOM order.
     *
     * @since 6.0.0
     * @since 6.1.0 Implemented the style engine to generate CSS and classnames.
     * @since 6.6.0 Element block support class and styles are generated via the `render_block_data` filter instead of `pre_render_block`.
     * @access private
     *
     * @param array $parsed_block The parsed block.
     * @return array The same parsed block with elements classname added if appropriate.
     */
    function wp_render_elements_support_styles($parsed_block)
    {
    }
    /**
     * Ensure the elements block support class name generated, and added to
     * block attributes, in the `render_block_data` filter gets applied to the
     * block's markup.
     *
     * @see wp_render_elements_support_styles
     * @since 6.6.0
     *
     * @param  string $block_content Rendered block content.
     * @param  array  $block         Block object.
     * @return string                Filtered block content.
     */
    function wp_render_elements_class_name($block_content, $block)
    {
    }
    /**
     * Gets the generated classname from a given block name.
     *
     * @since 5.6.0
     *
     * @access private
     *
     * @param string $block_name Block Name.
     * @return string Generated classname.
     */
    function wp_get_block_default_classname($block_name)
    {
    }
    /**
     * Adds the generated classnames to the output.
     *
     * @since 5.6.0
     *
     * @access private
     *
     * @param WP_Block_Type $block_type Block Type.
     * @return array Block CSS classes and inline styles.
     */
    function wp_apply_generated_classname_support($block_type)
    {
    }
    /**
     * Returns layout definitions, keyed by layout type.
     *
     * Provides a common definition of slugs, classnames, base styles, and spacing styles for each layout type.
     * When making changes or additions to layout definitions, the corresponding JavaScript definitions should
     * also be updated.
     *
     * @since 6.3.0
     * @since 6.6.0 Updated specificity for compatibility with 0-1-0 global styles specificity.
     * @access private
     *
     * @return array[] Layout definitions.
     */
    function wp_get_layout_definitions()
    {
    }
    /**
     * Registers the layout block attribute for block types that support it.
     *
     * @since 5.8.0
     * @since 6.3.0 Check for layout support via the `layout` key with fallback to `__experimentalLayout`.
     * @access private
     *
     * @param WP_Block_Type $block_type Block Type.
     */
    function wp_register_layout_support($block_type)
    {
    }
    /**
     * Generates the CSS corresponding to the provided layout.
     *
     * @since 5.9.0
     * @since 6.1.0 Added `$block_spacing` param, use style engine to enqueue styles.
     * @since 6.3.0 Added grid layout type.
     * @since 6.6.0 Removed duplicated selector from layout styles.
     *              Enabled negative margins for alignfull children of blocks with custom padding.
     * @access private
     *
     * @param string               $selector                      CSS selector.
     * @param array                $layout                        Layout object. The one that is passed has already checked
     *                                                            the existence of default block layout.
     * @param bool                 $has_block_gap_support         Optional. Whether the theme has support for the block gap. Default false.
     * @param string|string[]|null $gap_value                     Optional. The block gap value to apply. Default null.
     * @param bool                 $should_skip_gap_serialization Optional. Whether to skip applying the user-defined value set in the editor. Default false.
     * @param string               $fallback_gap_value            Optional. The block gap value to apply. Default '0.5em'.
     * @param array|null           $block_spacing                 Optional. Custom spacing set on the block. Default null.
     * @return string CSS styles on success. Else, empty string.
     */
    function wp_get_layout_style($selector, $layout, $has_block_gap_support = \false, $gap_value = \null, $should_skip_gap_serialization = \false, $fallback_gap_value = '0.5em', $block_spacing = \null)
    {
    }
    /**
     * Renders the layout config to the block wrapper.
     *
     * @since 5.8.0
     * @since 6.3.0 Adds compound class to layout wrapper for global spacing styles.
     * @since 6.3.0 Check for layout support via the `layout` key with fallback to `__experimentalLayout`.
     * @since 6.6.0 Removed duplicate container class from layout styles.
     * @access private
     *
     * @param string $block_content Rendered block content.
     * @param array  $block         Block object.
     * @return string Filtered block content.
     */
    function wp_render_layout_support_flag($block_content, $block)
    {
    }
    /**
     * Check if the parent block exists and if it has a layout attribute.
     * If it does, add the parent layout to the parsed block
     *
     * @since 6.6.0
     * @access private
     *
     * @param array    $parsed_block The parsed block.
     * @param array    $source_block The source block.
     * @param WP_Block $parent_block The parent block.
     * @return array The parsed block with parent layout attribute if it exists.
     */
    function wp_add_parent_layout_to_parsed_block($parsed_block, $source_block, $parent_block)
    {
    }
    /**
     * For themes without theme.json file, make sure
     * to restore the inner div for the group block
     * to avoid breaking styles relying on that div.
     *
     * @since 5.8.0
     * @since 6.6.1 Removed inner container from Grid variations.
     * @access private
     *
     * @param string $block_content Rendered block content.
     * @param array  $block         Block object.
     * @return string Filtered block content.
     */
    function wp_restore_group_inner_container($block_content, $block)
    {
    }
    /**
     * For themes without theme.json file, make sure
     * to restore the outer div for the aligned image block
     * to avoid breaking styles relying on that div.
     *
     * @since 6.0.0
     * @access private
     *
     * @param string $block_content Rendered block content.
     * @param  array  $block        Block object.
     * @return string Filtered block content.
     */
    function wp_restore_image_outer_container($block_content, $block)
    {
    }
    /**
     * Registers the style block attribute for block types that support it.
     *
     * @since 6.2.0
     * @access private
     *
     * @param WP_Block_Type $block_type Block Type.
     */
    function wp_register_position_support($block_type)
    {
    }
    /**
     * Renders position styles to the block wrapper.
     *
     * @since 6.2.0
     * @access private
     *
     * @param  string $block_content Rendered block content.
     * @param  array  $block         Block object.
     * @return string                Filtered block content.
     */
    function wp_render_position_support($block_content, $block)
    {
    }
    /**
     * Get the class name used on block level presets.
     *
     * @internal
     *
     * @since 6.2.0
     * @access private
     *
     * @param array $block Block object.
     * @return string      The unique class name.
     */
    function _wp_get_presets_class_name($block)
    {
    }
    /**
     * Update the block content with block level presets class name.
     *
     * @internal
     *
     * @since 6.2.0
     * @access private
     *
     * @param  string $block_content Rendered block content.
     * @param  array  $block         Block object.
     * @return string                Filtered block content.
     */
    function _wp_add_block_level_presets_class($block_content, $block)
    {
    }
    /**
     * Render the block level presets stylesheet.
     *
     * @internal
     *
     * @since 6.2.0
     * @since 6.3.0 Updated preset styles to use Selectors API.
     * @access private
     *
     * @param string|null $pre_render   The pre-rendered content. Default null.
     * @param array       $block The block being rendered.
     *
     * @return null
     */
    function _wp_add_block_level_preset_styles($pre_render, $block)
    {
    }
    /**
     * Registers the style and shadow block attributes for block types that support it.
     *
     * @since 6.3.0
     * @access private
     *
     * @param WP_Block_Type $block_type Block Type.
     * @phpstan-return void
     */
    function wp_register_shadow_support($block_type)
    {
    }
    /**
     * Add CSS classes and inline styles for shadow features to the incoming attributes array.
     * This will be applied to the block markup in the front-end.
     *
     * @since 6.3.0
     * @since 6.6.0 Return early if __experimentalSkipSerialization is true.
     * @access private
     *
     * @param  WP_Block_Type $block_type       Block type.
     * @param  array         $block_attributes Block attributes.
     * @return array Shadow CSS classes and inline styles.
     */
    function wp_apply_shadow_support($block_type, $block_attributes)
    {
    }
    /**
     * Registers the style block attribute for block types that support it.
     *
     * @since 5.8.0
     * @access private
     *
     * @param WP_Block_Type $block_type Block Type.
     */
    function wp_register_spacing_support($block_type)
    {
    }
    /**
     * Adds CSS classes for block spacing to the incoming attributes array.
     * This will be applied to the block markup in the front-end.
     *
     * @since 5.8.0
     * @since 6.1.0 Implemented the style engine to generate CSS and classnames.
     * @access private
     *
     * @param WP_Block_Type $block_type       Block Type.
     * @param array         $block_attributes Block attributes.
     * @return array Block spacing CSS classes and inline styles.
     */
    function wp_apply_spacing_support($block_type, $block_attributes)
    {
    }
    /**
     * Registers the style and typography block attributes for block types that support it.
     *
     * @since 5.6.0
     * @since 6.3.0 Added support for text-columns.
     * @access private
     *
     * @param WP_Block_Type $block_type Block Type.
     * @phpstan-return void
     */
    function wp_register_typography_support($block_type)
    {
    }
    /**
     * Adds CSS classes and inline styles for typography features such as font sizes
     * to the incoming attributes array. This will be applied to the block markup in
     * the front-end.
     *
     * @since 5.6.0
     * @since 6.1.0 Used the style engine to generate CSS and classnames.
     * @since 6.3.0 Added support for text-columns.
     * @access private
     *
     * @param WP_Block_Type $block_type       Block type.
     * @param array         $block_attributes Block attributes.
     * @return array Typography CSS classes and inline styles.
     */
    function wp_apply_typography_support($block_type, $block_attributes)
    {
    }
    /**
     * Generates an inline style value for a typography feature e.g. text decoration,
     * text transform, and font style.
     *
     * Note: This function is for backwards compatibility.
     * * It is necessary to parse older blocks whose typography styles contain presets.
     * * It mostly replaces the deprecated `wp_typography_get_css_variable_inline_style()`,
     *   but skips compiling a CSS declaration as the style engine takes over this role.
     * @link https://github.com/wordpress/gutenberg/pull/27555
     *
     * @since 6.1.0
     *
     * @param string $style_value  A raw style value for a single typography feature from a block's style attribute.
     * @param string $css_property Slug for the CSS property the inline style sets.
     * @return string A CSS inline style value.
     */
    function wp_typography_get_preset_inline_style_value($style_value, $css_property)
    {
    }
    /**
     * Renders typography styles/content to the block wrapper.
     *
     * @since 6.1.0
     *
     * @param string $block_content Rendered block content.
     * @param array  $block         Block object.
     * @return string Filtered block content.
     */
    function wp_render_typography_support($block_content, $block)
    {
    }
    /**
     * Checks a string for a unit and value and returns an array
     * consisting of `'value'` and `'unit'`, e.g. array( '42', 'rem' ).
     *
     * @since 6.1.0
     *
     * @param string|int|float $raw_value Raw size value from theme.json.
     * @param array            $options   {
     *     Optional. An associative array of options. Default is empty array.
     *
     *     @type string   $coerce_to        Coerce the value to rem or px. Default `'rem'`.
     *     @type int      $root_size_value  Value of root font size for rem|em <-> px conversion. Default `16`.
     *     @type string[] $acceptable_units An array of font size units. Default `array( 'rem', 'px', 'em' )`;
     * }
     * @return array|null An array consisting of `'value'` and `'unit'` properties on success.
     *                    `null` on failure.
     * @phpstan-param array{
     *   coerce_to?: string,
     *   root_size_value?: int,
     *   acceptable_units?: string[],
     * } $options
     */
    function wp_get_typography_value_and_unit($raw_value, $options = array())
    {
    }
    /**
     * Internal implementation of CSS clamp() based on available min/max viewport
     * width and min/max font sizes.
     *
     * @since 6.1.0
     * @since 6.3.0 Checks for unsupported min/max viewport values that cause invalid clamp values.
     * @since 6.5.0 Returns early when min and max viewport subtraction is zero to avoid division by zero.
     * @access private
     *
     * @param array $args {
     *     Optional. An associative array of values to calculate a fluid formula
     *     for font size. Default is empty array.
     *
     *     @type string $maximum_viewport_width Maximum size up to which type will have fluidity.
     *     @type string $minimum_viewport_width Minimum viewport size from which type will have fluidity.
     *     @type string $maximum_font_size      Maximum font size for any clamp() calculation.
     *     @type string $minimum_font_size      Minimum font size for any clamp() calculation.
     *     @type int    $scale_factor           A scale factor to determine how fast a font scales within boundaries.
     * }
     * @return string|null A font-size value using clamp() on success, otherwise null.
     * @phpstan-param array{
     *   maximum_viewport_width?: string,
     *   minimum_viewport_width?: string,
     *   maximum_font_size?: string,
     *   minimum_font_size?: string,
     *   scale_factor?: int,
     * } $args
     */
    function wp_get_computed_fluid_typography_value($args = array())
    {
    }
    /**
     * Returns a font-size value based on a given font-size preset.
     * Takes into account fluid typography parameters and attempts to return a CSS
     * formula depending on available, valid values.
     *
     * @since 6.1.0
     * @since 6.1.1 Adjusted rules for min and max font sizes.
     * @since 6.2.0 Added 'settings.typography.fluid.minFontSize' support.
     * @since 6.3.0 Using layout.wideSize as max viewport width, and logarithmic scale factor to calculate minimum font scale.
     * @since 6.4.0 Added configurable min and max viewport width values to the typography.fluid theme.json schema.
     * @since 6.6.0 Deprecated bool argument $should_use_fluid_typography.
     * @since 6.7.0 Font size presets can enable fluid typography individually, even if it’s disabled globally.
     *
     * @param array      $preset   {
     *     Required. fontSizes preset value as seen in theme.json.
     *
     *     @type string           $name Name of the font size preset.
     *     @type string           $slug Kebab-case, unique identifier for the font size preset.
     *     @type string|int|float $size CSS font-size value, including units if applicable.
     * }
     * @param bool|array $settings Optional Theme JSON settings array that overrides any global theme settings.
     *                             Default is false.
     * @return string|null Font-size value or null if a size is not passed in $preset.
     * @phpstan-param array{
     *   name?: string,
     *   slug?: string,
     *   size?: string|int|float,
     * } $preset
     */
    function wp_get_typography_font_size_value($preset, $settings = array())
    {
    }
    /**
     * Checks whether serialization of the current block's supported properties
     * should occur.
     *
     * @since 6.0.0
     * @access private
     *
     * @param WP_Block_Type $block_type  Block type.
     * @param string        $feature_set Name of block support feature set..
     * @param string        $feature     Optional name of individual feature to check.
     *
     * @return bool Whether to serialize block support styles & classes.
     */
    function wp_should_skip_block_supports_serialization($block_type, $feature_set, $feature = \null)
    {
    }
    /**
     * For backward compatibility reasons,
     * block themes might be using block-templates or block-template-parts,
     * this function ensures we fallback to these folders properly.
     *
     * @since 5.9.0
     *
     * @param string $theme_stylesheet The stylesheet. Default is to leverage the main theme root.
     *
     * @return string[] {
     *     Folder names used by block themes.
     *
     *     @type string $wp_template      Theme-relative directory name for block templates.
     *     @type string $wp_template_part Theme-relative directory name for block template parts.
     * }
     * @phpstan-return array{
     *   wp_template: string,
     *   wp_template_part: string,
     * }
     */
    function get_block_theme_folders($theme_stylesheet = \null)
    {
    }
    /**
     * Returns a filtered list of allowed area values for template parts.
     *
     * @since 5.9.0
     *
     * @return array[] {
     *     The allowed template part area values.
     *
     *     @type array ...$0 {
     *         Data for the allowed template part area.
     *
     *         @type string $area        Template part area name.
     *         @type string $label       Template part area label.
     *         @type string $description Template part area description.
     *         @type string $icon        Template part area icon.
     *         @type string $area_tag    Template part area tag.
     *     }
     * }
     * @phpstan-return array<int|string, array{
     *   area: string,
     *   label: string,
     *   description: string,
     *   icon: string,
     *   area_tag: string,
     * }>
     */
    function get_allowed_block_template_part_areas()
    {
    }
    /**
     * Returns a filtered list of default template types, containing their
     * localized titles and descriptions.
     *
     * @since 5.9.0
     *
     * @return array[] {
     *     The default template types.
     *
     *     @type array ...$0 {
     *         Data for the template type.
     *
     *         @type string $title       Template type title.
     *         @type string $description Template type description.
     *    }
     * }
     * @phpstan-return array<int|string, array{
     *   title: string,
     *   description: string,
     * }>
     */
    function get_default_block_template_types()
    {
    }
    /**
     * Checks whether the input 'area' is a supported value.
     * Returns the input if supported, otherwise returns the 'uncategorized' value.
     *
     * @since 5.9.0
     * @access private
     *
     * @param string $type Template part area name.
     * @return string Input if supported, else the uncategorized value.
     */
    function _filter_block_template_part_area($type)
    {
    }
    /**
     * Finds all nested template part file paths in a theme's directory.
     *
     * @since 5.9.0
     * @access private
     *
     * @param string $base_directory The theme's file path.
     * @return string[] A list of paths to all template part files.
     */
    function _get_block_templates_paths($base_directory)
    {
    }
    /**
     * Retrieves the template file from the theme for a given slug.
     *
     * @since 5.9.0
     * @access private
     *
     * @param string $template_type Template type. Either 'wp_template' or 'wp_template_part'.
     * @param string $slug          Template slug.
     * @return array|null {
     *     Array with template metadata if $template_type is one of 'wp_template' or 'wp_template_part',
     *     null otherwise.
     *
     *     @type string   $slug      Template slug.
     *     @type string   $path      Template file path.
     *     @type string   $theme     Theme slug.
     *     @type string   $type      Template type.
     *     @type string   $area      Template area. Only for 'wp_template_part'.
     *     @type string   $title     Optional. Template title.
     *     @type string[] $postTypes Optional. List of post types that the template supports. Only for 'wp_template'.
     * }
     * @phpstan-param 'wp_template'|'wp_template_part' $template_type
     * @phpstan-return null|array{
     *   slug: string,
     *   path: string,
     *   theme: string,
     *   type: string,
     *   area: string,
     *   title: string,
     *   postTypes: string[],
     * }
     */
    function _get_block_template_file($template_type, $slug)
    {
    }
    /**
     * Retrieves the template files from the theme.
     *
     * @since 5.9.0
     * @since 6.3.0 Added the `$query` parameter.
     * @access private
     *
     * @param string $template_type Template type. Either 'wp_template' or 'wp_template_part'.
     * @param array  $query {
     *     Arguments to retrieve templates. Optional, empty by default.
     *
     *     @type string[] $slug__in     List of slugs to include.
     *     @type string[] $slug__not_in List of slugs to skip.
     *     @type string   $area         A 'wp_template_part_area' taxonomy value to filter by (for 'wp_template_part' template type only).
     *     @type string   $post_type    Post type to get the templates for.
     * }
     *
     * @return array|null Template files on success, null if `$template_type` is not matched.
     * @phpstan-param 'wp_template'|'wp_template_part' $template_type
     * @phpstan-param array{
     *   slug__in?: string[],
     *   slug__not_in?: string[],
     *   area?: string,
     *   post_type?: string,
     * } $query
     */
    function _get_block_templates_files($template_type, $query = array())
    {
    }
    /**
     * Attempts to add custom template information to the template item.
     *
     * @since 5.9.0
     * @access private
     *
     * @param array $template_item Template to add information to (requires 'slug' field).
     * @return array Template item.
     */
    function _add_block_template_info($template_item)
    {
    }
    /**
     * Attempts to add the template part's area information to the input template.
     *
     * @since 5.9.0
     * @access private
     *
     * @param array $template_info Template to add information to (requires 'type' and 'slug' fields).
     * @return array Template info.
     */
    function _add_block_template_part_area_info($template_info)
    {
    }
    /**
     * Returns an array containing the references of
     * the passed blocks and their inner blocks.
     *
     * @since 5.9.0
     * @access private
     *
     * @param array $blocks array of blocks.
     * @return array block references to the passed blocks and their inner blocks.
     */
    function _flatten_blocks(&$blocks)
    {
    }
    /**
     * Injects the active theme's stylesheet as a `theme` attribute
     * into a given template part block.
     *
     * @since 6.4.0
     * @access private
     *
     * @param array $block a parsed block.
     */
    function _inject_theme_attribute_in_template_part_block(&$block)
    {
    }
    /**
     * Removes the `theme` attribute from a given template part block.
     *
     * @since 6.4.0
     * @access private
     *
     * @param array $block a parsed block.
     */
    function _remove_theme_attribute_from_template_part_block(&$block)
    {
    }
    /**
     * Builds a unified template object based on a theme file.
     *
     * @since 5.9.0
     * @since 6.3.0 Added `modified` property to template objects.
     * @access private
     *
     * @param array  $template_file Theme file.
     * @param string $template_type Template type. Either 'wp_template' or 'wp_template_part'.
     * @return WP_Block_Template Template.
     * @phpstan-param 'wp_template'|'wp_template_part' $template_type
     */
    function _build_block_template_result_from_file($template_file, $template_type)
    {
    }
    /**
     * Builds the title and description of a post-specific template based on the underlying referenced post.
     *
     * Mutates the underlying template object.
     *
     * @since 6.1.0
     * @access private
     *
     * @param string            $post_type Post type, e.g. page, post, product.
     * @param string            $slug      Slug of the post, e.g. a-story-about-shoes.
     * @param WP_Block_Template $template  Template to mutate adding the description and title computed.
     * @return bool Returns true if the referenced post was found and false otherwise.
     */
    function _wp_build_title_and_description_for_single_post_type_block_template($post_type, $slug, \WP_Block_Template $template)
    {
    }
    /**
     * Builds the title and description of a taxonomy-specific template based on the underlying entity referenced.
     *
     * Mutates the underlying template object.
     *
     * @since 6.1.0
     * @access private
     *
     * @param string            $taxonomy Identifier of the taxonomy, e.g. category.
     * @param string            $slug     Slug of the term, e.g. shoes.
     * @param WP_Block_Template $template Template to mutate adding the description and title computed.
     * @return bool True if the term referenced was found and false otherwise.
     */
    function _wp_build_title_and_description_for_taxonomy_block_template($taxonomy, $slug, \WP_Block_Template $template)
    {
    }
    /**
     * Builds a block template object from a post object.
     *
     * This is a helper function that creates a block template object from a given post object.
     * It is self-sufficient in that it only uses information passed as arguments; it does not
     * query the database for additional information.
     *
     * @since 6.5.3
     * @access private
     *
     * @param WP_Post $post  Template post.
     * @param array   $terms Additional terms to inform the template object.
     * @param array   $meta  Additional meta fields to inform the template object.
     * @return WP_Block_Template|WP_Error Template or error object.
     */
    function _build_block_template_object_from_post_object($post, $terms = array(), $meta = array())
    {
    }
    /**
     * Builds a unified template object based a post Object.
     *
     * @since 5.9.0
     * @since 6.3.0 Added `modified` property to template objects.
     * @since 6.4.0 Added support for a revision post to be passed to this function.
     * @access private
     *
     * @param WP_Post $post Template post.
     * @return WP_Block_Template|WP_Error Template or error object.
     */
    function _build_block_template_result_from_post($post)
    {
    }
    /**
     * Retrieves a list of unified template objects based on a query.
     *
     * @since 5.8.0
     *
     * @param array  $query {
     *     Optional. Arguments to retrieve templates.
     *
     *     @type string[] $slug__in  List of slugs to include.
     *     @type int      $wp_id     Post ID of customized template.
     *     @type string   $area      A 'wp_template_part_area' taxonomy value to filter by (for 'wp_template_part' template type only).
     *     @type string   $post_type Post type to get the templates for.
     * }
     * @param string $template_type Template type. Either 'wp_template' or 'wp_template_part'.
     * @return WP_Block_Template[] Array of block templates.
     * @phpstan-param array{
     *   slug__in?: string[],
     *   wp_id?: int,
     *   area?: string,
     *   post_type?: string,
     * } $query
     * @phpstan-param 'wp_template'|'wp_template_part' $template_type
     */
    function get_block_templates($query = array(), $template_type = 'wp_template')
    {
    }
    /**
     * Retrieves a single unified template object using its id.
     *
     * @since 5.8.0
     *
     * @param string $id            Template unique identifier (example: 'theme_slug//template_slug').
     * @param string $template_type Optional. Template type. Either 'wp_template' or 'wp_template_part'.
     *                              Default 'wp_template'.
     * @return WP_Block_Template|null Template.
     * @phpstan-param 'wp_template'|'wp_template_part' $template_type
     */
    function get_block_template($id, $template_type = 'wp_template')
    {
    }
    /**
     * Retrieves a unified template object based on a theme file.
     *
     * This is a fallback of get_block_template(), used when no templates are found in the database.
     *
     * @since 5.9.0
     *
     * @param string $id            Template unique identifier (example: 'theme_slug//template_slug').
     * @param string $template_type Optional. Template type. Either 'wp_template' or 'wp_template_part'.
     *                              Default 'wp_template'.
     * @return WP_Block_Template|null The found block template, or null if there isn't one.
     * @phpstan-param 'wp_template'|'wp_template_part' $template_type
     */
    function get_block_file_template($id, $template_type = 'wp_template')
    {
    }
    /**
     * Prints a block template part.
     *
     * @since 5.9.0
     *
     * @param string $part The block template part to print, for example 'header' or 'footer'.
     * @phpstan-return void
     */
    function block_template_part($part)
    {
    }
    /**
     * Prints the header block template part.
     *
     * @since 5.9.0
     */
    function block_header_area()
    {
    }
    /**
     * Prints the footer block template part.
     *
     * @since 5.9.0
     */
    function block_footer_area()
    {
    }
    /**
     * Determines whether a theme directory should be ignored during export.
     *
     * @since 6.0.0
     *
     * @param string $path The path of the file in the theme.
     * @return bool Whether this file is in an ignored directory.
     */
    function wp_is_theme_directory_ignored($path)
    {
    }
    /**
     * Creates an export of the current templates and
     * template parts from the site editor at the
     * specified path in a ZIP file.
     *
     * @since 5.9.0
     * @since 6.0.0 Adds the whole theme to the export archive.
     *
     * @return WP_Error|string Path of the ZIP file or error on failure.
     */
    function wp_generate_block_templates_export_file()
    {
    }
    /**
     * Gets the template hierarchy for the given template slug to be created.
     *
     * Note: Always add `index` as the last fallback template.
     *
     * @since 6.1.0
     *
     * @param string $slug            The template slug to be created.
     * @param bool   $is_custom       Optional. Indicates if a template is custom or
     *                                part of the template hierarchy. Default false.
     * @param string $template_prefix Optional. The template prefix for the created template.
     *                                Used to extract the main template type, e.g.
     *                                in `taxonomy-books` the `taxonomy` is extracted.
     *                                Default empty string.
     * @return string[] The template hierarchy.
     */
    function get_template_hierarchy($slug, $is_custom = \false, $template_prefix = '')
    {
    }
    /**
     * Inject ignoredHookedBlocks metadata attributes into a template or template part.
     *
     * Given an object that represents a `wp_template` or `wp_template_part` post object
     * prepared for inserting or updating the database, locate all blocks that have
     * hooked blocks, and inject a `metadata.ignoredHookedBlocks` attribute into the anchor
     * blocks to reflect the latter.
     *
     * @since 6.5.0
     * @access private
     *
     * @param stdClass        $changes    An object representing a template or template part
     *                                    prepared for inserting or updating the database.
     * @param WP_REST_Request $deprecated Deprecated. Not used.
     * @return stdClass|WP_Error The updated object representing a template or template part.
     */
    function inject_ignored_hooked_blocks_metadata_attributes($changes, $deprecated = \null)
    {
    }
    /**
     * Adds necessary hooks to resolve '_wp-find-template' requests.
     *
     * @access private
     * @since 5.9.0
     */
    function _add_template_loader_filters()
    {
    }
    /**
     * Finds a block template with equal or higher specificity than a given PHP template file.
     *
     * Internally, this communicates the block content that needs to be used by the template canvas through a global variable.
     *
     * @since 5.8.0
     * @since 6.3.0 Added `$_wp_current_template_id` global for editing of current template directly from the admin bar.
     *
     * @global string $_wp_current_template_content
     * @global string $_wp_current_template_id
     *
     * @param string   $template  Path to the template. See locate_template().
     * @param string   $type      Sanitized filename without extension.
     * @param string[] $templates A list of template candidates, in descending order of priority.
     * @return string The path to the Site Editor template canvas file, or the fallback PHP template.
     */
    function locate_block_template($template, $type, array $templates)
    {
    }
    /**
     * Returns the correct 'wp_template' to render for the request template type.
     *
     * @access private
     * @since 5.8.0
     * @since 5.9.0 Added the `$fallback_template` parameter.
     *
     * @param string   $template_type      The current template type.
     * @param string[] $template_hierarchy The current template hierarchy, ordered by priority.
     * @param string   $fallback_template  A PHP fallback template to use if no matching block template is found.
     * @return WP_Block_Template|null template A template object, or null if none could be found.
     */
    function resolve_block_template($template_type, $template_hierarchy, $fallback_template)
    {
    }
    /**
     * Displays title tag with content, regardless of whether theme has title-tag support.
     *
     * @access private
     * @since 5.8.0
     *
     * @see _wp_render_title_tag()
     */
    function _block_template_render_title_tag()
    {
    }
    /**
     * Returns the markup for the current template.
     *
     * @access private
     * @since 5.8.0
     *
     * @global string   $_wp_current_template_id
     * @global string   $_wp_current_template_content
     * @global WP_Embed $wp_embed                     WordPress Embed object.
     * @global WP_Query $wp_query                     WordPress Query object.
     *
     * @return string Block template markup.
     */
    function get_the_block_template_html()
    {
    }
    /**
     * Renders a 'viewport' meta tag.
     *
     * This is hooked into {@see 'wp_head'} to decouple its output from the default template canvas.
     *
     * @access private
     * @since 5.8.0
     */
    function _block_template_viewport_meta_tag()
    {
    }
    /**
     * Strips .php or .html suffix from template file names.
     *
     * @access private
     * @since 5.8.0
     *
     * @param string $template_file Template file name.
     * @return string Template file name without extension.
     */
    function _strip_template_file_suffix($template_file)
    {
    }
    /**
     * Removes post details from block context when rendering a block template.
     *
     * @access private
     * @since 5.8.0
     *
     * @param array $context Default context.
     *
     * @return array Filtered context.
     */
    function _block_template_render_without_post_block_context($context)
    {
    }
    /**
     * Sets the current WP_Query to return auto-draft posts.
     *
     * The auto-draft status indicates a new post, so allow the the WP_Query instance to
     * return an auto-draft post for template resolution when editing a new post.
     *
     * @access private
     * @since 5.9.0
     *
     * @param WP_Query $wp_query Current WP_Query instance, passed by reference.
     * @phpstan-return void
     */
    function _resolve_template_for_new_post($wp_query)
    {
    }
    /**
     * Register a block template.
     *
     * @since 6.7.0
     *
     * @param string       $template_name  Template name in the form of `plugin_uri//template_name`.
     * @param array|string $args           {
     *     @type string        $title                 Optional. Title of the template as it will be shown in the Site Editor
     *                                                and other UI elements.
     *     @type string        $description           Optional. Description of the template as it will be shown in the Site
     *                                                Editor.
     *     @type string        $content               Optional. Default content of the template that will be used when the
     *                                                template is rendered or edited in the editor.
     *     @type string[]      $post_types            Optional. Array of post types to which the template should be available.
     *     @type string        $plugin                Optional. Slug of the plugin that registers the template.
     * }
     * @return WP_Block_Template|WP_Error The registered template object on success, WP_Error object on failure.
     * @phpstan-param array{
     *   title?: string,
     *   description?: string,
     *   content?: string,
     *   post_types?: string[],
     *   plugin?: string,
     * } $args
     */
    function register_block_template($template_name, $args = array())
    {
    }
    /**
     * Unregister a block template.
     *
     * @since 6.7.0
     *
     * @param string $template_name Template name in the form of `plugin_uri//template_name`.
     * @return WP_Block_Template|WP_Error The unregistered template object on success, WP_Error object on failure or if the
     *                                    template doesn't exist.
     */
    function unregister_block_template($template_name)
    {
    }
    /**
     * Removes the block asset's path prefix if provided.
     *
     * @since 5.5.0
     *
     * @param string $asset_handle_or_path Asset handle or prefixed path.
     * @return string Path without the prefix or the original value.
     */
    function remove_block_asset_path_prefix($asset_handle_or_path)
    {
    }
    /**
     * Generates the name for an asset based on the name of the block
     * and the field name provided.
     *
     * @since 5.5.0
     * @since 6.1.0 Added `$index` parameter.
     * @since 6.5.0 Added support for `viewScriptModule` field.
     *
     * @param string $block_name Name of the block.
     * @param string $field_name Name of the metadata field.
     * @param int    $index      Optional. Index of the asset when multiple items passed.
     *                           Default 0.
     * @return string Generated asset name for the block's field.
     */
    function generate_block_asset_handle($block_name, $field_name, $index = 0)
    {
    }
    /**
     * Gets the URL to a block asset.
     *
     * @since 6.4.0
     *
     * @param string $path A normalized path to a block asset.
     * @return string|false The URL to the block asset or false on failure.
     */
    function get_block_asset_url($path)
    {
    }
    /**
     * Finds a script module ID for the selected block metadata field. It detects
     * when a path to file was provided and optionally finds a corresponding asset
     * file with details necessary to register the script module under with an
     * automatically generated module ID. It returns unprocessed script module
     * ID otherwise.
     *
     * @since 6.5.0
     *
     * @param array  $metadata   Block metadata.
     * @param string $field_name Field name to pick from metadata.
     * @param int    $index      Optional. Index of the script module ID to register when multiple
     *                           items passed. Default 0.
     * @return string|false Script module ID or false on failure.
     */
    function register_block_script_module_id($metadata, $field_name, $index = 0)
    {
    }
    /**
     * Finds a script handle for the selected block metadata field. It detects
     * when a path to file was provided and optionally finds a corresponding asset
     * file with details necessary to register the script under automatically
     * generated handle name. It returns unprocessed script handle otherwise.
     *
     * @since 5.5.0
     * @since 6.1.0 Added `$index` parameter.
     * @since 6.5.0 The asset file is optional. Added script handle support in the asset file.
     *
     * @param array  $metadata   Block metadata.
     * @param string $field_name Field name to pick from metadata.
     * @param int    $index      Optional. Index of the script to register when multiple items passed.
     *                           Default 0.
     * @return string|false Script handle provided directly or created through
     *                      script's registration, or false on failure.
     */
    function register_block_script_handle($metadata, $field_name, $index = 0)
    {
    }
    /**
     * Finds a style handle for the block metadata field. It detects when a path
     * to file was provided and registers the style under automatically
     * generated handle name. It returns unprocessed style handle otherwise.
     *
     * @since 5.5.0
     * @since 6.1.0 Added `$index` parameter.
     *
     * @param array  $metadata   Block metadata.
     * @param string $field_name Field name to pick from metadata.
     * @param int    $index      Optional. Index of the style to register when multiple items passed.
     *                           Default 0.
     * @return string|false Style handle provided directly or created through
     *                      style's registration, or false on failure.
     */
    function register_block_style_handle($metadata, $field_name, $index = 0)
    {
    }
    /**
     * Gets i18n schema for block's metadata read from `block.json` file.
     *
     * @since 5.9.0
     *
     * @return object The schema for block's metadata.
     */
    function get_block_metadata_i18n_schema()
    {
    }
    /**
     * Registers a block metadata collection.
     *
     * This function allows core and third-party plugins to register their block metadata
     * collections in a centralized location. Registering collections can improve performance
     * by avoiding multiple reads from the filesystem and parsing JSON.
     *
     * @since 6.7.0
     *
     * @param string $path     The base path in which block files for the collection reside.
     * @param string $manifest The path to the manifest file for the collection.
     */
    function wp_register_block_metadata_collection($path, $manifest)
    {
    }
    /**
     * Registers a block type from the metadata stored in the `block.json` file.
     *
     * @since 5.5.0
     * @since 5.7.0 Added support for `textdomain` field and i18n handling for all translatable fields.
     * @since 5.9.0 Added support for `variations` and `viewScript` fields.
     * @since 6.1.0 Added support for `render` field.
     * @since 6.3.0 Added `selectors` field.
     * @since 6.4.0 Added support for `blockHooks` field.
     * @since 6.5.0 Added support for `allowedBlocks`, `viewScriptModule`, and `viewStyle` fields.
     * @since 6.7.0 Allow PHP filename as `variations` argument.
     *
     * @param string $file_or_folder Path to the JSON file with metadata definition for
     *                               the block or path to the folder where the `block.json` file is located.
     *                               If providing the path to a JSON file, the filename must end with `block.json`.
     * @param array  $args           Optional. Array of block type arguments. Accepts any public property
     *                               of `WP_Block_Type`. See WP_Block_Type::__construct() for information
     *                               on accepted arguments. Default empty array.
     * @return WP_Block_Type|false The registered block type on success, or false on failure.
     * @phpstan-param array{
     *   api_version?: string,
     *   title?: string,
     *   category?: string|null,
     *   parent?: string[]|null,
     *   ancestor?: string[]|null,
     *   allowed_blocks?: string[]|null,
     *   icon?: string|null,
     *   description?: string,
     *   keywords?: string[],
     *   textdomain?: string|null,
     *   styles?: array[],
     *   variations?: array[],
     *   selectors?: array,
     *   supports?: array|null,
     *   example?: array|null,
     *   render_callback?: callable|null,
     *   variation_callback?: callable|null,
     *   attributes?: array|null,
     *   uses_context?: string[],
     *   provides_context?: string[]|null,
     *   block_hooks?: string[],
     *   editor_script_handles?: string[],
     *   script_handles?: string[],
     *   view_script_handles?: string[],
     *   editor_style_handles?: string[],
     *   style_handles?: string[],
     *   view_style_handles?: string[],
     * } $args See WP_Block_Type::__construct()
     */
    function register_block_type_from_metadata($file_or_folder, $args = array())
    {
    }
    /**
     * Registers a block type. The recommended way is to register a block type using
     * the metadata stored in the `block.json` file.
     *
     * @since 5.0.0
     * @since 5.8.0 First parameter now accepts a path to the `block.json` file.
     *
     * @param string|WP_Block_Type $block_type Block type name including namespace, or alternatively
     *                                         a path to the JSON file with metadata definition for the block,
     *                                         or a path to the folder where the `block.json` file is located,
     *                                         or a complete WP_Block_Type instance.
     *                                         In case a WP_Block_Type is provided, the $args parameter will be ignored.
     * @param array                $args       Optional. Array of block type arguments. Accepts any public property
     *                                         of `WP_Block_Type`. See WP_Block_Type::__construct() for information
     *                                         on accepted arguments. Default empty array.
     *
     * @return WP_Block_Type|false The registered block type on success, or false on failure.
     * @phpstan-param array{
     *   api_version?: string,
     *   title?: string,
     *   category?: string|null,
     *   parent?: string[]|null,
     *   ancestor?: string[]|null,
     *   allowed_blocks?: string[]|null,
     *   icon?: string|null,
     *   description?: string,
     *   keywords?: string[],
     *   textdomain?: string|null,
     *   styles?: array[],
     *   variations?: array[],
     *   selectors?: array,
     *   supports?: array|null,
     *   example?: array|null,
     *   render_callback?: callable|null,
     *   variation_callback?: callable|null,
     *   attributes?: array|null,
     *   uses_context?: string[],
     *   provides_context?: string[]|null,
     *   block_hooks?: string[],
     *   editor_script_handles?: string[],
     *   script_handles?: string[],
     *   view_script_handles?: string[],
     *   editor_style_handles?: string[],
     *   style_handles?: string[],
     *   view_style_handles?: string[],
     * } $args See WP_Block_Type::__construct()
     */
    function register_block_type($block_type, $args = array())
    {
    }
    /**
     * Unregisters a block type.
     *
     * @since 5.0.0
     *
     * @param string|WP_Block_Type $name Block type name including namespace, or alternatively
     *                                   a complete WP_Block_Type instance.
     * @return WP_Block_Type|false The unregistered block type on success, or false on failure.
     */
    function unregister_block_type($name)
    {
    }
    /**
     * Determines whether a post or content string has blocks.
     *
     * This test optimizes for performance rather than strict accuracy, detecting
     * the pattern of a block but not validating its structure. For strict accuracy,
     * you should use the block parser on post content.
     *
     * @since 5.0.0
     *
     * @see parse_blocks()
     *
     * @param int|string|WP_Post|null $post Optional. Post content, post ID, or post object.
     *                                      Defaults to global $post.
     * @return bool Whether the post has blocks.
     */
    function has_blocks($post = \null)
    {
    }
    /**
     * Determines whether a $post or a string contains a specific block type.
     *
     * This test optimizes for performance rather than strict accuracy, detecting
     * whether the block type exists but not validating its structure and not checking
     * synced patterns (formerly called reusable blocks). For strict accuracy,
     * you should use the block parser on post content.
     *
     * @since 5.0.0
     *
     * @see parse_blocks()
     *
     * @param string                  $block_name Full block type to look for.
     * @param int|string|WP_Post|null $post       Optional. Post content, post ID, or post object.
     *                                            Defaults to global $post.
     * @return bool Whether the post content contains the specified block.
     */
    function has_block($block_name, $post = \null)
    {
    }
    /**
     * Returns an array of the names of all registered dynamic block types.
     *
     * @since 5.0.0
     *
     * @return string[] Array of dynamic block names.
     */
    function get_dynamic_block_names()
    {
    }
    /**
     * Retrieves block types hooked into the given block, grouped by anchor block type and the relative position.
     *
     * @since 6.4.0
     *
     * @return array[] Array of block types grouped by anchor block type and the relative position.
     */
    function get_hooked_blocks()
    {
    }
    /**
     * Returns the markup for blocks hooked to the given anchor block in a specific relative position.
     *
     * @since 6.5.0
     * @access private
     *
     * @param array                           $parsed_anchor_block The anchor block, in parsed block array format.
     * @param string                          $relative_position   The relative position of the hooked blocks.
     *                                                             Can be one of 'before', 'after', 'first_child', or 'last_child'.
     * @param array                           $hooked_blocks       An array of hooked block types, grouped by anchor block and relative position.
     * @param WP_Block_Template|WP_Post|array $context             The block template, template part, or pattern that the anchor block belongs to.
     * @return string
     * @phpstan-param 'before'|'after'|'first_child'|'last_child' $relative_position
     */
    function insert_hooked_blocks(&$parsed_anchor_block, $relative_position, $hooked_blocks, $context)
    {
    }
    /**
     * Adds a list of hooked block types to an anchor block's ignored hooked block types.
     *
     * This function is meant for internal use only.
     *
     * @since 6.5.0
     * @access private
     *
     * @param array                           $parsed_anchor_block The anchor block, in parsed block array format.
     * @param string                          $relative_position   The relative position of the hooked blocks.
     *                                                             Can be one of 'before', 'after', 'first_child', or 'last_child'.
     * @param array                           $hooked_blocks       An array of hooked block types, grouped by anchor block and relative position.
     * @param WP_Block_Template|WP_Post|array $context             The block template, template part, or pattern that the anchor block belongs to.
     * @return string Empty string.
     * @phpstan-param 'before'|'after'|'first_child'|'last_child' $relative_position
     */
    function set_ignored_hooked_blocks_metadata(&$parsed_anchor_block, $relative_position, $hooked_blocks, $context)
    {
    }
    /**
     * Runs the hooked blocks algorithm on the given content.
     *
     * @since 6.6.0
     * @since 6.7.0 Injects the `theme` attribute into Template Part blocks, even if no hooked blocks are registered.
     * @access private
     *
     * @param string                          $content  Serialized content.
     * @param WP_Block_Template|WP_Post|array $context  A block template, template part, `wp_navigation` post object,
     *                                                  or pattern that the blocks belong to.
     * @param callable                        $callback A function that will be called for each block to generate
     *                                                  the markup for a given list of blocks that are hooked to it.
     *                                                  Default: 'insert_hooked_blocks'.
     * @return string The serialized markup.
     */
    function apply_block_hooks_to_content($content, $context, $callback = 'insert_hooked_blocks')
    {
    }
    /**
     * Accepts the serialized markup of a block and its inner blocks, and returns serialized markup of the inner blocks.
     *
     * @since 6.6.0
     * @access private
     *
     * @param string $serialized_block The serialized markup of a block and its inner blocks.
     * @return string The serialized markup of the inner blocks.
     */
    function remove_serialized_parent_block($serialized_block)
    {
    }
    /**
     * Accepts the serialized markup of a block and its inner blocks, and returns serialized markup of the wrapper block.
     *
     * @since 6.7.0
     * @access private
     *
     * @see remove_serialized_parent_block()
     *
     * @param string $serialized_block The serialized markup of a block and its inner blocks.
     * @return string The serialized markup of the wrapper block.
     */
    function extract_serialized_parent_block($serialized_block)
    {
    }
    /**
     * Updates the wp_postmeta with the list of ignored hooked blocks where the inner blocks are stored as post content.
     * Currently only supports `wp_navigation` post types.
     *
     * @since 6.6.0
     * @access private
     *
     * @param stdClass $post Post object.
     * @return stdClass The updated post object.
     */
    function update_ignored_hooked_blocks_postmeta($post)
    {
    }
    /**
     * Returns the markup for blocks hooked to the given anchor block in a specific relative position and then
     * adds a list of hooked block types to an anchor block's ignored hooked block types.
     *
     * This function is meant for internal use only.
     *
     * @since 6.6.0
     * @access private
     *
     * @param array                           $parsed_anchor_block The anchor block, in parsed block array format.
     * @param string                          $relative_position   The relative position of the hooked blocks.
     *                                                             Can be one of 'before', 'after', 'first_child', or 'last_child'.
     * @param array                           $hooked_blocks       An array of hooked block types, grouped by anchor block and relative position.
     * @param WP_Block_Template|WP_Post|array $context             The block template, template part, or pattern that the anchor block belongs to.
     * @return string
     * @phpstan-param 'before'|'after'|'first_child'|'last_child' $relative_position
     */
    function insert_hooked_blocks_and_set_ignored_hooked_blocks_metadata(&$parsed_anchor_block, $relative_position, $hooked_blocks, $context)
    {
    }
    /**
     * Hooks into the REST API response for the core/navigation block and adds the first and last inner blocks.
     *
     * @since 6.6.0
     *
     * @param WP_REST_Response $response The response object.
     * @param WP_Post          $post     Post object.
     * @return WP_REST_Response The response object.
     */
    function insert_hooked_blocks_into_rest_response($response, $post)
    {
    }
    /**
     * Returns a function that injects the theme attribute into, and hooked blocks before, a given block.
     *
     * The returned function can be used as `$pre_callback` argument to `traverse_and_serialize_block(s)`,
     * where it will inject the `theme` attribute into all Template Part blocks, and prepend the markup for
     * any blocks hooked `before` the given block and as its parent's `first_child`, respectively.
     *
     * This function is meant for internal use only.
     *
     * @since 6.4.0
     * @since 6.5.0 Added $callback argument.
     * @access private
     *
     * @param array                           $hooked_blocks An array of blocks hooked to another given block.
     * @param WP_Block_Template|WP_Post|array $context       A block template, template part, `wp_navigation` post object,
     *                                                       or pattern that the blocks belong to.
     * @param callable                        $callback      A function that will be called for each block to generate
     *                                                       the markup for a given list of blocks that are hooked to it.
     *                                                       Default: 'insert_hooked_blocks'.
     * @return callable A function that returns the serialized markup for the given block,
     *                  including the markup for any hooked blocks before it.
     */
    function make_before_block_visitor($hooked_blocks, $context, $callback = 'insert_hooked_blocks')
    {
    }
    /**
     * Returns a function that injects the hooked blocks after a given block.
     *
     * The returned function can be used as `$post_callback` argument to `traverse_and_serialize_block(s)`,
     * where it will append the markup for any blocks hooked `after` the given block and as its parent's
     * `last_child`, respectively.
     *
     * This function is meant for internal use only.
     *
     * @since 6.4.0
     * @since 6.5.0 Added $callback argument.
     * @access private
     *
     * @param array                           $hooked_blocks An array of blocks hooked to another block.
     * @param WP_Block_Template|WP_Post|array $context       A block template, template part, `wp_navigation` post object,
     *                                                       or pattern that the blocks belong to.
     * @param callable                        $callback      A function that will be called for each block to generate
     *                                                       the markup for a given list of blocks that are hooked to it.
     *                                                       Default: 'insert_hooked_blocks'.
     * @return callable A function that returns the serialized markup for the given block,
     *                  including the markup for any hooked blocks after it.
     */
    function make_after_block_visitor($hooked_blocks, $context, $callback = 'insert_hooked_blocks')
    {
    }
    /**
     * Given an array of attributes, returns a string in the serialized attributes
     * format prepared for post content.
     *
     * The serialized result is a JSON-encoded string, with unicode escape sequence
     * substitution for characters which might otherwise interfere with embedding
     * the result in an HTML comment.
     *
     * This function must produce output that remains in sync with the output of
     * the serializeAttributes JavaScript function in the block editor in order
     * to ensure consistent operation between PHP and JavaScript.
     *
     * @since 5.3.1
     *
     * @param array $block_attributes Attributes object.
     * @return string Serialized attributes.
     */
    function serialize_block_attributes($block_attributes)
    {
    }
    /**
     * Returns the block name to use for serialization. This will remove the default
     * "core/" namespace from a block name.
     *
     * @since 5.3.1
     *
     * @param string|null $block_name Optional. Original block name. Null if the block name is unknown,
     *                                e.g. Classic blocks have their name set to null. Default null.
     * @return string Block name to use for serialization.
     */
    function strip_core_block_namespace($block_name = \null)
    {
    }
    /**
     * Returns the content of a block, including comment delimiters.
     *
     * @since 5.3.1
     *
     * @param string|null $block_name       Block name. Null if the block name is unknown,
     *                                      e.g. Classic blocks have their name set to null.
     * @param array       $block_attributes Block attributes.
     * @param string      $block_content    Block save content.
     * @return string Comment-delimited block content.
     */
    function get_comment_delimited_block_content($block_name, $block_attributes, $block_content)
    {
    }
    /**
     * Returns the content of a block, including comment delimiters, serializing all
     * attributes from the given parsed block.
     *
     * This should be used when preparing a block to be saved to post content.
     * Prefer `render_block` when preparing a block for display. Unlike
     * `render_block`, this does not evaluate a block's `render_callback`, and will
     * instead preserve the markup as parsed.
     *
     * @since 5.3.1
     *
     * @param array $block {
     *     An associative array of a single parsed block object. See WP_Block_Parser_Block.
     *
     *     @type string   $blockName    Name of block.
     *     @type array    $attrs        Attributes from block comment delimiters.
     *     @type array[]  $innerBlocks  List of inner blocks. An array of arrays that
     *                                  have the same structure as this one.
     *     @type string   $innerHTML    HTML from inside block comment delimiters.
     *     @type array    $innerContent List of string fragments and null markers where
     *                                  inner blocks were found.
     * }
     * @return string String of rendered HTML.
     * @phpstan-param array{
     *   blockName?: string,
     *   attrs?: array,
     *   innerBlocks?: array[],
     *   innerHTML?: string,
     *   innerContent?: array,
     * } $block
     */
    function serialize_block($block)
    {
    }
    /**
     * Returns a joined string of the aggregate serialization of the given
     * parsed blocks.
     *
     * @since 5.3.1
     *
     * @param array[] $blocks {
     *     Array of block structures.
     *
     *     @type array ...$0 {
     *         An associative array of a single parsed block object. See WP_Block_Parser_Block.
     *
     *         @type string   $blockName    Name of block.
     *         @type array    $attrs        Attributes from block comment delimiters.
     *         @type array[]  $innerBlocks  List of inner blocks. An array of arrays that
     *                                      have the same structure as this one.
     *         @type string   $innerHTML    HTML from inside block comment delimiters.
     *         @type array    $innerContent List of string fragments and null markers where
     *                                      inner blocks were found.
     *     }
     * }
     * @return string String of rendered HTML.
     * @phpstan-param array<int|string, array{
     *   blockName: string,
     *   attrs: array,
     *   innerBlocks: array[],
     *   innerHTML: string,
     *   innerContent: array,
     * }> $blocks
     */
    function serialize_blocks($blocks)
    {
    }
    /**
     * Traverses a parsed block tree and applies callbacks before and after serializing it.
     *
     * Recursively traverses the block and its inner blocks and applies the two callbacks provided as
     * arguments, the first one before serializing the block, and the second one after serializing it.
     * If either callback returns a string value, it will be prepended and appended to the serialized
     * block markup, respectively.
     *
     * The callbacks will receive a reference to the current block as their first argument, so that they
     * can also modify it, and the current block's parent block as second argument. Finally, the
     * `$pre_callback` receives the previous block, whereas the `$post_callback` receives
     * the next block as third argument.
     *
     * Serialized blocks are returned including comment delimiters, and with all attributes serialized.
     *
     * This function should be used when there is a need to modify the saved block, or to inject markup
     * into the return value. Prefer `serialize_block` when preparing a block to be saved to post content.
     *
     * This function is meant for internal use only.
     *
     * @since 6.4.0
     * @access private
     *
     * @see serialize_block()
     *
     * @param array    $block         An associative array of a single parsed block object. See WP_Block_Parser_Block.
     * @param callable $pre_callback  Callback to run on each block in the tree before it is traversed and serialized.
     *                                It is called with the following arguments: &$block, $parent_block, $previous_block.
     *                                Its string return value will be prepended to the serialized block markup.
     * @param callable $post_callback Callback to run on each block in the tree after it is traversed and serialized.
     *                                It is called with the following arguments: &$block, $parent_block, $next_block.
     *                                Its string return value will be appended to the serialized block markup.
     * @return string Serialized block markup.
     */
    function traverse_and_serialize_block($block, $pre_callback = \null, $post_callback = \null)
    {
    }
    /**
     * Replaces patterns in a block tree with their content.
     *
     * @since 6.6.0
     *
     * @param array $blocks An array blocks.
     *
     * @return array An array of blocks with patterns replaced by their content.
     */
    function resolve_pattern_blocks($blocks)
    {
    }
    /**
     * Given an array of parsed block trees, applies callbacks before and after serializing them and
     * returns their concatenated output.
     *
     * Recursively traverses the blocks and their inner blocks and applies the two callbacks provided as
     * arguments, the first one before serializing a block, and the second one after serializing.
     * If either callback returns a string value, it will be prepended and appended to the serialized
     * block markup, respectively.
     *
     * The callbacks will receive a reference to the current block as their first argument, so that they
     * can also modify it, and the current block's parent block as second argument. Finally, the
     * `$pre_callback` receives the previous block, whereas the `$post_callback` receives
     * the next block as third argument.
     *
     * Serialized blocks are returned including comment delimiters, and with all attributes serialized.
     *
     * This function should be used when there is a need to modify the saved blocks, or to inject markup
     * into the return value. Prefer `serialize_blocks` when preparing blocks to be saved to post content.
     *
     * This function is meant for internal use only.
     *
     * @since 6.4.0
     * @access private
     *
     * @see serialize_blocks()
     *
     * @param array[]  $blocks        An array of parsed blocks. See WP_Block_Parser_Block.
     * @param callable $pre_callback  Callback to run on each block in the tree before it is traversed and serialized.
     *                                It is called with the following arguments: &$block, $parent_block, $previous_block.
     *                                Its string return value will be prepended to the serialized block markup.
     * @param callable $post_callback Callback to run on each block in the tree after it is traversed and serialized.
     *                                It is called with the following arguments: &$block, $parent_block, $next_block.
     *                                Its string return value will be appended to the serialized block markup.
     * @return string Serialized block markup.
     */
    function traverse_and_serialize_blocks($blocks, $pre_callback = \null, $post_callback = \null)
    {
    }
    /**
     * Filters and sanitizes block content to remove non-allowable HTML
     * from parsed block attribute values.
     *
     * @since 5.3.1
     *
     * @param string         $text              Text that may contain block content.
     * @param array[]|string $allowed_html      Optional. An array of allowed HTML elements and attributes,
     *                                          or a context name such as 'post'. See wp_kses_allowed_html()
     *                                          for the list of accepted context names. Default 'post'.
     * @param string[]       $allowed_protocols Optional. Array of allowed URL protocols.
     *                                          Defaults to the result of wp_allowed_protocols().
     * @return string The filtered and sanitized content result.
     */
    function filter_block_content($text, $allowed_html = 'post', $allowed_protocols = array())
    {
    }
    /**
     * Callback used for regular expression replacement in filter_block_content().
     *
     * @since 6.2.1
     * @access private
     *
     * @param array $matches Array of preg_replace_callback matches.
     * @return string Replacement string.
     */
    function _filter_block_content_callback($matches)
    {
    }
    /**
     * Filters and sanitizes a parsed block to remove non-allowable HTML
     * from block attribute values.
     *
     * @since 5.3.1
     *
     * @param WP_Block_Parser_Block $block             The parsed block object.
     * @param array[]|string        $allowed_html      An array of allowed HTML elements and attributes,
     *                                                 or a context name such as 'post'. See wp_kses_allowed_html()
     *                                                 for the list of accepted context names.
     * @param string[]              $allowed_protocols Optional. Array of allowed URL protocols.
     *                                                 Defaults to the result of wp_allowed_protocols().
     * @return array The filtered and sanitized block object result.
     */
    function filter_block_kses($block, $allowed_html, $allowed_protocols = array())
    {
    }
    /**
     * Filters and sanitizes a parsed block attribute value to remove
     * non-allowable HTML.
     *
     * @since 5.3.1
     * @since 6.5.5 Added the `$block_context` parameter.
     *
     * @param string[]|string $value             The attribute value to filter.
     * @param array[]|string  $allowed_html      An array of allowed HTML elements and attributes,
     *                                           or a context name such as 'post'. See wp_kses_allowed_html()
     *                                           for the list of accepted context names.
     * @param string[]        $allowed_protocols Optional. Array of allowed URL protocols.
     *                                           Defaults to the result of wp_allowed_protocols().
     * @param array           $block_context     Optional. The block the attribute belongs to, in parsed block array format.
     * @return string[]|string The filtered and sanitized result.
     */
    function filter_block_kses_value($value, $allowed_html, $allowed_protocols = array(), $block_context = \null)
    {
    }
    /**
     * Sanitizes the value of the Template Part block's `tagName` attribute.
     *
     * @since 6.5.5
     *
     * @param string         $attribute_value The attribute value to filter.
     * @param string         $attribute_name  The attribute name.
     * @param array[]|string $allowed_html    An array of allowed HTML elements and attributes,
     *                                        or a context name such as 'post'. See wp_kses_allowed_html()
     *                                        for the list of accepted context names.
     * @return string The sanitized attribute value.
     */
    function filter_block_core_template_part_attributes($attribute_value, $attribute_name, $allowed_html)
    {
    }
    /**
     * Parses blocks out of a content string, and renders those appropriate for the excerpt.
     *
     * As the excerpt should be a small string of text relevant to the full post content,
     * this function renders the blocks that are most likely to contain such text.
     *
     * @since 5.0.0
     *
     * @param string $content The content to parse.
     * @return string The parsed and filtered content.
     */
    function excerpt_remove_blocks($content)
    {
    }
    /**
     * Parses footnotes markup out of a content string,
     * and renders those appropriate for the excerpt.
     *
     * @since 6.3.0
     *
     * @param string $content The content to parse.
     * @return string The parsed and filtered content.
     */
    function excerpt_remove_footnotes($content)
    {
    }
    /**
     * Renders inner blocks from the allowed wrapper blocks
     * for generating an excerpt.
     *
     * @since 5.8.0
     * @access private
     *
     * @param array $parsed_block   The parsed block.
     * @param array $allowed_blocks The list of allowed inner blocks.
     * @return string The rendered inner blocks.
     */
    function _excerpt_render_inner_blocks($parsed_block, $allowed_blocks)
    {
    }
    /**
     * Renders a single block into a HTML string.
     *
     * @since 5.0.0
     *
     * @global WP_Post $post The post to edit.
     *
     * @param array $parsed_block {
     *     An associative array of the block being rendered. See WP_Block_Parser_Block.
     *
     *     @type string   $blockName    Name of block.
     *     @type array    $attrs        Attributes from block comment delimiters.
     *     @type array[]  $innerBlocks  List of inner blocks. An array of arrays that
     *                                  have the same structure as this one.
     *     @type string   $innerHTML    HTML from inside block comment delimiters.
     *     @type array    $innerContent List of string fragments and null markers where
     *                                  inner blocks were found.
     * }
     * @return string String of rendered HTML.
     * @phpstan-param array{
     *   blockName?: string,
     *   attrs?: array,
     *   innerBlocks?: array[],
     *   innerHTML?: string,
     *   innerContent?: array,
     * } $parsed_block
     */
    function render_block($parsed_block)
    {
    }
    /**
     * Parses blocks out of a content string.
     *
     * @since 5.0.0
     *
     * @param string $content Post content.
     * @return array[] {
     *     Array of block structures.
     *
     *     @type array ...$0 {
     *         An associative array of a single parsed block object. See WP_Block_Parser_Block.
     *
     *         @type string   $blockName    Name of block.
     *         @type array    $attrs        Attributes from block comment delimiters.
     *         @type array[]  $innerBlocks  List of inner blocks. An array of arrays that
     *                                      have the same structure as this one.
     *         @type string   $innerHTML    HTML from inside block comment delimiters.
     *         @type array    $innerContent List of string fragments and null markers where
     *                                      inner blocks were found.
     *     }
     * }
     * @phpstan-return array<int|string, array{
     *   blockName: string,
     *   attrs: array,
     *   innerBlocks: array[],
     *   innerHTML: string,
     *   innerContent: array,
     * }>
     */
    function parse_blocks($content)
    {
    }
    /**
     * Parses dynamic blocks out of `post_content` and re-renders them.
     *
     * @since 5.0.0
     *
     * @param string $content Post content.
     * @return string Updated post content.
     */
    function do_blocks($content)
    {
    }
    /**
     * If do_blocks() needs to remove wpautop() from the `the_content` filter, this re-adds it afterwards,
     * for subsequent `the_content` usage.
     *
     * @since 5.0.0
     * @access private
     *
     * @param string $content The post content running through this filter.
     * @return string The unmodified content.
     */
    function _restore_wpautop_hook($content)
    {
    }
    /**
     * Returns the current version of the block format that the content string is using.
     *
     * If the string doesn't contain blocks, it returns 0.
     *
     * @since 5.0.0
     *
     * @param string $content Content to test.
     * @return int The block format version is 1 if the content contains one or more blocks, 0 otherwise.
     */
    function block_version($content)
    {
    }
    /**
     * Registers a new block style.
     *
     * @since 5.3.0
     * @since 6.6.0 Added support for registering styles for multiple block types.
     *
     * @link https://developer.wordpress.org/block-editor/reference-guides/block-api/block-styles/
     *
     * @param string|string[] $block_name       Block type name including namespace or array of namespaced block type names.
     * @param array           $style_properties Array containing the properties of the style name, label,
     *                                          style_handle (name of the stylesheet to be enqueued),
     *                                          inline_style (string containing the CSS to be added),
     *                                          style_data (theme.json-like array to generate CSS from).
     *                                          See WP_Block_Styles_Registry::register().
     * @return bool True if the block style was registered with success and false otherwise.
     * @phpstan-param array{
     *   name?: string,
     *   label?: string,
     *   inline_style?: string,
     *   style_handle?: string,
     *   is_default?: bool,
     *   style_data?: array,
     * } $style_properties See WP_Block_Styles_Registry::register()
     */
    function register_block_style($block_name, $style_properties)
    {
    }
    /**
     * Unregisters a block style.
     *
     * @since 5.3.0
     *
     * @param string $block_name       Block type name including namespace.
     * @param string $block_style_name Block style name.
     * @return bool True if the block style was unregistered with success and false otherwise.
     */
    function unregister_block_style($block_name, $block_style_name)
    {
    }
    /**
     * Checks whether the current block type supports the feature requested.
     *
     * @since 5.8.0
     * @since 6.4.0 The `$feature` parameter now supports a string.
     *
     * @param WP_Block_Type $block_type    Block type to check for support.
     * @param string|array  $feature       Feature slug, or path to a specific feature to check support for.
     * @param mixed         $default_value Optional. Fallback value for feature support. Default false.
     * @return bool Whether the feature is supported.
     */
    function block_has_support($block_type, $feature, $default_value = \false)
    {
    }
    /**
     * Converts typography keys declared under `supports.*` to `supports.typography.*`.
     *
     * Displays a `_doing_it_wrong()` notice when a block using the older format is detected.
     *
     * @since 5.8.0
     *
     * @param array $metadata Metadata for registering a block type.
     * @return array Filtered metadata for registering a block type.
     */
    function wp_migrate_old_typography_shape($metadata)
    {
    }
    /**
     * Helper function that constructs a WP_Query args array from
     * a `Query` block properties.
     *
     * It's used in Query Loop, Query Pagination Numbers and Query Pagination Next blocks.
     *
     * @since 5.8.0
     * @since 6.1.0 Added `query_loop_block_query_vars` filter and `parents` support in query.
     * @since 6.7.0 Added support for the `format` property in query.
     *
     * @param WP_Block $block Block instance.
     * @param int      $page  Current query's page.
     *
     * @return array Returns the constructed WP_Query arguments.
     */
    function build_query_vars_from_query_block($block, $page)
    {
    }
    /**
     * Helper function that returns the proper pagination arrow HTML for
     * `QueryPaginationNext` and `QueryPaginationPrevious` blocks based
     * on the provided `paginationArrow` from `QueryPagination` context.
     *
     * It's used in QueryPaginationNext and QueryPaginationPrevious blocks.
     *
     * @since 5.9.0
     *
     * @param WP_Block $block   Block instance.
     * @param bool     $is_next Flag for handling `next/previous` blocks.
     * @return string|null The pagination arrow HTML or null if there is none.
     */
    function get_query_pagination_arrow($block, $is_next)
    {
    }
    /**
     * Helper function that constructs a comment query vars array from the passed
     * block properties.
     *
     * It's used with the Comment Query Loop inner blocks.
     *
     * @since 6.0.0
     *
     * @param WP_Block $block Block instance.
     * @return array Returns the comment query parameters to use with the
     *               WP_Comment_Query constructor.
     */
    function build_comment_query_vars_from_block($block)
    {
    }
    /**
     * Helper function that returns the proper pagination arrow HTML for
     * `CommentsPaginationNext` and `CommentsPaginationPrevious` blocks based on the
     * provided `paginationArrow` from `CommentsPagination` context.
     *
     * It's used in CommentsPaginationNext and CommentsPaginationPrevious blocks.
     *
     * @since 6.0.0
     *
     * @param WP_Block $block           Block instance.
     * @param string   $pagination_type Optional. Type of the arrow we will be rendering.
     *                                  Accepts 'next' or 'previous'. Default 'next'.
     * @return string|null The pagination arrow HTML or null if there is none.
     * @phpstan-param 'next'|'previous' $pagination_type
     */
    function get_comments_pagination_arrow($block, $pagination_type = 'next')
    {
    }
    /**
     * Strips all HTML from the content of footnotes, and sanitizes the ID.
     *
     * This function expects slashed data on the footnotes content.
     *
     * @access private
     * @since 6.3.2
     *
     * @param string $footnotes JSON-encoded string of an array containing the content and ID of each footnote.
     * @return string Filtered content without any HTML on the footnote content and with the sanitized ID.
     */
    function _wp_filter_post_meta_footnotes($footnotes)
    {
    }
    /**
     * Adds the filters for footnotes meta field.
     *
     * @access private
     * @since 6.3.2
     */
    function _wp_footnotes_kses_init_filters()
    {
    }
    /**
     * Removes the filters for footnotes meta field.
     *
     * @access private
     * @since 6.3.2
     */
    function _wp_footnotes_remove_filters()
    {
    }
    /**
     * Registers the filter of footnotes meta field if the user does not have `unfiltered_html` capability.
     *
     * @access private
     * @since 6.3.2
     */
    function _wp_footnotes_kses_init()
    {
    }
    /**
     * Initializes the filters for footnotes meta field when imported data should be filtered.
     *
     * This filter is the last one being executed on {@see 'force_filtered_html_on_import'}.
     * If the input of the filter is true, it means we are in an import situation and should
     * enable kses, independently of the user capabilities. So in that case we call
     * _wp_footnotes_kses_init_filters().
     *
     * @access private
     * @since 6.3.2
     *
     * @param string $arg Input argument of the filter.
     * @return string Input argument of the filter.
     */
    function _wp_footnotes_force_filtered_html_on_import_filter($arg)
    {
    }
    /**
     * Renders the `core/archives` block on server.
     *
     * @since 5.0.0
     *
     * @see WP_Widget_Archives
     *
     * @param array $attributes The block attributes.
     *
     * @return string Returns the post content with archives added.
     */
    function render_block_core_archives($attributes)
    {
    }
    /**
     * Register archives block.
     *
     * @since 5.0.0
     */
    function register_block_core_archives()
    {
    }
    /**
     * Renders the `core/avatar` block on the server.
     *
     * @since 6.0.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     * @return string Return the avatar.
     */
    function render_block_core_avatar($attributes, $content, $block)
    {
    }
    /**
     * Generates class names and styles to apply the border support styles for
     * the Avatar block.
     *
     * @since 6.3.0
     *
     * @param array $attributes The block attributes.
     * @return array The border-related classnames and styles for the block.
     */
    function get_block_core_avatar_border_attributes($attributes)
    {
    }
    /**
     * Registers the `core/avatar` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_avatar()
    {
    }
    /**
     * Renders the `core/block` block on server.
     *
     * @since 5.0.0
     *
     * @global WP_Embed $wp_embed
     *
     * @param array $attributes The block attributes.
     *
     * @return string Rendered HTML of the referenced block.
     */
    function render_block_core_block($attributes)
    {
    }
    /**
     * Registers the `core/block` block.
     *
     * @since 5.3.0
     */
    function register_block_core_block()
    {
    }
    /**
     * Renders the `core/button` block on the server,
     *
     * @since 6.6.0
     *
     * @param array    $attributes The block attributes.
     * @param string   $content    The block content.
     * @param WP_Block $block      The block object.
     *
     * @return string The block content.
     */
    function render_block_core_button($attributes, $content)
    {
    }
    /**
     * Registers the `core/button` block on server.
     *
     * @since 6.6.0
     */
    function register_block_core_button()
    {
    }
    /**
     * Renders the `core/calendar` block on server.
     *
     * @since 5.2.0
     *
     * @global int $monthnum.
     * @global int $year.
     *
     * @param array $attributes The block attributes.
     *
     * @return string Returns the block content.
     */
    function render_block_core_calendar($attributes)
    {
    }
    /**
     * Registers the `core/calendar` block on server.
     *
     * @since 5.2.0
     */
    function register_block_core_calendar()
    {
    }
    /**
     * Returns whether or not there are any published posts.
     *
     * Used to hide the calendar block when there are no published posts.
     * This compensates for a known Core bug: https://core.trac.wordpress.org/ticket/12016
     *
     * @since 5.9.0
     *
     * @return bool Has any published posts or not.
     */
    function block_core_calendar_has_published_posts()
    {
    }
    /**
     * Queries the database for any published post and saves
     * a flag whether any published post exists or not.
     *
     * @since 5.9.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return bool Has any published posts or not.
     */
    function block_core_calendar_update_has_published_posts()
    {
    }
    /**
     * Handler for updating the has published posts flag when a post is deleted.
     *
     * @since 5.9.0
     *
     * @param int $post_id Deleted post ID.
     * @phpstan-return void
     */
    function block_core_calendar_update_has_published_post_on_delete($post_id)
    {
    }
    /**
     * Handler for updating the has published posts flag when a post status changes.
     *
     * @since 5.9.0
     *
     * @param string  $new_status The status the post is changing to.
     * @param string  $old_status The status the post is changing from.
     * @param WP_Post $post       Post object.
     * @phpstan-return void
     */
    function block_core_calendar_update_has_published_post_on_transition_post_status($new_status, $old_status, $post)
    {
    }
    /**
     * Renders the `core/categories` block on server.
     *
     * @since 5.0.0
     * @since 6.7.0 Enable client-side rendering if enhancedPagination context is true.
     *
     * @param array    $attributes The block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     *
     * @return string Returns the categories list/dropdown markup.
     */
    function render_block_core_categories($attributes, $content, $block)
    {
    }
    /**
     * Generates the inline script for a categories dropdown field.
     *
     * @since 5.0.0
     *
     * @param string $dropdown_id ID of the dropdown field.
     *
     * @return string Returns the dropdown onChange redirection script.
     */
    function build_dropdown_script_block_core_categories($dropdown_id)
    {
    }
    /**
     * Registers the `core/categories` block on server.
     *
     * @since 5.0.0
     */
    function register_block_core_categories()
    {
    }
    /**
     * Renders the `core/comment-author-name` block on the server.
     *
     * @since 6.0.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     * @return string Return the post comment's author.
     */
    function render_block_core_comment_author_name($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/comment-author-name` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_comment_author_name()
    {
    }
    /**
     * Renders the `core/comment-content` block on the server.
     *
     * @since 6.0.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     * @return string Return the post comment's content.
     */
    function render_block_core_comment_content($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/comment-content` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_comment_content()
    {
    }
    /**
     * Renders the `core/comment-date` block on the server.
     *
     * @since 6.0.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     * @return string Return the post comment's date.
     */
    function render_block_core_comment_date($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/comment-date` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_comment_date()
    {
    }
    /**
     * Renders the `core/comment-edit-link` block on the server.
     *
     * @since 6.0.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     *
     * @return string Return the post comment's date.
     */
    function render_block_core_comment_edit_link($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/comment-edit-link` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_comment_edit_link()
    {
    }
    /**
     * Renders the `core/comment-reply-link` block on the server.
     *
     * @since 6.0.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     * @return string Return the post comment's reply link.
     */
    function render_block_core_comment_reply_link($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/comment-reply-link` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_comment_reply_link()
    {
    }
    /**
     * Function that recursively renders a list of nested comments.
     *
     * @since 6.3.0 Changed render_block_context priority to `1`.
     *
     * @global int $comment_depth
     *
     * @param WP_Comment[] $comments        The array of comments.
     * @param WP_Block     $block           Block instance.
     * @return string
     */
    function block_core_comment_template_render_comments($comments, $block)
    {
    }
    /**
     * Renders the `core/comment-template` block on the server.
     *
     * @since 6.0.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     *
     * @return string Returns the HTML representing the comments using the layout
     * defined by the block's inner blocks.
     */
    function render_block_core_comment_template($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/comment-template` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_comment_template()
    {
    }
    /**
     * Renders the `core/comments-pagination-next` block on the server.
     *
     * @since 6.0.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     *
     * @return string Returns the next comments link for the query pagination.
     */
    function render_block_core_comments_pagination_next($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/comments-pagination-next` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_comments_pagination_next()
    {
    }
    /**
     * Renders the `core/comments-pagination-numbers` block on the server.
     *
     * @since 6.0.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     *
     * @return string Returns the pagination numbers for the comments.
     */
    function render_block_core_comments_pagination_numbers($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/comments-pagination-numbers` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_comments_pagination_numbers()
    {
    }
    /**
     * Renders the `core/comments-pagination-previous` block on the server.
     *
     * @since 6.0.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     *
     * @return string Returns the previous posts link for the comments pagination.
     */
    function render_block_core_comments_pagination_previous($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/comments-pagination-previous` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_comments_pagination_previous()
    {
    }
    /**
     * Renders the `core/comments-pagination` block on the server.
     *
     * @since 6.0.0
     *
     * @param array  $attributes Block attributes.
     * @param string $content    Block default content.
     *
     * @return string Returns the wrapper for the Comments pagination.
     */
    function render_block_core_comments_pagination($attributes, $content)
    {
    }
    /**
     * Registers the `core/comments-pagination` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_comments_pagination()
    {
    }
    /**
     * Renders the `core/comments-title` block on the server.
     *
     * @since 6.0.0
     *
     * @param array $attributes Block attributes.
     *
     * @return string Return the post comments title.
     */
    function render_block_core_comments_title($attributes)
    {
    }
    /**
     * Registers the `core/comments-title` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_comments_title()
    {
    }
    /**
     * Renders the `core/comments` block on the server.
     *
     * This render callback is mainly for rendering a dynamic, legacy version of
     * this block (the old `core/post-comments`). It uses the `comments_template()`
     * function to generate the output, in the same way as classic PHP themes.
     *
     * As this callback will always run during SSR, first we need to check whether
     * the block is in legacy mode. If not, the HTML generated in the editor is
     * returned instead.
     *
     * @since 6.1.0
     *
     * @global WP_Post $post Global post object.
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     * @return string Returns the filtered post comments for the current post wrapped inside "p" tags.
     */
    function render_block_core_comments($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/comments` block on the server.
     *
     * @since 6.1.0
     */
    function register_block_core_comments()
    {
    }
    /**
     * Use the button block classes for the form-submit button.
     *
     * @since 6.1.0
     *
     * @param array $fields The default comment form arguments.
     *
     * @return array Returns the modified fields.
     */
    function comments_block_form_defaults($fields)
    {
    }
    /**
     * Enqueues styles from the legacy `core/post-comments` block. These styles are
     * required only by the block's fallback.
     *
     * @since 6.1.0
     *
     * @param string $block_name Name of the new block type.
     */
    function enqueue_legacy_post_comments_block_styles($block_name)
    {
    }
    /**
     * Ensures backwards compatibility for any users running the Gutenberg plugin
     * who have used Post Comments before it was merged into Comments Query Loop.
     *
     * The same approach was followed when core/query-loop was renamed to
     * core/post-template.
     *
     * @since 6.1.0
     *
     * @see https://github.com/WordPress/gutenberg/pull/41807
     * @see https://github.com/WordPress/gutenberg/pull/32514
     */
    function register_legacy_post_comments_block()
    {
    }
    /**
     * Renders the `core/cover` block on server.
     *
     * @since 6.0.0
     *
     * @param array  $attributes The block attributes.
     * @param string $content    The block rendered content.
     *
     * @return string Returns the cover block markup, if useFeaturedImage is true.
     */
    function render_block_core_cover($attributes, $content)
    {
    }
    /**
     * Registers the `core/cover` block renderer on server.
     *
     * @since 6.0.0
     */
    function register_block_core_cover()
    {
    }
    /**
     * When the `core/file` block is rendering, check if we need to enqueue the `wp-block-file-view` script.
     *
     * @since 5.8.0
     *
     * @param array    $attributes The block attributes.
     * @param string   $content    The block content.
     * @param WP_Block $block      The parsed block.
     *
     * @return string Returns the block content.
     */
    function render_block_core_file($attributes, $content)
    {
    }
    /**
     * Registers the `core/file` block on server.
     *
     * @since 5.8.0
     */
    function register_block_core_file()
    {
    }
    /**
     * Renders the `core/footnotes` block on the server.
     *
     * @since 6.3.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     *
     * @return string Returns the HTML representing the footnotes.
     */
    function render_block_core_footnotes($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/footnotes` block on the server.
     *
     * @since 6.3.0
     */
    function register_block_core_footnotes()
    {
    }
    /**
     * Registers the footnotes meta field required for footnotes to work.
     *
     * @since 6.5.0
     */
    function register_block_core_footnotes_post_meta()
    {
    }
    /**
     * Adds the footnotes field to the revisions display.
     *
     * @since 6.3.0
     *
     * @param array $fields The revision fields.
     * @return array The revision fields.
     */
    function wp_add_footnotes_to_revision($fields)
    {
    }
    /**
     * Gets the footnotes field from the revision for the revisions screen.
     *
     * @since 6.3.0
     *
     * @param string $revision_field The field value, but $revision->$field
     *                               (footnotes) does not exist.
     * @param string $field          The field name, in this case "footnotes".
     * @param object $revision       The revision object to compare against.
     * @return string The field value.
     */
    function wp_get_footnotes_from_revision($revision_field, $field, $revision)
    {
    }
    /**
     * Handles backwards compatibility for Gallery Blocks,
     * whose images feature a `data-id` attribute.
     *
     * Now that the Gallery Block contains inner Image Blocks,
     * we add a custom `data-id` attribute before rendering the gallery
     * so that the Image Block can pick it up in its render_callback.
     *
     * @since 5.9.0
     *
     * @param array $parsed_block The block being rendered.
     * @return array The migrated block object.
     */
    function block_core_gallery_data_id_backcompatibility($parsed_block)
    {
    }
    /**
     * Renders the `core/gallery` block on the server.
     *
     * @since 6.0.0
     *
     * @param array  $attributes Attributes of the block being rendered.
     * @param string $content Content of the block being rendered.
     * @return string The content of the block being rendered.
     */
    function block_core_gallery_render($attributes, $content)
    {
    }
    /**
     * Registers the `core/gallery` block on server.
     *
     * @since 5.9.0
     */
    function register_block_core_gallery()
    {
    }
    /**
     * Adds a wp-block-heading class to the heading block content.
     *
     * For example, the following block content:
     *  <h2 class="align-left">Hello World</h2>
     *
     * Would be transformed to:
     *  <h2 class="align-left wp-block-heading">Hello World</h2>
     *
     * @since 6.2.0
     *
     * @param array  $attributes Attributes of the block being rendered.
     * @param string $content Content of the block being rendered.
     *
     * @return string The content of the block being rendered.
     */
    function block_core_heading_render($attributes, $content)
    {
    }
    /**
     * Registers the `core/heading` block on server.
     *
     * @since 6.2.0
     */
    function register_block_core_heading()
    {
    }
    /**
     * Build an array with CSS classes and inline styles defining the colors
     * which will be applied to the home link markup in the front-end.
     *
     * @since 6.0.0
     *
     * @param  array $context home link block context.
     * @return array Colors CSS classes and inline styles.
     */
    function block_core_home_link_build_css_colors($context)
    {
    }
    /**
     * Build an array with CSS classes and inline styles defining the font sizes
     * which will be applied to the home link markup in the front-end.
     *
     * @since 6.0.0
     *
     * @param  array $context Home link block context.
     * @return array Font size CSS classes and inline styles.
     */
    function block_core_home_link_build_css_font_sizes($context)
    {
    }
    /**
     * Builds an array with classes and style for the li wrapper
     *
     * @since 6.0.0
     *
     * @param  array $context    Home link block context.
     * @return string The li wrapper attributes.
     */
    function block_core_home_link_build_li_wrapper_attributes($context)
    {
    }
    /**
     * Renders the `core/home-link` block.
     *
     * @since 6.0.0
     *
     * @param array    $attributes The block attributes.
     * @param string   $content    The saved content.
     * @param WP_Block $block      The parsed block.
     *
     * @return string Returns the post content with the home url added.
     */
    function render_block_core_home_link($attributes, $content, $block)
    {
    }
    /**
     * Register the home block
     *
     * @since 6.0.0
     *
     * @uses render_block_core_home_link()
     * @throws WP_Error An WP_Error exception parsing the block definition.
     */
    function register_block_core_home_link()
    {
    }
    /**
     * Renders the `core/image` block on the server,
     * adding a data-id attribute to the element if core/gallery has added on pre-render.
     *
     * @since 5.9.0
     *
     * @param array    $attributes The block attributes.
     * @param string   $content    The block content.
     * @param WP_Block $block      The block object.
     *
     * @return string The block content with the data-id attribute added.
     */
    function render_block_core_image($attributes, $content, $block)
    {
    }
    /**
     * Adds the lightboxEnabled flag to the block data.
     *
     * This is used to determine whether the lightbox should be rendered or not.
     *
     * @since 6.4.0
     *
     * @param array $block Block data.
     *
     * @return array Filtered block data.
     */
    function block_core_image_get_lightbox_settings($block)
    {
    }
    /**
     * Adds the directives and layout needed for the lightbox behavior.
     *
     * @since 6.4.0
     *
     * @param string $block_content Rendered block content.
     * @param array  $block         Block object.
     *
     * @return string Filtered block content.
     */
    function block_core_image_render_lightbox($block_content, $block)
    {
    }
    /**
     * @since 6.5.0
     */
    function block_core_image_print_lightbox_overlay()
    {
    }
    /**
     * Registers the `core/image` block on server.
     *
     * @since 5.9.0
     */
    function register_block_core_image()
    {
    }
    /**
     * Registers core block style handles.
     *
     * While {@see register_block_style_handle()} is typically used for that, the way it is
     * implemented is inefficient for core block styles. Registering those style handles here
     * avoids unnecessary logic and filesystem lookups in the other function.
     *
     * @since 6.3.0
     */
    function register_core_block_style_handles()
    {
    }
    /**
     * Registers core block types using metadata files.
     * Dynamic core blocks are registered separately.
     *
     * @since 5.5.0
     */
    function register_core_block_types_from_metadata()
    {
    }
    /**
     * Registers the core block metadata collection.
     *
     * This function is hooked into the 'init' action with a priority of 9,
     * ensuring that the core block metadata is registered before the regular
     * block initialization that happens at priority 10.
     *
     * @since 6.7.0
     */
    function wp_register_core_block_metadata_collection()
    {
    }
    /**
     * Get the post title.
     *
     * The post title is fetched and if it is blank then a default string is
     * returned.
     *
     * Copied from `wp-admin/includes/template.php`, but we can't include that
     * file because:
     *
     * 1. It causes bugs with test fixture generation and strange Docker 255 error
     *    codes.
     * 2. It's in the admin; ideally we *shouldn't* be including files from the
     *    admin for a block's output. It's a very small/simple function as well,
     *    so duplicating it isn't too terrible.
     *
     * @since 3.3.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return string The post title if set; "(no title)" if no title is set.
     */
    function wp_latest_comments_draft_or_post_title($post = 0)
    {
    }
    /**
     * Renders the `core/latest-comments` block on server.
     *
     * @since 5.1.0
     *
     * @param array $attributes The block attributes.
     *
     * @return string Returns the post content with latest comments added.
     */
    function render_block_core_latest_comments($attributes = array())
    {
    }
    /**
     * Registers the `core/latest-comments` block.
     *
     * @since 5.3.0
     */
    function register_block_core_latest_comments()
    {
    }
    /**
     * Callback for the excerpt_length filter used by
     * the Latest Posts block at render time.
     *
     * @since 5.4.0
     *
     * @return int Returns the global $block_core_latest_posts_excerpt_length variable
     *             to allow the excerpt_length filter respect the Latest Block setting.
     */
    function block_core_latest_posts_get_excerpt_length()
    {
    }
    /**
     * Renders the `core/latest-posts` block on server.
     *
     * @since 5.0.0
     *
     * @param array $attributes The block attributes.
     *
     * @return string Returns the post content with latest posts added.
     */
    function render_block_core_latest_posts($attributes)
    {
    }
    /**
     * Registers the `core/latest-posts` block on server.
     *
     * @since 5.0.0
     */
    function register_block_core_latest_posts()
    {
    }
    /**
     * Handles outdated versions of the `core/latest-posts` block by converting
     * attribute `categories` from a numeric string to an array with key `id`.
     *
     * This is done to accommodate the changes introduced in #20781 that sought to
     * add support for multiple categories to the block. However, given that this
     * block is dynamic, the usual provisions for block migration are insufficient,
     * as they only act when a block is loaded in the editor.
     *
     * TODO: Remove when and if the bottom client-side deprecation for this block
     * is removed.
     *
     * @since 5.5.0
     *
     * @param array $block A single parsed block object.
     *
     * @return array The migrated block object.
     */
    function block_core_latest_posts_migrate_categories($block)
    {
    }
    /**
     * Renders the 'core/legacy-widget' block.
     *
     * @since 5.8.0
     *
     * @global int $wp_widget_factory.
     *
     * @param array $attributes The block attributes.
     *
     * @return string Rendered block.
     */
    function render_block_core_legacy_widget($attributes)
    {
    }
    /**
     * Registers the 'core/legacy-widget' block.
     *
     * @since 5.8.0
     */
    function register_block_core_legacy_widget()
    {
    }
    /**
     * Intercepts any request with legacy-widget-preview in the query param and, if
     * set, renders a page containing a preview of the requested Legacy Widget
     * block.
     *
     * @since 5.8.0
     * @phpstan-return void
     */
    function handle_legacy_widget_preview_iframe()
    {
    }
    /**
     * Adds the wp-block-list class to the rendered list block.
     * Ensures that pre-existing list blocks use the class name on the front.
     * For example, <ol> is transformed to <ol class="wp-block-list">.
     *
     * @since 6.6.0
     *
     * @see https://github.com/WordPress/gutenberg/issues/12420
     *
     * @param array  $attributes Attributes of the block being rendered.
     * @param string $content Content of the block being rendered.
     *
     * @return string The content of the block being rendered.
     */
    function block_core_list_render($attributes, $content)
    {
    }
    /**
     * Registers the `core/list` block on server.
     *
     * @since 6.6.0
     */
    function register_block_core_list()
    {
    }
    /**
     * Renders the `core/loginout` block on server.
     *
     * @since 5.8.0
     *
     * @param array $attributes The block attributes.
     *
     * @return string Returns the login-out link or form.
     */
    function render_block_core_loginout($attributes)
    {
    }
    /**
     * Registers the `core/loginout` block on server.
     *
     * @since 5.8.0
     */
    function register_block_core_loginout()
    {
    }
    /**
     * Renders the `core/media-text` block on server.
     *
     * @since 6.6.0
     *
     * @param array  $attributes The block attributes.
     * @param string $content    The block rendered content.
     *
     * @return string Returns the Media & Text block markup, if useFeaturedImage is true.
     */
    function render_block_core_media_text($attributes, $content)
    {
    }
    /**
     * Registers the `core/media-text` block renderer on server.
     *
     * @since 6.6.0
     */
    function register_block_core_media_text()
    {
    }
    /**
     * Build an array with CSS classes and inline styles defining the colors
     * which will be applied to the navigation markup in the front-end.
     *
     * @since 5.9.0
     *
     * @param  array $context     Navigation block context.
     * @param  array $attributes  Block attributes.
     * @param  bool  $is_sub_menu Whether the link is part of a sub-menu.
     * @return array Colors CSS classes and inline styles.
     */
    function block_core_navigation_link_build_css_colors($context, $attributes, $is_sub_menu = \false)
    {
    }
    /**
     * Build an array with CSS classes and inline styles defining the font sizes
     * which will be applied to the navigation markup in the front-end.
     *
     * @since 5.9.0
     *
     * @param  array $context Navigation block context.
     * @return array Font size CSS classes and inline styles.
     */
    function block_core_navigation_link_build_css_font_sizes($context)
    {
    }
    /**
     * Returns the top-level submenu SVG chevron icon.
     *
     * @since 5.9.0
     *
     * @return string
     */
    function block_core_navigation_link_render_submenu_icon()
    {
    }
    /**
     * Decodes a url if it's encoded, returning the same url if not.
     *
     * @since 6.2.0
     *
     * @param string $url The url to decode.
     *
     * @return string $url Returns the decoded url.
     */
    function block_core_navigation_link_maybe_urldecode($url)
    {
    }
    /**
     * Renders the `core/navigation-link` block.
     *
     * @since 5.9.0
     *
     * @param array    $attributes The block attributes.
     * @param string   $content    The saved content.
     * @param WP_Block $block      The parsed block.
     *
     * @return string Returns the post content with the legacy widget added.
     */
    function render_block_core_navigation_link($attributes, $content, $block)
    {
    }
    /**
     * Returns a navigation link variation
     *
     * @since 5.9.0
     *
     * @param WP_Taxonomy|WP_Post_Type $entity post type or taxonomy entity.
     * @param string                   $kind string of value 'taxonomy' or 'post-type'.
     *
     * @return array
     */
    function build_variation_for_navigation_link($entity, $kind)
    {
    }
    /**
     * Filters the registered variations for a block type.
     * Returns the dynamically built variations for all post-types and taxonomies.
     *
     * @since 6.5.0
     *
     * @param array         $variations Array of registered variations for a block type.
     * @param WP_Block_Type $block_type The full block type object.
     */
    function block_core_navigation_link_filter_variations($variations, $block_type)
    {
    }
    /**
     * Returns an array of variations for the navigation link block.
     *
     * @since 6.5.0
     *
     * @return array
     */
    function block_core_navigation_link_build_variations()
    {
    }
    /**
     * Registers the navigation link block.
     *
     * @since 5.9.0
     *
     * @uses render_block_core_navigation_link()
     * @throws WP_Error An WP_Error exception parsing the block definition.
     */
    function register_block_core_navigation_link()
    {
    }
    /**
     * Build an array with CSS classes and inline styles defining the font sizes
     * which will be applied to the navigation markup in the front-end.
     *
     * @since 5.9.0
     *
     * @param  array $context Navigation block context.
     * @return array Font size CSS classes and inline styles.
     */
    function block_core_navigation_submenu_build_css_font_sizes($context)
    {
    }
    /**
     * Returns the top-level submenu SVG chevron icon.
     *
     * @since 5.9.0
     *
     * @return string
     */
    function block_core_navigation_submenu_render_submenu_icon()
    {
    }
    /**
     * Renders the `core/navigation-submenu` block.
     *
     * @since 5.9.0
     *
     * @param array    $attributes The block attributes.
     * @param string   $content    The saved content.
     * @param WP_Block $block      The parsed block.
     *
     * @return string Returns the post content with the legacy widget added.
     */
    function render_block_core_navigation_submenu($attributes, $content, $block)
    {
    }
    /**
     * Register the navigation submenu block.
     *
     * @since 5.9.0
     *
     * @uses render_block_core_navigation_submenu()
     * @throws WP_Error An WP_Error exception parsing the block definition.
     */
    function register_block_core_navigation_submenu()
    {
    }
    /**
     * Returns the menu items for a WordPress menu location.
     *
     * @since 5.9.0
     *
     * @param string $location The menu location.
     * @return array Menu items for the location.
     */
    function block_core_navigation_get_menu_items_at_location($location)
    {
    }
    /**
     * Sorts a standard array of menu items into a nested structure keyed by the
     * id of the parent menu.
     *
     * @since 5.9.0
     *
     * @param array $menu_items Menu items to sort.
     * @return array An array keyed by the id of the parent menu where each element
     *               is an array of menu items that belong to that parent.
     */
    function block_core_navigation_sort_menu_items_by_parent_id($menu_items)
    {
    }
    /**
     * Gets the inner blocks for the navigation block from the unstable location attribute.
     *
     * @since 6.5.0
     *
     * @param array $attributes The block attributes.
     * @return WP_Block_List Returns the inner blocks for the navigation block.
     */
    function block_core_navigation_get_inner_blocks_from_unstable_location($attributes)
    {
    }
    /**
     * Add Interactivity API directives to the navigation-submenu and page-list
     * blocks markup using the Tag Processor.
     *
     * @since 6.3.0
     *
     * @param WP_HTML_Tag_Processor $tags             Markup of the navigation block.
     * @param array                 $block_attributes Block attributes.
     *
     * @return string Submenu markup with the directives injected.
     */
    function block_core_navigation_add_directives_to_submenu($tags, $block_attributes)
    {
    }
    /**
     * Build an array with CSS classes and inline styles defining the colors
     * which will be applied to the navigation markup in the front-end.
     *
     * @since 5.9.0
     *
     * @param array $attributes Navigation block attributes.
     *
     * @return array Colors CSS classes and inline styles.
     */
    function block_core_navigation_build_css_colors($attributes)
    {
    }
    /**
     * Build an array with CSS classes and inline styles defining the font sizes
     * which will be applied to the navigation markup in the front-end.
     *
     * @since 5.9.0
     *
     * @param array $attributes Navigation block attributes.
     *
     * @return array Font size CSS classes and inline styles.
     */
    function block_core_navigation_build_css_font_sizes($attributes)
    {
    }
    /**
     * Returns the top-level submenu SVG chevron icon.
     *
     * @since 5.9.0
     *
     * @return string
     */
    function block_core_navigation_render_submenu_icon()
    {
    }
    /**
     * Filter out empty "null" blocks from the block list.
     * 'parse_blocks' includes a null block with '\n\n' as the content when
     * it encounters whitespace. This is not a bug but rather how the parser
     * is designed.
     *
     * @since 5.9.0
     *
     * @param array $parsed_blocks the parsed blocks to be normalized.
     * @return array the normalized parsed blocks.
     */
    function block_core_navigation_filter_out_empty_blocks($parsed_blocks)
    {
    }
    /**
     * Returns true if the navigation block contains a nested navigation block.
     *
     * @since 6.2.0
     *
     * @param WP_Block_List $inner_blocks Inner block instance to be normalized.
     * @return bool true if the navigation block contains a nested navigation block.
     */
    function block_core_navigation_block_contains_core_navigation($inner_blocks)
    {
    }
    /**
     * Retrieves the appropriate fallback to be used on the front of the
     * site when there is no menu assigned to the Nav block.
     *
     * This aims to mirror how the fallback mechanic for wp_nav_menu works.
     * See https://developer.wordpress.org/reference/functions/wp_nav_menu/#more-information.
     *
     * @since 5.9.0
     *
     * @return array the array of blocks to be used as a fallback.
     */
    function block_core_navigation_get_fallback_blocks()
    {
    }
    /**
     * Iterate through all inner blocks recursively and get navigation link block's post IDs.
     *
     * @since 6.0.0
     *
     * @param WP_Block_List $inner_blocks Block list class instance.
     *
     * @return array Array of post IDs.
     */
    function block_core_navigation_get_post_ids($inner_blocks)
    {
    }
    /**
     * Get post IDs from a navigation link block instance.
     *
     * @since 6.0.0
     *
     * @param WP_Block $block Instance of a block.
     *
     * @return array Array of post IDs.
     */
    function block_core_navigation_from_block_get_post_ids($block)
    {
    }
    /**
     * Renders the `core/navigation` block on server.
     *
     * @since 5.9.0
     *
     * @param array    $attributes The block attributes.
     * @param string   $content    The saved content.
     * @param WP_Block $block      The parsed block.
     *
     * @return string Returns the navigation block markup.
     */
    function render_block_core_navigation($attributes, $content, $block)
    {
    }
    /**
     * Register the navigation block.
     *
     * @since 5.9.0
     *
     * @uses render_block_core_navigation()
     * @throws WP_Error An WP_Error exception parsing the block definition.
     */
    function register_block_core_navigation()
    {
    }
    /**
     * Filter that changes the parsed attribute values of navigation blocks contain typographic presets to contain the values directly.
     *
     * @since 5.9.0
     *
     * @param array $parsed_block The block being rendered.
     *
     * @return array The block being rendered without typographic presets.
     */
    function block_core_navigation_typographic_presets_backcompatibility($parsed_block)
    {
    }
    /**
     * Turns menu item data into a nested array of parsed blocks
     *
     * @since 5.9.0
     *
     * @deprecated 6.3.0 Use WP_Navigation_Fallback::parse_blocks_from_menu_items() instead.
     *
     * @param array $menu_items               An array of menu items that represent
     *                                        an individual level of a menu.
     * @param array $menu_items_by_parent_id  An array keyed by the id of the
     *                                        parent menu where each element is an
     *                                        array of menu items that belong to
     *                                        that parent.
     * @return array An array of parsed block data.
     */
    function block_core_navigation_parse_blocks_from_menu_items($menu_items, $menu_items_by_parent_id)
    {
    }
    /**
     * Get the classic navigation menu to use as a fallback.
     *
     * @since 6.2.0
     *
     * @deprecated 6.3.0 Use WP_Navigation_Fallback::get_classic_menu_fallback() instead.
     *
     * @return object WP_Term The classic navigation.
     */
    function block_core_navigation_get_classic_menu_fallback()
    {
    }
    /**
     * Converts a classic navigation to blocks.
     *
     * @since 6.2.0
     *
     * @deprecated 6.3.0 Use WP_Navigation_Fallback::get_classic_menu_fallback_blocks() instead.
     *
     * @param  object $classic_nav_menu WP_Term The classic navigation object to convert.
     * @return array the normalized parsed blocks.
     */
    function block_core_navigation_get_classic_menu_fallback_blocks($classic_nav_menu)
    {
    }
    /**
     * If there's a classic menu then use it as a fallback.
     *
     * @since 6.2.0
     *
     * @deprecated 6.3.0 Use WP_Navigation_Fallback::create_classic_menu_fallback() instead.
     *
     * @return array the normalized parsed blocks.
     */
    function block_core_navigation_maybe_use_classic_menu_fallback()
    {
    }
    /**
     * Finds the most recently published `wp_navigation` Post.
     *
     * @since 6.1.0
     *
     * @deprecated 6.3.0 Use WP_Navigation_Fallback::get_most_recently_published_navigation() instead.
     *
     * @return WP_Post|null the first non-empty Navigation or null.
     */
    function block_core_navigation_get_most_recently_published_navigation()
    {
    }
    /**
     * Accepts the serialized markup of a block and its inner blocks, and returns serialized markup of the inner blocks.
     *
     * @since 6.5.0
     *
     * @param string $serialized_block The serialized markup of a block and its inner blocks.
     * @return string
     */
    function block_core_navigation_remove_serialized_parent_block($serialized_block)
    {
    }
    /**
     * Mock a parsed block for the Navigation block given its inner blocks and the `wp_navigation` post object.
     * The `wp_navigation` post's `_wp_ignored_hooked_blocks` meta is queried to add the `metadata.ignoredHookedBlocks` attribute.
     *
     * @since 6.5.0
     *
     * @param array   $inner_blocks Parsed inner blocks of a Navigation block.
     * @param WP_Post $post         `wp_navigation` post object corresponding to the block.
     *
     * @return array the normalized parsed blocks.
     */
    function block_core_navigation_mock_parsed_block($inner_blocks, $post)
    {
    }
    /**
     * Insert hooked blocks into a Navigation block.
     *
     * Given a Navigation block's inner blocks and its corresponding `wp_navigation` post object,
     * this function inserts hooked blocks into it, and returns the serialized inner blocks in a
     * mock Navigation block wrapper.
     *
     * If there are any hooked blocks that need to be inserted as the Navigation block's first or last
     * children, the `wp_navigation` post's `_wp_ignored_hooked_blocks` meta is checked to see if any
     * of those hooked blocks should be exempted from insertion.
     *
     * @since 6.5.0
     *
     * @param array   $inner_blocks Parsed inner blocks of a Navigation block.
     * @param WP_Post $post         `wp_navigation` post object corresponding to the block.
     * @return string Serialized inner blocks in mock Navigation block wrapper, with hooked blocks inserted, if any.
     */
    function block_core_navigation_insert_hooked_blocks($inner_blocks, $post)
    {
    }
    /**
     * Insert ignoredHookedBlocks meta into the Navigation block and its inner blocks.
     *
     * Given a Navigation block's inner blocks and its corresponding `wp_navigation` post object,
     * this function inserts ignoredHookedBlocks meta into it, and returns the serialized inner blocks in a
     * mock Navigation block wrapper.
     *
     * @since 6.5.0
     *
     * @param array   $inner_blocks Parsed inner blocks of a Navigation block.
     * @param WP_Post $post         `wp_navigation` post object corresponding to the block.
     * @return string Serialized inner blocks in mock Navigation block wrapper, with hooked blocks inserted, if any.
     */
    function block_core_navigation_set_ignored_hooked_blocks_metadata($inner_blocks, $post)
    {
    }
    /**
     * Updates the post meta with the list of ignored hooked blocks when the navigation is created or updated via the REST API.
     *
     * @access private
     * @since 6.5.0
     *
     * @param stdClass $post Post object.
     * @return stdClass The updated post object.
     */
    function block_core_navigation_update_ignore_hooked_blocks_meta($post)
    {
    }
    /**
     * Hooks into the REST API response for the core/navigation block and adds the first and last inner blocks.
     *
     * @since 6.5.0
     *
     * @param WP_REST_Response $response The response object.
     * @param WP_Post          $post     Post object.
     * @return WP_REST_Response The response object.
     */
    function block_core_navigation_insert_hooked_blocks_into_rest_response($response, $post)
    {
    }
    /**
     * Registers the `core/page-list-item` block on server.
     *
     * @since 6.3.0
     */
    function register_block_core_page_list_item()
    {
    }
    /**
     * Build an array with CSS classes and inline styles defining the colors
     * which will be applied to the pages markup in the front-end when it is a descendant of navigation.
     *
     * @since 5.8.0
     *
     * @param  array $attributes Block attributes.
     * @param  array $context    Navigation block context.
     * @return array Colors CSS classes and inline styles.
     */
    function block_core_page_list_build_css_colors($attributes, $context)
    {
    }
    /**
     * Build an array with CSS classes and inline styles defining the font sizes
     * which will be applied to the pages markup in the front-end when it is a descendant of navigation.
     *
     * @since 5.8.0
     *
     * @param  array $context Navigation block context.
     * @return array Font size CSS classes and inline styles.
     */
    function block_core_page_list_build_css_font_sizes($context)
    {
    }
    /**
     * Outputs Page list markup from an array of pages with nested children.
     *
     * @since 5.8.0
     *
     * @param boolean $open_submenus_on_click Whether to open submenus on click instead of hover.
     * @param boolean $show_submenu_icons Whether to show submenu indicator icons.
     * @param boolean $is_navigation_child If block is a child of Navigation block.
     * @param array   $nested_pages The array of nested pages.
     * @param boolean $is_nested Whether the submenu is nested or not.
     * @param array   $active_page_ancestor_ids An array of ancestor ids for active page.
     * @param array   $colors Color information for overlay styles.
     * @param integer $depth The nesting depth.
     *
     * @return string List markup.
     */
    function block_core_page_list_render_nested_page_list($open_submenus_on_click, $show_submenu_icons, $is_navigation_child, $nested_pages, $is_nested, $active_page_ancestor_ids = array(), $colors = array(), $depth = 0)
    {
    }
    /**
     * Outputs nested array of pages
     *
     * @since 5.8.0
     *
     * @param array $current_level The level being iterated through.
     * @param array $children The children grouped by parent post ID.
     *
     * @return array The nested array of pages.
     */
    function block_core_page_list_nest_pages($current_level, $children)
    {
    }
    /**
     * Renders the `core/page-list` block on server.
     *
     * @since 5.8.0
     *
     * @param array    $attributes The block attributes.
     * @param string   $content    The saved content.
     * @param WP_Block $block      The parsed block.
     *
     * @return string Returns the page list markup.
     */
    function render_block_core_page_list($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/pages` block on server.
     *
     * @since 5.8.0
     */
    function register_block_core_page_list()
    {
    }
    /**
     *  Registers the `core/pattern` block on the server.
     *
     * @since 5.9.0
     */
    function register_block_core_pattern()
    {
    }
    /**
     * Renders the `core/pattern` block on the server.
     *
     * @since 6.3.0 Backwards compatibility: blocks with no `syncStatus` attribute do not receive block wrapper.
     *
     * @global WP_Embed $wp_embed Used to process embedded content within patterns
     *
     * @param array $attributes Block attributes.
     *
     * @return string Returns the output of the pattern.
     */
    function render_block_core_pattern($attributes)
    {
    }
    /**
     * Renders the `core/post-author-biography` block on the server.
     *
     * @since 6.0.0
     *
     * @param  array    $attributes Block attributes.
     * @param  string   $content    Block default content.
     * @param  WP_Block $block      Block instance.
     * @return string Returns the rendered post author biography block.
     */
    function render_block_core_post_author_biography($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/post-author-biography` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_post_author_biography()
    {
    }
    /**
     * Renders the `core/post-author-name` block on the server.
     *
     * @since 6.2.0
     *
     * @param  array    $attributes Block attributes.
     * @param  string   $content    Block default content.
     * @param  WP_Block $block      Block instance.
     * @return string Returns the rendered post author name block.
     */
    function render_block_core_post_author_name($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/post-author-name` block on the server.
     *
     * @since 6.2.0
     */
    function register_block_core_post_author_name()
    {
    }
    /**
     * Renders the `core/post-author` block on the server.
     *
     * @since 5.9.0
     *
     * @param  array    $attributes Block attributes.
     * @param  string   $content    Block default content.
     * @param  WP_Block $block      Block instance.
     * @return string Returns the rendered author block.
     */
    function render_block_core_post_author($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/post-author` block on the server.
     *
     * @since 5.9.0
     */
    function register_block_core_post_author()
    {
    }
    /**
     * Renders the `core/post-comments-form` block on the server.
     *
     * @since 6.0.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     * @return string Returns the filtered post comments form for the current post.
     */
    function render_block_core_post_comments_form($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/post-comments-form` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_post_comments_form()
    {
    }
    /**
     * Use the button block classes for the form-submit button.
     *
     * @since 6.0.0
     *
     * @param array $fields The default comment form arguments.
     *
     * @return array Returns the modified fields.
     */
    function post_comments_form_block_form_defaults($fields)
    {
    }
    /**
     * Renders the `core/post-content` block on the server.
     *
     * @since 5.8.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     * @return string Returns the filtered post content of the current post.
     */
    function render_block_core_post_content($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/post-content` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_post_content()
    {
    }
    /**
     * Renders the `core/post-date` block on the server.
     *
     * @since 5.8.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     * @return string Returns the filtered post date for the current post wrapped inside "time" tags.
     */
    function render_block_core_post_date($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/post-date` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_post_date()
    {
    }
    /**
     * Renders the `core/post-excerpt` block on the server.
     *
     * @since 5.8.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     * @return string Returns the filtered post excerpt for the current post wrapped inside "p" tags.
     */
    function render_block_core_post_excerpt($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/post-excerpt` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_post_excerpt()
    {
    }
    /**
     * Renders the `core/post-featured-image` block on the server.
     *
     * @since 5.8.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     * @return string Returns the featured image for the current post.
     */
    function render_block_core_post_featured_image($attributes, $content, $block)
    {
    }
    /**
     * Generate markup for the HTML element that will be used for the overlay.
     *
     * @since 6.1.0
     *
     * @param array $attributes Block attributes.
     *
     * @return string HTML markup in string format.
     */
    function get_block_core_post_featured_image_overlay_element_markup($attributes)
    {
    }
    /**
     * Generates class names and styles to apply the border support styles for
     * the Post Featured Image block.
     *
     * @since 6.1.0
     *
     * @param array $attributes The block attributes.
     * @return array The border-related classnames and styles for the block.
     */
    function get_block_core_post_featured_image_border_attributes($attributes)
    {
    }
    /**
     * Registers the `core/post-featured-image` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_post_featured_image()
    {
    }
    /**
     * Renders the `core/post-navigation-link` block on the server.
     *
     * @since 5.9.0
     *
     * @param array  $attributes Block attributes.
     * @param string $content    Block default content.
     *
     * @return string Returns the next or previous post link that is adjacent to the current post.
     */
    function render_block_core_post_navigation_link($attributes, $content)
    {
    }
    /**
     * Registers the `core/post-navigation-link` block on the server.
     *
     * @since 5.9.0
     */
    function register_block_core_post_navigation_link()
    {
    }
    /**
     * Determines whether a block list contains a block that uses the featured image.
     *
     * @since 6.0.0
     *
     * @param WP_Block_List $inner_blocks Inner block instance.
     *
     * @return bool Whether the block list contains a block that uses the featured image.
     */
    function block_core_post_template_uses_featured_image($inner_blocks)
    {
    }
    /**
     * Renders the `core/post-template` block on the server.
     *
     * @since 6.3.0 Changed render_block_context priority to `1`.
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     *
     * @return string Returns the output of the query, structured using the layout defined by the block's inner blocks.
     */
    function render_block_core_post_template($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/post-template` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_post_template()
    {
    }
    /**
     * Renders the `core/post-terms` block on the server.
     *
     * @since 5.8.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     * @return string Returns the filtered post terms for the current post wrapped inside "a" tags.
     */
    function render_block_core_post_terms($attributes, $content, $block)
    {
    }
    /**
     * Returns the available variations for the `core/post-terms` block.
     *
     * @since 6.5.0
     *
     * @return array The available variations for the block.
     */
    function block_core_post_terms_build_variations()
    {
    }
    /**
     * Registers the `core/post-terms` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_post_terms()
    {
    }
    /**
     * Renders the `core/post-title` block on the server.
     *
     * @since 6.3.0 Omitting the $post argument from the `get_the_title`.
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     *
     * @return string Returns the filtered post title for the current post wrapped inside "h1" tags.
     */
    function render_block_core_post_title($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/post-title` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_post_title()
    {
    }
    /**
     * Renders the `core/query-no-results` block on the server.
     *
     * @since 6.0.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     *
     * @return string Returns the wrapper for the no results block.
     */
    function render_block_core_query_no_results($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/query-no-results` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_query_no_results()
    {
    }
    /**
     * Renders the `core/query-pagination-next` block on the server.
     *
     * @since 5.8.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     *
     * @return string Returns the next posts link for the query pagination.
     */
    function render_block_core_query_pagination_next($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/query-pagination-next` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_query_pagination_next()
    {
    }
    /**
     * Renders the `core/query-pagination-numbers` block on the server.
     *
     * @since 5.8.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     *
     * @return string Returns the pagination numbers for the Query.
     */
    function render_block_core_query_pagination_numbers($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/query-pagination-numbers` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_query_pagination_numbers()
    {
    }
    /**
     * Renders the `core/query-pagination-previous` block on the server.
     *
     * @since 5.8.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     *
     * @return string Returns the previous posts link for the query.
     */
    function render_block_core_query_pagination_previous($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/query-pagination-previous` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_query_pagination_previous()
    {
    }
    /**
     * Renders the `core/query-pagination` block on the server.
     *
     * @since 5.9.0
     *
     * @param array  $attributes Block attributes.
     * @param string $content    Block default content.
     *
     * @return string Returns the wrapper for the Query pagination.
     */
    function render_block_core_query_pagination($attributes, $content)
    {
    }
    /**
     * Registers the `core/query-pagination` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_query_pagination()
    {
    }
    /**
     * Renders the `core/query-title` block on the server.
     * For now it only supports Archive title,
     * using queried object information
     *
     * @since 5.8.0
     *
     * @param array $attributes Block attributes.
     *
     * @return string Returns the query title based on the queried object.
     */
    function render_block_core_query_title($attributes)
    {
    }
    /**
     * Registers the `core/query-title` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_query_title()
    {
    }
    /**
     * Modifies the static `core/query` block on the server.
     *
     * @since 6.4.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      The block instance.
     *
     * @return string Returns the modified output of the query block.
     */
    function render_block_core_query($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/query` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_query()
    {
    }
    /**
     * Traverse the tree of blocks looking for any plugin block (i.e., a block from
     * an installed plugin) inside a Query block with the enhanced pagination
     * enabled. If at least one is found, the enhanced pagination is effectively
     * disabled to prevent any potential incompatibilities.
     *
     * @since 6.4.0
     *
     * @param array $parsed_block The block being rendered.
     * @return string Returns the parsed block, unmodified.
     */
    function block_core_query_disable_enhanced_pagination($parsed_block)
    {
    }
    /**
     * Renders the `core/read-more` block on the server.
     *
     * @since 6.0.0
     *
     * @param array    $attributes Block attributes.
     * @param string   $content    Block default content.
     * @param WP_Block $block      Block instance.
     * @return string  Returns the post link.
     */
    function render_block_core_read_more($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/read-more` block on the server.
     *
     * @since 6.0.0
     */
    function register_block_core_read_more()
    {
    }
    /**
     * Renders the `core/rss` block on server.
     *
     * @since 5.2.0
     *
     * @param array $attributes The block attributes.
     *
     * @return string Returns the block content with received rss items.
     */
    function render_block_core_rss($attributes)
    {
    }
    /**
     * Registers the `core/rss` block on server.
     *
     * @since 5.2.0
     */
    function register_block_core_rss()
    {
    }
    /**
     * Dynamically renders the `core/search` block.
     *
     * @since 6.3.0 Using block.json `viewScript` to register script, and update `view_script_handles()` only when needed.
     *
     * @param array    $attributes The block attributes.
     * @param string   $content    The saved content.
     * @param WP_Block $block      The parsed block.
     *
     * @return string The search block markup.
     */
    function render_block_core_search($attributes)
    {
    }
    /**
     * Registers the `core/search` block on the server.
     *
     * @since 5.2.0
     */
    function register_block_core_search()
    {
    }
    /**
     * Builds the correct top level classnames for the 'core/search' block.
     *
     * @since 5.6.0
     *
     * @param array $attributes The block attributes.
     *
     * @return string The classnames used in the block.
     */
    function classnames_for_block_core_search($attributes)
    {
    }
    /**
     * This generates a CSS rule for the given border property and side if provided.
     * Based on whether the Search block is configured to display the button inside
     * or not, the generated rule is injected into the appropriate collection of
     * styles for later application in the block's markup.
     *
     * @since 6.1.0
     *
     * @param array  $attributes     The block attributes.
     * @param string $property       Border property to generate rule for e.g. width or color.
     * @param string $side           Optional side border. The dictates the value retrieved and final CSS property.
     * @param array  $wrapper_styles Current collection of wrapper styles.
     * @param array  $button_styles  Current collection of button styles.
     * @param array  $input_styles   Current collection of input styles.
     * @phpstan-return void
     */
    function apply_block_core_search_border_style($attributes, $property, $side, &$wrapper_styles, &$button_styles, &$input_styles)
    {
    }
    /**
     * This adds CSS rules for a given border property e.g. width or color. It
     * injects rules into the provided wrapper, button and input style arrays for
     * uniform "flat" borders or those with individual sides configured.
     *
     * @since 6.1.0
     *
     * @param array  $attributes     The block attributes.
     * @param string $property       Border property to generate rule for e.g. width or color.
     * @param array  $wrapper_styles Current collection of wrapper styles.
     * @param array  $button_styles  Current collection of button styles.
     * @param array  $input_styles   Current collection of input styles.
     */
    function apply_block_core_search_border_styles($attributes, $property, &$wrapper_styles, &$button_styles, &$input_styles)
    {
    }
    /**
     * Builds an array of inline styles for the search block.
     *
     * The result will contain one entry for shared styles such as those for the
     * inner input or button and a second for the inner wrapper should the block
     * be positioning the button "inside".
     *
     * @since 5.8.0
     *
     * @param  array $attributes The block attributes.
     *
     * @return array Style HTML attribute.
     */
    function styles_for_block_core_search($attributes)
    {
    }
    /**
     * Returns typography classnames depending on whether there are named font sizes/families.
     *
     * @since 6.1.0
     *
     * @param array $attributes The block attributes.
     *
     * @return string The typography color classnames to be applied to the block elements.
     */
    function get_typography_classes_for_block_core_search($attributes)
    {
    }
    /**
     * Returns typography styles to be included in an HTML style tag.
     * This excludes text-decoration, which is applied only to the label and button elements of the search block.
     *
     * @since 6.1.0
     *
     * @param array $attributes The block attributes.
     *
     * @return string A string of typography CSS declarations.
     */
    function get_typography_styles_for_block_core_search($attributes)
    {
    }
    /**
     * Returns border color classnames depending on whether there are named or custom border colors.
     *
     * @since 5.9.0
     *
     * @param array $attributes The block attributes.
     *
     * @return string The border color classnames to be applied to the block elements.
     */
    function get_border_color_classes_for_block_core_search($attributes)
    {
    }
    /**
     * Returns color classnames depending on whether there are named or custom text and background colors.
     *
     * @since 5.9.0
     *
     * @param array $attributes The block attributes.
     *
     * @return string The color classnames to be applied to the block elements.
     */
    function get_color_classes_for_block_core_search($attributes)
    {
    }
    /**
     * Performs wpautop() on the shortcode block content.
     *
     * @since 5.0.0
     *
     * @param array  $attributes The block attributes.
     * @param string $content    The block content.
     *
     * @return string Returns the block content.
     */
    function render_block_core_shortcode($attributes, $content)
    {
    }
    /**
     * Registers the `core/shortcode` block on server.
     *
     * @since 5.0.0
     */
    function register_block_core_shortcode()
    {
    }
    /**
     * Renders the `core/site-logo` block on the server.
     *
     * @since 5.8.0
     *
     * @param array $attributes The block attributes.
     *
     * @return string The render.
     */
    function render_block_core_site_logo($attributes)
    {
    }
    /**
     * Register a core site setting for a site logo
     *
     * @since 5.8.0
     */
    function register_block_core_site_logo_setting()
    {
    }
    /**
     * Register a core site setting for a site icon
     *
     * @since 5.9.0
     */
    function register_block_core_site_icon_setting()
    {
    }
    /**
     * Registers the `core/site-logo` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_site_logo()
    {
    }
    /**
     * Overrides the custom logo with a site logo, if the option is set.
     *
     * @since 5.8.0
     *
     * @param string $custom_logo The custom logo set by a theme.
     *
     * @return string The site logo if set.
     */
    function _override_custom_logo_theme_mod($custom_logo)
    {
    }
    /**
     * Updates the site_logo option when the custom_logo theme-mod gets updated.
     *
     * @since 5.8.0
     *
     * @param  mixed $value Attachment ID of the custom logo or an empty value.
     * @return mixed
     */
    function _sync_custom_logo_to_site_logo($value)
    {
    }
    /**
     * Deletes the site_logo when the custom_logo theme mod is removed.
     *
     * @since 5.8.0
     *
     * @global array $_ignore_site_logo_changes
     *
     * @param array $old_value Previous theme mod settings.
     * @param array $value     Updated theme mod settings.
     * @phpstan-return void
     */
    function _delete_site_logo_on_remove_custom_logo($old_value, $value)
    {
    }
    /**
     * Deletes the site logo when all theme mods are being removed.
     *
     * @since 5.8.0
     *
     * @global array $_ignore_site_logo_changes
     * @phpstan-return void
     */
    function _delete_site_logo_on_remove_theme_mods()
    {
    }
    /**
     * Hooks `_delete_site_logo_on_remove_custom_logo` in `update_option_theme_mods_$theme`.
     * Hooks `_delete_site_logo_on_remove_theme_mods` in `delete_option_theme_mods_$theme`.
     *
     * Runs on `setup_theme` to account for dynamically-switched themes in the Customizer.
     *
     * @since 5.8.0
     */
    function _delete_site_logo_on_remove_custom_logo_on_setup_theme()
    {
    }
    /**
     * Removes the custom_logo theme-mod when the site_logo option gets deleted.
     *
     * @since 5.9.0
     *
     * @global array $_ignore_site_logo_changes
     */
    function _delete_custom_logo_on_remove_site_logo()
    {
    }
    /**
     * Renders the `core/site-tagline` block on the server.
     *
     * @since 5.8.0
     *
     * @param array $attributes The block attributes.
     *
     * @return string The render.
     */
    function render_block_core_site_tagline($attributes)
    {
    }
    /**
     * Registers the `core/site-tagline` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_site_tagline()
    {
    }
    /**
     * Renders the `core/site-title` block on the server.
     *
     * @since 5.8.0
     *
     * @param array $attributes The block attributes.
     *
     * @return string The render.
     */
    function render_block_core_site_title($attributes)
    {
    }
    /**
     * Registers the `core/site-title` block on the server.
     *
     * @since 5.8.0
     */
    function register_block_core_site_title()
    {
    }
    /**
     * Renders the `core/social-link` block on server.
     *
     * @since 5.4.0
     *
     * @param Array    $attributes The block attributes.
     * @param String   $content    InnerBlocks content of the Block.
     * @param WP_Block $block      Block object.
     *
     * @return string Rendered HTML of the referenced block.
     */
    function render_block_core_social_link($attributes, $content, $block)
    {
    }
    /**
     * Registers the `core/social-link` blocks.
     *
     * @since 5.4.0
     */
    function register_block_core_social_link()
    {
    }
    /**
     * Returns the SVG for social link.
     *
     * @since 5.4.0
     *
     * @param string $service The service icon.
     *
     * @return string SVG Element for service icon.
     */
    function block_core_social_link_get_icon($service)
    {
    }
    /**
     * Returns the brand name for social link.
     *
     * @since 5.4.0
     *
     * @param string $service The service icon.
     *
     * @return string Brand label.
     */
    function block_core_social_link_get_name($service)
    {
    }
    /**
     * Returns the SVG for social link.
     *
     * @since 5.4.0
     *
     * @param string $service The service slug to extract data from.
     * @param string $field The field ('name', 'icon', etc) to extract for a service.
     *
     * @return array|string
     */
    function block_core_social_link_services($service = '', $field = '')
    {
    }
    /**
     * Returns CSS styles for icon and icon background colors.
     *
     * @since 5.7.0
     *
     * @param array $context Block context passed to Social Link.
     *
     * @return string Inline CSS styles for link's icon and background colors.
     */
    function block_core_social_link_get_color_styles($context)
    {
    }
    /**
     * Returns CSS classes for icon and icon background colors.
     *
     * @since 6.3.0
     *
     * @param array $context Block context passed to Social Sharing Link.
     *
     * @return string CSS classes for link's icon and background colors.
     */
    function block_core_social_link_get_color_classes($context)
    {
    }
    /**
     * Renders the `core/tag-cloud` block on server.
     *
     * @since 5.2.0
     *
     * @param array $attributes The block attributes.
     *
     * @return string Returns the tag cloud for selected taxonomy.
     */
    function render_block_core_tag_cloud($attributes)
    {
    }
    /**
     * Registers the `core/tag-cloud` block on server.
     *
     * @since 5.2.0
     */
    function register_block_core_tag_cloud()
    {
    }
    /**
     * Renders the `core/template-part` block on the server.
     *
     * @since 5.9.0
     *
     * @global WP_Embed $wp_embed WordPress Embed object.
     *
     * @param array $attributes The block attributes.
     *
     * @return string The render.
     */
    function render_block_core_template_part($attributes)
    {
    }
    /**
     * Returns an array of area variation objects for the template part block.
     *
     * @since 6.1.0
     *
     * @param array $instance_variations The variations for instances.
     *
     * @return array Array containing the block variation objects.
     */
    function build_template_part_block_area_variations($instance_variations)
    {
    }
    /**
     * Returns an array of instance variation objects for the template part block
     *
     * @since 6.1.0
     *
     * @return array Array containing the block variation objects.
     */
    function build_template_part_block_instance_variations()
    {
    }
    /**
     * Returns an array of all template part block variations.
     *
     * @since 5.9.0
     *
     * @return array Array containing the block variation objects.
     */
    function build_template_part_block_variations()
    {
    }
    /**
     * Registers the `core/template-part` block on the server.
     *
     * @since 5.9.0
     */
    function register_block_core_template_part()
    {
    }
    /**
     * Renders the `core/term-description` block on the server.
     *
     * @since 5.9.0
     *
     * @param array $attributes Block attributes.
     *
     * @return string Returns the description of the current taxonomy term, if available
     */
    function render_block_core_term_description($attributes)
    {
    }
    /**
     * Registers the `core/term-description` block on the server.
     *
     * @since 5.9.0
     */
    function register_block_core_term_description()
    {
    }
    /**
     * Renders the 'core/widget-group' block.
     *
     * @since 5.9.0
     *
     * @global array      $wp_registered_sidebars
     * @global int|string $_sidebar_being_rendered
     *
     * @param array    $attributes The block attributes.
     * @param string   $content The block content.
     * @param WP_Block $block The block.
     *
     * @return string Rendered block.
     */
    function render_block_core_widget_group($attributes, $content, $block)
    {
    }
    /**
     * Registers the 'core/widget-group' block.
     *
     * @since 5.9.0
     */
    function register_block_core_widget_group()
    {
    }
    /**
     * Make a note of the sidebar being rendered before WordPress starts rendering
     * it. This lets us get to the current sidebar in
     * render_block_core_widget_group().
     *
     * @since 5.9.0
     *
     * @global int|string $_sidebar_being_rendered
     *
     * @param int|string $index       Index, name, or ID of the dynamic sidebar.
     */
    function note_sidebar_being_rendered($index)
    {
    }
    /**
     * Clear whatever we set in note_sidebar_being_rendered() after WordPress
     * finishes rendering a sidebar.
     *
     * @since 5.9.0
     *
     * @global int|string $_sidebar_being_rendered
     */
    function discard_sidebar_being_rendered()
    {
    }
    /**
     * The formatted output of a list of bookmarks.
     *
     * The $bookmarks array must contain bookmark objects and will be iterated over
     * to retrieve the bookmark to be used in the output.
     *
     * The output is formatted as HTML with no way to change that format. However,
     * what is between, before, and after can be changed. The link itself will be
     * HTML.
     *
     * This function is used internally by wp_list_bookmarks() and should not be
     * used by themes.
     *
     * @since 2.1.0
     * @access private
     *
     * @param array        $bookmarks List of bookmarks to traverse.
     * @param string|array $args {
     *     Optional. Bookmarks arguments.
     *
     *     @type int|bool $show_updated     Whether to show the time the bookmark was last updated.
     *                                      Accepts 1|true or 0|false. Default 0|false.
     *     @type int|bool $show_description Whether to show the bookmark description. Accepts 1|true,
     *                                      Accepts 1|true or 0|false. Default 0|false.
     *     @type int|bool $show_images      Whether to show the link image if available. Accepts 1|true
     *                                      or 0|false. Default 1|true.
     *     @type int|bool $show_name        Whether to show link name if available. Accepts 1|true or
     *                                      0|false. Default 0|false.
     *     @type string   $before           The HTML or text to prepend to each bookmark. Default `<li>`.
     *     @type string   $after            The HTML or text to append to each bookmark. Default `</li>`.
     *     @type string   $link_before      The HTML or text to prepend to each bookmark inside the anchor
     *                                      tags. Default empty.
     *     @type string   $link_after       The HTML or text to append to each bookmark inside the anchor
     *                                      tags. Default empty.
     *     @type string   $between          The string for use in between the link, description, and image.
     *                                      Default "\n".
     *     @type int|bool $show_rating      Whether to show the link rating. Accepts 1|true or 0|false.
     *                                      Default 0|false.
     *
     * }
     * @return string Formatted output in HTML
     * @phpstan-param array{
     *   show_updated?: int|bool,
     *   show_description?: int|bool,
     *   show_images?: int|bool,
     *   show_name?: int|bool,
     *   before?: string,
     *   after?: string,
     *   link_before?: string,
     *   link_after?: string,
     *   between?: string,
     *   show_rating?: int|bool,
     * } $args
     */
    function _walk_bookmarks($bookmarks, $args = '')
    {
    }
    /**
     * Retrieves or echoes all of the bookmarks.
     *
     * List of default arguments are as follows:
     *
     * These options define how the Category name will appear before the category
     * links are displayed, if 'categorize' is 1. If 'categorize' is 0, then it will
     * display for only the 'title_li' string and only if 'title_li' is not empty.
     *
     * @since 2.1.0
     *
     * @see _walk_bookmarks()
     *
     * @param string|array $args {
     *     Optional. String or array of arguments to list bookmarks.
     *
     *     @type string       $orderby          How to order the links by. Accepts post fields. Default 'name'.
     *     @type string       $order            Whether to order bookmarks in ascending or descending order.
     *                                          Accepts 'ASC' (ascending) or 'DESC' (descending). Default 'ASC'.
     *     @type int          $limit            Amount of bookmarks to display. Accepts 1+ or -1 for all.
     *                                          Default -1.
     *     @type string       $category         Comma-separated list of category IDs to include links from.
     *                                          Default empty.
     *     @type string       $category_name    Category to retrieve links for by name. Default empty.
     *     @type int|bool     $hide_invisible   Whether to show or hide links marked as 'invisible'. Accepts
     *                                          1|true or 0|false. Default 1|true.
     *     @type int|bool     $show_updated     Whether to display the time the bookmark was last updated.
     *                                          Accepts 1|true or 0|false. Default 0|false.
     *     @type int|bool     $echo             Whether to echo or return the formatted bookmarks. Accepts
     *                                          1|true (echo) or 0|false (return). Default 1|true.
     *     @type int|bool     $categorize       Whether to show links listed by category or in a single column.
     *                                          Accepts 1|true (by category) or 0|false (one column). Default 1|true.
     *     @type int|bool     $show_description Whether to show the bookmark descriptions. Accepts 1|true or 0|false.
     *                                          Default 0|false.
     *     @type string       $title_li         What to show before the links appear. Default 'Bookmarks'.
     *     @type string       $title_before     The HTML or text to prepend to the $title_li string. Default '<h2>'.
     *     @type string       $title_after      The HTML or text to append to the $title_li string. Default '</h2>'.
     *     @type string|array $class            The CSS class or an array of classes to use for the $title_li.
     *                                          Default 'linkcat'.
     *     @type string       $category_before  The HTML or text to prepend to $title_before if $categorize is true.
     *                                          String must contain '%id' and '%class' to inherit the category ID and
     *                                          the $class argument used for formatting in themes.
     *                                          Default '<li id="%id" class="%class">'.
     *     @type string       $category_after   The HTML or text to append to $title_after if $categorize is true.
     *                                          Default '</li>'.
     *     @type string       $category_orderby How to order the bookmark category based on term scheme if $categorize
     *                                          is true. Default 'name'.
     *     @type string       $category_order   Whether to order categories in ascending or descending order if
     *                                          $categorize is true. Accepts 'ASC' (ascending) or 'DESC' (descending).
     *                                          Default 'ASC'.
     * }
     * @return void|string Void if 'echo' argument is true, HTML list of bookmarks if 'echo' is false.
     * @phpstan-param array{
     *   orderby?: string,
     *   order?: string,
     *   limit?: int,
     *   category?: string,
     *   category_name?: string,
     *   hide_invisible?: int|bool,
     *   show_updated?: int|bool,
     *   echo?: int|bool,
     *   categorize?: int|bool,
     *   show_description?: int|bool,
     *   title_li?: string,
     *   title_before?: string,
     *   title_after?: string,
     *   class?: string|array,
     *   category_before?: string,
     *   category_after?: string,
     *   category_orderby?: string,
     *   category_order?: string,
     * } $args
     * @phpstan-return ($args is array{echo: false|0}&array ? string : void)
     */
    function wp_list_bookmarks($args = '')
    {
    }
    /**
     * Retrieves bookmark data.
     *
     * @since 2.1.0
     *
     * @global object $link Current link object.
     * @global wpdb   $wpdb WordPress database abstraction object.
     *
     * @param int|stdClass $bookmark
     * @param string       $output   Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
     *                               correspond to an stdClass object, an associative array, or a numeric array,
     *                               respectively. Default OBJECT.
     * @param string       $filter   Optional. How to sanitize bookmark fields. Default 'raw'.
     * @return array|object|null Type returned depends on $output value.
     * @phpstan-param 'OBJECT'|'ARRAY_A'|'ARRAY_N' $output
     * @phpstan-return null|($output is 'ARRAY_A' ? array<string, mixed> : ($output is 'ARRAY_N' ? array<int, mixed> : \stdClass))
     */
    function get_bookmark($bookmark, $output = \OBJECT, $filter = 'raw')
    {
    }
    /**
     * Retrieves single bookmark data item or field.
     *
     * @since 2.3.0
     *
     * @param string $field    The name of the data field to return.
     * @param int    $bookmark The bookmark ID to get field.
     * @param string $context  Optional. The context of how the field will be used. Default 'display'.
     * @return string|WP_Error
     */
    function get_bookmark_field($field, $bookmark, $context = 'display')
    {
    }
    /**
     * Retrieves the list of bookmarks.
     *
     * Attempts to retrieve from the cache first based on MD5 hash of arguments. If
     * that fails, then the query will be built from the arguments and executed. The
     * results will be stored to the cache.
     *
     * @since 2.1.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string|array $args {
     *     Optional. String or array of arguments to retrieve bookmarks.
     *
     *     @type string   $orderby        How to order the links by. Accepts 'id', 'link_id', 'name', 'link_name',
     *                                    'url', 'link_url', 'visible', 'link_visible', 'rating', 'link_rating',
     *                                    'owner', 'link_owner', 'updated', 'link_updated', 'notes', 'link_notes',
     *                                    'description', 'link_description', 'length' and 'rand'.
     *                                    When `$orderby` is 'length', orders by the character length of
     *                                    'link_name'. Default 'name'.
     *     @type string   $order          Whether to order bookmarks in ascending or descending order.
     *                                    Accepts 'ASC' (ascending) or 'DESC' (descending). Default 'ASC'.
     *     @type int      $limit          Amount of bookmarks to display. Accepts any positive number or
     *                                    -1 for all.  Default -1.
     *     @type string   $category       Comma-separated list of category IDs to include links from.
     *                                    Default empty.
     *     @type string   $category_name  Category to retrieve links for by name. Default empty.
     *     @type int|bool $hide_invisible Whether to show or hide links marked as 'invisible'. Accepts
     *                                    1|true or 0|false. Default 1|true.
     *     @type int|bool $show_updated   Whether to display the time the bookmark was last updated.
     *                                    Accepts 1|true or 0|false. Default 0|false.
     *     @type string   $include        Comma-separated list of bookmark IDs to include. Default empty.
     *     @type string   $exclude        Comma-separated list of bookmark IDs to exclude. Default empty.
     *     @type string   $search         Search terms. Will be SQL-formatted with wildcards before and after
     *                                    and searched in 'link_url', 'link_name' and 'link_description'.
     *                                    Default empty.
     * }
     * @return object[] List of bookmark row objects.
     * @phpstan-param array{
     *   orderby?: string,
     *   order?: string,
     *   limit?: int,
     *   category?: string,
     *   category_name?: string,
     *   hide_invisible?: int|bool,
     *   show_updated?: int|bool,
     *   include?: string,
     *   exclude?: string,
     *   search?: string,
     * } $args
     */
    function get_bookmarks($args = '')
    {
    }
    /**
     * Sanitizes all bookmark fields.
     *
     * @since 2.3.0
     *
     * @param stdClass|array $bookmark Bookmark row.
     * @param string         $context  Optional. How to filter the fields. Default 'display'.
     * @return stdClass|array Same type as $bookmark but with fields sanitized.
     */
    function sanitize_bookmark($bookmark, $context = 'display')
    {
    }
    /**
     * Sanitizes a bookmark field.
     *
     * Sanitizes the bookmark fields based on what the field name is. If the field
     * has a strict value set, then it will be tested for that, else a more generic
     * filtering is applied. After the more strict filter is applied, if the `$context`
     * is 'raw' then the value is immediately return.
     *
     * Hooks exist for the more generic cases. With the 'edit' context, the {@see 'edit_$field'}
     * filter will be called and passed the `$value` and `$bookmark_id` respectively.
     *
     * With the 'db' context, the {@see 'pre_$field'} filter is called and passed the value.
     * The 'display' context is the final context and has the `$field` has the filter name
     * and is passed the `$value`, `$bookmark_id`, and `$context`, respectively.
     *
     * @since 2.3.0
     *
     * @param string $field       The bookmark field.
     * @param mixed  $value       The bookmark field value.
     * @param int    $bookmark_id Bookmark ID.
     * @param string $context     How to filter the field value. Accepts 'raw', 'edit', 'db',
     *                            'display', 'attribute', or 'js'. Default 'display'.
     * @return mixed The filtered value.
     * @phpstan-param 'raw'|'edit'|'db'|'display'|'attribute'|'js' $context
     */
    function sanitize_bookmark_field($field, $value, $bookmark_id, $context)
    {
    }
    /**
     * Deletes the bookmark cache.
     *
     * @since 2.7.0
     *
     * @param int $bookmark_id Bookmark ID.
     */
    function clean_bookmark_cache($bookmark_id)
    {
    }
    /**
     * Sets up Object Cache Global and assigns it.
     *
     * @since 2.0.0
     *
     * @global WP_Object_Cache $wp_object_cache
     */
    function wp_cache_init()
    {
    }
    /**
     * Adds data to the cache, if the cache key doesn't already exist.
     *
     * @since 2.0.0
     *
     * @see WP_Object_Cache::add()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param int|string $key    The cache key to use for retrieval later.
     * @param mixed      $data   The data to add to the cache.
     * @param string     $group  Optional. The group to add the cache to. Enables the same key
     *                           to be used across groups. Default empty.
     * @param int        $expire Optional. When the cache data should expire, in seconds.
     *                           Default 0 (no expiration).
     * @return bool True on success, false if cache key and group already exist.
     */
    function wp_cache_add($key, $data, $group = '', $expire = 0)
    {
    }
    /**
     * Adds multiple values to the cache in one call.
     *
     * @since 6.0.0
     *
     * @see WP_Object_Cache::add_multiple()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param array  $data   Array of keys and values to be set.
     * @param string $group  Optional. Where the cache contents are grouped. Default empty.
     * @param int    $expire Optional. When to expire the cache contents, in seconds.
     *                       Default 0 (no expiration).
     * @return bool[] Array of return values, grouped by key. Each value is either
     *                true on success, or false if cache key and group already exist.
     */
    function wp_cache_add_multiple(array $data, $group = '', $expire = 0)
    {
    }
    /**
     * Replaces the contents of the cache with new data.
     *
     * @since 2.0.0
     *
     * @see WP_Object_Cache::replace()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param int|string $key    The key for the cache data that should be replaced.
     * @param mixed      $data   The new data to store in the cache.
     * @param string     $group  Optional. The group for the cache data that should be replaced.
     *                           Default empty.
     * @param int        $expire Optional. When to expire the cache contents, in seconds.
     *                           Default 0 (no expiration).
     * @return bool True if contents were replaced, false if original value does not exist.
     */
    function wp_cache_replace($key, $data, $group = '', $expire = 0)
    {
    }
    /**
     * Saves the data to the cache.
     *
     * Differs from wp_cache_add() and wp_cache_replace() in that it will always write data.
     *
     * @since 2.0.0
     *
     * @see WP_Object_Cache::set()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param int|string $key    The cache key to use for retrieval later.
     * @param mixed      $data   The contents to store in the cache.
     * @param string     $group  Optional. Where to group the cache contents. Enables the same key
     *                           to be used across groups. Default empty.
     * @param int        $expire Optional. When to expire the cache contents, in seconds.
     *                           Default 0 (no expiration).
     * @return bool True on success, false on failure.
     */
    function wp_cache_set($key, $data, $group = '', $expire = 0)
    {
    }
    /**
     * Sets multiple values to the cache in one call.
     *
     * @since 6.0.0
     *
     * @see WP_Object_Cache::set_multiple()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param array  $data   Array of keys and values to be set.
     * @param string $group  Optional. Where the cache contents are grouped. Default empty.
     * @param int    $expire Optional. When to expire the cache contents, in seconds.
     *                       Default 0 (no expiration).
     * @return bool[] Array of return values, grouped by key. Each value is either
     *                true on success, or false on failure.
     */
    function wp_cache_set_multiple(array $data, $group = '', $expire = 0)
    {
    }
    /**
     * Retrieves the cache contents from the cache by key and group.
     *
     * @since 2.0.0
     *
     * @see WP_Object_Cache::get()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param int|string $key   The key under which the cache contents are stored.
     * @param string     $group Optional. Where the cache contents are grouped. Default empty.
     * @param bool       $force Optional. Whether to force an update of the local cache
     *                          from the persistent cache. Default false.
     * @param bool       $found Optional. Whether the key was found in the cache (passed by reference).
     *                          Disambiguates a return of false, a storable value. Default null.
     * @return mixed|false The cache contents on success, false on failure to retrieve contents.
     */
    function wp_cache_get($key, $group = '', $force = \false, &$found = \null)
    {
    }
    /**
     * Retrieves multiple values from the cache in one call.
     *
     * @since 5.5.0
     *
     * @see WP_Object_Cache::get_multiple()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param array  $keys  Array of keys under which the cache contents are stored.
     * @param string $group Optional. Where the cache contents are grouped. Default empty.
     * @param bool   $force Optional. Whether to force an update of the local cache
     *                      from the persistent cache. Default false.
     * @return array Array of return values, grouped by key. Each value is either
     *               the cache contents on success, or false on failure.
     */
    function wp_cache_get_multiple($keys, $group = '', $force = \false)
    {
    }
    /**
     * Removes the cache contents matching key and group.
     *
     * @since 2.0.0
     *
     * @see WP_Object_Cache::delete()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param int|string $key   What the contents in the cache are called.
     * @param string     $group Optional. Where the cache contents are grouped. Default empty.
     * @return bool True on successful removal, false on failure.
     */
    function wp_cache_delete($key, $group = '')
    {
    }
    /**
     * Deletes multiple values from the cache in one call.
     *
     * @since 6.0.0
     *
     * @see WP_Object_Cache::delete_multiple()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param array  $keys  Array of keys under which the cache to deleted.
     * @param string $group Optional. Where the cache contents are grouped. Default empty.
     * @return bool[] Array of return values, grouped by key. Each value is either
     *                true on success, or false if the contents were not deleted.
     */
    function wp_cache_delete_multiple(array $keys, $group = '')
    {
    }
    /**
     * Increments numeric cache item's value.
     *
     * @since 3.3.0
     *
     * @see WP_Object_Cache::incr()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param int|string $key    The key for the cache contents that should be incremented.
     * @param int        $offset Optional. The amount by which to increment the item's value.
     *                           Default 1.
     * @param string     $group  Optional. The group the key is in. Default empty.
     * @return int|false The item's new value on success, false on failure.
     */
    function wp_cache_incr($key, $offset = 1, $group = '')
    {
    }
    /**
     * Decrements numeric cache item's value.
     *
     * @since 3.3.0
     *
     * @see WP_Object_Cache::decr()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param int|string $key    The cache key to decrement.
     * @param int        $offset Optional. The amount by which to decrement the item's value.
     *                           Default 1.
     * @param string     $group  Optional. The group the key is in. Default empty.
     * @return int|false The item's new value on success, false on failure.
     */
    function wp_cache_decr($key, $offset = 1, $group = '')
    {
    }
    /**
     * Removes all cache items.
     *
     * @since 2.0.0
     *
     * @see WP_Object_Cache::flush()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @return bool True on success, false on failure.
     */
    function wp_cache_flush()
    {
    }
    /**
     * Removes all cache items from the in-memory runtime cache.
     *
     * @since 6.0.0
     *
     * @see WP_Object_Cache::flush()
     *
     * @return bool True on success, false on failure.
     */
    function wp_cache_flush_runtime()
    {
    }
    /**
     * Removes all cache items in a group, if the object cache implementation supports it.
     *
     * Before calling this function, always check for group flushing support using the
     * `wp_cache_supports( 'flush_group' )` function.
     *
     * @since 6.1.0
     *
     * @see WP_Object_Cache::flush_group()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param string $group Name of group to remove from cache.
     * @return bool True if group was flushed, false otherwise.
     */
    function wp_cache_flush_group($group)
    {
    }
    /**
     * Determines whether the object cache implementation supports a particular feature.
     *
     * @since 6.1.0
     *
     * @param string $feature Name of the feature to check for. Possible values include:
     *                        'add_multiple', 'set_multiple', 'get_multiple', 'delete_multiple',
     *                        'flush_runtime', 'flush_group'.
     * @return bool True if the feature is supported, false otherwise.
     */
    function wp_cache_supports($feature)
    {
    }
    /**
     * Closes the cache.
     *
     * This function has ceased to do anything since WordPress 2.5. The
     * functionality was removed along with the rest of the persistent cache.
     *
     * This does not mean that plugins can't implement this function when they need
     * to make sure that the cache is cleaned up after WordPress no longer needs it.
     *
     * @since 2.0.0
     *
     * @return true Always returns true.
     */
    function wp_cache_close()
    {
    }
    /**
     * Adds a group or set of groups to the list of global groups.
     *
     * @since 2.6.0
     *
     * @see WP_Object_Cache::add_global_groups()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param string|string[] $groups A group or an array of groups to add.
     */
    function wp_cache_add_global_groups($groups)
    {
    }
    /**
     * Adds a group or set of groups to the list of non-persistent groups.
     *
     * @since 2.6.0
     *
     * @param string|string[] $groups A group or an array of groups to add.
     */
    function wp_cache_add_non_persistent_groups($groups)
    {
    }
    /**
     * Switches the internal blog ID.
     *
     * This changes the blog id used to create keys in blog specific groups.
     *
     * @since 3.5.0
     *
     * @see WP_Object_Cache::switch_to_blog()
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     *
     * @param int $blog_id Site ID.
     */
    function wp_cache_switch_to_blog($blog_id)
    {
    }
    /**
     * Resets internal cache keys and structures.
     *
     * If the cache back end uses global blog or site IDs as part of its cache keys,
     * this function instructs the back end to reset those keys and perform any cleanup
     * since blog or site IDs have changed since cache init.
     *
     * This function is deprecated. Use wp_cache_switch_to_blog() instead of this
     * function when preparing the cache for a blog switch. For clearing the cache
     * during unit tests, consider using wp_cache_init(). wp_cache_init() is not
     * recommended outside of unit tests as the performance penalty for using it is high.
     *
     * @since 3.0.0
     * @deprecated 3.5.0 Use wp_cache_switch_to_blog()
     * @see WP_Object_Cache::reset()
     *
     * @global WP_Object_Cache $wp_object_cache Object cache global instance.
     */
    function wp_cache_reset()
    {
    }
    /**
     * Redirects incoming links to the proper URL based on the site url.
     *
     * Search engines consider www.somedomain.com and somedomain.com to be two
     * different URLs when they both go to the same location. This SEO enhancement
     * prevents penalty for duplicate content by redirecting all incoming links to
     * one or the other.
     *
     * Prevents redirection for feeds, trackbacks, searches, and
     * admin URLs. Does not redirect on non-pretty-permalink-supporting IIS 7+,
     * page/post previews, WP admin, Trackbacks, robots.txt, favicon.ico, searches,
     * or on POST requests.
     *
     * Will also attempt to find the correct link when a user enters a URL that does
     * not exist based on exact WordPress query. Will instead try to parse the URL
     * or query in an attempt to figure the correct page to go to.
     *
     * @since 2.3.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     * @global bool       $is_IIS
     * @global WP_Query   $wp_query   WordPress Query object.
     * @global wpdb       $wpdb       WordPress database abstraction object.
     * @global WP         $wp         Current WordPress environment instance.
     *
     * @param string $requested_url Optional. The URL that was requested, used to
     *                              figure if redirect is needed.
     * @param bool   $do_redirect   Optional. Redirect to the new URL.
     * @return string|void The string of the URL, if redirect needed.
     */
    function redirect_canonical($requested_url = \null, $do_redirect = \true)
    {
    }
    /**
     * Removes arguments from a query string if they are not present in a URL
     * DO NOT use this in plugin code.
     *
     * @since 3.4.0
     * @access private
     *
     * @param string $query_string
     * @param array  $args_to_check
     * @param string $url
     * @return string The altered query string
     */
    function _remove_qs_args_if_not_in_url($query_string, array $args_to_check, $url)
    {
    }
    /**
     * Strips the #fragment from a URL, if one is present.
     *
     * @since 4.4.0
     *
     * @param string $url The URL to strip.
     * @return string The altered URL.
     */
    function strip_fragment_from_url($url)
    {
    }
    /**
     * Attempts to guess the correct URL for a 404 request based on query vars.
     *
     * @since 2.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return string|false The correct URL if one is found. False on failure.
     */
    function redirect_guess_404_permalink()
    {
    }
    /**
     * Redirects a variety of shorthand URLs to the admin.
     *
     * If a user visits example.com/admin, they'll be redirected to /wp-admin.
     * Visiting /login redirects to /wp-login.php, and so on.
     *
     * @since 3.4.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     * @phpstan-return void
     */
    function wp_redirect_admin_locations()
    {
    }
    /**
     * Maps a capability to the primitive capabilities required of the given user to
     * satisfy the capability being checked.
     *
     * This function also accepts an ID of an object to map against if the capability is a meta capability. Meta
     * capabilities such as `edit_post` and `edit_user` are capabilities used by this function to map to primitive
     * capabilities that a user or role requires, such as `edit_posts` and `edit_others_posts`.
     *
     * Example usage:
     *
     *     map_meta_cap( 'edit_posts', $user->ID );
     *     map_meta_cap( 'edit_post', $user->ID, $post->ID );
     *     map_meta_cap( 'edit_post_meta', $user->ID, $post->ID, $meta_key );
     *
     * This function does not check whether the user has the required capabilities,
     * it just returns what the required capabilities are.
     *
     * @since 2.0.0
     * @since 4.9.6 Added the `export_others_personal_data`, `erase_others_personal_data`,
     *              and `manage_privacy_options` capabilities.
     * @since 5.1.0 Added the `update_php` capability.
     * @since 5.2.0 Added the `resume_plugin` and `resume_theme` capabilities.
     * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
     *              by adding it to the function signature.
     * @since 5.7.0 Added the `create_app_password`, `list_app_passwords`, `read_app_password`,
     *              `edit_app_password`, `delete_app_passwords`, `delete_app_password`,
     *              and `update_https` capabilities.
     * @since 6.7.0 Added the `edit_block_binding` capability.
     *
     * @global array $post_type_meta_caps Used to get post type meta capabilities.
     *
     * @param string $cap     Capability being checked.
     * @param int    $user_id User ID.
     * @param mixed  ...$args Optional further parameters, typically starting with an object ID.
     * @return string[] Primitive capabilities required of the user.
     */
    function map_meta_cap($cap, $user_id, ...$args)
    {
    }
    /**
     * Returns whether the current user has the specified capability.
     *
     * This function also accepts an ID of an object to check against if the capability is a meta capability. Meta
     * capabilities such as `edit_post` and `edit_user` are capabilities used by the `map_meta_cap()` function to
     * map to primitive capabilities that a user or role has, such as `edit_posts` and `edit_others_posts`.
     *
     * Example usage:
     *
     *     current_user_can( 'edit_posts' );
     *     current_user_can( 'edit_post', $post->ID );
     *     current_user_can( 'edit_post_meta', $post->ID, $meta_key );
     *
     * While checking against particular roles in place of a capability is supported
     * in part, this practice is discouraged as it may produce unreliable results.
     *
     * Note: Will always return true if the current user is a super admin, unless specifically denied.
     *
     * @since 2.0.0
     * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
     *              by adding it to the function signature.
     * @since 5.8.0 Converted to wrapper for the user_can() function.
     *
     * @see WP_User::has_cap()
     * @see map_meta_cap()
     *
     * @param string $capability Capability name.
     * @param mixed  ...$args    Optional further parameters, typically starting with an object ID.
     * @return bool Whether the current user has the given capability. If `$capability` is a meta cap and `$object_id` is
     *              passed, whether the current user has the given meta capability for the given object.
     */
    function current_user_can($capability, ...$args)
    {
    }
    /**
     * Returns whether the current user has the specified capability for a given site.
     *
     * This function also accepts an ID of an object to check against if the capability is a meta capability. Meta
     * capabilities such as `edit_post` and `edit_user` are capabilities used by the `map_meta_cap()` function to
     * map to primitive capabilities that a user or role has, such as `edit_posts` and `edit_others_posts`.
     *
     * This function replaces the current_user_can_for_blog() function.
     *
     * Example usage:
     *
     *     current_user_can_for_site( $site_id, 'edit_posts' );
     *     current_user_can_for_site( $site_id, 'edit_post', $post->ID );
     *     current_user_can_for_site( $site_id, 'edit_post_meta', $post->ID, $meta_key );
     *
     * @since 6.7.0
     *
     * @param int    $site_id    Site ID.
     * @param string $capability Capability name.
     * @param mixed  ...$args    Optional further parameters, typically starting with an object ID.
     * @return bool Whether the user has the given capability.
     */
    function current_user_can_for_site($site_id, $capability, ...$args)
    {
    }
    /**
     * Returns whether the author of the supplied post has the specified capability.
     *
     * This function also accepts an ID of an object to check against if the capability is a meta capability. Meta
     * capabilities such as `edit_post` and `edit_user` are capabilities used by the `map_meta_cap()` function to
     * map to primitive capabilities that a user or role has, such as `edit_posts` and `edit_others_posts`.
     *
     * Example usage:
     *
     *     author_can( $post, 'edit_posts' );
     *     author_can( $post, 'edit_post', $post->ID );
     *     author_can( $post, 'edit_post_meta', $post->ID, $meta_key );
     *
     * @since 2.9.0
     * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
     *              by adding it to the function signature.
     *
     * @param int|WP_Post $post       Post ID or post object.
     * @param string      $capability Capability name.
     * @param mixed       ...$args    Optional further parameters, typically starting with an object ID.
     * @return bool Whether the post author has the given capability.
     */
    function author_can($post, $capability, ...$args)
    {
    }
    /**
     * Returns whether a particular user has the specified capability.
     *
     * This function also accepts an ID of an object to check against if the capability is a meta capability. Meta
     * capabilities such as `edit_post` and `edit_user` are capabilities used by the `map_meta_cap()` function to
     * map to primitive capabilities that a user or role has, such as `edit_posts` and `edit_others_posts`.
     *
     * Example usage:
     *
     *     user_can( $user->ID, 'edit_posts' );
     *     user_can( $user->ID, 'edit_post', $post->ID );
     *     user_can( $user->ID, 'edit_post_meta', $post->ID, $meta_key );
     *
     * @since 3.1.0
     * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
     *              by adding it to the function signature.
     *
     * @param int|WP_User $user       User ID or object.
     * @param string      $capability Capability name.
     * @param mixed       ...$args    Optional further parameters, typically starting with an object ID.
     * @return bool Whether the user has the given capability.
     */
    function user_can($user, $capability, ...$args)
    {
    }
    /**
     * Returns whether a particular user has the specified capability for a given site.
     *
     * This function also accepts an ID of an object to check against if the capability is a meta capability. Meta
     * capabilities such as `edit_post` and `edit_user` are capabilities used by the `map_meta_cap()` function to
     * map to primitive capabilities that a user or role has, such as `edit_posts` and `edit_others_posts`.
     *
     * Example usage:
     *
     *     user_can_for_site( $user->ID, $site_id, 'edit_posts' );
     *     user_can_for_site( $user->ID, $site_id, 'edit_post', $post->ID );
     *     user_can_for_site( $user->ID, $site_id, 'edit_post_meta', $post->ID, $meta_key );
     *
     * @since 6.7.0
     *
     * @param int|WP_User $user       User ID or object.
     * @param int         $site_id    Site ID.
     * @param string      $capability Capability name.
     * @param mixed       ...$args    Optional further parameters, typically starting with an object ID.
     * @return bool Whether the user has the given capability.
     */
    function user_can_for_site($user, $site_id, $capability, ...$args)
    {
    }
    /**
     * Retrieves the global WP_Roles instance and instantiates it if necessary.
     *
     * @since 4.3.0
     *
     * @global WP_Roles $wp_roles WordPress role management object.
     *
     * @return WP_Roles WP_Roles global instance if not already instantiated.
     */
    function wp_roles()
    {
    }
    /**
     * Retrieves role object.
     *
     * @since 2.0.0
     *
     * @param string $role Role name.
     * @return WP_Role|null WP_Role object if found, null if the role does not exist.
     */
    function get_role($role)
    {
    }
    /**
     * Adds a role, if it does not exist.
     *
     * @since 2.0.0
     *
     * @param string $role         Role name.
     * @param string $display_name Display name for role.
     * @param bool[] $capabilities List of capabilities keyed by the capability name,
     *                             e.g. array( 'edit_posts' => true, 'delete_posts' => false ).
     * @return WP_Role|void WP_Role object, if the role is added.
     */
    function add_role($role, $display_name, $capabilities = array())
    {
    }
    /**
     * Removes a role, if it exists.
     *
     * @since 2.0.0
     *
     * @param string $role Role name.
     */
    function remove_role($role)
    {
    }
    /**
     * Retrieves a list of super admins.
     *
     * @since 3.0.0
     *
     * @global array $super_admins
     *
     * @return string[] List of super admin logins.
     */
    function get_super_admins()
    {
    }
    /**
     * Determines whether user is a site admin.
     *
     * @since 3.0.0
     *
     * @param int|false $user_id Optional. The ID of a user. Defaults to false, to check the current user.
     * @return bool Whether the user is a site admin.
     */
    function is_super_admin($user_id = \false)
    {
    }
    /**
     * Grants Super Admin privileges.
     *
     * @since 3.0.0
     *
     * @global array $super_admins
     *
     * @param int $user_id ID of the user to be granted Super Admin privileges.
     * @return bool True on success, false on failure. This can fail when the user is
     *              already a super admin or when the `$super_admins` global is defined.
     */
    function grant_super_admin($user_id)
    {
    }
    /**
     * Revokes Super Admin privileges.
     *
     * @since 3.0.0
     *
     * @global array $super_admins
     *
     * @param int $user_id ID of the user Super Admin privileges to be revoked from.
     * @return bool True on success, false on failure. This can fail when the user's email
     *              is the network admin email or when the `$super_admins` global is defined.
     */
    function revoke_super_admin($user_id)
    {
    }
    /**
     * Filters the user capabilities to grant the 'install_languages' capability as necessary.
     *
     * A user must have at least one out of the 'update_core', 'install_plugins', and
     * 'install_themes' capabilities to qualify for 'install_languages'.
     *
     * @since 4.9.0
     *
     * @param bool[] $allcaps An array of all the user's capabilities.
     * @return bool[] Filtered array of the user's capabilities.
     */
    function wp_maybe_grant_install_languages_cap($allcaps)
    {
    }
    /**
     * Filters the user capabilities to grant the 'resume_plugins' and 'resume_themes' capabilities as necessary.
     *
     * @since 5.2.0
     *
     * @param bool[] $allcaps An array of all the user's capabilities.
     * @return bool[] Filtered array of the user's capabilities.
     */
    function wp_maybe_grant_resume_extensions_caps($allcaps)
    {
    }
    /**
     * Filters the user capabilities to grant the 'view_site_health_checks' capabilities as necessary.
     *
     * @since 5.2.2
     *
     * @param bool[]   $allcaps An array of all the user's capabilities.
     * @param string[] $caps    Required primitive capabilities for the requested capability.
     * @param array    $args {
     *     Arguments that accompany the requested capability check.
     *
     *     @type string    $0 Requested capability.
     *     @type int       $1 Concerned user ID.
     *     @type mixed  ...$2 Optional second and further parameters, typically object ID.
     * }
     * @param WP_User  $user    The user object.
     * @return bool[] Filtered array of the user's capabilities.
     */
    function wp_maybe_grant_site_health_caps($allcaps, $caps, $args, $user)
    {
    }
    /**
     * Retrieves category link URL.
     *
     * @since 1.0.0
     *
     * @see get_term_link()
     *
     * @param int|object $category Category ID or object.
     * @return string Link on success, empty string if category does not exist.
     */
    function get_category_link($category)
    {
    }
    /**
     * Retrieves category parents with separator.
     *
     * @since 1.2.0
     * @since 4.8.0 The `$visited` parameter was deprecated and renamed to `$deprecated`.
     *
     * @param int    $category_id Category ID.
     * @param bool   $link        Optional. Whether to format with link. Default false.
     * @param string $separator   Optional. How to separate categories. Default '/'.
     * @param bool   $nicename    Optional. Whether to use nice name for display. Default false.
     * @param array  $deprecated  Not used.
     * @return string|WP_Error A list of category parents on success, WP_Error on failure.
     */
    function get_category_parents($category_id, $link = \false, $separator = '/', $nicename = \false, $deprecated = array())
    {
    }
    /**
     * Retrieves post categories.
     *
     * This tag may be used outside The Loop by passing a post ID as the parameter.
     *
     * Note: This function only returns results from the default "category" taxonomy.
     * For custom taxonomies use get_the_terms().
     *
     * @since 0.71
     *
     * @param int $post_id Optional. The post ID. Defaults to current post ID.
     * @return WP_Term[] Array of WP_Term objects, one for each category assigned to the post.
     */
    function get_the_category($post_id = \false)
    {
    }
    /**
     * Retrieves category name based on category ID.
     *
     * @since 0.71
     *
     * @param int $cat_id Category ID.
     * @return string|WP_Error Category name on success, WP_Error on failure.
     */
    function get_the_category_by_ID($cat_id)
    {
    }
    /**
     * Retrieves category list for a post in either HTML list or custom format.
     *
     * Generally used for quick, delimited (e.g. comma-separated) lists of categories,
     * as part of a post entry meta.
     *
     * For a more powerful, list-based function, see wp_list_categories().
     *
     * @since 1.5.1
     *
     * @see wp_list_categories()
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string $separator Optional. Separator between the categories. By default, the links are placed
     *                          in an unordered list. An empty string will result in the default behavior.
     * @param string $parents   Optional. How to display the parents. Accepts 'multiple', 'single', or empty.
     *                          Default empty string.
     * @param int    $post_id   Optional. ID of the post to retrieve categories for. Defaults to the current post.
     * @return string Category list for a post.
     */
    function get_the_category_list($separator = '', $parents = '', $post_id = \false)
    {
    }
    /**
     * Checks if the current post is within any of the given categories.
     *
     * The given categories are checked against the post's categories' term_ids, names and slugs.
     * Categories given as integers will only be checked against the post's categories' term_ids.
     *
     * Prior to v2.5 of WordPress, category names were not supported.
     * Prior to v2.7, category slugs were not supported.
     * Prior to v2.7, only one category could be compared: in_category( $single_category ).
     * Prior to v2.7, this function could only be used in the WordPress Loop.
     * As of 2.7, the function can be used anywhere if it is provided a post ID or post object.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.2.0
     * @since 2.7.0 The `$post` parameter was added.
     *
     * @param int|string|int[]|string[] $category Category ID, name, slug, or array of such
     *                                            to check against.
     * @param int|WP_Post               $post     Optional. Post to check. Defaults to the current post.
     * @return bool True if the current post is in any of the given categories.
     */
    function in_category($category, $post = \null)
    {
    }
    /**
     * Displays category list for a post in either HTML list or custom format.
     *
     * @since 0.71
     *
     * @param string $separator Optional. Separator between the categories. By default, the links are placed
     *                          in an unordered list. An empty string will result in the default behavior.
     * @param string $parents   Optional. How to display the parents. Accepts 'multiple', 'single', or empty.
     *                          Default empty string.
     * @param int    $post_id   Optional. ID of the post to retrieve categories for. Defaults to the current post.
     */
    function the_category($separator = '', $parents = '', $post_id = \false)
    {
    }
    /**
     * Retrieves category description.
     *
     * @since 1.0.0
     *
     * @param int $category Optional. Category ID. Defaults to the current category ID.
     * @return string Category description, if available.
     */
    function category_description($category = 0)
    {
    }
    /**
     * Displays or retrieves the HTML dropdown list of categories.
     *
     * The 'hierarchical' argument, which is disabled by default, will override the
     * depth argument, unless it is true. When the argument is false, it will
     * display all of the categories. When it is enabled it will use the value in
     * the 'depth' argument.
     *
     * @since 2.1.0
     * @since 4.2.0 Introduced the `value_field` argument.
     * @since 4.6.0 Introduced the `required` argument.
     * @since 6.1.0 Introduced the `aria_describedby` argument.
     *
     * @param array|string $args {
     *     Optional. Array or string of arguments to generate a categories drop-down element. See WP_Term_Query::__construct()
     *     for information on additional accepted arguments.
     *
     *     @type string       $show_option_all   Text to display for showing all categories. Default empty.
     *     @type string       $show_option_none  Text to display for showing no categories. Default empty.
     *     @type string       $option_none_value Value to use when no category is selected. Default empty.
     *     @type string       $orderby           Which column to use for ordering categories. See get_terms() for a list
     *                                           of accepted values. Default 'id' (term_id).
     *     @type bool         $pad_counts        See get_terms() for an argument description. Default false.
     *     @type bool|int     $show_count        Whether to include post counts. Accepts 0, 1, or their bool equivalents.
     *                                           Default 0.
     *     @type bool|int     $echo              Whether to echo or return the generated markup. Accepts 0, 1, or their
     *                                           bool equivalents. Default 1.
     *     @type bool|int     $hierarchical      Whether to traverse the taxonomy hierarchy. Accepts 0, 1, or their bool
     *                                           equivalents. Default 0.
     *     @type int          $depth             Maximum depth. Default 0.
     *     @type int          $tab_index         Tab index for the select element. Default 0 (no tabindex).
     *     @type string       $name              Value for the 'name' attribute of the select element. Default 'cat'.
     *     @type string       $id                Value for the 'id' attribute of the select element. Defaults to the value
     *                                           of `$name`.
     *     @type string       $class             Value for the 'class' attribute of the select element. Default 'postform'.
     *     @type int|string   $selected          Value of the option that should be selected. Default 0.
     *     @type string       $value_field       Term field that should be used to populate the 'value' attribute
     *                                           of the option elements. Accepts any valid term field: 'term_id', 'name',
     *                                           'slug', 'term_group', 'term_taxonomy_id', 'taxonomy', 'description',
     *                                           'parent', 'count'. Default 'term_id'.
     *     @type string|array $taxonomy          Name of the taxonomy or taxonomies to retrieve. Default 'category'.
     *     @type bool         $hide_if_empty     True to skip generating markup if no categories are found.
     *                                           Default false (create select element even if no categories are found).
     *     @type bool         $required          Whether the `<select>` element should have the HTML5 'required' attribute.
     *                                           Default false.
     *     @type Walker       $walker            Walker object to use to build the output. Default empty which results in a
     *                                           Walker_CategoryDropdown instance being used.
     *     @type string       $aria_describedby  The 'id' of an element that contains descriptive text for the select.
     *                                           Default empty string.
     * }
     * @return string HTML dropdown list of categories.
     * @phpstan-param array{
     *   show_option_all?: string,
     *   show_option_none?: string,
     *   option_none_value?: string,
     *   orderby?: string,
     *   pad_counts?: bool,
     *   show_count?: bool|int,
     *   echo?: bool|int,
     *   hierarchical?: bool|int,
     *   depth?: int,
     *   tab_index?: int,
     *   name?: string,
     *   id?: string,
     *   class?: string,
     *   selected?: int|string,
     *   value_field?: string,
     *   taxonomy?: string|array,
     *   hide_if_empty?: bool,
     *   required?: bool,
     *   walker?: Walker,
     *   aria_describedby?: string,
     *   taxonomy?: string|string[],
     *   object_ids?: int|int[],
     *   orderby?: string,
     *   order?: string,
     *   hide_empty?: bool|int,
     *   include?: int[]|string,
     *   exclude?: int[]|string,
     *   exclude_tree?: int[]|string,
     *   number?: int|string,
     *   offset?: int,
     *   fields?: string,
     *   name?: string|string[],
     *   slug?: string|string[],
     *   term_taxonomy_id?: int|int[],
     *   hierarchical?: bool,
     *   search?: string,
     *   name__like?: string,
     *   description__like?: string,
     *   pad_counts?: bool,
     *   get?: string,
     *   child_of?: int,
     *   parent?: int,
     *   childless?: bool,
     *   cache_domain?: string,
     *   cache_results?: bool,
     *   update_term_meta_cache?: bool,
     *   meta_key?: string|string[],
     *   meta_value?: string|string[],
     *   meta_compare?: string,
     *   meta_compare_key?: string,
     *   meta_type?: string,
     *   meta_type_key?: string,
     *   meta_query?: array,
     * } $args
     */
    function wp_dropdown_categories($args = '')
    {
    }
    /**
     * Displays or retrieves the HTML list of categories.
     *
     * @since 2.1.0
     * @since 4.4.0 Introduced the `hide_title_if_empty` and `separator` arguments.
     * @since 4.4.0 The `current_category` argument was modified to optionally accept an array of values.
     * @since 6.1.0 Default value of the 'use_desc_for_title' argument was changed from 1 to 0.
     *
     * @param array|string $args {
     *     Array of optional arguments. See get_categories(), get_terms(), and WP_Term_Query::__construct()
     *     for information on additional accepted arguments.
     *
     *     @type int|int[]    $current_category      ID of category, or array of IDs of categories, that should get the
     *                                               'current-cat' class. Default 0.
     *     @type int          $depth                 Category depth. Used for tab indentation. Default 0.
     *     @type bool|int     $echo                  Whether to echo or return the generated markup. Accepts 0, 1, or their
     *                                               bool equivalents. Default 1.
     *     @type int[]|string $exclude               Array or comma/space-separated string of term IDs to exclude.
     *                                               If `$hierarchical` is true, descendants of `$exclude` terms will also
     *                                               be excluded; see `$exclude_tree`. See get_terms().
     *                                               Default empty string.
     *     @type int[]|string $exclude_tree          Array or comma/space-separated string of term IDs to exclude, along
     *                                               with their descendants. See get_terms(). Default empty string.
     *     @type string       $feed                  Text to use for the feed link. Default 'Feed for all posts filed
     *                                               under [cat name]'.
     *     @type string       $feed_image            URL of an image to use for the feed link. Default empty string.
     *     @type string       $feed_type             Feed type. Used to build feed link. See get_term_feed_link().
     *                                               Default empty string (default feed).
     *     @type bool         $hide_title_if_empty   Whether to hide the `$title_li` element if there are no terms in
     *                                               the list. Default false (title will always be shown).
     *     @type string       $separator             Separator between links. Default '<br />'.
     *     @type bool|int     $show_count            Whether to include post counts. Accepts 0, 1, or their bool equivalents.
     *                                               Default 0.
     *     @type string       $show_option_all       Text to display for showing all categories. Default empty string.
     *     @type string       $show_option_none      Text to display for the 'no categories' option.
     *                                               Default 'No categories'.
     *     @type string       $style                 The style used to display the categories list. If 'list', categories
     *                                               will be output as an unordered list. If left empty or another value,
     *                                               categories will be output separated by `<br>` tags. Default 'list'.
     *     @type string       $taxonomy              Name of the taxonomy to retrieve. Default 'category'.
     *     @type string       $title_li              Text to use for the list title `<li>` element. Pass an empty string
     *                                               to disable. Default 'Categories'.
     *     @type bool|int     $use_desc_for_title    Whether to use the category description as the title attribute.
     *                                               Accepts 0, 1, or their bool equivalents. Default 0.
     *     @type Walker       $walker                Walker object to use to build the output. Default empty which results
     *                                               in a Walker_Category instance being used.
     * }
     * @return void|string|false Void if 'echo' argument is true, HTML list of categories if 'echo' is false.
     *                           False if the taxonomy does not exist.
     * @phpstan-param array{
     *   current_category?: int|int[],
     *   depth?: int,
     *   echo?: bool|int,
     *   exclude?: int[]|string,
     *   exclude_tree?: int[]|string,
     *   feed?: string,
     *   feed_image?: string,
     *   feed_type?: string,
     *   hide_title_if_empty?: bool,
     *   separator?: string,
     *   show_count?: bool|int,
     *   show_option_all?: string,
     *   show_option_none?: string,
     *   style?: string,
     *   taxonomy?: string,
     *   title_li?: string,
     *   use_desc_for_title?: bool|int,
     *   walker?: Walker,
     *   taxonomy?: string,
     * } $args
     * @phpstan-return ($args is array{echo: false|0}&array ? string|false : false|void)
     */
    function wp_list_categories($args = '')
    {
    }
    /**
     * Displays a tag cloud.
     *
     * Outputs a list of tags in what is called a 'tag cloud', where the size of each tag
     * is determined by how many times that particular tag has been assigned to posts.
     *
     * @since 2.3.0
     * @since 2.8.0 Added the `taxonomy` argument.
     * @since 4.8.0 Added the `show_count` argument.
     *
     * @param array|string $args {
     *     Optional. Array or string of arguments for displaying a tag cloud. See wp_generate_tag_cloud()
     *     and get_terms() for the full lists of arguments that can be passed in `$args`.
     *
     *     @type int    $number    The number of tags to display. Accepts any positive integer
     *                             or zero to return all. Default 45.
     *     @type string $link      Whether to display term editing links or term permalinks.
     *                             Accepts 'edit' and 'view'. Default 'view'.
     *     @type string $post_type The post type. Used to highlight the proper post type menu
     *                             on the linked edit page. Defaults to the first post type
     *                             associated with the taxonomy.
     *     @type bool   $echo      Whether or not to echo the return value. Default true.
     * }
     * @return void|string|string[] Void if 'echo' argument is true, or on failure. Otherwise, tag cloud
     *                              as a string or an array, depending on 'format' argument.
     * @phpstan-param array{
     *   number?: int,
     *   link?: string,
     *   post_type?: string,
     *   echo?: bool,
     *   smallest?: int,
     *   largest?: int,
     *   unit?: string,
     *   number?: int,
     *   format?: string,
     *   separator?: string,
     *   orderby?: string,
     *   order?: string,
     *   filter?: int|bool,
     *   topic_count_text?: array,
     *   topic_count_text_callback?: callable,
     *   topic_count_scale_callback?: callable,
     *   show_count?: bool|int,
     * } $args
     * @phpstan-return ($args is array{format: 'array'}&array ? array<int, string>|void : ($args is array{echo: false|0}&array ? string|void : void))
     */
    function wp_tag_cloud($args = '')
    {
    }
    /**
     * Default topic count scaling for tag links.
     *
     * @since 2.9.0
     *
     * @param int $count Number of posts with that tag.
     * @return int Scaled count.
     */
    function default_topic_count_scale($count)
    {
    }
    /**
     * Generates a tag cloud (heatmap) from provided data.
     *
     * @todo Complete functionality.
     * @since 2.3.0
     * @since 4.8.0 Added the `show_count` argument.
     *
     * @param WP_Term[]    $tags Array of WP_Term objects to generate the tag cloud for.
     * @param string|array $args {
     *     Optional. Array or string of arguments for generating a tag cloud.
     *
     *     @type int      $smallest                   Smallest font size used to display tags. Paired
     *                                                with the value of `$unit`, to determine CSS text
     *                                                size unit. Default 8 (pt).
     *     @type int      $largest                    Largest font size used to display tags. Paired
     *                                                with the value of `$unit`, to determine CSS text
     *                                                size unit. Default 22 (pt).
     *     @type string   $unit                       CSS text size unit to use with the `$smallest`
     *                                                and `$largest` values. Accepts any valid CSS text
     *                                                size unit. Default 'pt'.
     *     @type int      $number                     The number of tags to return. Accepts any
     *                                                positive integer or zero to return all.
     *                                                Default 0.
     *     @type string   $format                     Format to display the tag cloud in. Accepts 'flat'
     *                                                (tags separated with spaces), 'list' (tags displayed
     *                                                in an unordered list), or 'array' (returns an array).
     *                                                Default 'flat'.
     *     @type string   $separator                  HTML or text to separate the tags. Default "\n" (newline).
     *     @type string   $orderby                    Value to order tags by. Accepts 'name' or 'count'.
     *                                                Default 'name'. The {@see 'tag_cloud_sort'} filter
     *                                                can also affect how tags are sorted.
     *     @type string   $order                      How to order the tags. Accepts 'ASC' (ascending),
     *                                                'DESC' (descending), or 'RAND' (random). Default 'ASC'.
     *     @type int|bool $filter                     Whether to enable filtering of the final output
     *                                                via {@see 'wp_generate_tag_cloud'}. Default 1.
     *     @type array    $topic_count_text           Nooped plural text from _n_noop() to supply to
     *                                                tag counts. Default null.
     *     @type callable $topic_count_text_callback  Callback used to generate nooped plural text for
     *                                                tag counts based on the count. Default null.
     *     @type callable $topic_count_scale_callback Callback used to determine the tag count scaling
     *                                                value. Default default_topic_count_scale().
     *     @type bool|int $show_count                 Whether to display the tag counts. Default 0. Accepts
     *                                                0, 1, or their bool equivalents.
     * }
     * @return string|string[] Tag cloud as a string or an array, depending on 'format' argument.
     * @phpstan-param array{
     *   smallest?: int,
     *   largest?: int,
     *   unit?: string,
     *   number?: int,
     *   format?: string,
     *   separator?: string,
     *   orderby?: string,
     *   order?: string,
     *   filter?: int|bool,
     *   topic_count_text?: array,
     *   topic_count_text_callback?: callable,
     *   topic_count_scale_callback?: callable,
     *   show_count?: bool|int,
     * } $args
     * @phpstan-return ($args is array{format: 'array'}&array ? array<int, string> : string)
     */
    function wp_generate_tag_cloud($tags, $args = '')
    {
    }
    /**
     * Serves as a callback for comparing objects based on name.
     *
     * Used with `uasort()`.
     *
     * @since 3.1.0
     * @access private
     *
     * @param object $a The first object to compare.
     * @param object $b The second object to compare.
     * @return int Negative number if `$a->name` is less than `$b->name`, zero if they are equal,
     *             or greater than zero if `$a->name` is greater than `$b->name`.
     */
    function _wp_object_name_sort_cb($a, $b)
    {
    }
    /**
     * Serves as a callback for comparing objects based on count.
     *
     * Used with `uasort()`.
     *
     * @since 3.1.0
     * @access private
     *
     * @param object $a The first object to compare.
     * @param object $b The second object to compare.
     * @return int Negative number if `$a->count` is less than `$b->count`, zero if they are equal,
     *             or greater than zero if `$a->count` is greater than `$b->count`.
     */
    function _wp_object_count_sort_cb($a, $b)
    {
    }
    /**
     * Retrieves HTML list content for category list.
     *
     * @since 2.1.0
     * @since 5.3.0 Formalized the existing `...$args` parameter by adding it
     *              to the function signature.
     *
     * @uses Walker_Category to create HTML list content.
     * @see Walker::walk() for parameters and return description.
     *
     * @param mixed ...$args Elements array, maximum hierarchical depth and optional additional arguments.
     * @return string
     */
    function walk_category_tree(...$args)
    {
    }
    /**
     * Retrieves HTML dropdown (select) content for category list.
     *
     * @since 2.1.0
     * @since 5.3.0 Formalized the existing `...$args` parameter by adding it
     *              to the function signature.
     *
     * @uses Walker_CategoryDropdown to create HTML dropdown content.
     * @see Walker::walk() for parameters and return description.
     *
     * @param mixed ...$args Elements array, maximum hierarchical depth and optional additional arguments.
     * @return string
     */
    function walk_category_dropdown_tree(...$args)
    {
    }
    /**
     * Retrieves the link to the tag.
     *
     * @since 2.3.0
     *
     * @see get_term_link()
     *
     * @param int|object $tag Tag ID or object.
     * @return string Link on success, empty string if tag does not exist.
     */
    function get_tag_link($tag)
    {
    }
    /**
     * Retrieves the tags for a post.
     *
     * @since 2.3.0
     *
     * @param int|WP_Post $post Post ID or object.
     * @return WP_Term[]|false|WP_Error Array of WP_Term objects on success, false if there are no terms
     *                                  or the post does not exist, WP_Error on failure.
     */
    function get_the_tags($post = 0)
    {
    }
    /**
     * Retrieves the tags for a post formatted as a string.
     *
     * @since 2.3.0
     *
     * @param string $before  Optional. String to use before the tags. Default empty.
     * @param string $sep     Optional. String to use between the tags. Default empty.
     * @param string $after   Optional. String to use after the tags. Default empty.
     * @param int    $post_id Optional. Post ID. Defaults to the current post ID.
     * @return string|false|WP_Error A list of tags on success, false if there are no terms,
     *                               WP_Error on failure.
     */
    function get_the_tag_list($before = '', $sep = '', $after = '', $post_id = 0)
    {
    }
    /**
     * Displays the tags for a post.
     *
     * @since 2.3.0
     *
     * @param string $before Optional. String to use before the tags. Defaults to 'Tags:'.
     * @param string $sep    Optional. String to use between the tags. Default ', '.
     * @param string $after  Optional. String to use after the tags. Default empty.
     */
    function the_tags($before = \null, $sep = ', ', $after = '')
    {
    }
    /**
     * Retrieves tag description.
     *
     * @since 2.8.0
     *
     * @param int $tag Optional. Tag ID. Defaults to the current tag ID.
     * @return string Tag description, if available.
     */
    function tag_description($tag = 0)
    {
    }
    /**
     * Retrieves term description.
     *
     * @since 2.8.0
     * @since 4.9.2 The `$taxonomy` parameter was deprecated.
     *
     * @param int  $term       Optional. Term ID. Defaults to the current term ID.
     * @param null $deprecated Deprecated. Not used.
     * @return string Term description, if available.
     */
    function term_description($term = 0, $deprecated = \null)
    {
    }
    /**
     * Retrieves the terms of the taxonomy that are attached to the post.
     *
     * @since 2.5.0
     *
     * @param int|WP_Post $post     Post ID or object.
     * @param string      $taxonomy Taxonomy name.
     * @return WP_Term[]|false|WP_Error Array of WP_Term objects on success, false if there are no terms
     *                                  or the post does not exist, WP_Error on failure.
     */
    function get_the_terms($post, $taxonomy)
    {
    }
    /**
     * Retrieves a post's terms as a list with specified format.
     *
     * Terms are linked to their respective term listing pages.
     *
     * @since 2.5.0
     *
     * @param int    $post_id  Post ID.
     * @param string $taxonomy Taxonomy name.
     * @param string $before   Optional. String to use before the terms. Default empty.
     * @param string $sep      Optional. String to use between the terms. Default empty.
     * @param string $after    Optional. String to use after the terms. Default empty.
     * @return string|false|WP_Error A list of terms on success, false if there are no terms,
     *                               WP_Error on failure.
     */
    function get_the_term_list($post_id, $taxonomy, $before = '', $sep = '', $after = '')
    {
    }
    /**
     * Retrieves term parents with separator.
     *
     * @since 4.8.0
     *
     * @param int          $term_id  Term ID.
     * @param string       $taxonomy Taxonomy name.
     * @param string|array $args {
     *     Array of optional arguments.
     *
     *     @type string $format    Use term names or slugs for display. Accepts 'name' or 'slug'.
     *                             Default 'name'.
     *     @type string $separator Separator for between the terms. Default '/'.
     *     @type bool   $link      Whether to format as a link. Default true.
     *     @type bool   $inclusive Include the term to get the parents for. Default true.
     * }
     * @return string|WP_Error A list of term parents on success, WP_Error or empty string on failure.
     * @phpstan-param array{
     *   format?: string,
     *   separator?: string,
     *   link?: bool,
     *   inclusive?: bool,
     * } $args
     */
    function get_term_parents_list($term_id, $taxonomy, $args = array())
    {
    }
    /**
     * Displays the terms for a post in a list.
     *
     * @since 2.5.0
     *
     * @param int    $post_id  Post ID.
     * @param string $taxonomy Taxonomy name.
     * @param string $before   Optional. String to use before the terms. Default empty.
     * @param string $sep      Optional. String to use between the terms. Default ', '.
     * @param string $after    Optional. String to use after the terms. Default empty.
     * @return void|false Void on success, false on failure.
     */
    function the_terms($post_id, $taxonomy, $before = '', $sep = ', ', $after = '')
    {
    }
    /**
     * Checks if the current post has any of given category.
     *
     * The given categories are checked against the post's categories' term_ids, names and slugs.
     * Categories given as integers will only be checked against the post's categories' term_ids.
     *
     * If no categories are given, determines if post has any categories.
     *
     * @since 3.1.0
     *
     * @param string|int|array $category Optional. The category name/term_id/slug,
     *                                   or an array of them to check for. Default empty.
     * @param int|WP_Post      $post     Optional. Post to check. Defaults to the current post.
     * @return bool True if the current post has any of the given categories
     *              (or any category, if no category specified). False otherwise.
     */
    function has_category($category = '', $post = \null)
    {
    }
    /**
     * Checks if the current post has any of given tags.
     *
     * The given tags are checked against the post's tags' term_ids, names and slugs.
     * Tags given as integers will only be checked against the post's tags' term_ids.
     *
     * If no tags are given, determines if post has any tags.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.6.0
     * @since 2.7.0 Tags given as integers are only checked against
     *              the post's tags' term_ids, not names or slugs.
     * @since 2.7.0 Can be used outside of the WordPress Loop if `$post` is provided.
     *
     * @param string|int|array $tag  Optional. The tag name/term_id/slug,
     *                               or an array of them to check for. Default empty.
     * @param int|WP_Post      $post Optional. Post to check. Defaults to the current post.
     * @return bool True if the current post has any of the given tags
     *              (or any tag, if no tag specified). False otherwise.
     */
    function has_tag($tag = '', $post = \null)
    {
    }
    /**
     * Checks if the current post has any of given terms.
     *
     * The given terms are checked against the post's terms' term_ids, names and slugs.
     * Terms given as integers will only be checked against the post's terms' term_ids.
     *
     * If no terms are given, determines if post has any terms.
     *
     * @since 3.1.0
     *
     * @param string|int|array $term     Optional. The term name/term_id/slug,
     *                                   or an array of them to check for. Default empty.
     * @param string           $taxonomy Optional. Taxonomy name. Default empty.
     * @param int|WP_Post      $post     Optional. Post to check. Defaults to the current post.
     * @return bool True if the current post has any of the given terms
     *              (or any term, if no term specified). False otherwise.
     */
    function has_term($term = '', $taxonomy = '', $post = \null)
    {
    }
    /**
     * Retrieves a list of category objects.
     *
     * If you set the 'taxonomy' argument to 'link_category', the link categories
     * will be returned instead.
     *
     * @since 2.1.0
     *
     * @see get_terms() Type of arguments that can be changed.
     *
     * @param string|array $args {
     *     Optional. Arguments to retrieve categories. See get_terms() for additional options.
     *
     *     @type string $taxonomy Taxonomy to retrieve terms for. Default 'category'.
     * }
     * @return array List of category objects.
     * @phpstan-param array{
     *   taxonomy?: string,
     * } $args
     * @phpstan-return ($args is array{fields: 'count'}&array ? list<numeric-string> : ($args is array{fields: 'names'|'slugs'}&array ? list<string> : ($args is array{fields: 'id=>name'|'id=>slug'}&array ? array<int, string> : ($args is array{fields: 'id=>parent'}&array ? array<int, int> : ($args is array{fields: 'ids'|'tt_ids'}&array ? list<int> : array<int, \WP_Term>)))))
     */
    function get_categories($args = '')
    {
    }
    /**
     * Retrieves category data given a category ID or category object.
     *
     * If you pass the $category parameter an object, which is assumed to be the
     * category row object retrieved the database. It will cache the category data.
     *
     * If you pass $category an integer of the category ID, then that category will
     * be retrieved from the database, if it isn't already cached, and pass it back.
     *
     * If you look at get_term(), then both types will be passed through several
     * filters and finally sanitized based on the $filter parameter value.
     *
     * @since 1.5.1
     *
     * @param int|object $category Category ID or category row object.
     * @param string     $output   Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
     *                             correspond to a WP_Term object, an associative array, or a numeric array,
     *                             respectively. Default OBJECT.
     * @param string     $filter   Optional. How to sanitize category fields. Default 'raw'.
     * @return object|array|WP_Error|null Category data in type defined by $output parameter.
     *                                    WP_Error if $category is empty, null if it does not exist.
     * @phpstan-param 'OBJECT'|'ARRAY_A'|'ARRAY_N' $output
     * @phpstan-return ($category is object ? array<array-key, mixed>|\WP_Term : array<array-key, mixed>|\WP_Term|\WP_Error|null) & ($output is 'ARRAY_A' ? array<string, mixed>|\WP_Error|null : ($output is 'ARRAY_N' ? array<int, mixed>|\WP_Error|null : \WP_Term|\WP_Error|null))
     */
    function get_category($category, $output = \OBJECT, $filter = 'raw')
    {
    }
    /**
     * Retrieves a category based on URL containing the category slug.
     *
     * Breaks the $category_path parameter up to get the category slug.
     *
     * Tries to find the child path and will return it. If it doesn't find a
     * match, then it will return the first category matching slug, if $full_match,
     * is set to false. If it does not, then it will return null.
     *
     * It is also possible that it will return a WP_Error object on failure. Check
     * for it when using this function.
     *
     * @since 2.1.0
     *
     * @param string $category_path URL containing category slugs.
     * @param bool   $full_match    Optional. Whether full path should be matched.
     * @param string $output        Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
     *                              correspond to a WP_Term object, an associative array, or a numeric array,
     *                              respectively. Default OBJECT.
     * @return WP_Term|array|WP_Error|null Type is based on $output value.
     * @phpstan-param 'OBJECT'|'ARRAY_A'|'ARRAY_N' $output
     * @phpstan-return ($output is 'ARRAY_A' ? array<string, mixed>|\WP_Error|null : ($output is 'ARRAY_N' ? array<int, mixed>|\WP_Error|null : \WP_Term|\WP_Error|null))
     */
    function get_category_by_path($category_path, $full_match = \true, $output = \OBJECT)
    {
    }
    /**
     * Retrieves a category object by category slug.
     *
     * @since 2.3.0
     *
     * @param string $slug The category slug.
     * @return object|false Category data object on success, false if not found.
     */
    function get_category_by_slug($slug)
    {
    }
    /**
     * Retrieves the ID of a category from its name.
     *
     * @since 1.0.0
     *
     * @param string $cat_name Category name.
     * @return int Category ID on success, 0 if the category doesn't exist.
     */
    function get_cat_ID($cat_name)
    {
    }
    /**
     * Retrieves the name of a category from its ID.
     *
     * @since 1.0.0
     *
     * @param int $cat_id Category ID.
     * @return string Category name, or an empty string if the category doesn't exist.
     */
    function get_cat_name($cat_id)
    {
    }
    /**
     * Checks if a category is an ancestor of another category.
     *
     * You can use either an ID or the category object for both parameters.
     * If you use an integer, the category will be retrieved.
     *
     * @since 2.1.0
     *
     * @param int|object $cat1 ID or object to check if this is the parent category.
     * @param int|object $cat2 The child category.
     * @return bool Whether $cat2 is child of $cat1.
     */
    function cat_is_ancestor_of($cat1, $cat2)
    {
    }
    /**
     * Sanitizes category data based on context.
     *
     * @since 2.3.0
     *
     * @param object|array $category Category data.
     * @param string       $context  Optional. Default 'display'.
     * @return object|array Same type as $category with sanitized data for safe use.
     * @phpstan-template T of array|object
     * @phpstan-param T $category
     * @phpstan-return T
     */
    function sanitize_category($category, $context = 'display')
    {
    }
    /**
     * Sanitizes data in single category key field.
     *
     * @since 2.3.0
     *
     * @param string $field   Category key to sanitize.
     * @param mixed  $value   Category value to sanitize.
     * @param int    $cat_id  Category ID.
     * @param string $context What filter to use, 'raw', 'display', etc.
     * @return mixed Value after $value has been sanitized.
     */
    function sanitize_category_field($field, $value, $cat_id, $context)
    {
    }
    /**
     * Retrieves all post tags.
     *
     * @since 2.3.0
     *
     * @param string|array $args {
     *     Optional. Arguments to retrieve tags. See get_terms() for additional options.
     *
     *     @type string $taxonomy Taxonomy to retrieve terms for. Default 'post_tag'.
     * }
     * @return WP_Term[]|int|WP_Error Array of 'post_tag' term objects, a count thereof,
     *                                or WP_Error if any of the taxonomies do not exist.
     * @phpstan-param array{
     *   taxonomy?: string,
     * } $args
     * @phpstan-return ($args is array{fields: 'count'}&array ? numeric-string : ($args is array{fields: 'names'|'slugs'}&array ? list<string> : ($args is array{fields: 'id=>name'|'id=>slug'}&array ? array<int, string> : ($args is array{fields: 'id=>parent'}&array ? array<int, int> : ($args is array{fields: 'ids'|'tt_ids'}&array ? list<int> : array<int, \WP_Term>)))))|\WP_Error
     */
    function get_tags($args = '')
    {
    }
    /**
     * Retrieves a post tag by tag ID or tag object.
     *
     * If you pass the $tag parameter an object, which is assumed to be the tag row
     * object retrieved from the database, it will cache the tag data.
     *
     * If you pass $tag an integer of the tag ID, then that tag will be retrieved
     * from the database, if it isn't already cached, and passed back.
     *
     * If you look at get_term(), both types will be passed through several filters
     * and finally sanitized based on the $filter parameter value.
     *
     * @since 2.3.0
     *
     * @param int|WP_Term|object $tag    A tag ID or object.
     * @param string             $output Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
     *                                   correspond to a WP_Term object, an associative array, or a numeric array,
     *                                   respectively. Default OBJECT.
     * @param string             $filter Optional. How to sanitize tag fields. Default 'raw'.
     * @return WP_Term|array|WP_Error|null Tag data in type defined by $output parameter.
     *                                     WP_Error if $tag is empty, null if it does not exist.
     */
    function get_tag($tag, $output = \OBJECT, $filter = 'raw')
    {
    }
    /**
     * Removes the category cache data based on ID.
     *
     * @since 2.1.0
     *
     * @param int $id Category ID
     */
    function clean_category_cache($id)
    {
    }
    /**
     * Updates category structure to old pre-2.3 from new taxonomy structure.
     *
     * This function was added for the taxonomy support to update the new category
     * structure with the old category one. This will maintain compatibility with
     * plugins and themes which depend on the old key or property names.
     *
     * The parameter should only be passed a variable and not create the array or
     * object inline to the parameter. The reason for this is that parameter is
     * passed by reference and PHP will fail unless it has the variable.
     *
     * There is no return value, because everything is updated on the variable you
     * pass to it. This is one of the features with using pass by reference in PHP.
     *
     * @since 2.3.0
     * @since 4.4.0 The `$category` parameter now also accepts a WP_Term object.
     * @access private
     *
     * @param array|object|WP_Term $category Category row object or array.
     */
    function _make_cat_compat(&$category)
    {
    }
    /**
     * WordPress autoloader for SimplePie.
     *
     * @since 3.5.0
     * @deprecated 6.7.0 Use `SimplePie_Autoloader` instead.
     *
     * @param string $class Class name.
     */
    function wp_simplepie_autoload($class)
    {
    }
    /**
     * Registers a new pattern category.
     *
     * @since 5.5.0
     *
     * @param string $category_name       Pattern category name including namespace.
     * @param array  $category_properties List of properties for the block pattern.
     *                                    See WP_Block_Pattern_Categories_Registry::register() for
     *                                    accepted arguments.
     * @return bool True if the pattern category was registered with success and false otherwise.
     * @phpstan-param array{
     *   label?: string,
     * } $category_properties See WP_Block_Pattern_Categories_Registry::register()
     */
    function register_block_pattern_category($category_name, $category_properties)
    {
    }
    /**
     * Unregisters a pattern category.
     *
     * @since 5.5.0
     *
     * @param string $category_name Pattern category name including namespace.
     * @return bool True if the pattern category was unregistered with success and false otherwise.
     */
    function unregister_block_pattern_category($category_name)
    {
    }
    /**
     * Registers a new block pattern.
     *
     * @since 5.5.0
     *
     * @param string $pattern_name       Block pattern name including namespace.
     * @param array  $pattern_properties List of properties for the block pattern.
     *                                   See WP_Block_Patterns_Registry::register() for accepted arguments.
     * @return bool True if the pattern was registered with success and false otherwise.
     * @phpstan-param array{
     *   title?: string,
     *   content?: string,
     *   description?: string,
     *   viewportWidth?: int,
     *   inserter?: bool,
     *   categories?: string[],
     *   keywords?: string[],
     *   blockTypes?: string[],
     *   postTypes?: string[],
     *   templateTypes?: string[],
     *   filePath?: string,
     * } $pattern_properties See WP_Block_Patterns_Registry::register()
     */
    function register_block_pattern($pattern_name, $pattern_properties)
    {
    }
    /**
     * Unregisters a block pattern.
     *
     * @since 5.5.0
     *
     * @param string $pattern_name Block pattern name including namespace.
     * @return bool True if the pattern was unregistered with success and false otherwise.
     */
    function unregister_block_pattern($pattern_name)
    {
    }
    /**
     * Generates a string of attributes by applying to the current block being
     * rendered all of the features that the block supports.
     *
     * @since 5.6.0
     *
     * @param string[] $extra_attributes Optional. Array of extra attributes to render on the block wrapper.
     * @return string String of HTML attributes.
     */
    function get_block_wrapper_attributes($extra_attributes = array())
    {
    }
    /**
     * Retrieves the author of the current comment.
     *
     * If the comment has an empty comment_author field, then 'Anonymous' person is
     * assumed.
     *
     * @since 1.5.0
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or the ID of the comment for which to retrieve the author.
     *                                   Default current comment.
     * @return string The comment author
     */
    function get_comment_author($comment_id = 0)
    {
    }
    /**
     * Displays the author of the current comment.
     *
     * @since 0.71
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or the ID of the comment for which to print the author.
     *                                   Default current comment.
     */
    function comment_author($comment_id = 0)
    {
    }
    /**
     * Retrieves the email of the author of the current comment.
     *
     * @since 1.5.0
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or the ID of the comment for which to get the author's email.
     *                                   Default current comment.
     * @return string The current comment author's email
     */
    function get_comment_author_email($comment_id = 0)
    {
    }
    /**
     * Displays the email of the author of the current global $comment.
     *
     * Care should be taken to protect the email address and assure that email
     * harvesters do not capture your commenter's email address. Most assume that
     * their email address will not appear in raw form on the site. Doing so will
     * enable anyone, including those that people don't want to get the email
     * address and use it for their own means good and bad.
     *
     * @since 0.71
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or the ID of the comment for which to print the author's email.
     *                                   Default current comment.
     */
    function comment_author_email($comment_id = 0)
    {
    }
    /**
     * Displays the HTML email link to the author of the current comment.
     *
     * Care should be taken to protect the email address and assure that email
     * harvesters do not capture your commenter's email address. Most assume that
     * their email address will not appear in raw form on the site. Doing so will
     * enable anyone, including those that people don't want to get the email
     * address and use it for their own means good and bad.
     *
     * @since 0.71
     * @since 4.6.0 Added the `$comment` parameter.
     *
     * @param string         $link_text Optional. Text to display instead of the comment author's email address.
     *                                  Default empty.
     * @param string         $before    Optional. Text or HTML to display before the email link. Default empty.
     * @param string         $after     Optional. Text or HTML to display after the email link. Default empty.
     * @param int|WP_Comment $comment   Optional. Comment ID or WP_Comment object. Default is the current comment.
     */
    function comment_author_email_link($link_text = '', $before = '', $after = '', $comment = \null)
    {
    }
    /**
     * Returns the HTML email link to the author of the current comment.
     *
     * Care should be taken to protect the email address and assure that email
     * harvesters do not capture your commenter's email address. Most assume that
     * their email address will not appear in raw form on the site. Doing so will
     * enable anyone, including those that people don't want to get the email
     * address and use it for their own means good and bad.
     *
     * @since 2.7.0
     * @since 4.6.0 Added the `$comment` parameter.
     *
     * @param string         $link_text Optional. Text to display instead of the comment author's email address.
     *                                  Default empty.
     * @param string         $before    Optional. Text or HTML to display before the email link. Default empty.
     * @param string         $after     Optional. Text or HTML to display after the email link. Default empty.
     * @param int|WP_Comment $comment   Optional. Comment ID or WP_Comment object. Default is the current comment.
     * @return string HTML markup for the comment author email link. By default, the email address is obfuscated
     *                via the {@see 'comment_email'} filter with antispambot().
     */
    function get_comment_author_email_link($link_text = '', $before = '', $after = '', $comment = \null)
    {
    }
    /**
     * Retrieves the HTML link to the URL of the author of the current comment.
     *
     * Both get_comment_author_url() and get_comment_author() rely on get_comment(),
     * which falls back to the global comment variable if the $comment_id argument is empty.
     *
     * @since 1.5.0
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or the ID of the comment for which to get the author's link.
     *                                   Default current comment.
     * @return string The comment author name or HTML link for author's URL.
     */
    function get_comment_author_link($comment_id = 0)
    {
    }
    /**
     * Displays the HTML link to the URL of the author of the current comment.
     *
     * @since 0.71
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or the ID of the comment for which to print the author's link.
     *                                   Default current comment.
     */
    function comment_author_link($comment_id = 0)
    {
    }
    /**
     * Retrieves the IP address of the author of the current comment.
     *
     * @since 1.5.0
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or the ID of the comment for which to get the author's IP address.
     *                                   Default current comment.
     * @return string Comment author's IP address, or an empty string if it's not available.
     */
    function get_comment_author_IP($comment_id = 0)
    {
    }
    /**
     * Displays the IP address of the author of the current comment.
     *
     * @since 0.71
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or the ID of the comment for which to print the author's IP address.
     *                                   Default current comment.
     */
    function comment_author_IP($comment_id = 0)
    {
    }
    /**
     * Retrieves the URL of the author of the current comment, not linked.
     *
     * @since 1.5.0
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or the ID of the comment for which to get the author's URL.
     *                                   Default current comment.
     * @return string Comment author URL, if provided, an empty string otherwise.
     */
    function get_comment_author_url($comment_id = 0)
    {
    }
    /**
     * Displays the URL of the author of the current comment, not linked.
     *
     * @since 0.71
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or the ID of the comment for which to print the author's URL.
     *                                   Default current comment.
     */
    function comment_author_url($comment_id = 0)
    {
    }
    /**
     * Retrieves the HTML link of the URL of the author of the current comment.
     *
     * $link_text parameter is only used if the URL does not exist for the comment
     * author. If the URL does exist then the URL will be used and the $link_text
     * will be ignored.
     *
     * Encapsulate the HTML link between the $before and $after. So it will appear
     * in the order of $before, link, and finally $after.
     *
     * @since 1.5.0
     * @since 4.6.0 Added the `$comment` parameter.
     *
     * @param string         $link_text Optional. The text to display instead of the comment
     *                                  author's email address. Default empty.
     * @param string         $before    Optional. The text or HTML to display before the email link.
     *                                  Default empty.
     * @param string         $after     Optional. The text or HTML to display after the email link.
     *                                  Default empty.
     * @param int|WP_Comment $comment   Optional. Comment ID or WP_Comment object.
     *                                  Default is the current comment.
     * @return string The HTML link between the $before and $after parameters.
     */
    function get_comment_author_url_link($link_text = '', $before = '', $after = '', $comment = 0)
    {
    }
    /**
     * Displays the HTML link of the URL of the author of the current comment.
     *
     * @since 0.71
     * @since 4.6.0 Added the `$comment` parameter.
     *
     * @param string         $link_text Optional. Text to display instead of the comment author's
     *                                  email address. Default empty.
     * @param string         $before    Optional. Text or HTML to display before the email link.
     *                                  Default empty.
     * @param string         $after     Optional. Text or HTML to display after the email link.
     *                                  Default empty.
     * @param int|WP_Comment $comment   Optional. Comment ID or WP_Comment object.
     *                                  Default is the current comment.
     */
    function comment_author_url_link($link_text = '', $before = '', $after = '', $comment = 0)
    {
    }
    /**
     * Generates semantic classes for each comment element.
     *
     * @since 2.7.0
     * @since 4.4.0 Added the ability for `$comment` to also accept a WP_Comment object.
     *
     * @param string|string[] $css_class Optional. One or more classes to add to the class list.
     *                                   Default empty.
     * @param int|WP_Comment  $comment   Optional. Comment ID or WP_Comment object. Default current comment.
     * @param int|WP_Post     $post      Optional. Post ID or WP_Post object. Default current post.
     * @param bool            $display   Optional. Whether to print or return the output.
     *                                   Default true.
     * @return void|string Void if `$display` argument is true, comment classes if `$display` is false.
     * @phpstan-return ($display is true ? void : string)
     */
    function comment_class($css_class = '', $comment = \null, $post = \null, $display = \true)
    {
    }
    /**
     * Returns the classes for the comment div as an array.
     *
     * @since 2.7.0
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @global int $comment_alt
     * @global int $comment_depth
     * @global int $comment_thread_alt
     *
     * @param string|string[] $css_class  Optional. One or more classes to add to the class list.
     *                                    Default empty.
     * @param int|WP_Comment  $comment_id Optional. Comment ID or WP_Comment object. Default current comment.
     * @param int|WP_Post     $post       Optional. Post ID or WP_Post object. Default current post.
     * @return string[] An array of classes.
     */
    function get_comment_class($css_class = '', $comment_id = \null, $post = \null)
    {
    }
    /**
     * Retrieves the comment date of the current comment.
     *
     * @since 1.5.0
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param string         $format     Optional. PHP date format. Defaults to the 'date_format' option.
     * @param int|WP_Comment $comment_id Optional. WP_Comment or ID of the comment for which to get the date.
     *                                   Default current comment.
     * @return string The comment's date.
     */
    function get_comment_date($format = '', $comment_id = 0)
    {
    }
    /**
     * Displays the comment date of the current comment.
     *
     * @since 0.71
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param string         $format     Optional. PHP date format. Defaults to the 'date_format' option.
     * @param int|WP_Comment $comment_id WP_Comment or ID of the comment for which to print the date.
     *                                   Default current comment.
     */
    function comment_date($format = '', $comment_id = 0)
    {
    }
    /**
     * Retrieves the excerpt of the given comment.
     *
     * Returns a maximum of 20 words with an ellipsis appended if necessary.
     *
     * @since 1.5.0
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or ID of the comment for which to get the excerpt.
     *                                   Default current comment.
     * @return string The possibly truncated comment excerpt.
     */
    function get_comment_excerpt($comment_id = 0)
    {
    }
    /**
     * Displays the excerpt of the current comment.
     *
     * @since 1.2.0
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or ID of the comment for which to print the excerpt.
     *                                   Default current comment.
     */
    function comment_excerpt($comment_id = 0)
    {
    }
    /**
     * Retrieves the comment ID of the current comment.
     *
     * @since 1.5.0
     *
     * @return string The comment ID as a numeric string.
     */
    function get_comment_ID()
    {
    }
    /**
     * Displays the comment ID of the current comment.
     *
     * @since 0.71
     */
    function comment_ID()
    {
    }
    /**
     * Retrieves the link to a given comment.
     *
     * @since 1.5.0
     * @since 4.4.0 Added the ability for `$comment` to also accept a WP_Comment object. Added `$cpage` argument.
     *
     * @see get_page_of_comment()
     *
     * @global WP_Rewrite $wp_rewrite      WordPress rewrite component.
     * @global bool       $in_comment_loop
     *
     * @param WP_Comment|int|null $comment Optional. Comment to retrieve. Default current comment.
     * @param array               $args {
     *     An array of optional arguments to override the defaults.
     *
     *     @type string     $type      Passed to get_page_of_comment().
     *     @type int        $page      Current page of comments, for calculating comment pagination.
     *     @type int        $per_page  Per-page value for comment pagination.
     *     @type int        $max_depth Passed to get_page_of_comment().
     *     @type int|string $cpage     Value to use for the comment's "comment-page" or "cpage" value.
     *                                 If provided, this value overrides any value calculated from `$page`
     *                                 and `$per_page`.
     * }
     * @return string The permalink to the given comment.
     * @phpstan-param array{
     *   type?: string,
     *   page?: int,
     *   per_page?: int,
     *   max_depth?: int,
     *   cpage?: int|string,
     * } $args
     */
    function get_comment_link($comment = \null, $args = array())
    {
    }
    /**
     * Retrieves the link to the current post comments.
     *
     * @since 1.5.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return string The link to the comments.
     */
    function get_comments_link($post = 0)
    {
    }
    /**
     * Displays the link to the current post comments.
     *
     * @since 0.71
     *
     * @param string $deprecated   Not Used.
     * @param string $deprecated_2 Not Used.
     */
    function comments_link($deprecated = '', $deprecated_2 = '')
    {
    }
    /**
     * Retrieves the amount of comments a post has.
     *
     * @since 1.5.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is the global `$post`.
     * @return string|int If the post exists, a numeric string representing the number of comments
     *                    the post has, otherwise 0.
     */
    function get_comments_number($post = 0)
    {
    }
    /**
     * Displays the language string for the number of comments the current post has.
     *
     * @since 0.71
     * @since 5.4.0 The `$deprecated` parameter was changed to `$post`.
     *
     * @param string|false $zero Optional. Text for no comments. Default false.
     * @param string|false $one  Optional. Text for one comment. Default false.
     * @param string|false $more Optional. Text for more than one comment. Default false.
     * @param int|WP_Post  $post Optional. Post ID or WP_Post object. Default is the global `$post`.
     */
    function comments_number($zero = \false, $one = \false, $more = \false, $post = 0)
    {
    }
    /**
     * Displays the language string for the number of comments the current post has.
     *
     * @since 4.0.0
     * @since 5.4.0 Added the `$post` parameter to allow using the function outside of the loop.
     *
     * @param string      $zero Optional. Text for no comments. Default false.
     * @param string      $one  Optional. Text for one comment. Default false.
     * @param string      $more Optional. Text for more than one comment. Default false.
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is the global `$post`.
     * @return string Language string for the number of comments a post has.
     */
    function get_comments_number_text($zero = \false, $one = \false, $more = \false, $post = 0)
    {
    }
    /**
     * Retrieves the text of the current comment.
     *
     * @since 1.5.0
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     * @since 5.4.0 Added 'In reply to %s.' prefix to child comments in comments feed.
     *
     * @see Walker_Comment::comment()
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or ID of the comment for which to get the text.
     *                                   Default current comment.
     * @param array          $args       Optional. An array of arguments. Default empty array.
     * @return string The comment content.
     */
    function get_comment_text($comment_id = 0, $args = array())
    {
    }
    /**
     * Displays the text of the current comment.
     *
     * @since 0.71
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @see Walker_Comment::comment()
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or ID of the comment for which to print the text.
     *                                   Default current comment.
     * @param array          $args       Optional. An array of arguments. Default empty array.
     */
    function comment_text($comment_id = 0, $args = array())
    {
    }
    /**
     * Retrieves the comment time of the current comment.
     *
     * @since 1.5.0
     * @since 6.2.0 Added the `$comment_id` parameter.
     *
     * @param string         $format     Optional. PHP date format. Defaults to the 'time_format' option.
     * @param bool           $gmt        Optional. Whether to use the GMT date. Default false.
     * @param bool           $translate  Optional. Whether to translate the time (for use in feeds).
     *                                   Default true.
     * @param int|WP_Comment $comment_id Optional. WP_Comment or ID of the comment for which to get the time.
     *                                   Default current comment.
     * @return string The formatted time.
     */
    function get_comment_time($format = '', $gmt = \false, $translate = \true, $comment_id = 0)
    {
    }
    /**
     * Displays the comment time of the current comment.
     *
     * @since 0.71
     * @since 6.2.0 Added the `$comment_id` parameter.
     *
     * @param string         $format     Optional. PHP time format. Defaults to the 'time_format' option.
     * @param int|WP_Comment $comment_id Optional. WP_Comment or ID of the comment for which to print the time.
     *                                   Default current comment.
     */
    function comment_time($format = '', $comment_id = 0)
    {
    }
    /**
     * Retrieves the comment type of the current comment.
     *
     * @since 1.5.0
     * @since 4.4.0 Added the ability for `$comment_id` to also accept a WP_Comment object.
     *
     * @param int|WP_Comment $comment_id Optional. WP_Comment or ID of the comment for which to get the type.
     *                                   Default current comment.
     * @return string The comment type.
     */
    function get_comment_type($comment_id = 0)
    {
    }
    /**
     * Displays the comment type of the current comment.
     *
     * @since 0.71
     *
     * @param string|false $commenttxt   Optional. String to display for comment type. Default false.
     * @param string|false $trackbacktxt Optional. String to display for trackback type. Default false.
     * @param string|false $pingbacktxt  Optional. String to display for pingback type. Default false.
     */
    function comment_type($commenttxt = \false, $trackbacktxt = \false, $pingbacktxt = \false)
    {
    }
    /**
     * Retrieves the current post's trackback URL.
     *
     * There is a check to see if permalink's have been enabled and if so, will
     * retrieve the pretty path. If permalinks weren't enabled, the ID of the
     * current post is used and appended to the correct page to go to.
     *
     * @since 1.5.0
     *
     * @return string The trackback URL after being filtered.
     */
    function get_trackback_url()
    {
    }
    /**
     * Displays the current post's trackback URL.
     *
     * @since 0.71
     *
     * @param bool $deprecated_echo Not used.
     * @return void|string Should only be used to echo the trackback URL, use get_trackback_url()
     *                     for the result instead.
     */
    function trackback_url($deprecated_echo = \true)
    {
    }
    /**
     * Generates and displays the RDF for the trackback information of current post.
     *
     * Deprecated in 3.0.0, and restored in 3.0.1.
     *
     * @since 0.71
     *
     * @param int|string $deprecated Not used (Was $timezone = 0).
     * @phpstan-return void
     */
    function trackback_rdf($deprecated = '')
    {
    }
    /**
     * Determines whether the current post is open for comments.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default current post.
     * @return bool True if the comments are open.
     */
    function comments_open($post = \null)
    {
    }
    /**
     * Determines whether the current post is open for pings.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default current post.
     * @return bool True if pings are accepted
     */
    function pings_open($post = \null)
    {
    }
    /**
     * Displays form token for unfiltered comments.
     *
     * Will only display nonce token if the current user has permissions for
     * unfiltered html. Won't display the token for other users.
     *
     * The function was backported to 2.0.10 and was added to versions 2.1.3 and
     * above. Does not exist in versions prior to 2.0.10 in the 2.0 branch and in
     * the 2.1 branch, prior to 2.1.3. Technically added in 2.2.0.
     *
     * Backported to 2.0.10.
     *
     * @since 2.1.3
     */
    function wp_comment_form_unfiltered_html_nonce()
    {
    }
    /**
     * Loads the comment template specified in $file.
     *
     * Will not display the comments template if not on single post or page, or if
     * the post does not have comments.
     *
     * Uses the WordPress database object to query for the comments. The comments
     * are passed through the {@see 'comments_array'} filter hook with the list of comments
     * and the post ID respectively.
     *
     * The `$file` path is passed through a filter hook called {@see 'comments_template'},
     * which includes the template directory and $file combined. Tries the $filtered path
     * first and if it fails it will require the default comment template from the
     * default theme. If either does not exist, then the WordPress process will be
     * halted. It is advised for that reason, that the default theme is not deleted.
     *
     * Will not try to get the comments if the post has none.
     *
     * @since 1.5.0
     *
     * @global WP_Query   $wp_query           WordPress Query object.
     * @global WP_Post    $post               Global post object.
     * @global wpdb       $wpdb               WordPress database abstraction object.
     * @global int        $id
     * @global WP_Comment $comment            Global comment object.
     * @global string     $user_login
     * @global string     $user_identity
     * @global bool       $overridden_cpage
     * @global bool       $withcomments
     * @global string     $wp_stylesheet_path Path to current theme's stylesheet directory.
     * @global string     $wp_template_path   Path to current theme's template directory.
     *
     * @param string $file              Optional. The file to load. Default '/comments.php'.
     * @param bool   $separate_comments Optional. Whether to separate the comments by comment type.
     *                                  Default false.
     * @phpstan-return void
     */
    function comments_template($file = '/comments.php', $separate_comments = \false)
    {
    }
    /**
     * Displays the link to the comments for the current post ID.
     *
     * @since 0.71
     *
     * @param false|string $zero      Optional. String to display when no comments. Default false.
     * @param false|string $one       Optional. String to display when only one comment is available. Default false.
     * @param false|string $more      Optional. String to display when there are more than one comment. Default false.
     * @param string       $css_class Optional. CSS class to use for comments. Default empty.
     * @param false|string $none      Optional. String to display when comments have been turned off. Default false.
     * @phpstan-return void
     */
    function comments_popup_link($zero = \false, $one = \false, $more = \false, $css_class = '', $none = \false)
    {
    }
    /**
     * Retrieves HTML content for reply to comment link.
     *
     * @since 2.7.0
     * @since 4.4.0 Added the ability for `$comment` to also accept a WP_Comment object.
     *
     * @param array          $args {
     *     Optional. Override default arguments.
     *
     *     @type string $add_below          The first part of the selector used to identify the comment to respond below.
     *                                      The resulting value is passed as the first parameter to addComment.moveForm(),
     *                                      concatenated as $add_below-$comment->comment_ID. Default 'comment'.
     *     @type string $respond_id         The selector identifying the responding comment. Passed as the third parameter
     *                                      to addComment.moveForm(), and appended to the link URL as a hash value.
     *                                      Default 'respond'.
     *     @type string $reply_text         The visible text of the Reply link. Default 'Reply'.
     *     @type string $reply_to_text      The accessible name of the Reply link, using `%s` as a placeholder
     *                                      for the comment author's name. Default 'Reply to %s'.
     *                                      Should start with the visible `reply_text` value.
     *     @type bool   $show_reply_to_text Whether to use `reply_to_text` as visible link text. Default false.
     *     @type string $login_text         The text of the link to reply if logged out. Default 'Log in to Reply'.
     *     @type int    $max_depth          The max depth of the comment tree. Default 0.
     *     @type int    $depth              The depth of the new comment. Must be greater than 0 and less than the value
     *                                      of the 'thread_comments_depth' option set in Settings > Discussion. Default 0.
     *     @type string $before             The text or HTML to add before the reply link. Default empty.
     *     @type string $after              The text or HTML to add after the reply link. Default empty.
     * }
     * @param int|WP_Comment $comment Optional. Comment being replied to. Default current comment.
     * @param int|WP_Post    $post    Optional. Post ID or WP_Post object the comment is going to be displayed on.
     *                                Default current post.
     * @return string|false|null Link to show comment form, if successful. False, if comments are closed.
     * @phpstan-param array{
     *   add_below?: string,
     *   respond_id?: string,
     *   reply_text?: string,
     *   reply_to_text?: string,
     *   show_reply_to_text?: bool,
     *   login_text?: string,
     *   max_depth?: int,
     *   depth?: int,
     *   before?: string,
     *   after?: string,
     * } $args
     */
    function get_comment_reply_link($args = array(), $comment = \null, $post = \null)
    {
    }
    /**
     * Displays the HTML content for reply to comment link.
     *
     * @since 2.7.0
     *
     * @see get_comment_reply_link()
     *
     * @param array          $args    Optional. Override default options. Default empty array.
     * @param int|WP_Comment $comment Optional. Comment being replied to. Default current comment.
     * @param int|WP_Post    $post    Optional. Post ID or WP_Post object the comment is going to be displayed on.
     *                                Default current post.
     */
    function comment_reply_link($args = array(), $comment = \null, $post = \null)
    {
    }
    /**
     * Retrieves HTML content for reply to post link.
     *
     * @since 2.7.0
     *
     * @param array       $args {
     *     Optional. Override default arguments.
     *
     *     @type string $add_below  The first part of the selector used to identify the comment to respond below.
     *                              The resulting value is passed as the first parameter to addComment.moveForm(),
     *                              concatenated as $add_below-$comment->comment_ID. Default is 'post'.
     *     @type string $respond_id The selector identifying the responding comment. Passed as the third parameter
     *                              to addComment.moveForm(), and appended to the link URL as a hash value.
     *                              Default 'respond'.
     *     @type string $reply_text Text of the Reply link. Default is 'Leave a Comment'.
     *     @type string $login_text Text of the link to reply if logged out. Default is 'Log in to leave a Comment'.
     *     @type string $before     Text or HTML to add before the reply link. Default empty.
     *     @type string $after      Text or HTML to add after the reply link. Default empty.
     * }
     * @param int|WP_Post $post    Optional. Post ID or WP_Post object the comment is going to be displayed on.
     *                             Default current post.
     * @return string|false|null Link to show comment form, if successful. False, if comments are closed.
     * @phpstan-param array{
     *   add_below?: string,
     *   respond_id?: string,
     *   reply_text?: string,
     *   login_text?: string,
     *   before?: string,
     *   after?: string,
     * } $args
     */
    function get_post_reply_link($args = array(), $post = \null)
    {
    }
    /**
     * Displays the HTML content for reply to post link.
     *
     * @since 2.7.0
     *
     * @see get_post_reply_link()
     *
     * @param array       $args Optional. Override default options. Default empty array.
     * @param int|WP_Post $post Optional. Post ID or WP_Post object the comment is going to be displayed on.
     *                          Default current post.
     */
    function post_reply_link($args = array(), $post = \null)
    {
    }
    /**
     * Retrieves HTML content for cancel comment reply link.
     *
     * @since 2.7.0
     * @since 6.2.0 Added the `$post` parameter.
     *
     * @param string           $link_text Optional. Text to display for cancel reply link. If empty,
     *                                    defaults to 'Click here to cancel reply'. Default empty.
     * @param int|WP_Post|null $post      Optional. The post the comment thread is being
     *                                    displayed for. Defaults to the current global post.
     * @return string
     */
    function get_cancel_comment_reply_link($link_text = '', $post = \null)
    {
    }
    /**
     * Displays HTML content for cancel comment reply link.
     *
     * @since 2.7.0
     *
     * @param string $link_text Optional. Text to display for cancel reply link. If empty,
     *                     defaults to 'Click here to cancel reply'. Default empty.
     */
    function cancel_comment_reply_link($link_text = '')
    {
    }
    /**
     * Retrieves hidden input HTML for replying to comments.
     *
     * @since 3.0.0
     * @since 6.2.0 Renamed `$post_id` to `$post` and added WP_Post support.
     *
     * @param int|WP_Post|null $post Optional. The post the comment is being displayed for.
     *                               Defaults to the current global post.
     * @return string Hidden input HTML for replying to comments.
     */
    function get_comment_id_fields($post = \null)
    {
    }
    /**
     * Outputs hidden input HTML for replying to comments.
     *
     * Adds two hidden inputs to the comment form to identify the `comment_post_ID`
     * and `comment_parent` values for threaded comments.
     *
     * This tag must be within the `<form>` section of the `comments.php` template.
     *
     * @since 2.7.0
     * @since 6.2.0 Renamed `$post_id` to `$post` and added WP_Post support.
     *
     * @see get_comment_id_fields()
     *
     * @param int|WP_Post|null $post Optional. The post the comment is being displayed for.
     *                               Defaults to the current global post.
     */
    function comment_id_fields($post = \null)
    {
    }
    /**
     * Displays text based on comment reply status.
     *
     * Only affects users with JavaScript disabled.
     *
     * @internal The $comment global must be present to allow template tags access to the current
     *           comment. See https://core.trac.wordpress.org/changeset/36512.
     *
     * @since 2.7.0
     * @since 6.2.0 Added the `$post` parameter.
     *
     * @global WP_Comment $comment Global comment object.
     *
     * @param string|false     $no_reply_text  Optional. Text to display when not replying to a comment.
     *                                         Default false.
     * @param string|false     $reply_text     Optional. Text to display when replying to a comment.
     *                                         Default false. Accepts "%s" for the author of the comment
     *                                         being replied to.
     * @param bool             $link_to_parent Optional. Boolean to control making the author's name a link
     *                                         to their comment. Default true.
     * @param int|WP_Post|null $post           Optional. The post that the comment form is being displayed for.
     *                                         Defaults to the current global post.
     * @phpstan-return void
     */
    function comment_form_title($no_reply_text = \false, $reply_text = \false, $link_to_parent = \true, $post = \null)
    {
    }
    /**
     * Gets the comment's reply to ID from the $_GET['replytocom'].
     *
     * @since 6.2.0
     *
     * @access private
     *
     * @param int|WP_Post $post The post the comment is being displayed for.
     *                          Defaults to the current global post.
     * @return int Comment's reply to ID.
     */
    function _get_comment_reply_id($post = \null)
    {
    }
    /**
     * Displays a list of comments.
     *
     * Used in the comments.php template to list comments for a particular post.
     *
     * @since 2.7.0
     *
     * @see WP_Query::$comments
     *
     * @global WP_Query $wp_query           WordPress Query object.
     * @global int      $comment_alt
     * @global int      $comment_depth
     * @global int      $comment_thread_alt
     * @global bool     $overridden_cpage
     * @global bool     $in_comment_loop
     *
     * @param string|array $args {
     *     Optional. Formatting options.
     *
     *     @type object   $walker            Instance of a Walker class to list comments. Default null.
     *     @type int      $max_depth         The maximum comments depth. Default empty.
     *     @type string   $style             The style of list ordering. Accepts 'ul', 'ol', or 'div'.
     *                                       'div' will result in no additional list markup. Default 'ul'.
     *     @type callable $callback          Callback function to use. Default null.
     *     @type callable $end-callback      Callback function to use at the end. Default null.
     *     @type string   $type              Type of comments to list. Accepts 'all', 'comment',
     *                                       'pingback', 'trackback', 'pings'. Default 'all'.
     *     @type int      $page              Page ID to list comments for. Default empty.
     *     @type int      $per_page          Number of comments to list per page. Default empty.
     *     @type int      $avatar_size       Height and width dimensions of the avatar size. Default 32.
     *     @type bool     $reverse_top_level Ordering of the listed comments. If true, will display
     *                                       newest comments first. Default null.
     *     @type bool     $reverse_children  Whether to reverse child comments in the list. Default null.
     *     @type string   $format            How to format the comments list. Accepts 'html5', 'xhtml'.
     *                                       Default 'html5' if the theme supports it.
     *     @type bool     $short_ping        Whether to output short pings. Default false.
     *     @type bool     $echo              Whether to echo the output or return it. Default true.
     * }
     * @param WP_Comment[] $comments Optional. Array of WP_Comment objects. Default null.
     * @return void|string Void if 'echo' argument is true, or no comments to list.
     *                     Otherwise, HTML list of comments.
     * @phpstan-param array{
     *   walker?: object,
     *   max_depth?: int,
     *   style?: string,
     *   callback?: callable,
     *   end-callback?: callable,
     *   type?: string,
     *   page?: int,
     *   per_page?: int,
     *   avatar_size?: int,
     *   reverse_top_level?: bool,
     *   reverse_children?: bool,
     *   format?: string,
     *   short_ping?: bool,
     *   echo?: bool,
     * } $args
     */
    function wp_list_comments($args = array(), $comments = \null)
    {
    }
    /**
     * Outputs a complete commenting form for use within a template.
     *
     * Most strings and form fields may be controlled through the `$args` array passed
     * into the function, while you may also choose to use the {@see 'comment_form_default_fields'}
     * filter to modify the array of default fields if you'd just like to add a new
     * one or remove a single field. All fields are also individually passed through
     * a filter of the {@see 'comment_form_field_$name'} where `$name` is the key used
     * in the array of fields.
     *
     * @since 3.0.0
     * @since 4.1.0 Introduced the 'class_submit' argument.
     * @since 4.2.0 Introduced the 'submit_button' and 'submit_fields' arguments.
     * @since 4.4.0 Introduced the 'class_form', 'title_reply_before', 'title_reply_after',
     *              'cancel_reply_before', and 'cancel_reply_after' arguments.
     * @since 4.5.0 The 'author', 'email', and 'url' form fields are limited to 245, 100,
     *              and 200 characters, respectively.
     * @since 4.6.0 Introduced the 'action' argument.
     * @since 4.9.6 Introduced the 'cookies' default comment field.
     * @since 5.5.0 Introduced the 'class_container' argument.
     *
     * @param array       $args {
     *     Optional. Default arguments and form fields to override.
     *
     *     @type array $fields {
     *         Default comment fields, filterable by default via the {@see 'comment_form_default_fields'} hook.
     *
     *         @type string $author  Comment author field HTML.
     *         @type string $email   Comment author email field HTML.
     *         @type string $url     Comment author URL field HTML.
     *         @type string $cookies Comment cookie opt-in field HTML.
     *     }
     *     @type string $comment_field        The comment textarea field HTML.
     *     @type string $must_log_in          HTML element for a 'must be logged in to comment' message.
     *     @type string $logged_in_as         The HTML for the 'logged in as [user]' message, the Edit profile link,
     *                                        and the Log out link.
     *     @type string $comment_notes_before HTML element for a message displayed before the comment fields
     *                                        if the user is not logged in.
     *                                        Default 'Your email address will not be published.'.
     *     @type string $comment_notes_after  HTML element for a message displayed after the textarea field.
     *     @type string $action               The comment form element action attribute. Default '/wp-comments-post.php'.
     *     @type string $id_form              The comment form element id attribute. Default 'commentform'.
     *     @type string $id_submit            The comment submit element id attribute. Default 'submit'.
     *     @type string $class_container      The comment form container class attribute. Default 'comment-respond'.
     *     @type string $class_form           The comment form element class attribute. Default 'comment-form'.
     *     @type string $class_submit         The comment submit element class attribute. Default 'submit'.
     *     @type string $name_submit          The comment submit element name attribute. Default 'submit'.
     *     @type string $title_reply          The translatable 'reply' button label. Default 'Leave a Reply'.
     *     @type string $title_reply_to       The translatable 'reply-to' button label. Default 'Leave a Reply to %s',
     *                                        where %s is the author of the comment being replied to.
     *     @type string $title_reply_before   HTML displayed before the comment form title.
     *                                        Default: '<h3 id="reply-title" class="comment-reply-title">'.
     *     @type string $title_reply_after    HTML displayed after the comment form title.
     *                                        Default: '</h3>'.
     *     @type string $cancel_reply_before  HTML displayed before the cancel reply link.
     *     @type string $cancel_reply_after   HTML displayed after the cancel reply link.
     *     @type string $cancel_reply_link    The translatable 'cancel reply' button label. Default 'Cancel reply'.
     *     @type string $label_submit         The translatable 'submit' button label. Default 'Post a comment'.
     *     @type string $submit_button        HTML format for the Submit button.
     *                                        Default: '<input name="%1$s" type="submit" id="%2$s" class="%3$s" value="%4$s" />'.
     *     @type string $submit_field         HTML format for the markup surrounding the Submit button and comment hidden
     *                                        fields. Default: '<p class="form-submit">%1$s %2$s</p>', where %1$s is the
     *                                        submit button markup and %2$s is the comment hidden fields.
     *     @type string $format               The comment form format. Default 'xhtml'. Accepts 'xhtml', 'html5'.
     * }
     * @param int|WP_Post $post Optional. Post ID or WP_Post object to generate the form for. Default current post.
     * @phpstan-param array{
     *   fields?: array{
     *     author: string,
     *     email: string,
     *     url: string,
     *     cookies: string,
     *   },
     *   comment_field?: string,
     *   must_log_in?: string,
     *   logged_in_as?: string,
     *   comment_notes_before?: string,
     *   comment_notes_after?: string,
     *   action?: string,
     *   id_form?: string,
     *   id_submit?: string,
     *   class_container?: string,
     *   class_form?: string,
     *   class_submit?: string,
     *   name_submit?: string,
     *   title_reply?: string,
     *   title_reply_to?: string,
     *   title_reply_before?: string,
     *   title_reply_after?: string,
     *   cancel_reply_before?: string,
     *   cancel_reply_after?: string,
     *   cancel_reply_link?: string,
     *   label_submit?: string,
     *   submit_button?: string,
     *   submit_field?: string,
     *   format?: string,
     * } $args
     * @phpstan-return void
     */
    function comment_form($args = array(), $post = \null)
    {
    }
    /**
     * Checks whether a comment passes internal checks to be allowed to add.
     *
     * If manual comment moderation is set in the administration, then all checks,
     * regardless of their type and substance, will fail and the function will
     * return false.
     *
     * If the number of links exceeds the amount in the administration, then the
     * check fails. If any of the parameter contents contain any disallowed words,
     * then the check fails.
     *
     * If the comment author was approved before, then the comment is automatically
     * approved.
     *
     * If all checks pass, the function will return true.
     *
     * @since 1.2.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $author       Comment author name.
     * @param string $email        Comment author email.
     * @param string $url          Comment author URL.
     * @param string $comment      Content of the comment.
     * @param string $user_ip      Comment author IP address.
     * @param string $user_agent   Comment author User-Agent.
     * @param string $comment_type Comment type, either user-submitted comment,
     *                             trackback, or pingback.
     * @return bool If all checks pass, true, otherwise false.
     */
    function check_comment($author, $email, $url, $comment, $user_ip, $user_agent, $comment_type)
    {
    }
    /**
     * Retrieves the approved comments for a post.
     *
     * @since 2.0.0
     * @since 4.1.0 Refactored to leverage WP_Comment_Query over a direct query.
     *
     * @param int   $post_id The ID of the post.
     * @param array $args    {
     *     Optional. See WP_Comment_Query::__construct() for information on accepted arguments.
     *
     *     @type int    $status  Comment status to limit results by. Defaults to approved comments.
     *     @type int    $post_id Limit results to those affiliated with a given post ID.
     *     @type string $order   How to order retrieved comments. Default 'ASC'.
     * }
     * @return WP_Comment[]|int[]|int The approved comments, or number of comments if `$count`
     *                                argument is true.
     * @phpstan-param array{
     *   status?: int,
     *   post_id?: int,
     *   order?: string,
     *   author_email?: string,
     *   author_url?: string,
     *   author__in?: int[],
     *   author__not_in?: int[],
     *   comment__in?: int[],
     *   comment__not_in?: int[],
     *   count?: bool,
     *   date_query?: array,
     *   fields?: string,
     *   include_unapproved?: array,
     *   karma?: int,
     *   meta_key?: string|string[],
     *   meta_value?: string|string[],
     *   meta_compare?: string,
     *   meta_compare_key?: string,
     *   meta_type?: string,
     *   meta_type_key?: string,
     *   meta_query?: array,
     *   number?: int,
     *   paged?: int,
     *   offset?: int,
     *   no_found_rows?: bool,
     *   orderby?: string|array,
     *   order?: string,
     *   parent?: int,
     *   parent__in?: int[],
     *   parent__not_in?: int[],
     *   post_author__in?: int[],
     *   post_author__not_in?: int[],
     *   post_id?: int,
     *   post__in?: int[],
     *   post__not_in?: int[],
     *   post_author?: int,
     *   post_status?: string|string[],
     *   post_type?: string|string[],
     *   post_name?: string,
     *   post_parent?: int,
     *   search?: string,
     *   status?: string|array,
     *   type?: string|string[],
     *   type__in?: string[],
     *   type__not_in?: string[],
     *   user_id?: int,
     *   hierarchical?: bool|string,
     *   cache_domain?: string,
     *   update_comment_meta_cache?: bool,
     *   update_comment_post_cache?: bool,
     * } $args
     * @phpstan-return ($args is array{count: true}&array ? int : ($args is array{fields: 'ids'}&array ?  array<int, int> : array<int, \WP_Comment>))
     */
    function get_approved_comments($post_id, $args = array())
    {
    }
    /**
     * Retrieves comment data given a comment ID or comment object.
     *
     * If an object is passed then the comment data will be cached and then returned
     * after being passed through a filter. If the comment is empty, then the global
     * comment variable will be used, if it is set.
     *
     * @since 2.0.0
     *
     * @global WP_Comment $comment Global comment object.
     *
     * @param WP_Comment|string|int $comment Comment to retrieve.
     * @param string                $output  Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
     *                                       correspond to a WP_Comment object, an associative array, or a numeric array,
     *                                       respectively. Default OBJECT.
     * @return WP_Comment|array|null Depends on $output value.
     * @phpstan-param 'OBJECT'|'ARRAY_A'|'ARRAY_N' $output
     * @phpstan-return ($comment is \WP_Comment ? array<array-key, mixed>|\WP_Comment : array<array-key, mixed>|\WP_Comment|null) & ($output is 'ARRAY_A' ? array<string, mixed>|null : ($output is 'ARRAY_N' ? array<int, mixed>|null : \WP_Comment|null))
     */
    function get_comment($comment = \null, $output = \OBJECT)
    {
    }
    /**
     * Retrieves a list of comments.
     *
     * The comment list can be for the blog as a whole or for an individual post.
     *
     * @since 2.7.0
     *
     * @param string|array $args Optional. Array or string of arguments. See WP_Comment_Query::__construct()
     *                           for information on accepted arguments. Default empty string.
     * @return WP_Comment[]|int[]|int List of comments or number of found comments if `$count` argument is true.
     * @phpstan-param array{
     *   author_email?: string,
     *   author_url?: string,
     *   author__in?: int[],
     *   author__not_in?: int[],
     *   comment__in?: int[],
     *   comment__not_in?: int[],
     *   count?: bool,
     *   date_query?: array,
     *   fields?: string,
     *   include_unapproved?: array,
     *   karma?: int,
     *   meta_key?: string|string[],
     *   meta_value?: string|string[],
     *   meta_compare?: string,
     *   meta_compare_key?: string,
     *   meta_type?: string,
     *   meta_type_key?: string,
     *   meta_query?: array,
     *   number?: int,
     *   paged?: int,
     *   offset?: int,
     *   no_found_rows?: bool,
     *   orderby?: string|array,
     *   order?: string,
     *   parent?: int,
     *   parent__in?: int[],
     *   parent__not_in?: int[],
     *   post_author__in?: int[],
     *   post_author__not_in?: int[],
     *   post_id?: int,
     *   post__in?: int[],
     *   post__not_in?: int[],
     *   post_author?: int,
     *   post_status?: string|string[],
     *   post_type?: string|string[],
     *   post_name?: string,
     *   post_parent?: int,
     *   search?: string,
     *   status?: string|array,
     *   type?: string|string[],
     *   type__in?: string[],
     *   type__not_in?: string[],
     *   user_id?: int,
     *   hierarchical?: bool|string,
     *   cache_domain?: string,
     *   update_comment_meta_cache?: bool,
     *   update_comment_post_cache?: bool,
     * } $args See WP_Comment_Query::__construct()
     */
    function get_comments($args = '')
    {
    }
    /**
     * Retrieves all of the WordPress supported comment statuses.
     *
     * Comments have a limited set of valid status values, this provides the comment
     * status values and descriptions.
     *
     * @since 2.7.0
     *
     * @return string[] List of comment status labels keyed by status.
     */
    function get_comment_statuses()
    {
    }
    /**
     * Gets the default comment status for a post type.
     *
     * @since 4.3.0
     *
     * @param string $post_type    Optional. Post type. Default 'post'.
     * @param string $comment_type Optional. Comment type. Default 'comment'.
     * @return string Either 'open' or 'closed'.
     * @phpstan-return 'open'|'closed'
     */
    function get_default_comment_status($post_type = 'post', $comment_type = 'comment')
    {
    }
    /**
     * Retrieves the date the last comment was modified.
     *
     * @since 1.5.0
     * @since 4.7.0 Replaced caching the modified date in a local static variable
     *              with the Object Cache API.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $timezone Which timezone to use in reference to 'gmt', 'blog', or 'server' locations.
     * @return string|false Last comment modified date on success, false on failure.
     */
    function get_lastcommentmodified($timezone = 'server')
    {
    }
    /**
     * Retrieves the total comment counts for the whole site or a single post.
     *
     * @since 2.0.0
     *
     * @param int $post_id Optional. Restrict the comment counts to the given post. Default 0, which indicates that
     *                     comment counts for the whole site will be retrieved.
     * @return int[] {
     *     The number of comments keyed by their status.
     *
     *     @type int $approved            The number of approved comments.
     *     @type int $awaiting_moderation The number of comments awaiting moderation (a.k.a. pending).
     *     @type int $spam                The number of spam comments.
     *     @type int $trash               The number of trashed comments.
     *     @type int $post-trashed        The number of comments for posts that are in the trash.
     *     @type int $total_comments      The total number of non-trashed comments, including spam.
     *     @type int $all                 The total number of pending or approved comments.
     * }
     * @phpstan-return array{
     *   approved: int,
     *   awaiting_moderation: int,
     *   spam: int,
     *   trash: int,
     *   post-trashed: int,
     *   total_comments: int,
     *   all: int,
     * }
     */
    function get_comment_count($post_id = 0)
    {
    }
    /**
     * Adds meta data field to a comment.
     *
     * @since 2.9.0
     *
     * @link https://developer.wordpress.org/reference/functions/add_comment_meta/
     *
     * @param int    $comment_id Comment ID.
     * @param string $meta_key   Metadata name.
     * @param mixed  $meta_value Metadata value. Must be serializable if non-scalar.
     * @param bool   $unique     Optional. Whether the same key should not be added.
     *                           Default false.
     * @return int|false Meta ID on success, false on failure.
     */
    function add_comment_meta($comment_id, $meta_key, $meta_value, $unique = \false)
    {
    }
    /**
     * Removes metadata matching criteria from a comment.
     *
     * You can match based on the key, or key and value. Removing based on key and
     * value, will keep from removing duplicate metadata with the same key. It also
     * allows removing all metadata matching key, if needed.
     *
     * @since 2.9.0
     *
     * @link https://developer.wordpress.org/reference/functions/delete_comment_meta/
     *
     * @param int    $comment_id Comment ID.
     * @param string $meta_key   Metadata name.
     * @param mixed  $meta_value Optional. Metadata value. If provided,
     *                           rows will only be removed that match the value.
     *                           Must be serializable if non-scalar. Default empty string.
     * @return bool True on success, false on failure.
     */
    function delete_comment_meta($comment_id, $meta_key, $meta_value = '')
    {
    }
    /**
     * Retrieves comment meta field for a comment.
     *
     * @since 2.9.0
     *
     * @link https://developer.wordpress.org/reference/functions/get_comment_meta/
     *
     * @param int    $comment_id Comment ID.
     * @param string $key        Optional. The meta key to retrieve. By default,
     *                           returns data for all keys. Default empty string.
     * @param bool   $single     Optional. Whether to return a single value.
     *                           This parameter has no effect if `$key` is not specified.
     *                           Default false.
     * @return mixed An array of values if `$single` is false.
     *               The value of meta data field if `$single` is true.
     *               False for an invalid `$comment_id` (non-numeric, zero, or negative value).
     *               An empty array if a valid but non-existing comment ID is passed and `$single` is false.
     *               An empty string if a valid but non-existing comment ID is passed and `$single` is true.
     */
    function get_comment_meta($comment_id, $key = '', $single = \false)
    {
    }
    /**
     * Queue comment meta for lazy-loading.
     *
     * @since 6.3.0
     *
     * @param array $comment_ids List of comment IDs.
     * @phpstan-return void
     */
    function wp_lazyload_comment_meta(array $comment_ids)
    {
    }
    /**
     * Updates comment meta field based on comment ID.
     *
     * Use the $prev_value parameter to differentiate between meta fields with the
     * same key and comment ID.
     *
     * If the meta field for the comment does not exist, it will be added.
     *
     * @since 2.9.0
     *
     * @link https://developer.wordpress.org/reference/functions/update_comment_meta/
     *
     * @param int    $comment_id Comment ID.
     * @param string $meta_key   Metadata key.
     * @param mixed  $meta_value Metadata value. Must be serializable if non-scalar.
     * @param mixed  $prev_value Optional. Previous value to check before updating.
     *                           If specified, only update existing metadata entries with
     *                           this value. Otherwise, update all entries. Default empty string.
     * @return int|bool Meta ID if the key didn't exist, true on successful update,
     *                  false on failure or if the value passed to the function
     *                  is the same as the one that is already in the database.
     */
    function update_comment_meta($comment_id, $meta_key, $meta_value, $prev_value = '')
    {
    }
    /**
     * Sets the cookies used to store an unauthenticated commentator's identity. Typically used
     * to recall previous comments by this commentator that are still held in moderation.
     *
     * @since 3.4.0
     * @since 4.9.6 The `$cookies_consent` parameter was added.
     *
     * @param WP_Comment $comment         Comment object.
     * @param WP_User    $user            Comment author's user object. The user may not exist.
     * @param bool       $cookies_consent Optional. Comment author's consent to store cookies. Default true.
     * @phpstan-return void
     */
    function wp_set_comment_cookies($comment, $user, $cookies_consent = \true)
    {
    }
    /**
     * Sanitizes the cookies sent to the user already.
     *
     * Will only do anything if the cookies have already been created for the user.
     * Mostly used after cookies had been sent to use elsewhere.
     *
     * @since 2.0.4
     */
    function sanitize_comment_cookies()
    {
    }
    /**
     * Validates whether this comment is allowed to be made.
     *
     * @since 2.0.0
     * @since 4.7.0 The `$avoid_die` parameter was added, allowing the function
     *              to return a WP_Error object instead of dying.
     * @since 5.5.0 The `$avoid_die` parameter was renamed to `$wp_error`.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array $commentdata Contains information on the comment.
     * @param bool  $wp_error    When true, a disallowed comment will result in the function
     *                           returning a WP_Error object, rather than executing wp_die().
     *                           Default false.
     * @return int|string|WP_Error Allowed comments return the approval status (0|1|'spam'|'trash').
     *                             If `$wp_error` is true, disallowed comments return a WP_Error.
     */
    function wp_allow_comment($commentdata, $wp_error = \false)
    {
    }
    /**
     * Hooks WP's native database-based comment-flood check.
     *
     * This wrapper maintains backward compatibility with plugins that expect to
     * be able to unhook the legacy check_comment_flood_db() function from
     * 'check_comment_flood' using remove_action().
     *
     * @since 2.3.0
     * @since 4.7.0 Converted to be an add_filter() wrapper.
     */
    function check_comment_flood_db()
    {
    }
    /**
     * Checks whether comment flooding is occurring.
     *
     * Won't run, if current user can manage options, so to not block
     * administrators.
     *
     * @since 4.7.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param bool   $is_flood  Is a comment flooding occurring?
     * @param string $ip        Comment author's IP address.
     * @param string $email     Comment author's email address.
     * @param string $date      MySQL time string.
     * @param bool   $avoid_die When true, a disallowed comment will result in the function
     *                          returning without executing wp_die() or die(). Default false.
     * @return bool Whether comment flooding is occurring.
     */
    function wp_check_comment_flood($is_flood, $ip, $email, $date, $avoid_die = \false)
    {
    }
    /**
     * Separates an array of comments into an array keyed by comment_type.
     *
     * @since 2.7.0
     *
     * @param WP_Comment[] $comments Array of comments
     * @return WP_Comment[] Array of comments keyed by comment_type.
     */
    function separate_comments(&$comments)
    {
    }
    /**
     * Calculates the total number of comment pages.
     *
     * @since 2.7.0
     *
     * @uses Walker_Comment
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param WP_Comment[] $comments Optional. Array of WP_Comment objects. Defaults to `$wp_query->comments`.
     * @param int          $per_page Optional. Comments per page. Defaults to the value of `comments_per_page`
     *                               query var, option of the same name, or 1 (in that order).
     * @param bool         $threaded Optional. Control over flat or threaded comments. Defaults to the value
     *                               of `thread_comments` option.
     * @return int Number of comment pages.
     */
    function get_comment_pages_count($comments = \null, $per_page = \null, $threaded = \null)
    {
    }
    /**
     * Calculates what page number a comment will appear on for comment paging.
     *
     * @since 2.7.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int   $comment_id Comment ID.
     * @param array $args {
     *     Array of optional arguments.
     *
     *     @type string     $type      Limit paginated comments to those matching a given type.
     *                                 Accepts 'comment', 'trackback', 'pingback', 'pings'
     *                                 (trackbacks and pingbacks), or 'all'. Default 'all'.
     *     @type int        $per_page  Per-page count to use when calculating pagination.
     *                                 Defaults to the value of the 'comments_per_page' option.
     *     @type int|string $max_depth If greater than 1, comment page will be determined
     *                                 for the top-level parent `$comment_id`.
     *                                 Defaults to the value of the 'thread_comments_depth' option.
     * }
     * @return int|null Comment page number or null on error.
     * @phpstan-param array{
     *   type?: string,
     *   per_page?: int,
     *   max_depth?: int|string,
     * } $args
     */
    function get_page_of_comment($comment_id, $args = array())
    {
    }
    /**
     * Retrieves the maximum character lengths for the comment form fields.
     *
     * @since 4.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return int[] Array of maximum lengths keyed by field name.
     */
    function wp_get_comment_fields_max_lengths()
    {
    }
    /**
     * Compares the lengths of comment data against the maximum character limits.
     *
     * @since 4.7.0
     *
     * @param array $comment_data Array of arguments for inserting a comment.
     * @return WP_Error|true WP_Error when a comment field exceeds the limit,
     *                       otherwise true.
     */
    function wp_check_comment_data_max_lengths($comment_data)
    {
    }
    /**
     * Checks whether comment data passes internal checks or has disallowed content.
     *
     * @since 6.7.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array $comment_data Array of arguments for inserting a comment.
     * @return int|string|WP_Error The approval status on success (0|1|'spam'|'trash'),
     *                            WP_Error otherwise.
     */
    function wp_check_comment_data($comment_data)
    {
    }
    /**
     * Checks if a comment contains disallowed characters or words.
     *
     * @since 5.5.0
     *
     * @param string $author The author of the comment
     * @param string $email The email of the comment
     * @param string $url The url used in the comment
     * @param string $comment The comment content
     * @param string $user_ip The comment author's IP address
     * @param string $user_agent The author's browser user agent
     * @return bool True if comment contains disallowed content, false if comment does not
     */
    function wp_check_comment_disallowed_list($author, $email, $url, $comment, $user_ip, $user_agent)
    {
    }
    /**
     * Retrieves the total comment counts for the whole site or a single post.
     *
     * The comment stats are cached and then retrieved, if they already exist in the
     * cache.
     *
     * @see get_comment_count() Which handles fetching the live comment counts.
     *
     * @since 2.5.0
     *
     * @param int $post_id Optional. Restrict the comment counts to the given post. Default 0, which indicates that
     *                     comment counts for the whole site will be retrieved.
     * @return stdClass {
     *     The number of comments keyed by their status.
     *
     *     @type int $approved       The number of approved comments.
     *     @type int $moderated      The number of comments awaiting moderation (a.k.a. pending).
     *     @type int $spam           The number of spam comments.
     *     @type int $trash          The number of trashed comments.
     *     @type int $post-trashed   The number of comments for posts that are in the trash.
     *     @type int $total_comments The total number of non-trashed comments, including spam.
     *     @type int $all            The total number of pending or approved comments.
     * }
     * @phpstan-return object{
     *   approved: int,
     *   moderated: int,
     *   spam: int,
     *   trash: int,
     *   post-trashed: int,
     *   total_comments: int,
     *   all: int,
     * }
     */
    function wp_count_comments($post_id = 0)
    {
    }
    /**
     * Trashes or deletes a comment.
     *
     * The comment is moved to Trash instead of permanently deleted unless Trash is
     * disabled, item is already in the Trash, or $force_delete is true.
     *
     * The post comment count will be updated if the comment was approved and has a
     * post ID available.
     *
     * @since 2.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|WP_Comment $comment_id   Comment ID or WP_Comment object.
     * @param bool           $force_delete Whether to bypass Trash and force deletion. Default false.
     * @return bool True on success, false on failure.
     */
    function wp_delete_comment($comment_id, $force_delete = \false)
    {
    }
    /**
     * Moves a comment to the Trash
     *
     * If Trash is disabled, comment is permanently deleted.
     *
     * @since 2.9.0
     *
     * @param int|WP_Comment $comment_id Comment ID or WP_Comment object.
     * @return bool True on success, false on failure.
     */
    function wp_trash_comment($comment_id)
    {
    }
    /**
     * Removes a comment from the Trash
     *
     * @since 2.9.0
     *
     * @param int|WP_Comment $comment_id Comment ID or WP_Comment object.
     * @return bool True on success, false on failure.
     */
    function wp_untrash_comment($comment_id)
    {
    }
    /**
     * Marks a comment as Spam.
     *
     * @since 2.9.0
     *
     * @param int|WP_Comment $comment_id Comment ID or WP_Comment object.
     * @return bool True on success, false on failure.
     */
    function wp_spam_comment($comment_id)
    {
    }
    /**
     * Removes a comment from the Spam.
     *
     * @since 2.9.0
     *
     * @param int|WP_Comment $comment_id Comment ID or WP_Comment object.
     * @return bool True on success, false on failure.
     */
    function wp_unspam_comment($comment_id)
    {
    }
    /**
     * Retrieves the status of a comment by comment ID.
     *
     * @since 1.0.0
     *
     * @param int|WP_Comment $comment_id Comment ID or WP_Comment object
     * @return string|false Status might be 'trash', 'approved', 'unapproved', 'spam'. False on failure.
     */
    function wp_get_comment_status($comment_id)
    {
    }
    /**
     * Calls hooks for when a comment status transition occurs.
     *
     * Calls hooks for comment status transitions. If the new comment status is not the same
     * as the previous comment status, then two hooks will be ran, the first is
     * {@see 'transition_comment_status'} with new status, old status, and comment data.
     * The next action called is {@see 'comment_$old_status_to_$new_status'}. It has
     * the comment data.
     *
     * The final action will run whether or not the comment statuses are the same.
     * The action is named {@see 'comment_$new_status_$comment->comment_type'}.
     *
     * @since 2.7.0
     *
     * @param string     $new_status New comment status.
     * @param string     $old_status Previous comment status.
     * @param WP_Comment $comment    Comment object.
     */
    function wp_transition_comment_status($new_status, $old_status, $comment)
    {
    }
    /**
     * Clears the lastcommentmodified cached value when a comment status is changed.
     *
     * Deletes the lastcommentmodified cache key when a comment enters or leaves
     * 'approved' status.
     *
     * @since 4.7.0
     * @access private
     *
     * @param string $new_status The new comment status.
     * @param string $old_status The old comment status.
     */
    function _clear_modified_cache_on_transition_comment_status($new_status, $old_status)
    {
    }
    /**
     * Gets current commenter's name, email, and URL.
     *
     * Expects cookies content to already be sanitized. User of this function might
     * wish to recheck the returned array for validity.
     *
     * @see sanitize_comment_cookies() Use to sanitize cookies
     *
     * @since 2.0.4
     *
     * @return array {
     *     An array of current commenter variables.
     *
     *     @type string $comment_author       The name of the current commenter, or an empty string.
     *     @type string $comment_author_email The email address of the current commenter, or an empty string.
     *     @type string $comment_author_url   The URL address of the current commenter, or an empty string.
     * }
     * @phpstan-return array{
     *   comment_author: string,
     *   comment_author_email: string,
     *   comment_author_url: string,
     * }
     */
    function wp_get_current_commenter()
    {
    }
    /**
     * Gets unapproved comment author's email.
     *
     * Used to allow the commenter to see their pending comment.
     *
     * @since 5.1.0
     * @since 5.7.0 The window within which the author email for an unapproved comment
     *              can be retrieved was extended to 10 minutes.
     *
     * @return string The unapproved comment author's email (when supplied).
     */
    function wp_get_unapproved_comment_author_email()
    {
    }
    /**
     * Inserts a comment into the database.
     *
     * @since 2.0.0
     * @since 4.4.0 Introduced the `$comment_meta` argument.
     * @since 5.5.0 Default value for `$comment_type` argument changed to `comment`.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array $commentdata {
     *     Array of arguments for inserting a new comment.
     *
     *     @type string     $comment_agent        The HTTP user agent of the `$comment_author` when
     *                                            the comment was submitted. Default empty.
     *     @type int|string $comment_approved     Whether the comment has been approved. Default 1.
     *     @type string     $comment_author       The name of the author of the comment. Default empty.
     *     @type string     $comment_author_email The email address of the `$comment_author`. Default empty.
     *     @type string     $comment_author_IP    The IP address of the `$comment_author`. Default empty.
     *     @type string     $comment_author_url   The URL address of the `$comment_author`. Default empty.
     *     @type string     $comment_content      The content of the comment. Default empty.
     *     @type string     $comment_date         The date the comment was submitted. To set the date
     *                                            manually, `$comment_date_gmt` must also be specified.
     *                                            Default is the current time.
     *     @type string     $comment_date_gmt     The date the comment was submitted in the GMT timezone.
     *                                            Default is `$comment_date` in the site's GMT timezone.
     *     @type int        $comment_karma        The karma of the comment. Default 0.
     *     @type int        $comment_parent       ID of this comment's parent, if any. Default 0.
     *     @type int        $comment_post_ID      ID of the post that relates to the comment, if any.
     *                                            Default 0.
     *     @type string     $comment_type         Comment type. Default 'comment'.
     *     @type array      $comment_meta         Optional. Array of key/value pairs to be stored in commentmeta for the
     *                                            new comment.
     *     @type int        $user_id              ID of the user who submitted the comment. Default 0.
     * }
     * @return int|false The new comment's ID on success, false on failure.
     * @phpstan-param array{
     *   comment_agent?: string,
     *   comment_approved?: int|string,
     *   comment_author?: string,
     *   comment_author_email?: string,
     *   comment_author_IP?: string,
     *   comment_author_url?: string,
     *   comment_content?: string,
     *   comment_date?: string,
     *   comment_date_gmt?: string,
     *   comment_karma?: int,
     *   comment_parent?: int,
     *   comment_post_ID?: int,
     *   comment_type?: string,
     *   comment_meta?: array,
     *   user_id?: int,
     * } $commentdata
     */
    function wp_insert_comment($commentdata)
    {
    }
    /**
     * Filters and sanitizes comment data.
     *
     * Sets the comment data 'filtered' field to true when finished. This can be
     * checked as to whether the comment should be filtered and to keep from
     * filtering the same comment more than once.
     *
     * @since 2.0.0
     *
     * @param array $commentdata Contains information on the comment.
     * @return array Parsed comment information.
     */
    function wp_filter_comment($commentdata)
    {
    }
    /**
     * Determines whether a comment should be blocked because of comment flood.
     *
     * @since 2.1.0
     *
     * @param bool $block            Whether plugin has already blocked comment.
     * @param int  $time_lastcomment Timestamp for last comment.
     * @param int  $time_newcomment  Timestamp for new comment.
     * @return bool Whether comment should be blocked.
     */
    function wp_throttle_comment_flood($block, $time_lastcomment, $time_newcomment)
    {
    }
    /**
     * Adds a new comment to the database.
     *
     * Filters new comment to ensure that the fields are sanitized and valid before
     * inserting comment into database. Calls {@see 'comment_post'} action with comment ID
     * and whether comment is approved by WordPress. Also has {@see 'preprocess_comment'}
     * filter for processing the comment data before the function handles it.
     *
     * We use `REMOTE_ADDR` here directly. If you are behind a proxy, you should ensure
     * that it is properly set, such as in wp-config.php, for your environment.
     *
     * See {@link https://core.trac.wordpress.org/ticket/9235}
     *
     * @since 1.5.0
     * @since 4.3.0 Introduced the `comment_agent` and `comment_author_IP` arguments.
     * @since 4.7.0 The `$avoid_die` parameter was added, allowing the function
     *              to return a WP_Error object instead of dying.
     * @since 5.5.0 The `$avoid_die` parameter was renamed to `$wp_error`.
     * @since 5.5.0 Introduced the `comment_type` argument.
     *
     * @see wp_insert_comment()
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array $commentdata {
     *     Comment data.
     *
     *     @type string $comment_author       The name of the comment author.
     *     @type string $comment_author_email The comment author email address.
     *     @type string $comment_author_url   The comment author URL.
     *     @type string $comment_content      The content of the comment.
     *     @type string $comment_date         The date the comment was submitted. Default is the current time.
     *     @type string $comment_date_gmt     The date the comment was submitted in the GMT timezone.
     *                                        Default is `$comment_date` in the GMT timezone.
     *     @type string $comment_type         Comment type. Default 'comment'.
     *     @type int    $comment_parent       The ID of this comment's parent, if any. Default 0.
     *     @type int    $comment_post_ID      The ID of the post that relates to the comment.
     *     @type int    $user_id              The ID of the user who submitted the comment. Default 0.
     *     @type int    $user_ID              Kept for backward-compatibility. Use `$user_id` instead.
     *     @type string $comment_agent        Comment author user agent. Default is the value of 'HTTP_USER_AGENT'
     *                                        in the `$_SERVER` superglobal sent in the original request.
     *     @type string $comment_author_IP    Comment author IP address in IPv4 format. Default is the value of
     *                                        'REMOTE_ADDR' in the `$_SERVER` superglobal sent in the original request.
     * }
     * @param bool  $wp_error Should errors be returned as WP_Error objects instead of
     *                        executing wp_die()? Default false.
     * @return int|false|WP_Error The ID of the comment on success, false or WP_Error on failure.
     * @phpstan-param array{
     *   comment_author?: string,
     *   comment_author_email?: string,
     *   comment_author_url?: string,
     *   comment_content?: string,
     *   comment_date?: string,
     *   comment_date_gmt?: string,
     *   comment_type?: string,
     *   comment_parent?: int,
     *   comment_post_ID?: int,
     *   user_id?: int,
     *   user_ID?: int,
     *   comment_agent?: string,
     *   comment_author_IP?: string,
     * } $commentdata
     */
    function wp_new_comment($commentdata, $wp_error = \false)
    {
    }
    /**
     * Sends a comment moderation notification to the comment moderator.
     *
     * @since 4.4.0
     *
     * @param int $comment_id ID of the comment.
     * @return bool True on success, false on failure.
     */
    function wp_new_comment_notify_moderator($comment_id)
    {
    }
    /**
     * Sends a notification of a new comment to the post author.
     *
     * @since 4.4.0
     *
     * Uses the {@see 'notify_post_author'} filter to determine whether the post author
     * should be notified when a new comment is added, overriding site setting.
     *
     * @param int $comment_id Comment ID.
     * @return bool True on success, false on failure.
     */
    function wp_new_comment_notify_postauthor($comment_id)
    {
    }
    /**
     * Sets the status of a comment.
     *
     * The {@see 'wp_set_comment_status'} action is called after the comment is handled.
     * If the comment status is not in the list, then false is returned.
     *
     * @since 1.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|WP_Comment $comment_id     Comment ID or WP_Comment object.
     * @param string         $comment_status New comment status, either 'hold', 'approve', 'spam', or 'trash'.
     * @param bool           $wp_error       Whether to return a WP_Error object if there is a failure. Default false.
     * @return bool|WP_Error True on success, false or WP_Error on failure.
     * @phpstan-param 'hold'|'approve'|'spam'|'trash' $comment_status
     * @phpstan-return ($wp_error is false ? bool : true|\WP_Error)
     */
    function wp_set_comment_status($comment_id, $comment_status, $wp_error = \false)
    {
    }
    /**
     * Updates an existing comment in the database.
     *
     * Filters the comment and makes sure certain fields are valid before updating.
     *
     * @since 2.0.0
     * @since 4.9.0 Add updating comment meta during comment update.
     * @since 5.5.0 The `$wp_error` parameter was added.
     * @since 5.5.0 The return values for an invalid comment or post ID
     *              were changed to false instead of 0.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array $commentarr Contains information on the comment.
     * @param bool  $wp_error   Optional. Whether to return a WP_Error on failure. Default false.
     * @return int|false|WP_Error The value 1 if the comment was updated, 0 if not updated.
     *                            False or a WP_Error object on failure.
     * @phpstan-return ($wp_error is false ? 0|1|false : 0|1|\WP_Error)
     */
    function wp_update_comment($commentarr, $wp_error = \false)
    {
    }
    /**
     * Determines whether to defer comment counting.
     *
     * When setting $defer to true, all post comment counts will not be updated
     * until $defer is set to false. When $defer is set to false, then all
     * previously deferred updated post comment counts will then be automatically
     * updated without having to call wp_update_comment_count() after.
     *
     * @since 2.5.0
     *
     * @param bool $defer
     * @return bool
     */
    function wp_defer_comment_counting($defer = \null)
    {
    }
    /**
     * Updates the comment count for post(s).
     *
     * When $do_deferred is false (is by default) and the comments have been set to
     * be deferred, the post_id will be added to a queue, which will be updated at a
     * later date and only updated once per post ID.
     *
     * If the comments have not be set up to be deferred, then the post will be
     * updated. When $do_deferred is set to true, then all previous deferred post
     * IDs will be updated along with the current $post_id.
     *
     * @since 2.1.0
     *
     * @see wp_update_comment_count_now() For what could cause a false return value
     *
     * @param int|null $post_id     Post ID.
     * @param bool     $do_deferred Optional. Whether to process previously deferred
     *                              post comment counts. Default false.
     * @return bool|void True on success, false on failure or if post with ID does
     *                   not exist.
     */
    function wp_update_comment_count($post_id, $do_deferred = \false)
    {
    }
    /**
     * Updates the comment count for the post.
     *
     * @since 2.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $post_id Post ID
     * @return bool True on success, false if the post does not exist.
     */
    function wp_update_comment_count_now($post_id)
    {
    }
    /**
     * Finds a pingback server URI based on the given URL.
     *
     * Checks the HTML for the rel="pingback" link and X-Pingback headers. It does
     * a check for the X-Pingback headers first and returns that, if available.
     * The check for the rel="pingback" has more overhead than just the header.
     *
     * @since 1.5.0
     *
     * @param string $url        URL to ping.
     * @param string $deprecated Not Used.
     * @return string|false String containing URI on success, false on failure.
     */
    function discover_pingback_server_uri($url, $deprecated = '')
    {
    }
    /**
     * Performs all pingbacks, enclosures, trackbacks, and sends to pingback services.
     *
     * @since 2.1.0
     * @since 5.6.0 Introduced `do_all_pings` action hook for individual services.
     */
    function do_all_pings()
    {
    }
    /**
     * Performs all pingbacks.
     *
     * @since 5.6.0
     */
    function do_all_pingbacks()
    {
    }
    /**
     * Performs all enclosures.
     *
     * @since 5.6.0
     */
    function do_all_enclosures()
    {
    }
    /**
     * Performs all trackbacks.
     *
     * @since 5.6.0
     */
    function do_all_trackbacks()
    {
    }
    /**
     * Performs trackbacks.
     *
     * @since 1.5.0
     * @since 4.7.0 `$post` can be a WP_Post object.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|WP_Post $post Post ID or object to do trackbacks on.
     * @return void|false Returns false on failure.
     */
    function do_trackbacks($post)
    {
    }
    /**
     * Sends pings to all of the ping site services.
     *
     * @since 1.2.0
     *
     * @param int $post_id Post ID.
     * @return int Same post ID as provided.
     */
    function generic_ping($post_id = 0)
    {
    }
    /**
     * Pings back the links found in a post.
     *
     * @since 0.71
     * @since 4.7.0 `$post` can be a WP_Post object.
     *
     * @param string      $content Post content to check for links. If empty will retrieve from post.
     * @param int|WP_Post $post    Post ID or object.
     * @phpstan-return void
     */
    function pingback($content, $post)
    {
    }
    /**
     * Checks whether blog is public before returning sites.
     *
     * @since 2.1.0
     *
     * @param mixed $sites Will return if blog is public, will not return if not public.
     * @return mixed Empty string if blog is not public, returns $sites, if site is public.
     */
    function privacy_ping_filter($sites)
    {
    }
    /**
     * Sends a Trackback.
     *
     * Updates database when sending trackback to prevent duplicates.
     *
     * @since 0.71
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $trackback_url URL to send trackbacks.
     * @param string $title         Title of post.
     * @param string $excerpt       Excerpt of post.
     * @param int    $post_id       Post ID.
     * @return int|false|void Database query from update.
     */
    function trackback($trackback_url, $title, $excerpt, $post_id)
    {
    }
    /**
     * Sends a pingback.
     *
     * @since 1.2.0
     *
     * @param string $server Host of blog to connect to.
     * @param string $path Path to send the ping.
     */
    function weblog_ping($server = '', $path = '')
    {
    }
    /**
     * Default filter attached to pingback_ping_source_uri to validate the pingback's Source URI.
     *
     * @since 3.5.1
     *
     * @see wp_http_validate_url()
     *
     * @param string $source_uri
     * @return string
     */
    function pingback_ping_source_uri($source_uri)
    {
    }
    /**
     * Default filter attached to xmlrpc_pingback_error.
     *
     * Returns a generic pingback error code unless the error code is 48,
     * which reports that the pingback is already registered.
     *
     * @since 3.5.1
     *
     * @link https://www.hixie.ch/specs/pingback/pingback#TOC3
     *
     * @param IXR_Error $ixr_error
     * @return IXR_Error
     */
    function xmlrpc_pingback_error($ixr_error)
    {
    }
    /**
     * Removes a comment from the object cache.
     *
     * @since 2.3.0
     *
     * @param int|array $ids Comment ID or an array of comment IDs to remove from cache.
     */
    function clean_comment_cache($ids)
    {
    }
    /**
     * Updates the comment cache of given comments.
     *
     * Will add the comments in $comments to the cache. If comment ID already exists
     * in the comment cache then it will not be updated. The comment is added to the
     * cache using the comment group with the key using the ID of the comments.
     *
     * @since 2.3.0
     * @since 4.4.0 Introduced the `$update_meta_cache` parameter.
     *
     * @param WP_Comment[] $comments          Array of comment objects
     * @param bool         $update_meta_cache Whether to update commentmeta cache. Default true.
     */
    function update_comment_cache($comments, $update_meta_cache = \true)
    {
    }
    /**
     * Adds any comments from the given IDs to the cache that do not already exist in cache.
     *
     * @since 4.4.0
     * @since 6.1.0 This function is no longer marked as "private".
     * @since 6.3.0 Use wp_lazyload_comment_meta() for lazy-loading of comment meta.
     *
     * @see update_comment_cache()
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int[] $comment_ids       Array of comment IDs.
     * @param bool  $update_meta_cache Optional. Whether to update the meta cache. Default true.
     */
    function _prime_comment_caches($comment_ids, $update_meta_cache = \true)
    {
    }
    /**
     * Closes comments on old posts on the fly, without any extra DB queries. Hooked to the_posts.
     *
     * @since 2.7.0
     * @access private
     *
     * @param WP_Post  $posts Post data object.
     * @param WP_Query $query Query object.
     * @return array
     */
    function _close_comments_for_old_posts($posts, $query)
    {
    }
    /**
     * Closes comments on an old post. Hooked to comments_open and pings_open.
     *
     * @since 2.7.0
     * @access private
     *
     * @param bool $open    Comments open or closed.
     * @param int  $post_id Post ID.
     * @return bool $open
     */
    function _close_comments_for_old_post($open, $post_id)
    {
    }
    /**
     * Handles the submission of a comment, usually posted to wp-comments-post.php via a comment form.
     *
     * This function expects unslashed data, as opposed to functions such as `wp_new_comment()` which
     * expect slashed data.
     *
     * @since 4.4.0
     *
     * @param array $comment_data {
     *     Comment data.
     *
     *     @type string|int $comment_post_ID             The ID of the post that relates to the comment.
     *     @type string     $author                      The name of the comment author.
     *     @type string     $email                       The comment author email address.
     *     @type string     $url                         The comment author URL.
     *     @type string     $comment                     The content of the comment.
     *     @type string|int $comment_parent              The ID of this comment's parent, if any. Default 0.
     *     @type string     $_wp_unfiltered_html_comment The nonce value for allowing unfiltered HTML.
     * }
     * @return WP_Comment|WP_Error A WP_Comment object on success, a WP_Error object on failure.
     * @phpstan-param array{
     *   comment_post_ID?: string|int,
     *   author?: string,
     *   email?: string,
     *   url?: string,
     *   comment?: string,
     *   comment_parent?: string|int,
     *   _wp_unfiltered_html_comment?: string,
     * } $comment_data
     */
    function wp_handle_comment_submission($comment_data)
    {
    }
    /**
     * Registers the personal data exporter for comments.
     *
     * @since 4.9.6
     *
     * @param array[] $exporters An array of personal data exporters.
     * @return array[] An array of personal data exporters.
     */
    function wp_register_comment_personal_data_exporter($exporters)
    {
    }
    /**
     * Finds and exports personal data associated with an email address from the comments table.
     *
     * @since 4.9.6
     *
     * @param string $email_address The comment author email address.
     * @param int    $page          Comment page number.
     * @return array {
     *     An array of personal data.
     *
     *     @type array[] $data An array of personal data arrays.
     *     @type bool    $done Whether the exporter is finished.
     * }
     * @phpstan-return array{
     *   data: array[],
     *   done: bool,
     * }
     */
    function wp_comments_personal_data_exporter($email_address, $page = 1)
    {
    }
    /**
     * Registers the personal data eraser for comments.
     *
     * @since 4.9.6
     *
     * @param array $erasers An array of personal data erasers.
     * @return array An array of personal data erasers.
     */
    function wp_register_comment_personal_data_eraser($erasers)
    {
    }
    /**
     * Erases personal data associated with an email address from the comments table.
     *
     * @since 4.9.6
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $email_address The comment author email address.
     * @param int    $page          Comment page number.
     * @return array {
     *     Data removal results.
     *
     *     @type bool     $items_removed  Whether items were actually removed.
     *     @type bool     $items_retained Whether items were retained.
     *     @type string[] $messages       An array of messages to add to the personal data export file.
     *     @type bool     $done           Whether the eraser is finished.
     * }
     * @phpstan-return array{
     *   items_removed: bool,
     *   items_retained: bool,
     *   messages: string[],
     *   done: bool,
     * }
     */
    function wp_comments_personal_data_eraser($email_address, $page = 1)
    {
    }
    /**
     * Sets the last changed time for the 'comment' cache group.
     *
     * @since 5.0.0
     */
    function wp_cache_set_comments_last_changed()
    {
    }
    /**
     * Updates the comment type for a batch of comments.
     *
     * @since 5.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     * @phpstan-return void
     */
    function _wp_batch_update_comment_type()
    {
    }
    /**
     * In order to avoid the _wp_batch_update_comment_type() job being accidentally removed,
     * check that it's still scheduled while we haven't finished updating comment types.
     *
     * @ignore
     * @since 5.5.0
     */
    function _wp_check_for_scheduled_update_comment_type()
    {
    }
    /**
     * Schedules an event to run only once.
     *
     * Schedules a hook which will be triggered by WordPress at the specified UTC time.
     * The action will trigger when someone visits your WordPress site if the scheduled
     * time has passed.
     *
     * Note that scheduling an event to occur within 10 minutes of an existing event
     * with the same action hook will be ignored unless you pass unique `$args` values
     * for each scheduled event.
     *
     * Use wp_next_scheduled() to prevent duplicate events.
     *
     * Use wp_schedule_event() to schedule a recurring event.
     *
     * @since 2.1.0
     * @since 5.1.0 Return value modified to boolean indicating success or failure,
     *              {@see 'pre_schedule_event'} filter added to short-circuit the function.
     * @since 5.7.0 The `$wp_error` parameter was added.
     *
     * @link https://developer.wordpress.org/reference/functions/wp_schedule_single_event/
     *
     * @param int    $timestamp  Unix timestamp (UTC) for when to next run the event.
     * @param string $hook       Action hook to execute when the event is run.
     * @param array  $args       Optional. Array containing arguments to pass to the
     *                           hook's callback function. Each value in the array
     *                           is passed to the callback as an individual parameter.
     *                           The array keys are ignored. Default empty array.
     * @param bool   $wp_error   Optional. Whether to return a WP_Error on failure. Default false.
     * @return bool|WP_Error True if event successfully scheduled. False or WP_Error on failure.
     * @phpstan-param list<mixed> $args
     * @phpstan-return ($wp_error is false ? bool : true|\WP_Error)
     */
    function wp_schedule_single_event($timestamp, $hook, $args = array(), $wp_error = \false)
    {
    }
    /**
     * Schedules a recurring event.
     *
     * Schedules a hook which will be triggered by WordPress at the specified interval.
     * The action will trigger when someone visits your WordPress site if the scheduled
     * time has passed.
     *
     * Valid values for the recurrence are 'hourly', 'twicedaily', 'daily', and 'weekly'.
     * These can be extended using the {@see 'cron_schedules'} filter in wp_get_schedules().
     *
     * Use wp_next_scheduled() to prevent duplicate events.
     *
     * Use wp_schedule_single_event() to schedule a non-recurring event.
     *
     * @since 2.1.0
     * @since 5.1.0 Return value modified to boolean indicating success or failure,
     *              {@see 'pre_schedule_event'} filter added to short-circuit the function.
     * @since 5.7.0 The `$wp_error` parameter was added.
     *
     * @link https://developer.wordpress.org/reference/functions/wp_schedule_event/
     *
     * @param int    $timestamp  Unix timestamp (UTC) for when to next run the event.
     * @param string $recurrence How often the event should subsequently recur.
     *                           See wp_get_schedules() for accepted values.
     * @param string $hook       Action hook to execute when the event is run.
     * @param array  $args       Optional. Array containing arguments to pass to the
     *                           hook's callback function. Each value in the array
     *                           is passed to the callback as an individual parameter.
     *                           The array keys are ignored. Default empty array.
     * @param bool   $wp_error   Optional. Whether to return a WP_Error on failure. Default false.
     * @return bool|WP_Error True if event successfully scheduled. False or WP_Error on failure.
     * @phpstan-param list<mixed> $args
     * @phpstan-return ($wp_error is false ? bool : true|\WP_Error)
     */
    function wp_schedule_event($timestamp, $recurrence, $hook, $args = array(), $wp_error = \false)
    {
    }
    /**
     * Reschedules a recurring event.
     *
     * Mainly for internal use, this takes the UTC timestamp of a previously run
     * recurring event and reschedules it for its next run.
     *
     * To change upcoming scheduled events, use wp_schedule_event() to
     * change the recurrence frequency.
     *
     * @since 2.1.0
     * @since 5.1.0 Return value modified to boolean indicating success or failure,
     *              {@see 'pre_reschedule_event'} filter added to short-circuit the function.
     * @since 5.7.0 The `$wp_error` parameter was added.
     *
     * @param int    $timestamp  Unix timestamp (UTC) for when the event was scheduled.
     * @param string $recurrence How often the event should subsequently recur.
     *                           See wp_get_schedules() for accepted values.
     * @param string $hook       Action hook to execute when the event is run.
     * @param array  $args       Optional. Array containing arguments to pass to the
     *                           hook's callback function. Each value in the array
     *                           is passed to the callback as an individual parameter.
     *                           The array keys are ignored. Default empty array.
     * @param bool   $wp_error   Optional. Whether to return a WP_Error on failure. Default false.
     * @return bool|WP_Error True if event successfully rescheduled. False or WP_Error on failure.
     * @phpstan-param list<mixed> $args
     * @phpstan-return ($wp_error is false ? bool : true|\WP_Error)
     */
    function wp_reschedule_event($timestamp, $recurrence, $hook, $args = array(), $wp_error = \false)
    {
    }
    /**
     * Unschedules a previously scheduled event.
     *
     * The `$timestamp` and `$hook` parameters are required so that the event can be
     * identified.
     *
     * @since 2.1.0
     * @since 5.1.0 Return value modified to boolean indicating success or failure,
     *              {@see 'pre_unschedule_event'} filter added to short-circuit the function.
     * @since 5.7.0 The `$wp_error` parameter was added.
     *
     * @param int    $timestamp Unix timestamp (UTC) of the event.
     * @param string $hook      Action hook of the event.
     * @param array  $args      Optional. Array containing each separate argument to pass to the hook's callback function.
     *                          Although not passed to a callback, these arguments are used to uniquely identify the
     *                          event, so they should be the same as those used when originally scheduling the event.
     *                          Default empty array.
     * @param bool   $wp_error  Optional. Whether to return a WP_Error on failure. Default false.
     * @return bool|WP_Error True if event successfully unscheduled. False or WP_Error on failure.
     * @phpstan-param list<mixed> $args
     * @phpstan-return ($wp_error is false ? bool : true|\WP_Error)
     */
    function wp_unschedule_event($timestamp, $hook, $args = array(), $wp_error = \false)
    {
    }
    /**
     * Unschedules all events attached to the hook with the specified arguments.
     *
     * Warning: This function may return boolean false, but may also return a non-boolean
     * value which evaluates to false. For information about casting to booleans see the
     * {@link https://www.php.net/manual/en/language.types.boolean.php PHP documentation}. Use
     * the `===` operator for testing the return value of this function.
     *
     * @since 2.1.0
     * @since 5.1.0 Return value modified to indicate success or failure,
     *              {@see 'pre_clear_scheduled_hook'} filter added to short-circuit the function.
     * @since 5.7.0 The `$wp_error` parameter was added.
     *
     * @param string $hook     Action hook, the execution of which will be unscheduled.
     * @param array  $args     Optional. Array containing each separate argument to pass to the hook's callback function.
     *                         Although not passed to a callback, these arguments are used to uniquely identify the
     *                         event, so they should be the same as those used when originally scheduling the event.
     *                         Default empty array.
     * @param bool   $wp_error Optional. Whether to return a WP_Error on failure. Default false.
     * @return int|false|WP_Error On success an integer indicating number of events unscheduled (0 indicates no
     *                            events were registered with the hook and arguments combination), false or WP_Error
     *                            if unscheduling one or more events fail.
     * @phpstan-param list<mixed> $args
     * @phpstan-return (int<0, max>|($wp_error is false ? false : \WP_Error))
     */
    function wp_clear_scheduled_hook($hook, $args = array(), $wp_error = \false)
    {
    }
    /**
     * Unschedules all events attached to the hook.
     *
     * Can be useful for plugins when deactivating to clean up the cron queue.
     *
     * Warning: This function may return boolean false, but may also return a non-boolean
     * value which evaluates to false. For information about casting to booleans see the
     * {@link https://www.php.net/manual/en/language.types.boolean.php PHP documentation}. Use
     * the `===` operator for testing the return value of this function.
     *
     * @since 4.9.0
     * @since 5.1.0 Return value added to indicate success or failure.
     * @since 5.7.0 The `$wp_error` parameter was added.
     *
     * @param string $hook     Action hook, the execution of which will be unscheduled.
     * @param bool   $wp_error Optional. Whether to return a WP_Error on failure. Default false.
     * @return int|false|WP_Error On success an integer indicating number of events unscheduled (0 indicates no
     *                            events were registered on the hook), false or WP_Error if unscheduling fails.
     * @phpstan-return ($wp_error is false ? int<0, max>|false : int<0, max>|\WP_Error)
     */
    function wp_unschedule_hook($hook, $wp_error = \false)
    {
    }
    /**
     * Retrieves a scheduled event.
     *
     * Retrieves the full event object for a given event, if no timestamp is specified the next
     * scheduled event is returned.
     *
     * @since 5.1.0
     *
     * @param string   $hook      Action hook of the event.
     * @param array    $args      Optional. Array containing each separate argument to pass to the hook's callback function.
     *                            Although not passed to a callback, these arguments are used to uniquely identify the
     *                            event, so they should be the same as those used when originally scheduling the event.
     *                            Default empty array.
     * @param int|null $timestamp Optional. Unix timestamp (UTC) of the event. If not specified, the next scheduled event
     *                            is returned. Default null.
     * @return object|false {
     *     The event object. False if the event does not exist.
     *
     *     @type string       $hook      Action hook to execute when the event is run.
     *     @type int          $timestamp Unix timestamp (UTC) for when to next run the event.
     *     @type string|false $schedule  How often the event should subsequently recur.
     *     @type array        $args      Array containing each separate argument to pass to the hook's callback function.
     *     @type int          $interval  Optional. The interval time in seconds for the schedule. Only present for recurring events.
     * }
     * @phpstan-return false|object{
     *   hook: string,
     *   timestamp: int,
     *   schedule: string|false,
     *   args: array,
     *   interval: int,
     * }
     * @phpstan-param list<mixed> $args
     */
    function wp_get_scheduled_event($hook, $args = array(), $timestamp = \null)
    {
    }
    /**
     * Retrieves the next timestamp for an event.
     *
     * @since 2.1.0
     *
     * @param string $hook Action hook of the event.
     * @param array  $args Optional. Array containing each separate argument to pass to the hook's callback function.
     *                     Although not passed to a callback, these arguments are used to uniquely identify the
     *                     event, so they should be the same as those used when originally scheduling the event.
     *                     Default empty array.
     * @return int|false The Unix timestamp of the next time the event will occur. False if the event doesn't exist.
     * @phpstan-param list<mixed> $args
     */
    function wp_next_scheduled($hook, $args = array())
    {
    }
    /**
     * Sends a request to run cron through HTTP request that doesn't halt page loading.
     *
     * @since 2.1.0
     * @since 5.1.0 Return values added.
     *
     * @param int $gmt_time Optional. Unix timestamp (UTC). Default 0 (current time is used).
     * @return bool True if spawned, false if no events spawned.
     */
    function spawn_cron($gmt_time = 0)
    {
    }
    /**
     * Registers _wp_cron() to run on the {@see 'wp_loaded'} action.
     *
     * If the {@see 'wp_loaded'} action has already fired, this function calls
     * _wp_cron() directly.
     *
     * Warning: This function may return Boolean FALSE, but may also return a non-Boolean
     * value which evaluates to FALSE. For information about casting to booleans see the
     * {@link https://www.php.net/manual/en/language.types.boolean.php PHP documentation}. Use
     * the `===` operator for testing the return value of this function.
     *
     * @since 2.1.0
     * @since 5.1.0 Return value added to indicate success or failure.
     * @since 5.7.0 Functionality moved to _wp_cron() to which this becomes a wrapper.
     *
     * @return false|int|void On success an integer indicating number of events spawned (0 indicates no
     *                        events needed to be spawned), false if spawning fails for one or more events or
     *                        void if the function registered _wp_cron() to run on the action.
     */
    function wp_cron()
    {
    }
    /**
     * Runs scheduled callbacks or spawns cron for all scheduled events.
     *
     * Warning: This function may return Boolean FALSE, but may also return a non-Boolean
     * value which evaluates to FALSE. For information about casting to booleans see the
     * {@link https://www.php.net/manual/en/language.types.boolean.php PHP documentation}. Use
     * the `===` operator for testing the return value of this function.
     *
     * @since 5.7.0
     * @access private
     *
     * @return int|false On success an integer indicating number of events spawned (0 indicates no
     *                   events needed to be spawned), false if spawning fails for one or more events.
     */
    function _wp_cron()
    {
    }
    /**
     * Retrieves supported event recurrence schedules.
     *
     * The default supported recurrences are 'hourly', 'twicedaily', 'daily', and 'weekly'.
     * A plugin may add more by hooking into the {@see 'cron_schedules'} filter.
     * The filter accepts an array of arrays. The outer array has a key that is the name
     * of the schedule, for example 'monthly'. The value is an array with two keys,
     * one is 'interval' and the other is 'display'.
     *
     * The 'interval' is a number in seconds of when the cron job should run.
     * So for 'hourly' the time is `HOUR_IN_SECONDS` (`60 * 60` or `3600`). For 'monthly',
     * the value would be `MONTH_IN_SECONDS` (`30 * 24 * 60 * 60` or `2592000`).
     *
     * The 'display' is the description. For the 'monthly' key, the 'display'
     * would be `__( 'Once Monthly' )`.
     *
     * For your plugin, you will be passed an array. You can add your
     * schedule by doing the following:
     *
     *     // Filter parameter variable name is 'array'.
     *     $array['monthly'] = array(
     *         'interval' => MONTH_IN_SECONDS,
     *         'display'  => __( 'Once Monthly' )
     *     );
     *
     * @since 2.1.0
     * @since 5.4.0 The 'weekly' schedule was added.
     *
     * @return array {
     *     The array of cron schedules keyed by the schedule name.
     *
     *     @type array ...$0 {
     *         Cron schedule information.
     *
     *         @type int    $interval The schedule interval in seconds.
     *         @type string $display  The schedule display name.
     *     }
     * }
     * @phpstan-return array<int|string, array{
     *   interval: int,
     *   display: string,
     * }>
     */
    function wp_get_schedules()
    {
    }
    /**
     * Retrieves the name of the recurrence schedule for an event.
     *
     * @see wp_get_schedules() for available schedules.
     *
     * @since 2.1.0
     * @since 5.1.0 {@see 'get_schedule'} filter added.
     *
     * @param string $hook Action hook to identify the event.
     * @param array  $args Optional. Arguments passed to the event's callback function.
     *                     Default empty array.
     * @return string|false Schedule name on success, false if no schedule.
     * @phpstan-param list<mixed> $args
     */
    function wp_get_schedule($hook, $args = array())
    {
    }
    /**
     * Retrieves cron jobs ready to be run.
     *
     * Returns the results of _get_cron_array() limited to events ready to be run,
     * ie, with a timestamp in the past.
     *
     * @since 5.1.0
     *
     * @return array[] Array of cron job arrays ready to be run.
     */
    function wp_get_ready_cron_jobs()
    {
    }
    /**
     * Retrieves cron info array option.
     *
     * @since 2.1.0
     * @since 6.1.0 Return type modified to consistently return an array.
     * @access private
     *
     * @return array[] Array of cron events.
     */
    function _get_cron_array()
    {
    }
    /**
     * Updates the cron option with the new cron array.
     *
     * @since 2.1.0
     * @since 5.1.0 Return value modified to outcome of update_option().
     * @since 5.7.0 The `$wp_error` parameter was added.
     *
     * @access private
     *
     * @param array[] $cron     Array of cron info arrays from _get_cron_array().
     * @param bool    $wp_error Optional. Whether to return a WP_Error on failure. Default false.
     * @return bool|WP_Error True if cron array updated. False or WP_Error on failure.
     */
    function _set_cron_array($cron, $wp_error = \false)
    {
    }
    /**
     * Upgrades a cron info array.
     *
     * This function upgrades the cron info array to version 2.
     *
     * @since 2.1.0
     * @access private
     *
     * @param array $cron Cron info array from _get_cron_array().
     * @return array An upgraded cron info array.
     */
    function _upgrade_cron_array($cron)
    {
    }
    /**
     * Defines initial WordPress constants.
     *
     * @see wp_debug_mode()
     *
     * @since 3.0.0
     *
     * @global int    $blog_id    The current site ID.
     * @global string $wp_version The WordPress version string.
     */
    function wp_initial_constants()
    {
    }
    /**
     * Defines plugin directory WordPress constants.
     *
     * Defines must-use plugin directory constants, which may be overridden in the sunrise.php drop-in.
     *
     * @since 3.0.0
     */
    function wp_plugin_directory_constants()
    {
    }
    /**
     * Defines cookie-related WordPress constants.
     *
     * Defines constants after multisite is loaded.
     *
     * @since 3.0.0
     */
    function wp_cookie_constants()
    {
    }
    /**
     * Defines SSL-related WordPress constants.
     *
     * @since 3.0.0
     */
    function wp_ssl_constants()
    {
    }
    /**
     * Defines functionality-related WordPress constants.
     *
     * @since 3.0.0
     */
    function wp_functionality_constants()
    {
    }
    /**
     * Defines templating-related WordPress constants.
     *
     * @since 3.0.0
     */
    function wp_templating_constants()
    {
    }
    /**
     * Retrieves all post data for a given post.
     *
     * @since 0.71
     * @deprecated 1.5.1 Use get_post()
     * @see get_post()
     *
     * @param int $postid Post ID.
     * @return array Post data.
     */
    function get_postdata($postid)
    {
    }
    /**
     * Sets up the WordPress Loop.
     *
     * Use The Loop instead.
     *
     * @link https://developer.wordpress.org/themes/basics/the-loop/
     *
     * @since 1.0.1
     * @deprecated 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     */
    function start_wp()
    {
    }
    /**
     * Returns or prints a category ID.
     *
     * @since 0.71
     * @deprecated 0.71 Use get_the_category()
     * @see get_the_category()
     *
     * @param bool $display Optional. Whether to display the output. Default true.
     * @return int Category ID.
     */
    function the_category_ID($display = \true)
    {
    }
    /**
     * Prints a category with optional text before and after.
     *
     * @since 0.71
     * @deprecated 0.71 Use get_the_category_by_ID()
     * @see get_the_category_by_ID()
     *
     * @param string $before Optional. Text to display before the category. Default empty.
     * @param string $after  Optional. Text to display after the category. Default empty.
     */
    function the_category_head($before = '', $after = '')
    {
    }
    /**
     * Prints a link to the previous post.
     *
     * @since 1.5.0
     * @deprecated 2.0.0 Use previous_post_link()
     * @see previous_post_link()
     *
     * @param string $format
     * @param string $previous
     * @param string $title
     * @param string $in_same_cat
     * @param int    $limitprev
     * @param string $excluded_categories
     * @phpstan-return void
     */
    function previous_post($format = '%', $previous = 'previous post: ', $title = 'yes', $in_same_cat = 'no', $limitprev = 1, $excluded_categories = '')
    {
    }
    /**
     * Prints link to the next post.
     *
     * @since 0.71
     * @deprecated 2.0.0 Use next_post_link()
     * @see next_post_link()
     *
     * @param string $format
     * @param string $next
     * @param string $title
     * @param string $in_same_cat
     * @param int $limitnext
     * @param string $excluded_categories
     * @phpstan-return void
     */
    function next_post($format = '%', $next = 'next post: ', $title = 'yes', $in_same_cat = 'no', $limitnext = 1, $excluded_categories = '')
    {
    }
    /**
     * Whether user can create a post.
     *
     * @since 1.5.0
     * @deprecated 2.0.0 Use current_user_can()
     * @see current_user_can()
     *
     * @param int $user_id
     * @param int $blog_id Not Used
     * @param int $category_id Not Used
     * @return bool
     */
    function user_can_create_post($user_id, $blog_id = 1, $category_id = 'None')
    {
    }
    /**
     * Whether user can create a post.
     *
     * @since 1.5.0
     * @deprecated 2.0.0 Use current_user_can()
     * @see current_user_can()
     *
     * @param int $user_id
     * @param int $blog_id Not Used
     * @param int $category_id Not Used
     * @return bool
     */
    function user_can_create_draft($user_id, $blog_id = 1, $category_id = 'None')
    {
    }
    /**
     * Whether user can edit a post.
     *
     * @since 1.5.0
     * @deprecated 2.0.0 Use current_user_can()
     * @see current_user_can()
     *
     * @param int $user_id
     * @param int $post_id
     * @param int $blog_id Not Used
     * @return bool
     */
    function user_can_edit_post($user_id, $post_id, $blog_id = 1)
    {
    }
    /**
     * Whether user can delete a post.
     *
     * @since 1.5.0
     * @deprecated 2.0.0 Use current_user_can()
     * @see current_user_can()
     *
     * @param int $user_id
     * @param int $post_id
     * @param int $blog_id Not Used
     * @return bool
     */
    function user_can_delete_post($user_id, $post_id, $blog_id = 1)
    {
    }
    /**
     * Whether user can set new posts' dates.
     *
     * @since 1.5.0
     * @deprecated 2.0.0 Use current_user_can()
     * @see current_user_can()
     *
     * @param int $user_id
     * @param int $blog_id Not Used
     * @param int $category_id Not Used
     * @return bool
     */
    function user_can_set_post_date($user_id, $blog_id = 1, $category_id = 'None')
    {
    }
    /**
     * Whether user can delete a post.
     *
     * @since 1.5.0
     * @deprecated 2.0.0 Use current_user_can()
     * @see current_user_can()
     *
     * @param int $user_id
     * @param int $post_id
     * @param int $blog_id Not Used
     * @return bool returns true if $user_id can edit $post_id's date
     */
    function user_can_edit_post_date($user_id, $post_id, $blog_id = 1)
    {
    }
    /**
     * Whether user can delete a post.
     *
     * @since 1.5.0
     * @deprecated 2.0.0 Use current_user_can()
     * @see current_user_can()
     *
     * @param int $user_id
     * @param int $post_id
     * @param int $blog_id Not Used
     * @return bool returns true if $user_id can edit $post_id's comments
     */
    function user_can_edit_post_comments($user_id, $post_id, $blog_id = 1)
    {
    }
    /**
     * Whether user can delete a post.
     *
     * @since 1.5.0
     * @deprecated 2.0.0 Use current_user_can()
     * @see current_user_can()
     *
     * @param int $user_id
     * @param int $post_id
     * @param int $blog_id Not Used
     * @return bool returns true if $user_id can delete $post_id's comments
     */
    function user_can_delete_post_comments($user_id, $post_id, $blog_id = 1)
    {
    }
    /**
     * Can user can edit other user.
     *
     * @since 1.5.0
     * @deprecated 2.0.0 Use current_user_can()
     * @see current_user_can()
     *
     * @param int $user_id
     * @param int $other_user
     * @return bool
     */
    function user_can_edit_user($user_id, $other_user)
    {
    }
    /**
     * Gets the links associated with category $cat_name.
     *
     * @since 0.71
     * @deprecated 2.1.0 Use get_bookmarks()
     * @see get_bookmarks()
     *
     * @param string $cat_name         Optional. The category name to use. If no match is found, uses all.
     *                                 Default 'noname'.
     * @param string $before           Optional. The HTML to output before the link. Default empty.
     * @param string $after            Optional. The HTML to output after the link. Default '<br />'.
     * @param string $between          Optional. The HTML to output between the link/image and its description.
     *                                 Not used if no image or $show_images is true. Default ' '.
     * @param bool   $show_images      Optional. Whether to show images (if defined). Default true.
     * @param string $orderby          Optional. The order to output the links. E.g. 'id', 'name', 'url',
     *                                 'description', 'rating', or 'owner'. Default 'id'.
     *                                 If you start the name with an underscore, the order will be reversed.
     *                                 Specifying 'rand' as the order will return links in a random order.
     * @param bool   $show_description Optional. Whether to show the description if show_images=false/not defined.
     *                                 Default true.
     * @param bool   $show_rating      Optional. Show rating stars/chars. Default false.
     * @param int    $limit            Optional. Limit to X entries. If not specified, all entries are shown.
     *                                 Default -1.
     * @param int    $show_updated     Optional. Whether to show last updated timestamp. Default 0.
     */
    function get_linksbyname($cat_name = "noname", $before = '', $after = '<br />', $between = " ", $show_images = \true, $orderby = 'id', $show_description = \true, $show_rating = \false, $limit = -1, $show_updated = 0)
    {
    }
    /**
     * Gets the links associated with the named category.
     *
     * @since 1.0.1
     * @deprecated 2.1.0 Use wp_list_bookmarks()
     * @see wp_list_bookmarks()
     *
     * @param string $category The category to use.
     * @param string $args
     * @return string|null
     */
    function wp_get_linksbyname($category, $args = '')
    {
    }
    /**
     * Gets an array of link objects associated with category $cat_name.
     *
     *     $links = get_linkobjectsbyname( 'fred' );
     *     foreach ( $links as $link ) {
     *      	echo '<li>' . $link->link_name . '</li>';
     *     }
     *
     * @since 1.0.1
     * @deprecated 2.1.0 Use get_bookmarks()
     * @see get_bookmarks()
     *
     * @param string $cat_name Optional. The category name to use. If no match is found, uses all.
     *                         Default 'noname'.
     * @param string $orderby  Optional. The order to output the links. E.g. 'id', 'name', 'url',
     *                         'description', 'rating', or 'owner'. Default 'name'.
     *                         If you start the name with an underscore, the order will be reversed.
     *                         Specifying 'rand' as the order will return links in a random order.
     * @param int    $limit    Optional. Limit to X entries. If not specified, all entries are shown.
     *                         Default -1.
     * @return array
     */
    function get_linkobjectsbyname($cat_name = "noname", $orderby = 'name', $limit = -1)
    {
    }
    /**
     * Gets an array of link objects associated with category n.
     *
     * Usage:
     *
     *     $links = get_linkobjects(1);
     *     if ($links) {
     *     	foreach ($links as $link) {
     *     		echo '<li>'.$link->link_name.'<br />'.$link->link_description.'</li>';
     *     	}
     *     }
     *
     * Fields are:
     *
     * - link_id
     * - link_url
     * - link_name
     * - link_image
     * - link_target
     * - link_category
     * - link_description
     * - link_visible
     * - link_owner
     * - link_rating
     * - link_updated
     * - link_rel
     * - link_notes
     *
     * @since 1.0.1
     * @deprecated 2.1.0 Use get_bookmarks()
     * @see get_bookmarks()
     *
     * @param int    $category Optional. The category to use. If no category supplied, uses all.
     *                         Default 0.
     * @param string $orderby  Optional. The order to output the links. E.g. 'id', 'name', 'url',
     *                         'description', 'rating', or 'owner'. Default 'name'.
     *                         If you start the name with an underscore, the order will be reversed.
     *                         Specifying 'rand' as the order will return links in a random order.
     * @param int    $limit    Optional. Limit to X entries. If not specified, all entries are shown.
     *                         Default 0.
     * @return array
     */
    function get_linkobjects($category = 0, $orderby = 'name', $limit = 0)
    {
    }
    /**
     * Gets the links associated with category 'cat_name' and display rating stars/chars.
     *
     * @since 0.71
     * @deprecated 2.1.0 Use get_bookmarks()
     * @see get_bookmarks()
     *
     * @param string $cat_name         Optional. The category name to use. If no match is found, uses all.
     *                                 Default 'noname'.
     * @param string $before           Optional. The HTML to output before the link. Default empty.
     * @param string $after            Optional. The HTML to output after the link. Default '<br />'.
     * @param string $between          Optional. The HTML to output between the link/image and its description.
     *                                 Not used if no image or $show_images is true. Default ' '.
     * @param bool   $show_images      Optional. Whether to show images (if defined). Default true.
     * @param string $orderby          Optional. The order to output the links. E.g. 'id', 'name', 'url',
     *                                 'description', 'rating', or 'owner'. Default 'id'.
     *                                 If you start the name with an underscore, the order will be reversed.
     *                                 Specifying 'rand' as the order will return links in a random order.
     * @param bool   $show_description Optional. Whether to show the description if show_images=false/not defined.
     *                                 Default true.
     * @param int    $limit		       Optional. Limit to X entries. If not specified, all entries are shown.
     *                                 Default -1.
     * @param int    $show_updated     Optional. Whether to show last updated timestamp. Default 0.
     */
    function get_linksbyname_withrating($cat_name = "noname", $before = '', $after = '<br />', $between = " ", $show_images = \true, $orderby = 'id', $show_description = \true, $limit = -1, $show_updated = 0)
    {
    }
    /**
     * Gets the links associated with category n and display rating stars/chars.
     *
     * @since 0.71
     * @deprecated 2.1.0 Use get_bookmarks()
     * @see get_bookmarks()
     *
     * @param int    $category         Optional. The category to use. If no category supplied, uses all.
     *                                 Default 0.
     * @param string $before           Optional. The HTML to output before the link. Default empty.
     * @param string $after            Optional. The HTML to output after the link. Default '<br />'.
     * @param string $between          Optional. The HTML to output between the link/image and its description.
     *                                 Not used if no image or $show_images is true. Default ' '.
     * @param bool   $show_images      Optional. Whether to show images (if defined). Default true.
     * @param string $orderby          Optional. The order to output the links. E.g. 'id', 'name', 'url',
     *                                 'description', 'rating', or 'owner'. Default 'id'.
     *                                 If you start the name with an underscore, the order will be reversed.
     *                                 Specifying 'rand' as the order will return links in a random order.
     * @param bool   $show_description Optional. Whether to show the description if show_images=false/not defined.
     *                                 Default true.
     * @param int    $limit		       Optional. Limit to X entries. If not specified, all entries are shown.
     *                                 Default -1.
     * @param int    $show_updated     Optional. Whether to show last updated timestamp. Default 0.
     */
    function get_links_withrating($category = -1, $before = '', $after = '<br />', $between = " ", $show_images = \true, $orderby = 'id', $show_description = \true, $limit = -1, $show_updated = 0)
    {
    }
    /**
     * Gets the auto_toggle setting.
     *
     * @since 0.71
     * @deprecated 2.1.0
     *
     * @param int $id The category to get. If no category supplied uses 0
     * @return int Only returns 0.
     */
    function get_autotoggle($id = 0)
    {
    }
    /**
     * Lists categories.
     *
     * @since 0.71
     * @deprecated 2.1.0 Use wp_list_categories()
     * @see wp_list_categories()
     *
     * @param int $optionall
     * @param string $all
     * @param string $sort_column
     * @param string $sort_order
     * @param string $file
     * @param bool $list
     * @param int $optiondates
     * @param int $optioncount
     * @param int $hide_empty
     * @param int $use_desc_for_title
     * @param bool $children
     * @param int $child_of
     * @param int $categories
     * @param int $recurse
     * @param string $feed
     * @param string $feed_image
     * @param string $exclude
     * @param bool $hierarchical
     * @return null|false
     */
    function list_cats($optionall = 1, $all = 'All', $sort_column = 'ID', $sort_order = 'asc', $file = '', $list = \true, $optiondates = 0, $optioncount = 0, $hide_empty = 1, $use_desc_for_title = 1, $children = \false, $child_of = 0, $categories = 0, $recurse = 0, $feed = '', $feed_image = '', $exclude = '', $hierarchical = \false)
    {
    }
    /**
     * Lists categories.
     *
     * @since 1.2.0
     * @deprecated 2.1.0 Use wp_list_categories()
     * @see wp_list_categories()
     *
     * @param string|array $args
     * @return null|string|false
     */
    function wp_list_cats($args = '')
    {
    }
    /**
     * Deprecated method for generating a drop-down of categories.
     *
     * @since 0.71
     * @deprecated 2.1.0 Use wp_dropdown_categories()
     * @see wp_dropdown_categories()
     *
     * @param int $optionall
     * @param string $all
     * @param string $orderby
     * @param string $order
     * @param int $show_last_update
     * @param int $show_count
     * @param int $hide_empty
     * @param bool $optionnone
     * @param int $selected
     * @param int $exclude
     * @return string
     */
    function dropdown_cats($optionall = 1, $all = 'All', $orderby = 'ID', $order = 'asc', $show_last_update = 0, $show_count = 0, $hide_empty = 1, $optionnone = \false, $selected = 0, $exclude = 0)
    {
    }
    /**
     * Lists authors.
     *
     * @since 1.2.0
     * @deprecated 2.1.0 Use wp_list_authors()
     * @see wp_list_authors()
     *
     * @param bool $optioncount
     * @param bool $exclude_admin
     * @param bool $show_fullname
     * @param bool $hide_empty
     * @param string $feed
     * @param string $feed_image
     * @return null|string
     */
    function list_authors($optioncount = \false, $exclude_admin = \true, $show_fullname = \false, $hide_empty = \true, $feed = '', $feed_image = '')
    {
    }
    /**
     * Retrieves a list of post categories.
     *
     * @since 1.0.1
     * @deprecated 2.1.0 Use wp_get_post_categories()
     * @see wp_get_post_categories()
     *
     * @param int $blogid Not Used
     * @param int $post_id
     * @return array
     */
    function wp_get_post_cats($blogid = '1', $post_id = 0)
    {
    }
    /**
     * Sets the categories that the post ID belongs to.
     *
     * @since 1.0.1
     * @deprecated 2.1.0
     * @deprecated Use wp_set_post_categories()
     * @see wp_set_post_categories()
     *
     * @param int $blogid Not used
     * @param int $post_id
     * @param array $post_categories
     * @return bool|mixed
     */
    function wp_set_post_cats($blogid = '1', $post_id = 0, $post_categories = array())
    {
    }
    /**
     * Retrieves a list of archives.
     *
     * @since 0.71
     * @deprecated 2.1.0 Use wp_get_archives()
     * @see wp_get_archives()
     *
     * @param string $type
     * @param string $limit
     * @param string $format
     * @param string $before
     * @param string $after
     * @param bool $show_post_count
     * @return string|null
     */
    function get_archives($type = '', $limit = '', $format = 'html', $before = '', $after = '', $show_post_count = \false)
    {
    }
    /**
     * Returns or Prints link to the author's posts.
     *
     * @since 1.2.0
     * @deprecated 2.1.0 Use get_author_posts_url()
     * @see get_author_posts_url()
     *
     * @param bool $display
     * @param int $author_id
     * @param string $author_nicename Optional.
     * @return string|null
     */
    function get_author_link($display, $author_id, $author_nicename = '')
    {
    }
    /**
     * Print list of pages based on arguments.
     *
     * @since 0.71
     * @deprecated 2.1.0 Use wp_link_pages()
     * @see wp_link_pages()
     *
     * @param string $before
     * @param string $after
     * @param string $next_or_number
     * @param string $nextpagelink
     * @param string $previouspagelink
     * @param string $pagelink
     * @param string $more_file
     * @return string
     */
    function link_pages($before = '<br />', $after = '<br />', $next_or_number = 'number', $nextpagelink = 'next page', $previouspagelink = 'previous page', $pagelink = '%', $more_file = '')
    {
    }
    /**
     * Get value based on option.
     *
     * @since 0.71
     * @deprecated 2.1.0 Use get_option()
     * @see get_option()
     *
     * @param string $option
     * @return string
     */
    function get_settings($option)
    {
    }
    /**
     * Print the permalink of the current post in the loop.
     *
     * @since 0.71
     * @deprecated 1.2.0 Use the_permalink()
     * @see the_permalink()
     */
    function permalink_link()
    {
    }
    /**
     * Print the permalink to the RSS feed.
     *
     * @since 0.71
     * @deprecated 2.3.0 Use the_permalink_rss()
     * @see the_permalink_rss()
     *
     * @param string $deprecated
     */
    function permalink_single_rss($deprecated = '')
    {
    }
    /**
     * Gets the links associated with category.
     *
     * @since 1.0.1
     * @deprecated 2.1.0 Use wp_list_bookmarks()
     * @see wp_list_bookmarks()
     *
     * @param string $args a query string
     * @return null|string
     */
    function wp_get_links($args = '')
    {
    }
    /**
     * Gets the links associated with category by ID.
     *
     * @since 0.71
     * @deprecated 2.1.0 Use get_bookmarks()
     * @see get_bookmarks()
     *
     * @param int    $category         Optional. The category to use. If no category supplied uses all.
     *                                 Default 0.
     * @param string $before           Optional. The HTML to output before the link. Default empty.
     * @param string $after            Optional. The HTML to output after the link. Default '<br />'.
     * @param string $between          Optional. The HTML to output between the link/image and its description.
     *                                 Not used if no image or $show_images is true. Default ' '.
     * @param bool   $show_images      Optional. Whether to show images (if defined). Default true.
     * @param string $orderby          Optional. The order to output the links. E.g. 'id', 'name', 'url',
     *                                 'description', 'rating', or 'owner'. Default 'name'.
     *                                 If you start the name with an underscore, the order will be reversed.
     *                                 Specifying 'rand' as the order will return links in a random order.
     * @param bool   $show_description Optional. Whether to show the description if show_images=false/not defined.
     *                                 Default true.
     * @param bool   $show_rating      Optional. Show rating stars/chars. Default false.
     * @param int    $limit            Optional. Limit to X entries. If not specified, all entries are shown.
     *                                 Default -1.
     * @param int    $show_updated     Optional. Whether to show last updated timestamp. Default 1.
     * @param bool   $display          Whether to display the results, or return them instead.
     * @return null|string
     */
    function get_links($category = -1, $before = '', $after = '<br />', $between = ' ', $show_images = \true, $orderby = 'name', $show_description = \true, $show_rating = \false, $limit = -1, $show_updated = 1, $display = \true)
    {
    }
    /**
     * Output entire list of links by category.
     *
     * Output a list of all links, listed by category, using the settings in
     * $wpdb->linkcategories and output it as a nested HTML unordered list.
     *
     * @since 1.0.1
     * @deprecated 2.1.0 Use wp_list_bookmarks()
     * @see wp_list_bookmarks()
     *
     * @param string $order Sort link categories by 'name' or 'id'
     */
    function get_links_list($order = 'name')
    {
    }
    /**
     * Show the link to the links popup and the number of links.
     *
     * @since 0.71
     * @deprecated 2.1.0
     *
     * @param string $text the text of the link
     * @param int $width the width of the popup window
     * @param int $height the height of the popup window
     * @param string $file the page to open in the popup window
     * @param bool $count the number of links in the db
     */
    function links_popup_script($text = 'Links', $width = 400, $height = 400, $file = 'links.all.php', $count = \true)
    {
    }
    /**
     * Legacy function that retrieved the value of a link's link_rating field.
     *
     * @since 1.0.1
     * @deprecated 2.1.0 Use sanitize_bookmark_field()
     * @see sanitize_bookmark_field()
     *
     * @param object $link Link object.
     * @return mixed Value of the 'link_rating' field, false otherwise.
     */
    function get_linkrating($link)
    {
    }
    /**
     * Gets the name of category by ID.
     *
     * @since 0.71
     * @deprecated 2.1.0 Use get_category()
     * @see get_category()
     *
     * @param int $id The category to get. If no category supplied uses 0
     * @return string
     */
    function get_linkcatname($id = 0)
    {
    }
    /**
     * Print RSS comment feed link.
     *
     * @since 1.0.1
     * @deprecated 2.5.0 Use post_comments_feed_link()
     * @see post_comments_feed_link()
     *
     * @param string $link_text
     */
    function comments_rss_link($link_text = 'Comments RSS')
    {
    }
    /**
     * Print/Return link to category RSS2 feed.
     *
     * @since 1.2.0
     * @deprecated 2.5.0 Use get_category_feed_link()
     * @see get_category_feed_link()
     *
     * @param bool $display
     * @param int $cat_id
     * @return string
     */
    function get_category_rss_link($display = \false, $cat_id = 1)
    {
    }
    /**
     * Print/Return link to author RSS feed.
     *
     * @since 1.2.0
     * @deprecated 2.5.0 Use get_author_feed_link()
     * @see get_author_feed_link()
     *
     * @param bool $display
     * @param int $author_id
     * @return string
     */
    function get_author_rss_link($display = \false, $author_id = 1)
    {
    }
    /**
     * Return link to the post RSS feed.
     *
     * @since 1.5.0
     * @deprecated 2.2.0 Use get_post_comments_feed_link()
     * @see get_post_comments_feed_link()
     *
     * @return string
     */
    function comments_rss()
    {
    }
    /**
     * An alias of wp_create_user().
     *
     * @since 2.0.0
     * @deprecated 2.0.0 Use wp_create_user()
     * @see wp_create_user()
     *
     * @param string $username The user's username.
     * @param string $password The user's password.
     * @param string $email    The user's email.
     * @return int The new user's ID.
     */
    function create_user($username, $password, $email)
    {
    }
    /**
     * Unused function.
     *
     * @deprecated 2.5.0
     */
    function gzip_compression()
    {
    }
    /**
     * Retrieve an array of comment data about comment $comment_id.
     *
     * @since 0.71
     * @deprecated 2.7.0 Use get_comment()
     * @see get_comment()
     *
     * @param int $comment_id The ID of the comment
     * @param int $no_cache Whether to use the cache (cast to bool)
     * @param bool $include_unapproved Whether to include unapproved comments
     * @return array The comment data
     */
    function get_commentdata($comment_id, $no_cache = 0, $include_unapproved = \false)
    {
    }
    /**
     * Retrieve the category name by the category ID.
     *
     * @since 0.71
     * @deprecated 2.8.0 Use get_cat_name()
     * @see get_cat_name()
     *
     * @param int $cat_id Category ID
     * @return string category name
     */
    function get_catname($cat_id)
    {
    }
    /**
     * Retrieve category children list separated before and after the term IDs.
     *
     * @since 1.2.0
     * @deprecated 2.8.0 Use get_term_children()
     * @see get_term_children()
     *
     * @param int    $id      Category ID to retrieve children.
     * @param string $before  Optional. Prepend before category term ID. Default '/'.
     * @param string $after   Optional. Append after category term ID. Default empty string.
     * @param array  $visited Optional. Category Term IDs that have already been added.
     *                        Default empty array.
     * @return string
     */
    function get_category_children($id, $before = '/', $after = '', $visited = array())
    {
    }
    /**
     * Retrieves all category IDs.
     *
     * @since 2.0.0
     * @deprecated 4.0.0 Use get_terms()
     * @see get_terms()
     *
     * @link https://developer.wordpress.org/reference/functions/get_all_category_ids/
     *
     * @return int[] List of all of the category IDs.
     */
    function get_all_category_ids()
    {
    }
    /**
     * Retrieve the description of the author of the current post.
     *
     * @since 1.5.0
     * @deprecated 2.8.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @return string The author's description.
     */
    function get_the_author_description()
    {
    }
    /**
     * Display the description of the author of the current post.
     *
     * @since 1.0.0
     * @deprecated 2.8.0 Use the_author_meta()
     * @see the_author_meta()
     */
    function the_author_description()
    {
    }
    /**
     * Retrieve the login name of the author of the current post.
     *
     * @since 1.5.0
     * @deprecated 2.8.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @return string The author's login name (username).
     */
    function get_the_author_login()
    {
    }
    /**
     * Display the login name of the author of the current post.
     *
     * @since 0.71
     * @deprecated 2.8.0 Use the_author_meta()
     * @see the_author_meta()
     */
    function the_author_login()
    {
    }
    /**
     * Retrieve the first name of the author of the current post.
     *
     * @since 1.5.0
     * @deprecated 2.8.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @return string The author's first name.
     */
    function get_the_author_firstname()
    {
    }
    /**
     * Display the first name of the author of the current post.
     *
     * @since 0.71
     * @deprecated 2.8.0 Use the_author_meta()
     * @see the_author_meta()
     */
    function the_author_firstname()
    {
    }
    /**
     * Retrieve the last name of the author of the current post.
     *
     * @since 1.5.0
     * @deprecated 2.8.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @return string The author's last name.
     */
    function get_the_author_lastname()
    {
    }
    /**
     * Display the last name of the author of the current post.
     *
     * @since 0.71
     * @deprecated 2.8.0 Use the_author_meta()
     * @see the_author_meta()
     */
    function the_author_lastname()
    {
    }
    /**
     * Retrieve the nickname of the author of the current post.
     *
     * @since 1.5.0
     * @deprecated 2.8.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @return string The author's nickname.
     */
    function get_the_author_nickname()
    {
    }
    /**
     * Display the nickname of the author of the current post.
     *
     * @since 0.71
     * @deprecated 2.8.0 Use the_author_meta()
     * @see the_author_meta()
     */
    function the_author_nickname()
    {
    }
    /**
     * Retrieve the email of the author of the current post.
     *
     * @since 1.5.0
     * @deprecated 2.8.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @return string The author's username.
     */
    function get_the_author_email()
    {
    }
    /**
     * Display the email of the author of the current post.
     *
     * @since 0.71
     * @deprecated 2.8.0 Use the_author_meta()
     * @see the_author_meta()
     */
    function the_author_email()
    {
    }
    /**
     * Retrieve the ICQ number of the author of the current post.
     *
     * @since 1.5.0
     * @deprecated 2.8.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @return string The author's ICQ number.
     */
    function get_the_author_icq()
    {
    }
    /**
     * Display the ICQ number of the author of the current post.
     *
     * @since 0.71
     * @deprecated 2.8.0 Use the_author_meta()
     * @see the_author_meta()
     */
    function the_author_icq()
    {
    }
    /**
     * Retrieve the Yahoo! IM name of the author of the current post.
     *
     * @since 1.5.0
     * @deprecated 2.8.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @return string The author's Yahoo! IM name.
     */
    function get_the_author_yim()
    {
    }
    /**
     * Display the Yahoo! IM name of the author of the current post.
     *
     * @since 0.71
     * @deprecated 2.8.0 Use the_author_meta()
     * @see the_author_meta()
     */
    function the_author_yim()
    {
    }
    /**
     * Retrieve the MSN address of the author of the current post.
     *
     * @since 1.5.0
     * @deprecated 2.8.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @return string The author's MSN address.
     */
    function get_the_author_msn()
    {
    }
    /**
     * Display the MSN address of the author of the current post.
     *
     * @since 0.71
     * @deprecated 2.8.0 Use the_author_meta()
     * @see the_author_meta()
     */
    function the_author_msn()
    {
    }
    /**
     * Retrieve the AIM address of the author of the current post.
     *
     * @since 1.5.0
     * @deprecated 2.8.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @return string The author's AIM address.
     */
    function get_the_author_aim()
    {
    }
    /**
     * Display the AIM address of the author of the current post.
     *
     * @since 0.71
     * @deprecated 2.8.0 Use the_author_meta('aim')
     * @see the_author_meta()
     */
    function the_author_aim()
    {
    }
    /**
     * Retrieve the specified author's preferred display name.
     *
     * @since 1.0.0
     * @deprecated 2.8.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @param int $auth_id The ID of the author.
     * @return string The author's display name.
     */
    function get_author_name($auth_id = \false)
    {
    }
    /**
     * Retrieve the URL to the home page of the author of the current post.
     *
     * @since 1.5.0
     * @deprecated 2.8.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @return string The URL to the author's page.
     */
    function get_the_author_url()
    {
    }
    /**
     * Display the URL to the home page of the author of the current post.
     *
     * @since 0.71
     * @deprecated 2.8.0 Use the_author_meta()
     * @see the_author_meta()
     */
    function the_author_url()
    {
    }
    /**
     * Retrieve the ID of the author of the current post.
     *
     * @since 1.5.0
     * @deprecated 2.8.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @return string|int The author's ID.
     */
    function get_the_author_ID()
    {
    }
    /**
     * Display the ID of the author of the current post.
     *
     * @since 0.71
     * @deprecated 2.8.0 Use the_author_meta()
     * @see the_author_meta()
     */
    function the_author_ID()
    {
    }
    /**
     * Display the post content for the feed.
     *
     * For encoding the HTML or the $encode_html parameter, there are three possible values:
     * - '0' will make urls footnotes and use make_url_footnote().
     * - '1' will encode special characters and automatically display all of the content.
     * - '2' will strip all HTML tags from the content.
     *
     * Also note that you cannot set the amount of words and not set the HTML encoding.
     * If that is the case, then the HTML encoding will default to 2, which will strip
     * all HTML tags.
     *
     * To restrict the amount of words of the content, you can use the cut parameter.
     * If the content is less than the amount, then there won't be any dots added to the end.
     * If there is content left over, then dots will be added and the rest of the content
     * will be removed.
     *
     * @since 0.71
     *
     * @deprecated 2.9.0 Use the_content_feed()
     * @see the_content_feed()
     *
     * @param string $more_link_text Optional. Text to display when more content is available
     *                               but not displayed. Default '(more...)'.
     * @param int    $stripteaser    Optional. Default 0.
     * @param string $more_file      Optional.
     * @param int    $cut            Optional. Amount of words to keep for the content.
     * @param int    $encode_html    Optional. How to encode the content.
     */
    function the_content_rss($more_link_text = '(more...)', $stripteaser = 0, $more_file = '', $cut = 0, $encode_html = 0)
    {
    }
    /**
     * Strip HTML and put links at the bottom of stripped content.
     *
     * Searches for all of the links, strips them out of the content, and places
     * them at the bottom of the content with numbers.
     *
     * @since 0.71
     * @deprecated 2.9.0
     *
     * @param string $content Content to get links.
     * @return string HTML stripped out of content with links at the bottom.
     */
    function make_url_footnote($content)
    {
    }
    /**
     * Retrieve translated string with vertical bar context
     *
     * Quite a few times, there will be collisions with similar translatable text
     * found in more than two places but with different translated context.
     *
     * In order to use the separate contexts, the _c() function is used and the
     * translatable string uses a pipe ('|') which has the context the string is in.
     *
     * When the translated string is returned, it is everything before the pipe, not
     * including the pipe character. If there is no pipe in the translated text then
     * everything is returned.
     *
     * @since 2.2.0
     * @deprecated 2.9.0 Use _x()
     * @see _x()
     *
     * @param string $text Text to translate.
     * @param string $domain Optional. Domain to retrieve the translated text.
     * @return string Translated context string without pipe.
     */
    function _c($text, $domain = 'default')
    {
    }
    /**
     * Translates $text like translate(), but assumes that the text
     * contains a context after its last vertical bar.
     *
     * @since 2.5.0
     * @deprecated 3.0.0 Use _x()
     * @see _x()
     *
     * @param string $text Text to translate.
     * @param string $domain Domain to retrieve the translated text.
     * @return string Translated text.
     */
    function translate_with_context($text, $domain = 'default')
    {
    }
    /**
     * Legacy version of _n(), which supports contexts.
     *
     * Strips everything from the translation after the last bar.
     *
     * @since 2.7.0
     * @deprecated 3.0.0 Use _nx()
     * @see _nx()
     *
     * @param string $single The text to be used if the number is singular.
     * @param string $plural The text to be used if the number is plural.
     * @param int    $number The number to compare against to use either the singular or plural form.
     * @param string $domain Optional. Text domain. Unique identifier for retrieving translated strings.
     *                       Default 'default'.
     * @return string The translated singular or plural form.
     */
    function _nc($single, $plural, $number, $domain = 'default')
    {
    }
    /**
     * Retrieve the plural or single form based on the amount.
     *
     * @since 1.2.0
     * @deprecated 2.8.0 Use _n()
     * @see _n()
     */
    function __ngettext(...$args)
    {
    }
    /**
     * Register plural strings in POT file, but don't translate them.
     *
     * @since 2.5.0
     * @deprecated 2.8.0 Use _n_noop()
     * @see _n_noop()
     */
    function __ngettext_noop(...$args)
    {
    }
    /**
     * Retrieve all autoload options, or all options if no autoloaded ones exist.
     *
     * @since 1.0.0
     * @deprecated 3.0.0 Use wp_load_alloptions())
     * @see wp_load_alloptions()
     *
     * @return array List of all options.
     */
    function get_alloptions()
    {
    }
    /**
     * Retrieve HTML content of attachment image with link.
     *
     * @since 2.0.0
     * @deprecated 2.5.0 Use wp_get_attachment_link()
     * @see wp_get_attachment_link()
     *
     * @param int   $id       Optional. Post ID.
     * @param bool  $fullsize Optional. Whether to use full size image. Default false.
     * @param array $max_dims Optional. Max image dimensions.
     * @param bool $permalink Optional. Whether to include permalink to image. Default false.
     * @return string
     */
    function get_the_attachment_link($id = 0, $fullsize = \false, $max_dims = \false, $permalink = \false)
    {
    }
    /**
     * Retrieve icon URL and Path.
     *
     * @since 2.1.0
     * @deprecated 2.5.0 Use wp_get_attachment_image_src()
     * @see wp_get_attachment_image_src()
     *
     * @param int  $id       Optional. Post ID.
     * @param bool $fullsize Optional. Whether to have full image. Default false.
     * @return array Icon URL and full path to file, respectively.
     */
    function get_attachment_icon_src($id = 0, $fullsize = \false)
    {
    }
    /**
     * Retrieve HTML content of icon attachment image element.
     *
     * @since 2.0.0
     * @deprecated 2.5.0 Use wp_get_attachment_image()
     * @see wp_get_attachment_image()
     *
     * @param int   $id       Optional. Post ID.
     * @param bool  $fullsize Optional. Whether to have full size image. Default false.
     * @param array $max_dims Optional. Dimensions of image.
     * @return string|false HTML content.
     */
    function get_attachment_icon($id = 0, $fullsize = \false, $max_dims = \false)
    {
    }
    /**
     * Retrieve HTML content of image element.
     *
     * @since 2.0.0
     * @deprecated 2.5.0 Use wp_get_attachment_image()
     * @see wp_get_attachment_image()
     *
     * @param int   $id       Optional. Post ID.
     * @param bool  $fullsize Optional. Whether to have full size image. Default false.
     * @param array $max_dims Optional. Dimensions of image.
     * @return string|false
     */
    function get_attachment_innerHTML($id = 0, $fullsize = \false, $max_dims = \false)
    {
    }
    /**
     * Retrieves bookmark data based on ID.
     *
     * @since 2.0.0
     * @deprecated 2.1.0 Use get_bookmark()
     * @see get_bookmark()
     *
     * @param int    $bookmark_id ID of link
     * @param string $output      Optional. Type of output. Accepts OBJECT, ARRAY_N, or ARRAY_A.
     *                            Default OBJECT.
     * @param string $filter      Optional. How to filter the link for output. Accepts 'raw', 'edit',
     *                            'attribute', 'js', 'db', or 'display'. Default 'raw'.
     * @return object|array Bookmark object or array, depending on the type specified by `$output`.
     * @phpstan-param 'raw'|'edit'|'attribute'|'js'|'db'|'display' $filter
     */
    function get_link($bookmark_id, $output = \OBJECT, $filter = 'raw')
    {
    }
    /**
     * Checks and cleans a URL.
     *
     * A number of characters are removed from the URL. If the URL is for displaying
     * (the default behavior) ampersands are also replaced. The 'clean_url' filter
     * is applied to the returned cleaned URL.
     *
     * @since 1.2.0
     * @deprecated 3.0.0 Use esc_url()
     * @see esc_url()
     *
     * @param string $url The URL to be cleaned.
     * @param array $protocols Optional. An array of acceptable protocols.
     * @param string $context Optional. How the URL will be used. Default is 'display'.
     * @return string The cleaned $url after the {@see 'clean_url'} filter is applied.
     */
    function clean_url($url, $protocols = \null, $context = 'display')
    {
    }
    /**
     * Escape single quotes, specialchar double quotes, and fix line endings.
     *
     * The filter {@see 'js_escape'} is also applied by esc_js().
     *
     * @since 2.0.4
     * @deprecated 2.8.0 Use esc_js()
     * @see esc_js()
     *
     * @param string $text The text to be escaped.
     * @return string Escaped text.
     */
    function js_escape($text)
    {
    }
    /**
     * Legacy escaping for HTML blocks.
     *
     * @deprecated 2.8.0 Use esc_html()
     * @see esc_html()
     *
     * @param string       $text          Text to escape.
     * @param string       $quote_style   Unused.
     * @param false|string $charset       Unused.
     * @param false        $double_encode Whether to double encode. Unused.
     * @return string Escaped `$text`.
     */
    function wp_specialchars($text, $quote_style = \ENT_NOQUOTES, $charset = \false, $double_encode = \false)
    {
    }
    /**
     * Escaping for HTML attributes.
     *
     * @since 2.0.6
     * @deprecated 2.8.0 Use esc_attr()
     * @see esc_attr()
     *
     * @param string $text
     * @return string
     */
    function attribute_escape($text)
    {
    }
    /**
     * Register widget for sidebar with backward compatibility.
     *
     * Allows $name to be an array that accepts either three elements to grab the
     * first element and the third for the name or just uses the first element of
     * the array for the name.
     *
     * Passes to wp_register_sidebar_widget() after argument list and backward
     * compatibility is complete.
     *
     * @since 2.2.0
     * @deprecated 2.8.0 Use wp_register_sidebar_widget()
     * @see wp_register_sidebar_widget()
     *
     * @param string|int $name            Widget ID.
     * @param callable   $output_callback Run when widget is called.
     * @param string     $classname       Optional. Classname widget option. Default empty.
     * @param mixed      ...$params       Widget parameters.
     */
    function register_sidebar_widget($name, $output_callback, $classname = '', ...$params)
    {
    }
    /**
     * Serves as an alias of wp_unregister_sidebar_widget().
     *
     * @since 2.2.0
     * @deprecated 2.8.0 Use wp_unregister_sidebar_widget()
     * @see wp_unregister_sidebar_widget()
     *
     * @param int|string $id Widget ID.
     */
    function unregister_sidebar_widget($id)
    {
    }
    /**
     * Registers widget control callback for customizing options.
     *
     * Allows $name to be an array that accepts either three elements to grab the
     * first element and the third for the name or just uses the first element of
     * the array for the name.
     *
     * Passes to wp_register_widget_control() after the argument list has
     * been compiled.
     *
     * @since 2.2.0
     * @deprecated 2.8.0 Use wp_register_widget_control()
     * @see wp_register_widget_control()
     *
     * @param int|string $name             Sidebar ID.
     * @param callable   $control_callback Widget control callback to display and process form.
     * @param int        $width            Widget width.
     * @param int        $height           Widget height.
     * @param mixed      ...$params        Widget parameters.
     */
    function register_widget_control($name, $control_callback, $width = '', $height = '', ...$params)
    {
    }
    /**
     * Alias of wp_unregister_widget_control().
     *
     * @since 2.2.0
     * @deprecated 2.8.0 Use wp_unregister_widget_control()
     * @see wp_unregister_widget_control()
     *
     * @param int|string $id Widget ID.
     */
    function unregister_widget_control($id)
    {
    }
    /**
     * Remove user meta data.
     *
     * @since 2.0.0
     * @deprecated 3.0.0 Use delete_user_meta()
     * @see delete_user_meta()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $user_id User ID.
     * @param string $meta_key Metadata key.
     * @param mixed $meta_value Optional. Metadata value. Default empty.
     * @return bool True deletion completed and false if user_id is not a number.
     */
    function delete_usermeta($user_id, $meta_key, $meta_value = '')
    {
    }
    /**
     * Retrieve user metadata.
     *
     * If $user_id is not a number, then the function will fail over with a 'false'
     * boolean return value. Other returned values depend on whether there is only
     * one item to be returned, which be that single item type. If there is more
     * than one metadata value, then it will be list of metadata values.
     *
     * @since 2.0.0
     * @deprecated 3.0.0 Use get_user_meta()
     * @see get_user_meta()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $user_id User ID
     * @param string $meta_key Optional. Metadata key. Default empty.
     * @return mixed
     */
    function get_usermeta($user_id, $meta_key = '')
    {
    }
    /**
     * Update metadata of user.
     *
     * There is no need to serialize values, they will be serialized if it is
     * needed. The metadata key can only be a string with underscores. All else will
     * be removed.
     *
     * Will remove the metadata, if the meta value is empty.
     *
     * @since 2.0.0
     * @deprecated 3.0.0 Use update_user_meta()
     * @see update_user_meta()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $user_id User ID
     * @param string $meta_key Metadata key.
     * @param mixed $meta_value Metadata value.
     * @return bool True on successful update, false on failure.
     */
    function update_usermeta($user_id, $meta_key, $meta_value)
    {
    }
    /**
     * Get users for the site.
     *
     * For setups that use the multisite feature. Can be used outside of the
     * multisite feature.
     *
     * @since 2.2.0
     * @deprecated 3.1.0 Use get_users()
     * @see get_users()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $id Site ID.
     * @return array List of users that are part of that site ID
     */
    function get_users_of_blog($id = '')
    {
    }
    /**
     * Enable/disable automatic general feed link outputting.
     *
     * @since 2.8.0
     * @deprecated 3.0.0 Use add_theme_support()
     * @see add_theme_support()
     *
     * @param bool $add Optional. Add or remove links. Default true.
     */
    function automatic_feed_links($add = \true)
    {
    }
    /**
     * Retrieve user data based on field.
     *
     * @since 1.5.0
     * @deprecated 3.0.0 Use get_the_author_meta()
     * @see get_the_author_meta()
     *
     * @param string    $field User meta field.
     * @param false|int $user  Optional. User ID to retrieve the field for. Default false (current user).
     * @return string The author's field from the current author's DB object.
     */
    function get_profile($field, $user = \false)
    {
    }
    /**
     * Retrieves the number of posts a user has written.
     *
     * @since 0.71
     * @deprecated 3.0.0 Use count_user_posts()
     * @see count_user_posts()
     *
     * @param int $userid User to count posts for.
     * @return int Number of posts the given user has written.
     */
    function get_usernumposts($userid)
    {
    }
    /**
     * Callback used to change %uXXXX to &#YYY; syntax
     *
     * @since 2.8.0
     * @access private
     * @deprecated 3.0.0
     *
     * @param array $matches Single Match
     * @return string An HTML entity
     */
    function funky_javascript_callback($matches)
    {
    }
    /**
     * Fixes JavaScript bugs in browsers.
     *
     * Converts unicode characters to HTML numbered entities.
     *
     * @since 1.5.0
     * @deprecated 3.0.0
     *
     * @global $is_macIE
     * @global $is_winIE
     *
     * @param string $text Text to be made safe.
     * @return string Fixed text.
     */
    function funky_javascript_fix($text)
    {
    }
    /**
     * Checks that the taxonomy name exists.
     *
     * @since 2.3.0
     * @deprecated 3.0.0 Use taxonomy_exists()
     * @see taxonomy_exists()
     *
     * @param string $taxonomy Name of taxonomy object
     * @return bool Whether the taxonomy exists.
     */
    function is_taxonomy($taxonomy)
    {
    }
    /**
     * Check if Term exists.
     *
     * @since 2.3.0
     * @deprecated 3.0.0 Use term_exists()
     * @see term_exists()
     *
     * @param int|string $term The term to check
     * @param string $taxonomy The taxonomy name to use
     * @param int $parent ID of parent term under which to confine the exists search.
     * @return mixed Get the term ID or term object, if exists.
     * @phpstan-return ($term is 0 ? 0 : ($term is '' ? null : ($taxonomy is '' ? string|null : array{term_id: string, term_taxonomy_id: string}|null)))
     */
    function is_term($term, $taxonomy = '', $parent = 0)
    {
    }
    /**
     * Determines whether the current admin page is generated by a plugin.
     *
     * Use global $plugin_page and/or get_plugin_page_hookname() hooks.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     * @deprecated 3.1.0
     *
     * @global $plugin_page
     *
     * @return bool
     */
    function is_plugin_page()
    {
    }
    /**
     * Update the categories cache.
     *
     * This function does not appear to be used anymore or does not appear to be
     * needed. It might be a legacy function left over from when there was a need
     * for updating the category cache.
     *
     * @since 1.5.0
     * @deprecated 3.1.0
     *
     * @return bool Always return True
     */
    function update_category_cache()
    {
    }
    /**
     * Check for PHP timezone support
     *
     * @since 2.9.0
     * @deprecated 3.2.0
     *
     * @return bool
     */
    function wp_timezone_supported()
    {
    }
    /**
     * Displays an editor: TinyMCE, HTML, or both.
     *
     * @since 2.1.0
     * @deprecated 3.3.0 Use wp_editor()
     * @see wp_editor()
     *
     * @param string $content       Textarea content.
     * @param string $id            Optional. HTML ID attribute value. Default 'content'.
     * @param string $prev_id       Optional. Unused.
     * @param bool   $media_buttons Optional. Whether to display media buttons. Default true.
     * @param int    $tab_index     Optional. Unused.
     * @param bool   $extended      Optional. Unused.
     */
    function the_editor($content, $id = 'content', $prev_id = 'title', $media_buttons = \true, $tab_index = 2, $extended = \true)
    {
    }
    /**
     * Perform the query to get the $metavalues array(s) needed by _fill_user and _fill_many_users
     *
     * @since 3.0.0
     * @deprecated 3.3.0
     *
     * @param array $ids User ID numbers list.
     * @return array of arrays. The array is indexed by user_id, containing $metavalues object arrays.
     */
    function get_user_metavalues($ids)
    {
    }
    /**
     * Sanitize every user field.
     *
     * If the context is 'raw', then the user object or array will get minimal sanitization of the int fields.
     *
     * @since 2.3.0
     * @deprecated 3.3.0
     *
     * @param object|array $user    The user object or array.
     * @param string       $context Optional. How to sanitize user fields. Default 'display'.
     * @return object|array The now sanitized user object or array (will be the same type as $user).
     */
    function sanitize_user_object($user, $context = 'display')
    {
    }
    /**
     * Get boundary post relational link.
     *
     * Can either be start or end post relational link.
     *
     * @since 2.8.0
     * @deprecated 3.3.0
     *
     * @param string $title               Optional. Link title format. Default '%title'.
     * @param bool   $in_same_cat         Optional. Whether link should be in a same category.
     *                                    Default false.
     * @param string $excluded_categories Optional. Excluded categories IDs. Default empty.
     * @param bool   $start               Optional. Whether to display link to first or last post.
     *                                    Default true.
     * @return string
     */
    function get_boundary_post_rel_link($title = '%title', $in_same_cat = \false, $excluded_categories = '', $start = \true)
    {
    }
    /**
     * Display relational link for the first post.
     *
     * @since 2.8.0
     * @deprecated 3.3.0
     *
     * @param string $title Optional. Link title format.
     * @param bool $in_same_cat Optional. Whether link should be in a same category.
     * @param string $excluded_categories Optional. Excluded categories IDs.
     */
    function start_post_rel_link($title = '%title', $in_same_cat = \false, $excluded_categories = '')
    {
    }
    /**
     * Get site index relational link.
     *
     * @since 2.8.0
     * @deprecated 3.3.0
     *
     * @return string
     */
    function get_index_rel_link()
    {
    }
    /**
     * Display relational link for the site index.
     *
     * @since 2.8.0
     * @deprecated 3.3.0
     */
    function index_rel_link()
    {
    }
    /**
     * Get parent post relational link.
     *
     * @since 2.8.0
     * @deprecated 3.3.0
     *
     * @global WP_Post $post Global post object.
     *
     * @param string $title Optional. Link title format. Default '%title'.
     * @return string
     */
    function get_parent_post_rel_link($title = '%title')
    {
    }
    /**
     * Display relational link for parent item
     *
     * @since 2.8.0
     * @deprecated 3.3.0
     *
     * @param string $title Optional. Link title format. Default '%title'.
     */
    function parent_post_rel_link($title = '%title')
    {
    }
    /**
     * Add the "Dashboard"/"Visit Site" menu.
     *
     * @since 3.2.0
     * @deprecated 3.3.0
     *
     * @param WP_Admin_Bar $wp_admin_bar WP_Admin_Bar instance.
     */
    function wp_admin_bar_dashboard_view_site_menu($wp_admin_bar)
    {
    }
    /**
     * Checks if the current user belong to a given site.
     *
     * @since MU (3.0.0)
     * @deprecated 3.3.0 Use is_user_member_of_blog()
     * @see is_user_member_of_blog()
     *
     * @param int $blog_id Site ID
     * @return bool True if the current users belong to $blog_id, false if not.
     */
    function is_blog_user($blog_id = 0)
    {
    }
    /**
     * Open the file handle for debugging.
     *
     * @since 0.71
     * @deprecated 3.4.0 Use error_log()
     * @see error_log()
     *
     * @link https://www.php.net/manual/en/function.error-log.php
     *
     * @param string $filename File name.
     * @param string $mode     Type of access you required to the stream.
     * @return false Always false.
     */
    function debug_fopen($filename, $mode)
    {
    }
    /**
     * Write contents to the file used for debugging.
     *
     * @since 0.71
     * @deprecated 3.4.0 Use error_log()
     * @see error_log()
     *
     * @link https://www.php.net/manual/en/function.error-log.php
     *
     * @param mixed  $fp      Unused.
     * @param string $message Message to log.
     */
    function debug_fwrite($fp, $message)
    {
    }
    /**
     * Close the debugging file handle.
     *
     * @since 0.71
     * @deprecated 3.4.0 Use error_log()
     * @see error_log()
     *
     * @link https://www.php.net/manual/en/function.error-log.php
     *
     * @param mixed $fp Unused.
     */
    function debug_fclose($fp)
    {
    }
    /**
     * Retrieve list of themes with theme data in theme directory.
     *
     * The theme is broken, if it doesn't have a parent theme and is missing either
     * style.css and, or index.php. If the theme has a parent theme then it is
     * broken, if it is missing style.css; index.php is optional.
     *
     * @since 1.5.0
     * @deprecated 3.4.0 Use wp_get_themes()
     * @see wp_get_themes()
     *
     * @return array Theme list with theme data.
     */
    function get_themes()
    {
    }
    /**
     * Retrieve theme data.
     *
     * @since 1.5.0
     * @deprecated 3.4.0 Use wp_get_theme()
     * @see wp_get_theme()
     *
     * @param string $theme Theme name.
     * @return array|null Null, if theme name does not exist. Theme data, if exists.
     */
    function get_theme($theme)
    {
    }
    /**
     * Retrieve current theme name.
     *
     * @since 1.5.0
     * @deprecated 3.4.0 Use wp_get_theme()
     * @see wp_get_theme()
     *
     * @return string
     */
    function get_current_theme()
    {
    }
    /**
     * Accepts matches array from preg_replace_callback in wpautop() or a string.
     *
     * Ensures that the contents of a `<pre>...</pre>` HTML block are not
     * converted into paragraphs or line breaks.
     *
     * @since 1.2.0
     * @deprecated 3.4.0
     *
     * @param array|string $matches The array or string
     * @return string The pre block without paragraph/line break conversion.
     */
    function clean_pre($matches)
    {
    }
    /**
     * Add callbacks for image header display.
     *
     * @since 2.1.0
     * @deprecated 3.4.0 Use add_theme_support()
     * @see add_theme_support()
     *
     * @param callable $wp_head_callback Call on the {@see 'wp_head'} action.
     * @param callable $admin_head_callback Call on custom header administration screen.
     * @param callable $admin_preview_callback Output a custom header image div on the custom header administration screen. Optional.
     */
    function add_custom_image_header($wp_head_callback, $admin_head_callback, $admin_preview_callback = '')
    {
    }
    /**
     * Remove image header support.
     *
     * @since 3.1.0
     * @deprecated 3.4.0 Use remove_theme_support()
     * @see remove_theme_support()
     *
     * @return null|bool Whether support was removed.
     */
    function remove_custom_image_header()
    {
    }
    /**
     * Add callbacks for background image display.
     *
     * @since 3.0.0
     * @deprecated 3.4.0 Use add_theme_support()
     * @see add_theme_support()
     *
     * @param callable $wp_head_callback Call on the {@see 'wp_head'} action.
     * @param callable $admin_head_callback Call on custom background administration screen.
     * @param callable $admin_preview_callback Output a custom background image div on the custom background administration screen. Optional.
     */
    function add_custom_background($wp_head_callback = '', $admin_head_callback = '', $admin_preview_callback = '')
    {
    }
    /**
     * Remove custom background support.
     *
     * @since 3.1.0
     * @deprecated 3.4.0 Use add_custom_background()
     * @see add_custom_background()
     *
     * @return null|bool Whether support was removed.
     */
    function remove_custom_background()
    {
    }
    /**
     * Retrieve theme data from parsed theme file.
     *
     * @since 1.5.0
     * @deprecated 3.4.0 Use wp_get_theme()
     * @see wp_get_theme()
     *
     * @param string $theme_file Theme file path.
     * @return array Theme data.
     */
    function get_theme_data($theme_file)
    {
    }
    /**
     * Alias of update_post_cache().
     *
     * @see update_post_cache() Posts and pages are the same, alias is intentional
     *
     * @since 1.5.1
     * @deprecated 3.4.0 Use update_post_cache()
     * @see update_post_cache()
     *
     * @param array $pages list of page objects
     */
    function update_page_cache(&$pages)
    {
    }
    /**
     * Will clean the page in the cache.
     *
     * Clean (read: delete) page from cache that matches $id. Will also clean cache
     * associated with 'all_page_ids' and 'get_pages'.
     *
     * @since 2.0.0
     * @deprecated 3.4.0 Use clean_post_cache
     * @see clean_post_cache()
     *
     * @param int $id Page ID to clean
     */
    function clean_page_cache($id)
    {
    }
    /**
     * Retrieve nonce action "Are you sure" message.
     *
     * Deprecated in 3.4.1 and 3.5.0. Backported to 3.3.3.
     *
     * @since 2.0.4
     * @deprecated 3.4.1 Use wp_nonce_ays()
     * @see wp_nonce_ays()
     *
     * @param string $action Nonce action.
     * @return string Are you sure message.
     */
    function wp_explain_nonce($action)
    {
    }
    /**
     * Display "sticky" CSS class, if a post is sticky.
     *
     * @since 2.7.0
     * @deprecated 3.5.0 Use post_class()
     * @see post_class()
     *
     * @param int $post_id An optional post ID.
     */
    function sticky_class($post_id = \null)
    {
    }
    /**
     * Retrieve post ancestors.
     *
     * This is no longer needed as WP_Post lazy-loads the ancestors
     * property with get_post_ancestors().
     *
     * @since 2.3.4
     * @deprecated 3.5.0 Use get_post_ancestors()
     * @see get_post_ancestors()
     *
     * @param WP_Post $post Post object, passed by reference (unused).
     */
    function _get_post_ancestors(&$post)
    {
    }
    /**
     * Load an image from a string, if PHP supports it.
     *
     * @since 2.1.0
     * @deprecated 3.5.0 Use wp_get_image_editor()
     * @see wp_get_image_editor()
     *
     * @param string $file Filename of the image to load.
     * @return resource|GdImage|string The resulting image resource or GdImage instance on success,
     *                                 error string on failure.
     */
    function wp_load_image($file)
    {
    }
    /**
     * Scale down an image to fit a particular size and save a new copy of the image.
     *
     * The PNG transparency will be preserved using the function, as well as the
     * image type. If the file going in is PNG, then the resized image is going to
     * be PNG. The only supported image types are PNG, GIF, and JPEG.
     *
     * Some functionality requires API to exist, so some PHP version may lose out
     * support. This is not the fault of WordPress (where functionality is
     * downgraded, not actual defects), but of your PHP version.
     *
     * @since 2.5.0
     * @deprecated 3.5.0 Use wp_get_image_editor()
     * @see wp_get_image_editor()
     *
     * @param string $file         Image file path.
     * @param int    $max_w        Maximum width to resize to.
     * @param int    $max_h        Maximum height to resize to.
     * @param bool   $crop         Optional. Whether to crop image or resize. Default false.
     * @param string $suffix       Optional. File suffix. Default null.
     * @param string $dest_path    Optional. New image file path. Default null.
     * @param int    $jpeg_quality Optional. Image quality percentage. Default 90.
     * @return mixed WP_Error on failure. String with new destination path.
     */
    function image_resize($file, $max_w, $max_h, $crop = \false, $suffix = \null, $dest_path = \null, $jpeg_quality = 90)
    {
    }
    /**
     * Retrieve a single post, based on post ID.
     *
     * Has categories in 'post_category' property or key. Has tags in 'tags_input'
     * property or key.
     *
     * @since 1.0.0
     * @deprecated 3.5.0 Use get_post()
     * @see get_post()
     *
     * @param int $postid Post ID.
     * @param string $mode How to return result, either OBJECT, ARRAY_N, or ARRAY_A.
     * @return WP_Post|null Post object or array holding post contents and information
     */
    function wp_get_single_post($postid = 0, $mode = \OBJECT)
    {
    }
    /**
     * Check that the user login name and password is correct.
     *
     * @since 0.71
     * @deprecated 3.5.0 Use wp_authenticate()
     * @see wp_authenticate()
     *
     * @param string $user_login User name.
     * @param string $user_pass User password.
     * @return bool False if does not authenticate, true if username and password authenticates.
     */
    function user_pass_ok($user_login, $user_pass)
    {
    }
    /**
     * Callback formerly fired on the save_post hook. No longer needed.
     *
     * @since 2.3.0
     * @deprecated 3.5.0
     */
    function _save_post_hook()
    {
    }
    /**
     * Check if the installed version of GD supports particular image type
     *
     * @since 2.9.0
     * @deprecated 3.5.0 Use wp_image_editor_supports()
     * @see wp_image_editor_supports()
     *
     * @param string $mime_type
     * @return bool
     */
    function gd_edit_image_support($mime_type)
    {
    }
    /**
     * Converts an integer byte value to a shorthand byte value.
     *
     * @since 2.3.0
     * @deprecated 3.6.0 Use size_format()
     * @see size_format()
     *
     * @param int $bytes An integer byte value.
     * @return string A shorthand byte value.
     */
    function wp_convert_bytes_to_hr($bytes)
    {
    }
    /**
     * Formerly used internally to tidy up the search terms.
     *
     * @since 2.9.0
     * @access private
     * @deprecated 3.7.0
     *
     * @param string $t Search terms to "tidy", e.g. trim.
     * @return string Trimmed search terms.
     */
    function _search_terms_tidy($t)
    {
    }
    /**
     * Determine if TinyMCE is available.
     *
     * Checks to see if the user has deleted the tinymce files to slim down
     * their WordPress installation.
     *
     * @since 2.1.0
     * @deprecated 3.9.0
     *
     * @return bool Whether TinyMCE exists.
     */
    function rich_edit_exists()
    {
    }
    /**
     * Old callback for tag link tooltips.
     *
     * @since 2.7.0
     * @access private
     * @deprecated 3.9.0
     *
     * @param int $count Number of topics.
     * @return int Number of topics.
     */
    function default_topic_count_text($count)
    {
    }
    /**
     * Formerly used to escape strings before inserting into the DB.
     *
     * Has not performed this function for many, many years. Use wpdb::prepare() instead.
     *
     * @since 0.71
     * @deprecated 3.9.0
     *
     * @param string $content The text to format.
     * @return string The very same text.
     */
    function format_to_post($content)
    {
    }
    /**
     * Formerly used to escape strings before searching the DB. It was poorly documented and never worked as described.
     *
     * @since 2.5.0
     * @deprecated 4.0.0 Use wpdb::esc_like()
     * @see wpdb::esc_like()
     *
     * @param string $text The text to be escaped.
     * @return string text, safe for inclusion in LIKE query.
     */
    function like_escape($text)
    {
    }
    /**
     * Determines if the URL can be accessed over SSL.
     *
     * Determines if the URL can be accessed over SSL by using the WordPress HTTP API to access
     * the URL using https as the scheme.
     *
     * @since 2.5.0
     * @deprecated 4.0.0
     *
     * @param string $url The URL to test.
     * @return bool Whether SSL access is available.
     */
    function url_is_accessable_via_ssl($url)
    {
    }
    /**
     * Start preview theme output buffer.
     *
     * Will only perform task if the user has permissions and template and preview
     * query variables exist.
     *
     * @since 2.6.0
     * @deprecated 4.3.0
     */
    function preview_theme()
    {
    }
    /**
     * Private function to modify the current template when previewing a theme
     *
     * @since 2.9.0
     * @deprecated 4.3.0
     * @access private
     *
     * @return string
     */
    function _preview_theme_template_filter()
    {
    }
    /**
     * Private function to modify the current stylesheet when previewing a theme
     *
     * @since 2.9.0
     * @deprecated 4.3.0
     * @access private
     *
     * @return string
     */
    function _preview_theme_stylesheet_filter()
    {
    }
    /**
     * Callback function for ob_start() to capture all links in the theme.
     *
     * @since 2.6.0
     * @deprecated 4.3.0
     * @access private
     *
     * @param string $content
     * @return string
     */
    function preview_theme_ob_filter($content)
    {
    }
    /**
     * Manipulates preview theme links in order to control and maintain location.
     *
     * Callback function for preg_replace_callback() to accept and filter matches.
     *
     * @since 2.6.0
     * @deprecated 4.3.0
     * @access private
     *
     * @param array $matches
     * @return string
     */
    function preview_theme_ob_filter_callback($matches)
    {
    }
    /**
     * Formats text for the rich text editor.
     *
     * The {@see 'richedit_pre'} filter is applied here. If `$text` is empty the filter will
     * be applied to an empty string.
     *
     * @since 2.0.0
     * @deprecated 4.3.0 Use format_for_editor()
     * @see format_for_editor()
     *
     * @param string $text The text to be formatted.
     * @return string The formatted text after filter is applied.
     */
    function wp_richedit_pre($text)
    {
    }
    /**
     * Formats text for the HTML editor.
     *
     * Unless $output is empty it will pass through htmlspecialchars before the
     * {@see 'htmledit_pre'} filter is applied.
     *
     * @since 2.5.0
     * @deprecated 4.3.0 Use format_for_editor()
     * @see format_for_editor()
     *
     * @param string $output The text to be formatted.
     * @return string Formatted text after filter applied.
     */
    function wp_htmledit_pre($output)
    {
    }
    /**
     * Retrieve permalink from post ID.
     *
     * @since 1.0.0
     * @deprecated 4.4.0 Use get_permalink()
     * @see get_permalink()
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return string|false
     */
    function post_permalink($post = 0)
    {
    }
    /**
     * Perform a HTTP HEAD or GET request.
     *
     * If $file_path is a writable filename, this will do a GET request and write
     * the file to that path.
     *
     * @since 2.5.0
     * @deprecated 4.4.0 Use WP_Http
     * @see WP_Http
     *
     * @param string      $url       URL to fetch.
     * @param string|bool $file_path Optional. File path to write request to. Default false.
     * @param int         $red       Optional. The number of Redirects followed, Upon 5 being hit,
     *                               returns false. Default 1.
     * @return \WpOrg\Requests\Utility\CaseInsensitiveDictionary|false Headers on success, false on failure.
     */
    function wp_get_http($url, $file_path = \false, $red = 1)
    {
    }
    /**
     * Whether SSL login should be forced.
     *
     * @since 2.6.0
     * @deprecated 4.4.0 Use force_ssl_admin()
     * @see force_ssl_admin()
     *
     * @param string|bool $force Optional Whether to force SSL login. Default null.
     * @return bool True if forced, false if not forced.
     */
    function force_ssl_login($force = \null)
    {
    }
    /**
     * Retrieve path of comment popup template in current or parent template.
     *
     * @since 1.5.0
     * @deprecated 4.5.0
     *
     * @return string Full path to comments popup template file.
     */
    function get_comments_popup_template()
    {
    }
    /**
     * Determines whether the current URL is within the comments popup window.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     * @deprecated 4.5.0
     *
     * @return false Always returns false.
     */
    function is_comments_popup()
    {
    }
    /**
     * Display the JS popup script to show a comment.
     *
     * @since 0.71
     * @deprecated 4.5.0
     */
    function comments_popup_script()
    {
    }
    /**
     * Adds element attributes to open links in new tabs.
     *
     * @since 0.71
     * @deprecated 4.5.0
     *
     * @param string $text Content to replace links to open in a new tab.
     * @return string Content that has filtered links.
     */
    function popuplinks($text)
    {
    }
    /**
     * The Google Video embed handler callback.
     *
     * Deprecated function that previously assisted in turning Google Video URLs
     * into embeds but that service has since been shut down.
     *
     * @since 2.9.0
     * @deprecated 4.6.0
     *
     * @return string An empty string.
     */
    function wp_embed_handler_googlevideo($matches, $attr, $url, $rawattr)
    {
    }
    /**
     * Retrieve path of paged template in current or parent template.
     *
     * @since 1.5.0
     * @deprecated 4.7.0 The paged.php template is no longer part of the theme template hierarchy.
     *
     * @return string Full path to paged template file.
     */
    function get_paged_template()
    {
    }
    /**
     * Removes the HTML JavaScript entities found in early versions of Netscape 4.
     *
     * Previously, this function was pulled in from the original
     * import of kses and removed a specific vulnerability only
     * existent in early version of Netscape 4. However, this
     * vulnerability never affected any other browsers and can
     * be considered safe for the modern web.
     *
     * The regular expression which sanitized this vulnerability
     * has been removed in consideration of the performance and
     * energy demands it placed, now merely passing through its
     * input to the return.
     *
     * @since 1.0.0
     * @deprecated 4.7.0 Officially dropped security support for Netscape 4.
     *
     * @param string $content
     * @return string
     */
    function wp_kses_js_entities($content)
    {
    }
    /**
     * Sort categories by ID.
     *
     * Used by usort() as a callback, should not be used directly. Can actually be
     * used to sort any term object.
     *
     * @since 2.3.0
     * @deprecated 4.7.0 Use wp_list_sort()
     * @access private
     *
     * @param object $a
     * @param object $b
     * @return int
     */
    function _usort_terms_by_ID($a, $b)
    {
    }
    /**
     * Sort categories by name.
     *
     * Used by usort() as a callback, should not be used directly. Can actually be
     * used to sort any term object.
     *
     * @since 2.3.0
     * @deprecated 4.7.0 Use wp_list_sort()
     * @access private
     *
     * @param object $a
     * @param object $b
     * @return int
     */
    function _usort_terms_by_name($a, $b)
    {
    }
    /**
     * Sort menu items by the desired key.
     *
     * @since 3.0.0
     * @deprecated 4.7.0 Use wp_list_sort()
     * @access private
     *
     * @global string $_menu_item_sort_prop
     *
     * @param object $a The first object to compare
     * @param object $b The second object to compare
     * @return int -1, 0, or 1 if $a is considered to be respectively less than, equal to, or greater than $b.
     */
    function _sort_nav_menu_items($a, $b)
    {
    }
    /**
     * Retrieves the Press This bookmarklet link.
     *
     * @since 2.6.0
     * @deprecated 4.9.0
     * @return string
     */
    function get_shortcut_link()
    {
    }
    /**
     * Ajax handler for saving a post from Press This.
     *
     * @since 4.2.0
     * @deprecated 4.9.0
     */
    function wp_ajax_press_this_save_post()
    {
    }
    /**
     * Ajax handler for creating new category from Press This.
     *
     * @since 4.2.0
     * @deprecated 4.9.0
     */
    function wp_ajax_press_this_add_category()
    {
    }
    /**
     * Return the user request object for the specified request ID.
     *
     * @since 4.9.6
     * @deprecated 5.4.0 Use wp_get_user_request()
     * @see wp_get_user_request()
     *
     * @param int $request_id The ID of the user request.
     * @return WP_User_Request|false
     */
    function wp_get_user_request_data($request_id)
    {
    }
    /**
     * Filters 'img' elements in post content to add 'srcset' and 'sizes' attributes.
     *
     * @since 4.4.0
     * @deprecated 5.5.0
     *
     * @see wp_image_add_srcset_and_sizes()
     *
     * @param string $content The raw post content to be filtered.
     * @return string Converted content with 'srcset' and 'sizes' attributes added to images.
     */
    function wp_make_content_images_responsive($content)
    {
    }
    /**
     * Turn register globals off.
     *
     * @since 2.1.0
     * @access private
     * @deprecated 5.5.0
     */
    function wp_unregister_GLOBALS()
    {
    }
    /**
     * Does comment contain disallowed characters or words.
     *
     * @since 1.5.0
     * @deprecated 5.5.0 Use wp_check_comment_disallowed_list() instead.
     *                   Please consider writing more inclusive code.
     *
     * @param string $author The author of the comment
     * @param string $email The email of the comment
     * @param string $url The url used in the comment
     * @param string $comment The comment content
     * @param string $user_ip The comment author's IP address
     * @param string $user_agent The author's browser user agent
     * @return bool True if comment contains disallowed content, false if comment does not
     */
    function wp_blacklist_check($author, $email, $url, $comment, $user_ip, $user_agent)
    {
    }
    /**
     * Filters out `register_meta()` args based on an allowed list.
     *
     * `register_meta()` args may change over time, so requiring the allowed list
     * to be explicitly turned off is a warranty seal of sorts.
     *
     * @access private
     * @since 4.6.0
     * @deprecated 5.5.0 Use _wp_register_meta_args_allowed_list() instead.
     *                   Please consider writing more inclusive code.
     *
     * @param array $args         Arguments from `register_meta()`.
     * @param array $default_args Default arguments for `register_meta()`.
     * @return array Filtered arguments.
     */
    function _wp_register_meta_args_whitelist($args, $default_args)
    {
    }
    /**
     * Adds an array of options to the list of allowed options.
     *
     * @since 2.7.0
     * @deprecated 5.5.0 Use add_allowed_options() instead.
     *                   Please consider writing more inclusive code.
     *
     * @param array        $new_options
     * @param string|array $options
     * @return array
     */
    function add_option_whitelist($new_options, $options = '')
    {
    }
    /**
     * Removes a list of options from the allowed options list.
     *
     * @since 2.7.0
     * @deprecated 5.5.0 Use remove_allowed_options() instead.
     *                   Please consider writing more inclusive code.
     *
     * @param array        $del_options
     * @param string|array $options
     * @return array
     */
    function remove_option_whitelist($del_options, $options = '')
    {
    }
    /**
     * Adds slashes to only string values in an array of values.
     *
     * This should be used when preparing data for core APIs that expect slashed data.
     * This should not be used to escape data going directly into an SQL query.
     *
     * @since 5.3.0
     * @deprecated 5.6.0 Use wp_slash()
     *
     * @see wp_slash()
     *
     * @param mixed $value Scalar or array of scalars.
     * @return mixed Slashes $value
     */
    function wp_slash_strings_only($value)
    {
    }
    /**
     * Adds slashes only if the provided value is a string.
     *
     * @since 5.3.0
     * @deprecated 5.6.0
     *
     * @see wp_slash()
     *
     * @param mixed $value
     * @return mixed
     */
    function addslashes_strings_only($value)
    {
    }
    /**
     * Displays a `noindex` meta tag if required by the blog configuration.
     *
     * If a blog is marked as not being public then the `noindex` meta tag will be
     * output to tell web robots not to index the page content.
     *
     * Typical usage is as a {@see 'wp_head'} callback:
     *
     *     add_action( 'wp_head', 'noindex' );
     *
     * @see wp_no_robots()
     *
     * @since 2.1.0
     * @deprecated 5.7.0 Use wp_robots_noindex() instead on 'wp_robots' filter.
     */
    function noindex()
    {
    }
    /**
     * Display a `noindex` meta tag.
     *
     * Outputs a `noindex` meta tag that tells web robots not to index the page content.
     *
     * Typical usage is as a {@see 'wp_head'} callback:
     *
     *     add_action( 'wp_head', 'wp_no_robots' );
     *
     * @since 3.3.0
     * @since 5.3.0 Echo `noindex,nofollow` if search engine visibility is discouraged.
     * @deprecated 5.7.0 Use wp_robots_no_robots() instead on 'wp_robots' filter.
     * @phpstan-return void
     */
    function wp_no_robots()
    {
    }
    /**
     * Display a `noindex,noarchive` meta tag and referrer `strict-origin-when-cross-origin` meta tag.
     *
     * Outputs a `noindex,noarchive` meta tag that tells web robots not to index or cache the page content.
     * Outputs a referrer `strict-origin-when-cross-origin` meta tag that tells the browser not to send
     * the full URL as a referrer to other sites when cross-origin assets are loaded.
     *
     * Typical usage is as a {@see 'wp_head'} callback:
     *
     *     add_action( 'wp_head', 'wp_sensitive_page_meta' );
     *
     * @since 5.0.1
     * @deprecated 5.7.0 Use wp_robots_sensitive_page() instead on 'wp_robots' filter
     *                   and wp_strict_cross_origin_referrer() on 'wp_head' action.
     *
     * @see wp_robots_sensitive_page()
     */
    function wp_sensitive_page_meta()
    {
    }
    /**
     * Render inner blocks from the `core/columns` block for generating an excerpt.
     *
     * @since 5.2.0
     * @access private
     * @deprecated 5.8.0 Use _excerpt_render_inner_blocks() introduced in 5.8.0.
     *
     * @see _excerpt_render_inner_blocks()
     *
     * @param array $columns        The parsed columns block.
     * @param array $allowed_blocks The list of allowed inner blocks.
     * @return string The rendered inner blocks.
     */
    function _excerpt_render_inner_columns_blocks($columns, $allowed_blocks)
    {
    }
    /**
     * Renders the duotone filter SVG and returns the CSS filter property to
     * reference the rendered SVG.
     *
     * @since 5.9.0
     * @deprecated 5.9.1 Use wp_get_duotone_filter_property() introduced in 5.9.1.
     *
     * @see wp_get_duotone_filter_property()
     *
     * @param array $preset Duotone preset value as seen in theme.json.
     * @return string Duotone CSS filter property.
     */
    function wp_render_duotone_filter_preset($preset)
    {
    }
    /**
     * Checks whether serialization of the current block's border properties should occur.
     *
     * @since 5.8.0
     * @access private
     * @deprecated 6.0.0 Use wp_should_skip_block_supports_serialization() introduced in 6.0.0.
     *
     * @see wp_should_skip_block_supports_serialization()
     *
     * @param WP_Block_Type $block_type Block type.
     * @return bool Whether serialization of the current block's border properties
     *              should occur.
     */
    function wp_skip_border_serialization($block_type)
    {
    }
    /**
     * Checks whether serialization of the current block's dimensions properties should occur.
     *
     * @since 5.9.0
     * @access private
     * @deprecated 6.0.0 Use wp_should_skip_block_supports_serialization() introduced in 6.0.0.
     *
     * @see wp_should_skip_block_supports_serialization()
     *
     * @param WP_Block_type $block_type Block type.
     * @return bool Whether to serialize spacing support styles & classes.
     */
    function wp_skip_dimensions_serialization($block_type)
    {
    }
    /**
     * Checks whether serialization of the current block's spacing properties should occur.
     *
     * @since 5.9.0
     * @access private
     * @deprecated 6.0.0 Use wp_should_skip_block_supports_serialization() introduced in 6.0.0.
     *
     * @see wp_should_skip_block_supports_serialization()
     *
     * @param WP_Block_Type $block_type Block type.
     * @return bool Whether to serialize spacing support styles & classes.
     */
    function wp_skip_spacing_serialization($block_type)
    {
    }
    /**
     * Inject the block editor assets that need to be loaded into the editor's iframe as an inline script.
     *
     * @since 5.8.0
     * @deprecated 6.0.0
     */
    function wp_add_iframed_editor_assets_html()
    {
    }
    /**
     * Retrieves thumbnail for an attachment.
     * Note that this works only for the (very) old image metadata style where 'thumb' was set,
     * and the 'sizes' array did not exist. This function returns false for the newer image metadata style
     * despite that 'thumbnail' is present in the 'sizes' array.
     *
     * @since 2.1.0
     * @deprecated 6.1.0
     *
     * @param int $post_id Optional. Attachment ID. Default is the ID of the global `$post`.
     * @return string|false Thumbnail file path on success, false on failure.
     */
    function wp_get_attachment_thumb_file($post_id = 0)
    {
    }
    /**
     * Gets the path to a translation file for loading a textdomain just in time.
     *
     * Caches the retrieved results internally.
     *
     * @since 4.7.0
     * @deprecated 6.1.0
     * @access private
     *
     * @see _load_textdomain_just_in_time()
     *
     * @param string $domain Text domain. Unique identifier for retrieving translated strings.
     * @param bool   $reset  Whether to reset the internal cache. Used by the switch to locale functionality.
     * @return string|false The path to the translation file or false if no translation file was found.
     */
    function _get_path_to_translation($domain, $reset = \false)
    {
    }
    /**
     * Gets the path to a translation file in the languages directory for the current locale.
     *
     * Holds a cached list of available .mo files to improve performance.
     *
     * @since 4.7.0
     * @deprecated 6.1.0
     * @access private
     *
     * @see _get_path_to_translation()
     *
     * @param string $domain Text domain. Unique identifier for retrieving translated strings.
     * @return string|false The path to the translation file or false if no translation file was found.
     */
    function _get_path_to_translation_from_lang_dir($domain)
    {
    }
    /**
     * Allows multiple block styles.
     *
     * @since 5.9.0
     * @deprecated 6.1.0
     *
     * @param array $metadata Metadata for registering a block type.
     * @return array Metadata for registering a block type.
     */
    function _wp_multiple_block_styles($metadata)
    {
    }
    /**
     * Generates an inline style for a typography feature e.g. text decoration,
     * text transform, and font style.
     *
     * @since 5.8.0
     * @access private
     * @deprecated 6.1.0 Use wp_style_engine_get_styles() introduced in 6.1.0.
     *
     * @see wp_style_engine_get_styles()
     *
     * @param array  $attributes   Block's attributes.
     * @param string $feature      Key for the feature within the typography styles.
     * @param string $css_property Slug for the CSS property the inline style sets.
     * @return string CSS inline style.
     */
    function wp_typography_get_css_variable_inline_style($attributes, $feature, $css_property)
    {
    }
    /**
     * Determines whether global terms are enabled.
     *
     * @since 3.0.0
     * @since 6.1.0 This function now always returns false.
     * @deprecated 6.1.0
     *
     * @return bool Always returns false.
     */
    function global_terms_enabled()
    {
    }
    /**
     * Filter the SQL clauses of an attachment query to include filenames.
     *
     * @since 4.7.0
     * @deprecated 6.0.3
     * @access private
     *
     * @param array $clauses An array including WHERE, GROUP BY, JOIN, ORDER BY,
     *                       DISTINCT, fields (SELECT), and LIMITS clauses.
     * @return array The unmodified clauses.
     */
    function _filter_query_attachment_filenames($clauses)
    {
    }
    /**
     * Retrieves a page given its title.
     *
     * If more than one post uses the same title, the post with the smallest ID will be returned.
     * Be careful: in case of more than one post having the same title, it will check the oldest
     * publication date, not the smallest ID.
     *
     * Because this function uses the MySQL '=' comparison, $page_title will usually be matched
     * as case-insensitive with default collation.
     *
     * @since 2.1.0
     * @since 3.0.0 The `$post_type` parameter was added.
     * @deprecated 6.2.0 Use WP_Query.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string       $page_title Page title.
     * @param string       $output     Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
     *                                 correspond to a WP_Post object, an associative array, or a numeric array,
     *                                 respectively. Default OBJECT.
     * @param string|array $post_type  Optional. Post type or array of post types. Default 'page'.
     * @return WP_Post|array|null WP_Post (or array) on success, or null on failure.
     */
    function get_page_by_title($page_title, $output = \OBJECT, $post_type = 'page')
    {
    }
    /**
     * Returns the correct template for the site's home page.
     *
     * @access private
     * @since 6.0.0
     * @deprecated 6.2.0 Site Editor's server-side redirect for missing postType and postId
     *                   query args is removed. Thus, this function is no longer used.
     *
     * @return array|null A template object, or null if none could be found.
     */
    function _resolve_home_block_template()
    {
    }
    /**
     * Displays the link to the Windows Live Writer manifest file.
     *
     * @link https://msdn.microsoft.com/en-us/library/bb463265.aspx
     * @since 2.3.1
     * @deprecated 6.3.0 WLW manifest is no longer in use and no longer included in core,
     *                   so the output from this function is removed.
     */
    function wlwmanifest_link()
    {
    }
    /**
     * Queues comments for metadata lazy-loading.
     *
     * @since 4.5.0
     * @deprecated 6.3.0 Use wp_lazyload_comment_meta() instead.
     *
     * @param WP_Comment[] $comments Array of comment objects.
     */
    function wp_queue_comments_for_comment_meta_lazyload($comments)
    {
    }
    /**
     * Gets the default value to use for a `loading` attribute on an element.
     *
     * This function should only be called for a tag and context if lazy-loading is generally enabled.
     *
     * The function usually returns 'lazy', but uses certain heuristics to guess whether the current element is likely to
     * appear above the fold, in which case it returns a boolean `false`, which will lead to the `loading` attribute being
     * omitted on the element. The purpose of this refinement is to avoid lazy-loading elements that are within the initial
     * viewport, which can have a negative performance impact.
     *
     * Under the hood, the function uses {@see wp_increase_content_media_count()} every time it is called for an element
     * within the main content. If the element is the very first content element, the `loading` attribute will be omitted.
     * This default threshold of 3 content elements to omit the `loading` attribute for can be customized using the
     * {@see 'wp_omit_loading_attr_threshold'} filter.
     *
     * @since 5.9.0
     * @deprecated 6.3.0 Use wp_get_loading_optimization_attributes() instead.
     * @see wp_get_loading_optimization_attributes()
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string $context Context for the element for which the `loading` attribute value is requested.
     * @return string|bool The default `loading` attribute value. Either 'lazy', 'eager', or a boolean `false`, to indicate
     *                     that the `loading` attribute should be skipped.
     */
    function wp_get_loading_attr_default($context)
    {
    }
    /**
     * Adds `loading` attribute to an `img` HTML tag.
     *
     * @since 5.5.0
     * @deprecated 6.3.0 Use wp_img_tag_add_loading_optimization_attrs() instead.
     * @see wp_img_tag_add_loading_optimization_attrs()
     *
     * @param string $image   The HTML `img` tag where the attribute should be added.
     * @param string $context Additional context to pass to the filters.
     * @return string Converted `img` tag with `loading` attribute added.
     */
    function wp_img_tag_add_loading_attr($image, $context)
    {
    }
    /**
     * Takes input from [0, n] and returns it as [0, 1].
     *
     * Direct port of TinyColor's function, lightly simplified to maintain
     * consistency with TinyColor.
     *
     * @link https://github.com/bgrins/TinyColor
     *
     * @since 5.8.0
     * @deprecated 6.3.0
     *
     * @access private
     *
     * @param mixed $n   Number of unknown type.
     * @param int   $max Upper value of the range to bound to.
     * @return float Value in the range [0, 1].
     */
    function wp_tinycolor_bound01($n, $max)
    {
    }
    /**
     * Direct port of tinycolor's boundAlpha function to maintain consistency with
     * how tinycolor works.
     *
     * @link https://github.com/bgrins/TinyColor
     *
     * @since 5.9.0
     * @deprecated 6.3.0
     *
     * @access private
     *
     * @param mixed $n Number of unknown type.
     * @return float Value in the range [0,1].
     */
    function _wp_tinycolor_bound_alpha($n)
    {
    }
    /**
     * Rounds and converts values of an RGB object.
     *
     * Direct port of TinyColor's function, lightly simplified to maintain
     * consistency with TinyColor.
     *
     * @link https://github.com/bgrins/TinyColor
     *
     * @since 5.8.0
     * @deprecated 6.3.0
     *
     * @access private
     *
     * @param array $rgb_color RGB object.
     * @return array Rounded and converted RGB object.
     */
    function wp_tinycolor_rgb_to_rgb($rgb_color)
    {
    }
    /**
     * Helper function for hsl to rgb conversion.
     *
     * Direct port of TinyColor's function, lightly simplified to maintain
     * consistency with TinyColor.
     *
     * @link https://github.com/bgrins/TinyColor
     *
     * @since 5.8.0
     * @deprecated 6.3.0
     *
     * @access private
     *
     * @param float $p first component.
     * @param float $q second component.
     * @param float $t third component.
     * @return float R, G, or B component.
     */
    function wp_tinycolor_hue_to_rgb($p, $q, $t)
    {
    }
    /**
     * Converts an HSL object to an RGB object with converted and rounded values.
     *
     * Direct port of TinyColor's function, lightly simplified to maintain
     * consistency with TinyColor.
     *
     * @link https://github.com/bgrins/TinyColor
     *
     * @since 5.8.0
     * @deprecated 6.3.0
     *
     * @access private
     *
     * @param array $hsl_color HSL object.
     * @return array Rounded and converted RGB object.
     */
    function wp_tinycolor_hsl_to_rgb($hsl_color)
    {
    }
    /**
     * Parses hex, hsl, and rgb CSS strings using the same regex as TinyColor v1.4.2
     * used in the JavaScript. Only colors output from react-color are implemented.
     *
     * Direct port of TinyColor's function, lightly simplified to maintain
     * consistency with TinyColor.
     *
     * @link https://github.com/bgrins/TinyColor
     * @link https://github.com/casesandberg/react-color/
     *
     * @since 5.8.0
     * @since 5.9.0 Added alpha processing.
     * @deprecated 6.3.0
     *
     * @access private
     *
     * @param string $color_str CSS color string.
     * @return array RGB object.
     */
    function wp_tinycolor_string_to_rgb($color_str)
    {
    }
    /**
     * Returns the prefixed id for the duotone filter for use as a CSS id.
     *
     * @since 5.9.1
     * @deprecated 6.3.0
     *
     * @access private
     *
     * @param array $preset Duotone preset value as seen in theme.json.
     * @return string Duotone filter CSS id.
     */
    function wp_get_duotone_filter_id($preset)
    {
    }
    /**
     * Returns the CSS filter property url to reference the rendered SVG.
     *
     * @since 5.9.0
     * @since 6.1.0 Allow unset for preset colors.
     * @deprecated 6.3.0
     *
     * @access private
     *
     * @param array $preset Duotone preset value as seen in theme.json.
     * @return string Duotone CSS filter property url value.
     */
    function wp_get_duotone_filter_property($preset)
    {
    }
    /**
     * Returns the duotone filter SVG string for the preset.
     *
     * @since 5.9.1
     * @deprecated 6.3.0
     *
     * @access private
     *
     * @param array $preset Duotone preset value as seen in theme.json.
     * @return string Duotone SVG filter.
     */
    function wp_get_duotone_filter_svg($preset)
    {
    }
    /**
     * Registers the style and colors block attributes for block types that support it.
     *
     * @since 5.8.0
     * @deprecated 6.3.0 Use WP_Duotone::register_duotone_support() instead.
     *
     * @access private
     *
     * @param WP_Block_Type $block_type Block Type.
     */
    function wp_register_duotone_support($block_type)
    {
    }
    /**
     * Renders out the duotone stylesheet and SVG.
     *
     * @since 5.8.0
     * @since 6.1.0 Allow unset for preset colors.
     * @deprecated 6.3.0 Use WP_Duotone::render_duotone_support() instead.
     *
     * @access private
     *
     * @param string $block_content Rendered block content.
     * @param array  $block         Block object.
     * @return string Filtered block content.
     */
    function wp_render_duotone_support($block_content, $block)
    {
    }
    /**
     * Returns a string containing the SVGs to be referenced as filters (duotone).
     *
     * @since 5.9.1
     * @deprecated 6.3.0 SVG generation is handled on a per-block basis in block supports.
     *
     * @return string
     */
    function wp_get_global_styles_svg_filters()
    {
    }
    /**
     * Renders the SVG filters supplied by theme.json.
     *
     * Note that this doesn't render the per-block user-defined
     * filters which are handled by wp_render_duotone_support,
     * but it should be rendered before the filtered content
     * in the body to satisfy Safari's rendering quirks.
     *
     * @since 5.9.1
     * @deprecated 6.3.0 SVG generation is handled on a per-block basis in block supports.
     * @phpstan-return void
     */
    function wp_global_styles_render_svg_filters()
    {
    }
    /**
     * Build an array with CSS classes and inline styles defining the colors
     * which will be applied to the navigation markup in the front-end.
     *
     * @since 5.9.0
     * @deprecated 6.3.0 This was removed from the Navigation Submenu block in favour of `wp_apply_colors_support()`.
     *                   `wp_apply_colors_support()` returns an array with similar class and style values,
     *                   but with different keys: `class` and `style`.
     *
     * @param  array $context     Navigation block context.
     * @param  array $attributes  Block attributes.
     * @param  bool  $is_sub_menu Whether the block is a sub-menu.
     * @return array Colors CSS classes and inline styles.
     */
    function block_core_navigation_submenu_build_css_colors($context, $attributes, $is_sub_menu = \false)
    {
    }
    /**
     * Runs the theme.json webfonts handler.
     *
     * Using `WP_Theme_JSON_Resolver`, it gets the fonts defined
     * in the `theme.json` for the current selection and style
     * variations, validates the font-face properties, generates
     * the '@font-face' style declarations, and then enqueues the
     * styles for both the editor and front-end.
     *
     * Design Notes:
     * This is not a public API, but rather an internal handler.
     * A future public Webfonts API will replace this stopgap code.
     *
     * This code design is intentional.
     *    a. It hides the inner-workings.
     *    b. It does not expose API ins or outs for consumption.
     *    c. It only works with a theme's `theme.json`.
     *
     * Why?
     *    a. To avoid backwards-compatibility issues when
     *       the Webfonts API is introduced in Core.
     *    b. To make `fontFace` declarations in `theme.json` work.
     *
     * @link  https://github.com/WordPress/gutenberg/issues/40472
     *
     * @since 6.0.0
     * @deprecated 6.4.0 Use wp_print_font_faces() instead.
     * @access private
     */
    function _wp_theme_json_webfonts_handler()
    {
    }
    /**
     * Prints the CSS in the embed iframe header.
     *
     * @since 4.4.0
     * @deprecated 6.4.0 Use wp_enqueue_embed_styles() instead.
     */
    function print_embed_styles()
    {
    }
    /**
     * Prints the important emoji-related styles.
     *
     * @since 4.2.0
     * @deprecated 6.4.0 Use wp_enqueue_emoji_styles() instead.
     * @phpstan-return void
     */
    function print_emoji_styles()
    {
    }
    /**
     * Prints style and scripts for the admin bar.
     *
     * @since 3.1.0
     * @deprecated 6.4.0 Use wp_enqueue_admin_bar_header_styles() instead.
     */
    function wp_admin_bar_header()
    {
    }
    /**
     * Prints default admin bar callback.
     *
     * @since 3.1.0
     * @deprecated 6.4.0 Use wp_enqueue_admin_bar_bump_styles() instead.
     */
    function _admin_bar_bump_cb()
    {
    }
    /**
     * Runs a remote HTTPS request to detect whether HTTPS supported, and stores potential errors.
     *
     * This internal function is called by a regular Cron hook to ensure HTTPS support is detected and maintained.
     *
     * @since 5.7.0
     * @deprecated 6.4.0 The `wp_update_https_detection_errors()` function is no longer used and has been replaced by
     *                   `wp_get_https_detection_errors()`. Previously the function was called by a regular Cron hook to
     *                    update the `https_detection_errors` option, but this is no longer necessary as the errors are
     *                    retrieved directly in Site Health and no longer used outside of Site Health.
     * @access private
     * @phpstan-return void
     */
    function wp_update_https_detection_errors()
    {
    }
    /**
     * Adds `decoding` attribute to an `img` HTML tag.
     *
     * The `decoding` attribute allows developers to indicate whether the
     * browser can decode the image off the main thread (`async`), on the
     * main thread (`sync`) or as determined by the browser (`auto`).
     *
     * By default WordPress adds `decoding="async"` to images but developers
     * can use the {@see 'wp_img_tag_add_decoding_attr'} filter to modify this
     * to remove the attribute or set it to another accepted value.
     *
     * @since 6.1.0
     * @deprecated 6.4.0 Use wp_img_tag_add_loading_optimization_attrs() instead.
     * @see wp_img_tag_add_loading_optimization_attrs()
     *
     * @param string $image   The HTML `img` tag where the attribute should be added.
     * @param string $context Additional context to pass to the filters.
     * @return string Converted `img` tag with `decoding` attribute added.
     */
    function wp_img_tag_add_decoding_attr($image, $context)
    {
    }
    /**
     * Parses wp_template content and injects the active theme's
     * stylesheet as a theme attribute into each wp_template_part
     *
     * @since 5.9.0
     * @deprecated 6.4.0 Use traverse_and_serialize_blocks( parse_blocks( $template_content ), '_inject_theme_attribute_in_template_part_block' ) instead.
     * @access private
     *
     * @param string $template_content serialized wp_template content.
     * @return string Updated 'wp_template' content.
     */
    function _inject_theme_attribute_in_block_template_content($template_content)
    {
    }
    /**
     * Parses a block template and removes the theme attribute from each template part.
     *
     * @since 5.9.0
     * @deprecated 6.4.0 Use traverse_and_serialize_blocks( parse_blocks( $template_content ), '_remove_theme_attribute_from_template_part_block' ) instead.
     * @access private
     *
     * @param string $template_content Serialized block template content.
     * @return string Updated block template content.
     */
    function _remove_theme_attribute_in_block_template_content($template_content)
    {
    }
    /**
     * Prints the skip-link script & styles.
     *
     * @since 5.8.0
     * @access private
     * @deprecated 6.4.0 Use wp_enqueue_block_template_skip_link() instead.
     *
     * @global string $_wp_current_template_content
     * @phpstan-return void
     */
    function the_block_template_skip_link()
    {
    }
    /**
     * Ensure that the view script has the `wp-interactivity` dependency.
     *
     * @since 6.4.0
     * @deprecated 6.5.0
     */
    function block_core_query_ensure_interactivity_dependency()
    {
    }
    /**
     * Ensure that the view script has the `wp-interactivity` dependency.
     *
     * @since 6.4.0
     * @deprecated 6.5.0
     */
    function block_core_file_ensure_interactivity_dependency()
    {
    }
    /**
     * Ensures that the view script has the `wp-interactivity` dependency.
     *
     * @since 6.4.0
     * @deprecated 6.5.0
     */
    function block_core_image_ensure_interactivity_dependency()
    {
    }
    /**
     * Updates the block content with elements class names.
     *
     * @deprecated 6.6.0 Generation of element class name is handled via `render_block_data` filter.
     *
     * @since 5.8.0
     * @since 6.4.0 Added support for button and heading element styling.
     * @access private
     *
     * @param string $block_content Rendered block content.
     * @param array  $block         Block object.
     * @return string Filtered block content.
     */
    function wp_render_elements_support($block_content, $block)
    {
    }
    /**
     * Processes the directives on the rendered HTML of the interactive blocks.
     *
     * This processes only one root interactive block at a time because the
     * rendered HTML of that block contains the rendered HTML of all its inner
     * blocks, including any interactive block. It does so by ignoring all the
     * interactive inner blocks until the root interactive block is processed.
     *
     * @since 6.5.0
     * @deprecated 6.6.0
     *
     * @param array $parsed_block The parsed block.
     * @return array The same parsed block.
     */
    function wp_interactivity_process_directives_of_interactive_blocks(array $parsed_block) : array
    {
    }
    /**
     * Gets the global styles custom CSS from theme.json.
     *
     * @since 6.2.0
     * @deprecated 6.7.0 Use {@see 'wp_get_global_stylesheet'} instead.
     *
     * @return string The global styles custom CSS.
     */
    function wp_get_global_styles_custom_css()
    {
    }
    /**
     * Enqueues the global styles custom css defined via theme.json.
     *
     * @since 6.2.0
     * @deprecated 6.7.0 Use {@see 'wp_enqueue_global_styles'} instead.
     * @phpstan-return void
     */
    function wp_enqueue_global_styles_custom_css()
    {
    }
    /**
     * Generate block style variation instance name.
     *
     * @since 6.6.0
     * @deprecated 6.7.0 Use `wp_unique_id( $variation . '--' )` instead.
     *
     * @access private
     *
     * @param array  $block     Block object.
     * @param string $variation Slug for the block style variation.
     *
     * @return string The unique variation name.
     */
    function wp_create_block_style_variation_instance_name($block, $variation)
    {
    }
    /**
     * Returns whether the current user has the specified capability for a given site.
     *
     * @since 3.0.0
     * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
     *              by adding it to the function signature.
     * @since 5.8.0 Wraps current_user_can() after switching to blog.
     * @deprecated 6.7.0 Use current_user_can_for_site() instead.
     *
     * @param int    $blog_id    Site ID.
     * @param string $capability Capability name.
     * @param mixed  ...$args    Optional further parameters, typically starting with an object ID.
     * @return bool Whether the user has the given capability.
     */
    function current_user_can_for_blog($blog_id, $capability, ...$args)
    {
    }
    /**
     * Registers an embed handler.
     *
     * Should probably only be used for sites that do not support oEmbed.
     *
     * @since 2.9.0
     *
     * @global WP_Embed $wp_embed WordPress Embed object.
     *
     * @param string   $id       An internal ID/name for the handler. Needs to be unique.
     * @param string   $regex    The regex that will be used to see if this handler should be used for a URL.
     * @param callable $callback The callback function that will be called if the regex is matched.
     * @param int      $priority Optional. Used to specify the order in which the registered handlers will
     *                           be tested. Default 10.
     */
    function wp_embed_register_handler($id, $regex, $callback, $priority = 10)
    {
    }
    /**
     * Unregisters a previously-registered embed handler.
     *
     * @since 2.9.0
     *
     * @global WP_Embed $wp_embed WordPress Embed object.
     *
     * @param string $id       The handler ID that should be removed.
     * @param int    $priority Optional. The priority of the handler to be removed. Default 10.
     */
    function wp_embed_unregister_handler($id, $priority = 10)
    {
    }
    /**
     * Creates default array of embed parameters.
     *
     * The width defaults to the content width as specified by the theme. If the
     * theme does not specify a content width, then 500px is used.
     *
     * The default height is 1.5 times the width, or 1000px, whichever is smaller.
     *
     * The {@see 'embed_defaults'} filter can be used to adjust either of these values.
     *
     * @since 2.9.0
     *
     * @global int $content_width
     *
     * @param string $url Optional. The URL that should be embedded. Default empty.
     * @return int[] {
     *     Indexed array of the embed width and height in pixels.
     *
     *     @type int $0 The embed width.
     *     @type int $1 The embed height.
     * }
     * @phpstan-return array{
     *   0: int,
     *   1: int,
     * }
     */
    function wp_embed_defaults($url = '')
    {
    }
    /**
     * Attempts to fetch the embed HTML for a provided URL using oEmbed.
     *
     * @since 2.9.0
     *
     * @see WP_oEmbed
     *
     * @param string $url  The URL that should be embedded.
     * @param array|string $args {
     *     Optional. Additional arguments for retrieving embed HTML. Default empty.
     *
     *     @type int|string $width    Optional. The `maxwidth` value passed to the provider URL.
     *     @type int|string $height   Optional. The `maxheight` value passed to the provider URL.
     *     @type bool       $discover Optional. Determines whether to attempt to discover link tags
     *                                at the given URL for an oEmbed provider when the provider URL
     *                                is not found in the built-in providers list. Default true.
     * }
     * @return string|false The embed HTML on success, false on failure.
     * @phpstan-param array{
     *   width?: int|string,
     *   height?: int|string,
     *   discover?: bool,
     * } $args
     */
    function wp_oembed_get($url, $args = '')
    {
    }
    /**
     * Returns the initialized WP_oEmbed object.
     *
     * @since 2.9.0
     * @access private
     *
     * @return WP_oEmbed object.
     */
    function _wp_oembed_get_object()
    {
    }
    /**
     * Adds a URL format and oEmbed provider URL pair.
     *
     * @since 2.9.0
     *
     * @see WP_oEmbed
     *
     * @param string $format   The format of URL that this provider can handle. You can use asterisks
     *                         as wildcards.
     * @param string $provider The URL to the oEmbed provider.
     * @param bool   $regex    Optional. Whether the `$format` parameter is in a RegEx format. Default false.
     */
    function wp_oembed_add_provider($format, $provider, $regex = \false)
    {
    }
    /**
     * Removes an oEmbed provider.
     *
     * @since 3.5.0
     *
     * @see WP_oEmbed
     *
     * @param string $format The URL format for the oEmbed provider to remove.
     * @return bool Was the provider removed successfully?
     */
    function wp_oembed_remove_provider($format)
    {
    }
    /**
     * Determines if default embed handlers should be loaded.
     *
     * Checks to make sure that the embeds library hasn't already been loaded. If
     * it hasn't, then it will load the embeds library.
     *
     * @since 2.9.0
     *
     * @see wp_embed_register_handler()
     * @phpstan-return void
     */
    function wp_maybe_load_embeds()
    {
    }
    /**
     * YouTube iframe embed handler callback.
     *
     * Catches YouTube iframe embed URLs that are not parsable by oEmbed but can be translated into a URL that is.
     *
     * @since 4.0.0
     *
     * @global WP_Embed $wp_embed WordPress Embed object.
     *
     * @param array  $matches The RegEx matches from the provided regex when calling
     *                        wp_embed_register_handler().
     * @param array  $attr    Embed attributes.
     * @param string $url     The original URL that was matched by the regex.
     * @param array  $rawattr The original unmodified attributes.
     * @return string The embed HTML.
     */
    function wp_embed_handler_youtube($matches, $attr, $url, $rawattr)
    {
    }
    /**
     * Audio embed handler callback.
     *
     * @since 3.6.0
     *
     * @param array  $matches The RegEx matches from the provided regex when calling wp_embed_register_handler().
     * @param array  $attr Embed attributes.
     * @param string $url The original URL that was matched by the regex.
     * @param array  $rawattr The original unmodified attributes.
     * @return string The embed HTML.
     */
    function wp_embed_handler_audio($matches, $attr, $url, $rawattr)
    {
    }
    /**
     * Video embed handler callback.
     *
     * @since 3.6.0
     *
     * @param array  $matches The RegEx matches from the provided regex when calling wp_embed_register_handler().
     * @param array  $attr    Embed attributes.
     * @param string $url     The original URL that was matched by the regex.
     * @param array  $rawattr The original unmodified attributes.
     * @return string The embed HTML.
     */
    function wp_embed_handler_video($matches, $attr, $url, $rawattr)
    {
    }
    /**
     * Registers the oEmbed REST API route.
     *
     * @since 4.4.0
     */
    function wp_oembed_register_route()
    {
    }
    /**
     * Adds oEmbed discovery links in the head element of the website.
     *
     * @since 4.4.0
     */
    function wp_oembed_add_discovery_links()
    {
    }
    /**
     * Adds the necessary JavaScript to communicate with the embedded iframes.
     *
     * This function is no longer used directly. For back-compat it exists exclusively as a way to indicate that the oEmbed
     * host JS _should_ be added. In `default-filters.php` there remains this code:
     *
     *     add_action( 'wp_head', 'wp_oembed_add_host_js' )
     *
     * Historically a site has been able to disable adding the oEmbed host script by doing:
     *
     *     remove_action( 'wp_head', 'wp_oembed_add_host_js' )
     *
     * In order to ensure that such code still works as expected, this function remains. There is now a `has_action()` check
     * in `wp_maybe_enqueue_oembed_host_js()` to see if `wp_oembed_add_host_js()` has not been unhooked from running at the
     * `wp_head` action.
     *
     * @since 4.4.0
     * @deprecated 5.9.0 Use {@see wp_maybe_enqueue_oembed_host_js()} instead.
     */
    function wp_oembed_add_host_js()
    {
    }
    /**
     * Enqueue the wp-embed script if the provided oEmbed HTML contains a post embed.
     *
     * In order to only enqueue the wp-embed script on pages that actually contain post embeds, this function checks if the
     * provided HTML contains post embed markup and if so enqueues the script so that it will get printed in the footer.
     *
     * @since 5.9.0
     *
     * @param string $html Embed markup.
     * @return string Embed markup (without modifications).
     */
    function wp_maybe_enqueue_oembed_host_js($html)
    {
    }
    /**
     * Retrieves the URL to embed a specific post in an iframe.
     *
     * @since 4.4.0
     *
     * @param int|WP_Post $post Optional. Post ID or object. Defaults to the current post.
     * @return string|false The post embed URL on success, false if the post doesn't exist.
     */
    function get_post_embed_url($post = \null)
    {
    }
    /**
     * Retrieves the oEmbed endpoint URL for a given permalink.
     *
     * Pass an empty string as the first argument to get the endpoint base URL.
     *
     * @since 4.4.0
     *
     * @param string $permalink Optional. The permalink used for the `url` query arg. Default empty.
     * @param string $format    Optional. The requested response format. Default 'json'.
     * @return string The oEmbed endpoint URL.
     */
    function get_oembed_endpoint_url($permalink = '', $format = 'json')
    {
    }
    /**
     * Retrieves the embed code for a specific post.
     *
     * @since 4.4.0
     *
     * @param int         $width  The width for the response.
     * @param int         $height The height for the response.
     * @param int|WP_Post $post   Optional. Post ID or object. Default is global `$post`.
     * @return string|false Embed code on success, false if post doesn't exist.
     */
    function get_post_embed_html($width, $height, $post = \null)
    {
    }
    /**
     * Retrieves the oEmbed response data for a given post.
     *
     * @since 4.4.0
     *
     * @param WP_Post|int $post  Post ID or post object.
     * @param int         $width The requested width.
     * @return array|false Response data on success, false if post doesn't exist
     *                     or is not publicly viewable.
     */
    function get_oembed_response_data($post, $width)
    {
    }
    /**
     * Retrieves the oEmbed response data for a given URL.
     *
     * @since 5.0.0
     *
     * @param string $url  The URL that should be inspected for discovery `<link>` tags.
     * @param array  $args oEmbed remote get arguments.
     * @return object|false oEmbed response data if the URL does belong to the current site. False otherwise.
     */
    function get_oembed_response_data_for_url($url, $args)
    {
    }
    /**
     * Filters the oEmbed response data to return an iframe embed code.
     *
     * @since 4.4.0
     *
     * @param array   $data   The response data.
     * @param WP_Post $post   The post object.
     * @param int     $width  The requested width.
     * @param int     $height The calculated height.
     * @return array The modified response data.
     */
    function get_oembed_response_data_rich($data, $post, $width, $height)
    {
    }
    /**
     * Ensures that the specified format is either 'json' or 'xml'.
     *
     * @since 4.4.0
     *
     * @param string $format The oEmbed response format. Accepts 'json' or 'xml'.
     * @return string The format, either 'xml' or 'json'. Default 'json'.
     * @phpstan-param 'json'|'xml' $format
     * @phpstan-return 'xml'|'json'
     */
    function wp_oembed_ensure_format($format)
    {
    }
    /**
     * Hooks into the REST API output to print XML instead of JSON.
     *
     * This is only done for the oEmbed API endpoint,
     * which supports both formats.
     *
     * @access private
     * @since 4.4.0
     *
     * @param bool             $served  Whether the request has already been served.
     * @param WP_HTTP_Response $result  Result to send to the client. Usually a `WP_REST_Response`.
     * @param WP_REST_Request  $request Request used to generate the response.
     * @param WP_REST_Server   $server  Server instance.
     * @return true
     */
    function _oembed_rest_pre_serve_request($served, $result, $request, $server)
    {
    }
    /**
     * Creates an XML string from a given array.
     *
     * @since 4.4.0
     * @access private
     *
     * @param array            $data The original oEmbed response data.
     * @param SimpleXMLElement $node Optional. XML node to append the result to recursively.
     * @return string|false XML string on success, false on error.
     */
    function _oembed_create_xml($data, $node = \null)
    {
    }
    /**
     * Filters the given oEmbed HTML to make sure iframes have a title attribute.
     *
     * @since 5.2.0
     *
     * @param string $result The oEmbed HTML result.
     * @param object $data   A data object result from an oEmbed provider.
     * @param string $url    The URL of the content to be embedded.
     * @return string The filtered oEmbed result.
     */
    function wp_filter_oembed_iframe_title_attribute($result, $data, $url)
    {
    }
    /**
     * Filters the given oEmbed HTML.
     *
     * If the `$url` isn't on the trusted providers list,
     * we need to filter the HTML heavily for security.
     *
     * Only filters 'rich' and 'video' response types.
     *
     * @since 4.4.0
     *
     * @param string $result The oEmbed HTML result.
     * @param object $data   A data object result from an oEmbed provider.
     * @param string $url    The URL of the content to be embedded.
     * @return string The filtered and sanitized oEmbed result.
     */
    function wp_filter_oembed_result($result, $data, $url)
    {
    }
    /**
     * Filters the string in the 'more' link displayed after a trimmed excerpt.
     *
     * Replaces '[...]' (appended to automatically generated excerpts) with an
     * ellipsis and a "Continue reading" link in the embed template.
     *
     * @since 4.4.0
     *
     * @param string $more_string Default 'more' string.
     * @return string 'Continue reading' link prepended with an ellipsis.
     */
    function wp_embed_excerpt_more($more_string)
    {
    }
    /**
     * Displays the post excerpt for the embed template.
     *
     * Intended to be used in 'The Loop'.
     *
     * @since 4.4.0
     */
    function the_excerpt_embed()
    {
    }
    /**
     * Filters the post excerpt for the embed template.
     *
     * Shows players for video and audio attachments.
     *
     * @since 4.4.0
     *
     * @param string $content The current post excerpt.
     * @return string The modified post excerpt.
     */
    function wp_embed_excerpt_attachment($content)
    {
    }
    /**
     * Enqueues embed iframe default CSS and JS.
     *
     * Enqueue PNG fallback CSS for embed iframe for legacy versions of IE.
     *
     * Allows plugins to queue scripts for the embed iframe end using wp_enqueue_script().
     * Runs first in oembed_head().
     *
     * @since 4.4.0
     */
    function enqueue_embed_scripts()
    {
    }
    /**
     * Enqueues the CSS in the embed iframe header.
     *
     * @since 6.4.0
     * @phpstan-return void
     */
    function wp_enqueue_embed_styles()
    {
    }
    /**
     * Prints the JavaScript in the embed iframe header.
     *
     * @since 4.4.0
     */
    function print_embed_scripts()
    {
    }
    /**
     * Prepare the oembed HTML to be displayed in an RSS feed.
     *
     * @since 4.4.0
     * @access private
     *
     * @param string $content The content to filter.
     * @return string The filtered content.
     */
    function _oembed_filter_feed_content($content)
    {
    }
    /**
     * Prints the necessary markup for the embed comments button.
     *
     * @since 4.4.0
     * @phpstan-return void
     */
    function print_embed_comments_button()
    {
    }
    /**
     * Prints the necessary markup for the embed sharing button.
     *
     * @since 4.4.0
     * @phpstan-return void
     */
    function print_embed_sharing_button()
    {
    }
    /**
     * Prints the necessary markup for the embed sharing dialog.
     *
     * @since 4.4.0
     * @phpstan-return void
     */
    function print_embed_sharing_dialog()
    {
    }
    /**
     * Prints the necessary markup for the site title in an embed template.
     *
     * @since 4.5.0
     */
    function the_embed_site_title()
    {
    }
    /**
     * Filters the oEmbed result before any HTTP requests are made.
     *
     * If the URL belongs to the current site, the result is fetched directly instead of
     * going through the oEmbed discovery process.
     *
     * @since 4.5.3
     *
     * @param null|string $result The UNSANITIZED (and potentially unsafe) HTML that should be used to embed. Default null.
     * @param string      $url    The URL that should be inspected for discovery `<link>` tags.
     * @param array       $args   oEmbed remote get arguments.
     * @return null|string The UNSANITIZED (and potentially unsafe) HTML that should be used to embed.
     *                     Null if the URL does not belong to the current site.
     */
    function wp_filter_pre_oembed_result($result, $url, $args)
    {
    }
    /**
     * Get the instance for storing paused plugins.
     *
     * @return WP_Paused_Extensions_Storage
     */
    function wp_paused_plugins()
    {
    }
    /**
     * Get the instance for storing paused extensions.
     *
     * @return WP_Paused_Extensions_Storage
     */
    function wp_paused_themes()
    {
    }
    /**
     * Get a human readable description of an extension's error.
     *
     * @since 5.2.0
     *
     * @param array $error Error details from `error_get_last()`.
     * @return string Formatted error description.
     */
    function wp_get_extension_error_description($error)
    {
    }
    /**
     * Registers the shutdown handler for fatal errors.
     *
     * The handler will only be registered if {@see wp_is_fatal_error_handler_enabled()} returns true.
     *
     * @since 5.2.0
     * @phpstan-return void
     */
    function wp_register_fatal_error_handler()
    {
    }
    /**
     * Checks whether the fatal error handler is enabled.
     *
     * A constant `WP_DISABLE_FATAL_ERROR_HANDLER` can be set in `wp-config.php` to disable it, or alternatively the
     * {@see 'wp_fatal_error_handler_enabled'} filter can be used to modify the return value.
     *
     * @since 5.2.0
     *
     * @return bool True if the fatal error handler is enabled, false otherwise.
     */
    function wp_is_fatal_error_handler_enabled()
    {
    }
    /**
     * Access the WordPress Recovery Mode instance.
     *
     * @since 5.2.0
     *
     * @return WP_Recovery_Mode
     */
    function wp_recovery_mode()
    {
    }
    /**
     * Retrieves RSS container for the bloginfo function.
     *
     * You can retrieve anything that you can using the get_bloginfo() function.
     * Everything will be stripped of tags and characters converted, when the values
     * are retrieved for use in the feeds.
     *
     * @since 1.5.1
     *
     * @see get_bloginfo() For the list of possible values to display.
     *
     * @param string $show See get_bloginfo() for possible values.
     * @return string
     */
    function get_bloginfo_rss($show = '')
    {
    }
    /**
     * Displays RSS container for the bloginfo function.
     *
     * You can retrieve anything that you can using the get_bloginfo() function.
     * Everything will be stripped of tags and characters converted, when the values
     * are retrieved for use in the feeds.
     *
     * @since 0.71
     *
     * @see get_bloginfo() For the list of possible values to display.
     *
     * @param string $show See get_bloginfo() for possible values.
     */
    function bloginfo_rss($show = '')
    {
    }
    /**
     * Retrieves the default feed.
     *
     * The default feed is 'rss2', unless a plugin changes it through the
     * {@see 'default_feed'} filter.
     *
     * @since 2.5.0
     *
     * @return string Default feed, or for example 'rss2', 'atom', etc.
     */
    function get_default_feed()
    {
    }
    /**
     * Retrieves the blog title for the feed title.
     *
     * @since 2.2.0
     * @since 4.4.0 The optional `$sep` parameter was deprecated and renamed to `$deprecated`.
     *
     * @param string $deprecated Unused.
     * @return string The document title.
     */
    function get_wp_title_rss($deprecated = '&#8211;')
    {
    }
    /**
     * Displays the blog title for display of the feed title.
     *
     * @since 2.2.0
     * @since 4.4.0 The optional `$sep` parameter was deprecated and renamed to `$deprecated`.
     *
     * @param string $deprecated Unused.
     */
    function wp_title_rss($deprecated = '&#8211;')
    {
    }
    /**
     * Retrieves the current post title for the feed.
     *
     * @since 2.0.0
     * @since 6.6.0 Added the `$post` parameter.
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return string Current post title.
     */
    function get_the_title_rss($post = 0)
    {
    }
    /**
     * Displays the post title in the feed.
     *
     * @since 0.71
     */
    function the_title_rss()
    {
    }
    /**
     * Retrieves the post content for feeds.
     *
     * @since 2.9.0
     *
     * @see get_the_content()
     *
     * @param string $feed_type The type of feed. rss2 | atom | rss | rdf
     * @return string The filtered content.
     */
    function get_the_content_feed($feed_type = \null)
    {
    }
    /**
     * Displays the post content for feeds.
     *
     * @since 2.9.0
     *
     * @param string $feed_type The type of feed. rss2 | atom | rss | rdf
     */
    function the_content_feed($feed_type = \null)
    {
    }
    /**
     * Displays the post excerpt for the feed.
     *
     * @since 0.71
     */
    function the_excerpt_rss()
    {
    }
    /**
     * Displays the permalink to the post for use in feeds.
     *
     * @since 2.3.0
     */
    function the_permalink_rss()
    {
    }
    /**
     * Outputs the link to the comments for the current post in an XML safe way.
     *
     * @since 3.0.0
     */
    function comments_link_feed()
    {
    }
    /**
     * Displays the feed GUID for the current comment.
     *
     * @since 2.5.0
     *
     * @param int|WP_Comment $comment_id Optional comment object or ID. Defaults to global comment object.
     */
    function comment_guid($comment_id = \null)
    {
    }
    /**
     * Retrieves the feed GUID for the current comment.
     *
     * @since 2.5.0
     *
     * @param int|WP_Comment $comment_id Optional comment object or ID. Defaults to global comment object.
     * @return string|false GUID for comment on success, false on failure.
     */
    function get_comment_guid($comment_id = \null)
    {
    }
    /**
     * Displays the link to the comments.
     *
     * @since 1.5.0
     * @since 4.4.0 Introduced the `$comment` argument.
     *
     * @param int|WP_Comment $comment Optional. Comment object or ID. Defaults to global comment object.
     */
    function comment_link($comment = \null)
    {
    }
    /**
     * Retrieves the current comment author for use in the feeds.
     *
     * @since 2.0.0
     *
     * @return string Comment Author.
     */
    function get_comment_author_rss()
    {
    }
    /**
     * Displays the current comment author in the feed.
     *
     * @since 1.0.0
     */
    function comment_author_rss()
    {
    }
    /**
     * Displays the current comment content for use in the feeds.
     *
     * @since 1.0.0
     */
    function comment_text_rss()
    {
    }
    /**
     * Retrieves all of the post categories, formatted for use in feeds.
     *
     * All of the categories for the current post in the feed loop, will be
     * retrieved and have feed markup added, so that they can easily be added to the
     * RSS2, Atom, or RSS1 and RSS0.91 RDF feeds.
     *
     * @since 2.1.0
     *
     * @param string $type Optional, default is the type returned by get_default_feed().
     * @return string All of the post categories for displaying in the feed.
     */
    function get_the_category_rss($type = \null)
    {
    }
    /**
     * Displays the post categories in the feed.
     *
     * @since 0.71
     *
     * @see get_the_category_rss() For better explanation.
     *
     * @param string $type Optional, default is the type returned by get_default_feed().
     */
    function the_category_rss($type = \null)
    {
    }
    /**
     * Displays the HTML type based on the blog setting.
     *
     * The two possible values are either 'xhtml' or 'html'.
     *
     * @since 2.2.0
     */
    function html_type_rss()
    {
    }
    /**
     * Displays the rss enclosure for the current post.
     *
     * Uses the global $post to check whether the post requires a password and if
     * the user has the password for the post. If not then it will return before
     * displaying.
     *
     * Also uses the function get_post_custom() to get the post's 'enclosure'
     * metadata field and parses the value to display the enclosure(s). The
     * enclosure(s) consist of enclosure HTML tag(s) with a URI and other
     * attributes.
     *
     * @since 1.5.0
     * @phpstan-return void
     */
    function rss_enclosure()
    {
    }
    /**
     * Displays the atom enclosure for the current post.
     *
     * Uses the global $post to check whether the post requires a password and if
     * the user has the password for the post. If not then it will return before
     * displaying.
     *
     * Also uses the function get_post_custom() to get the post's 'enclosure'
     * metadata field and parses the value to display the enclosure(s). The
     * enclosure(s) consist of link HTML tag(s) with a URI and other attributes.
     *
     * @since 2.2.0
     * @phpstan-return void
     */
    function atom_enclosure()
    {
    }
    /**
     * Determines the type of a string of data with the data formatted.
     *
     * Tell whether the type is text, HTML, or XHTML, per RFC 4287 section 3.1.
     *
     * In the case of WordPress, text is defined as containing no markup,
     * XHTML is defined as "well formed", and HTML as tag soup (i.e., the rest).
     *
     * Container div tags are added to XHTML values, per section 3.1.1.3.
     *
     * @link http://www.atomenabled.org/developers/syndication/atom-format-spec.php#rfc.section.3.1
     *
     * @since 2.5.0
     *
     * @param string $data Input string.
     * @return array array(type, value)
     */
    function prep_atom_text_construct($data)
    {
    }
    /**
     * Displays Site Icon in atom feeds.
     *
     * @since 4.3.0
     *
     * @see get_site_icon_url()
     */
    function atom_site_icon()
    {
    }
    /**
     * Displays Site Icon in RSS2.
     *
     * @since 4.3.0
     */
    function rss2_site_icon()
    {
    }
    /**
     * Returns the link for the currently displayed feed.
     *
     * @since 5.3.0
     *
     * @return string Correct link for the atom:self element.
     */
    function get_self_link()
    {
    }
    /**
     * Displays the link for the currently displayed feed in a XSS safe way.
     *
     * Generate a correct link for the atom:self element.
     *
     * @since 2.5.0
     */
    function self_link()
    {
    }
    /**
     * Gets the UTC time of the most recently modified post from WP_Query.
     *
     * If viewing a comment feed, the time of the most recently modified
     * comment will be returned.
     *
     * @since 5.2.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string $format Date format string to return the time in.
     * @return string|false The time in requested format, or false on failure.
     */
    function get_feed_build_date($format)
    {
    }
    /**
     * Returns the content type for specified feed type.
     *
     * @since 2.8.0
     *
     * @param string $type Type of feed. Possible values include 'rss', rss2', 'atom', and 'rdf'.
     * @return string Content type for specified feed type.
     */
    function feed_content_type($type = '')
    {
    }
    /**
     * Builds SimplePie object based on RSS or Atom feed from URL.
     *
     * @since 2.8.0
     *
     * @param string|string[] $url URL of feed to retrieve. If an array of URLs, the feeds are merged
     *                             using SimplePie's multifeed feature.
     *                             See also {@link http://simplepie.org/wiki/faq/typical_multifeed_gotchas}
     * @return SimplePie\SimplePie|WP_Error SimplePie object on success or WP_Error object on failure.
     */
    function fetch_feed($url)
    {
    }
    /**
     * Generates and prints font-face styles for given fonts or theme.json fonts.
     *
     * @since 6.4.0
     *
     * @param array[][] $fonts {
     *     Optional. The font-families and their font faces. Default empty array.
     *
     *     @type array ...$0 {
     *         An indexed or associative (keyed by font-family) array of font variations for this font-family.
     *         Each font face has the following structure.
     *
     *         @type array ...$0 {
     *             The font face properties.
     *
     *             @type string          $font-family             The font-family property.
     *             @type string|string[] $src                     The URL(s) to each resource containing the font data.
     *             @type string          $font-style              Optional. The font-style property. Default 'normal'.
     *             @type string          $font-weight             Optional. The font-weight property. Default '400'.
     *             @type string          $font-display            Optional. The font-display property. Default 'fallback'.
     *             @type string          $ascent-override         Optional. The ascent-override property.
     *             @type string          $descent-override        Optional. The descent-override property.
     *             @type string          $font-stretch            Optional. The font-stretch property.
     *             @type string          $font-variant            Optional. The font-variant property.
     *             @type string          $font-feature-settings   Optional. The font-feature-settings property.
     *             @type string          $font-variation-settings Optional. The font-variation-settings property.
     *             @type string          $line-gap-override       Optional. The line-gap-override property.
     *             @type string          $size-adjust             Optional. The size-adjust property.
     *             @type string          $unicode-range           Optional. The unicode-range property.
     *         }
     *     }
     * }
     * @phpstan-param array[]<int|string, array{
     * ?: array<array-key, array{
     *     font-family: string,
     *     src: string|string[],
     *     font-style?: string,
     *     font-weight?: string,
     *     font-display?: string,
     *     ascent-override?: string,
     *     descent-override?: string,
     *     font-stretch?: string,
     *     font-variant?: string,
     *     font-feature-settings?: string,
     *     font-variation-settings?: string,
     *     line-gap-override?: string,
     *     size-adjust?: string,
     *     unicode-range?: string,
     * }>,
     * }> $fonts
     * @phpstan-return void
     */
    function wp_print_font_faces($fonts = array())
    {
    }
    /**
     * Generates and prints font-face styles defined the the theme style variations.
     *
     * @since 6.7.0
     *
     * @phpstan-return void
     */
    function wp_print_font_faces_from_style_variations()
    {
    }
    /**
     * Registers a new font collection in the font library.
     *
     * See {@link https://schemas.wp.org/trunk/font-collection.json} for the schema
     * the font collection data must adhere to.
     *
     * @since 6.5.0
     *
     * @param string $slug Font collection slug. May only contain alphanumeric characters, dashes,
     *                     and underscores. See sanitize_title().
     * @param array  $args {
     *     Font collection data.
     *
     *     @type string       $name          Required. Name of the font collection shown in the Font Library.
     *     @type string       $description   Optional. A short descriptive summary of the font collection. Default empty.
     *     @type array|string $font_families Required. Array of font family definitions that are in the collection,
     *                                       or a string containing the path or URL to a JSON file containing the font collection.
     *     @type array        $categories    Optional. Array of categories, each with a name and slug, that are used by the
     *                                       fonts in the collection. Default empty.
     * }
     * @return WP_Font_Collection|WP_Error A font collection if it was registered
     *                                     successfully, or WP_Error object on failure.
     * @phpstan-param array{
     *   name?: string,
     *   description?: string,
     *   font_families?: array|string,
     *   categories?: array,
     * } $args
     */
    function wp_register_font_collection(string $slug, array $args)
    {
    }
    /**
     * Unregisters a font collection from the Font Library.
     *
     * @since 6.5.0
     *
     * @param string $slug Font collection slug.
     * @return bool True if the font collection was unregistered successfully, else false.
     */
    function wp_unregister_font_collection(string $slug)
    {
    }
    /**
     * Retrieves font uploads directory information.
     *
     * Same as wp_font_dir() but "light weight" as it doesn't attempt to create the font uploads directory.
     * Intended for use in themes, when only 'basedir' and 'baseurl' are needed, generally in all cases
     * when not uploading files.
     *
     * @since 6.5.0
     *
     * @see wp_font_dir()
     *
     * @return array See wp_font_dir() for description.
     */
    function wp_get_font_dir()
    {
    }
    /**
     * Returns an array containing the current fonts upload directory's path and URL.
     *
     * @since 6.5.0
     *
     * @param bool $create_dir Optional. Whether to check and create the font uploads directory. Default true.
     * @return array {
     *     Array of information about the font upload directory.
     *
     *     @type string       $path    Base directory and subdirectory or full path to the fonts upload directory.
     *     @type string       $url     Base URL and subdirectory or absolute URL to the fonts upload directory.
     *     @type string       $subdir  Subdirectory
     *     @type string       $basedir Path without subdir.
     *     @type string       $baseurl URL path without subdir.
     *     @type string|false $error   False or error message.
     * }
     * @phpstan-return array{
     *   path: string,
     *   url: string,
     *   subdir: string,
     *   basedir: string,
     *   baseurl: string,
     *   error: string|false,
     * }
     */
    function wp_font_dir($create_dir = \true)
    {
    }
    /**
     * A callback function for use in the {@see 'upload_dir'} filter.
     *
     * This function is intended for internal use only and should not be used by plugins and themes.
     * Use wp_get_font_dir() instead.
     *
     * @since 6.5.0
     * @access private
     *
     * @param string $font_dir The font directory.
     * @return string The modified font directory.
     */
    function _wp_filter_font_directory($font_dir)
    {
    }
    /**
     * Deletes child font faces when a font family is deleted.
     *
     * @access private
     * @since 6.5.0
     *
     * @param int     $post_id Post ID.
     * @param WP_Post $post    Post object.
     * @phpstan-return void
     */
    function _wp_after_delete_font_family($post_id, $post)
    {
    }
    /**
     * Deletes associated font files when a font face is deleted.
     *
     * @access private
     * @since 6.5.0
     *
     * @param int     $post_id Post ID.
     * @param WP_Post $post    Post object.
     * @phpstan-return void
     */
    function _wp_before_delete_font_face($post_id, $post)
    {
    }
    /**
     * Register the default font collections.
     *
     * @access private
     * @since 6.5.0
     */
    function _wp_register_default_font_collections()
    {
    }
    /**
     * Replaces common plain text characters with formatted entities.
     *
     * Returns given text with transformations of quotes into smart quotes, apostrophes,
     * dashes, ellipses, the trademark symbol, and the multiplication symbol.
     *
     * As an example,
     *
     *     'cause today's effort makes it worth tomorrow's "holiday" ...
     *
     * Becomes:
     *
     *     &#8217;cause today&#8217;s effort makes it worth tomorrow&#8217;s &#8220;holiday&#8221; &#8230;
     *
     * Code within certain HTML blocks are skipped.
     *
     * Do not use this function before the {@see 'init'} action hook; everything will break.
     *
     * @since 0.71
     *
     * @global array $wp_cockneyreplace Array of formatted entities for certain common phrases.
     * @global array $shortcode_tags
     *
     * @param string $text  The text to be formatted.
     * @param bool   $reset Set to true for unit testing. Translated patterns will reset.
     * @return string The string replaced with HTML entities.
     */
    function wptexturize($text, $reset = \false)
    {
    }
    /**
     * Implements a logic tree to determine whether or not "7'." represents seven feet,
     * then converts the special char into either a prime char or a closing quote char.
     *
     * @since 4.3.0
     *
     * @param string $haystack    The plain text to be searched.
     * @param string $needle      The character to search for such as ' or ".
     * @param string $prime       The prime char to use for replacement.
     * @param string $open_quote  The opening quote char. Opening quote replacement must be
     *                            accomplished already.
     * @param string $close_quote The closing quote char to use for replacement.
     * @return string The $haystack value after primes and quotes replacements.
     */
    function wptexturize_primes($haystack, $needle, $prime, $open_quote, $close_quote)
    {
    }
    /**
     * Searches for disabled element tags. Pushes element to stack on tag open
     * and pops on tag close.
     *
     * Assumes first char of `$text` is tag opening and last char is tag closing.
     * Assumes second char of `$text` is optionally `/` to indicate closing as in `</html>`.
     *
     * @since 2.9.0
     * @access private
     *
     * @param string   $text              Text to check. Must be a tag like `<html>` or `[shortcode]`.
     * @param string[] $stack             Array of open tag elements.
     * @param string[] $disabled_elements Array of tag names to match against. Spaces are not allowed in tag names.
     * @phpstan-return void
     */
    function _wptexturize_pushpop_element($text, &$stack, $disabled_elements)
    {
    }
    /**
     * Replaces double line breaks with paragraph elements.
     *
     * A group of regex replaces used to identify text formatted with newlines and
     * replace double line breaks with HTML paragraph tags. The remaining line breaks
     * after conversion become `<br />` tags, unless `$br` is set to '0' or 'false'.
     *
     * @since 0.71
     *
     * @param string $text The text which has to be formatted.
     * @param bool   $br   Optional. If set, this will convert all remaining line breaks
     *                     after paragraphing. Line breaks within `<script>`, `<style>`,
     *                     and `<svg>` tags are not affected. Default true.
     * @return string Text which has been converted into correct paragraph tags.
     */
    function wpautop($text, $br = \true)
    {
    }
    /**
     * Separates HTML elements and comments from the text.
     *
     * @since 4.2.4
     *
     * @param string $input The text which has to be formatted.
     * @return string[] Array of the formatted text.
     */
    function wp_html_split($input)
    {
    }
    /**
     * Retrieves the regular expression for an HTML element.
     *
     * @since 4.4.0
     *
     * @return string The regular expression
     */
    function get_html_split_regex()
    {
    }
    /**
     * Retrieves the combined regular expression for HTML and shortcodes.
     *
     * @access private
     * @ignore
     * @internal This function will be removed in 4.5.0 per Shortcode API Roadmap.
     * @since 4.4.0
     *
     * @param string $shortcode_regex Optional. The result from _get_wptexturize_shortcode_regex().
     * @return string The regular expression
     */
    function _get_wptexturize_split_regex($shortcode_regex = '')
    {
    }
    /**
     * Retrieves the regular expression for shortcodes.
     *
     * @access private
     * @ignore
     * @since 4.4.0
     *
     * @param string[] $tagnames Array of shortcodes to find.
     * @return string The regular expression
     */
    function _get_wptexturize_shortcode_regex($tagnames)
    {
    }
    /**
     * Replaces characters or phrases within HTML elements only.
     *
     * @since 4.2.3
     *
     * @param string $haystack      The text which has to be formatted.
     * @param array  $replace_pairs In the form array('from' => 'to', ...).
     * @return string The formatted text.
     */
    function wp_replace_in_html_tags($haystack, $replace_pairs)
    {
    }
    /**
     * Newline preservation help function for wpautop().
     *
     * @since 3.1.0
     * @access private
     *
     * @param array $matches preg_replace_callback matches array
     * @return string
     */
    function _autop_newline_preservation_helper($matches)
    {
    }
    /**
     * Don't auto-p wrap shortcodes that stand alone.
     *
     * Ensures that shortcodes are not wrapped in `<p>...</p>`.
     *
     * @since 2.9.0
     *
     * @global array $shortcode_tags
     *
     * @param string $text The content.
     * @return string The filtered content.
     */
    function shortcode_unautop($text)
    {
    }
    /**
     * Checks to see if a string is utf8 encoded.
     *
     * NOTE: This function checks for 5-Byte sequences, UTF8
     *       has Bytes Sequences with a maximum length of 4.
     *
     * @author bmorel at ssi dot fr (modified)
     * @since 1.2.1
     *
     * @param string $str The string to be checked
     * @return bool True if $str fits a UTF-8 model, false otherwise.
     */
    function seems_utf8($str)
    {
    }
    /**
     * Converts a number of special characters into their HTML entities.
     *
     * Specifically deals with: `&`, `<`, `>`, `"`, and `'`.
     *
     * `$quote_style` can be set to ENT_COMPAT to encode `"` to
     * `&quot;`, or ENT_QUOTES to do both. Default is ENT_NOQUOTES where no quotes are encoded.
     *
     * @since 1.2.2
     * @since 5.5.0 `$quote_style` also accepts `ENT_XML1`.
     * @access private
     *
     * @param string       $text          The text which is to be encoded.
     * @param int|string   $quote_style   Optional. Converts double quotes if set to ENT_COMPAT,
     *                                    both single and double if set to ENT_QUOTES or none if set to ENT_NOQUOTES.
     *                                    Converts single and double quotes, as well as converting HTML
     *                                    named entities (that are not also XML named entities) to their
     *                                    code points if set to ENT_XML1. Also compatible with old values;
     *                                    converting single quotes if set to 'single',
     *                                    double if set to 'double' or both if otherwise set.
     *                                    Default is ENT_NOQUOTES.
     * @param false|string $charset       Optional. The character encoding of the string. Default false.
     * @param bool         $double_encode Optional. Whether to encode existing HTML entities. Default false.
     * @return string The encoded text with HTML entities.
     */
    function _wp_specialchars($text, $quote_style = \ENT_NOQUOTES, $charset = \false, $double_encode = \false)
    {
    }
    /**
     * Converts a number of HTML entities into their special characters.
     *
     * Specifically deals with: `&`, `<`, `>`, `"`, and `'`.
     *
     * `$quote_style` can be set to ENT_COMPAT to decode `"` entities,
     * or ENT_QUOTES to do both `"` and `'`. Default is ENT_NOQUOTES where no quotes are decoded.
     *
     * @since 2.8.0
     *
     * @param string     $text        The text which is to be decoded.
     * @param string|int $quote_style Optional. Converts double quotes if set to ENT_COMPAT,
     *                                both single and double if set to ENT_QUOTES or
     *                                none if set to ENT_NOQUOTES.
     *                                Also compatible with old _wp_specialchars() values;
     *                                converting single quotes if set to 'single',
     *                                double if set to 'double' or both if otherwise set.
     *                                Default is ENT_NOQUOTES.
     * @return string The decoded text without HTML entities.
     */
    function wp_specialchars_decode($text, $quote_style = \ENT_NOQUOTES)
    {
    }
    /**
     * Checks for invalid UTF8 in a string.
     *
     * @since 2.8.0
     *
     * @param string $text   The text which is to be checked.
     * @param bool   $strip  Optional. Whether to attempt to strip out invalid UTF8. Default false.
     * @return string The checked text.
     */
    function wp_check_invalid_utf8($text, $strip = \false)
    {
    }
    /**
     * Encodes the Unicode values to be used in the URI.
     *
     * @since 1.5.0
     * @since 5.8.3 Added the `encode_ascii_characters` parameter.
     *
     * @param string $utf8_string             String to encode.
     * @param int    $length                  Max length of the string
     * @param bool   $encode_ascii_characters Whether to encode ascii characters such as < " '
     * @return string String with Unicode encoded for URI.
     */
    function utf8_uri_encode($utf8_string, $length = 0, $encode_ascii_characters = \false)
    {
    }
    /**
     * Converts all accent characters to ASCII characters.
     *
     * If there are no accent characters, then the string given is just returned.
     *
     * **Accent characters converted:**
     *
     * Currency signs:
     *
     * |   Code   | Glyph | Replacement |     Description     |
     * | -------- | ----- | ----------- | ------------------- |
     * | U+00A3   | £     | (empty)     | British Pound sign  |
     * | U+20AC   | €     | E           | Euro sign           |
     *
     * Decompositions for Latin-1 Supplement:
     *
     * |  Code   | Glyph | Replacement |               Description              |
     * | ------- | ----- | ----------- | -------------------------------------- |
     * | U+00AA  | ª     | a           | Feminine ordinal indicator             |
     * | U+00BA  | º     | o           | Masculine ordinal indicator            |
     * | U+00C0  | À     | A           | Latin capital letter A with grave      |
     * | U+00C1  | Á     | A           | Latin capital letter A with acute      |
     * | U+00C2  | Â     | A           | Latin capital letter A with circumflex |
     * | U+00C3  | Ã     | A           | Latin capital letter A with tilde      |
     * | U+00C4  | Ä     | A           | Latin capital letter A with diaeresis  |
     * | U+00C5  | Å     | A           | Latin capital letter A with ring above |
     * | U+00C6  | Æ     | AE          | Latin capital letter AE                |
     * | U+00C7  | Ç     | C           | Latin capital letter C with cedilla    |
     * | U+00C8  | È     | E           | Latin capital letter E with grave      |
     * | U+00C9  | É     | E           | Latin capital letter E with acute      |
     * | U+00CA  | Ê     | E           | Latin capital letter E with circumflex |
     * | U+00CB  | Ë     | E           | Latin capital letter E with diaeresis  |
     * | U+00CC  | Ì     | I           | Latin capital letter I with grave      |
     * | U+00CD  | Í     | I           | Latin capital letter I with acute      |
     * | U+00CE  | Î     | I           | Latin capital letter I with circumflex |
     * | U+00CF  | Ï     | I           | Latin capital letter I with diaeresis  |
     * | U+00D0  | Ð     | D           | Latin capital letter Eth               |
     * | U+00D1  | Ñ     | N           | Latin capital letter N with tilde      |
     * | U+00D2  | Ò     | O           | Latin capital letter O with grave      |
     * | U+00D3  | Ó     | O           | Latin capital letter O with acute      |
     * | U+00D4  | Ô     | O           | Latin capital letter O with circumflex |
     * | U+00D5  | Õ     | O           | Latin capital letter O with tilde      |
     * | U+00D6  | Ö     | O           | Latin capital letter O with diaeresis  |
     * | U+00D8  | Ø     | O           | Latin capital letter O with stroke     |
     * | U+00D9  | Ù     | U           | Latin capital letter U with grave      |
     * | U+00DA  | Ú     | U           | Latin capital letter U with acute      |
     * | U+00DB  | Û     | U           | Latin capital letter U with circumflex |
     * | U+00DC  | Ü     | U           | Latin capital letter U with diaeresis  |
     * | U+00DD  | Ý     | Y           | Latin capital letter Y with acute      |
     * | U+00DE  | Þ     | TH          | Latin capital letter Thorn             |
     * | U+00DF  | ß     | s           | Latin small letter sharp s             |
     * | U+00E0  | à     | a           | Latin small letter a with grave        |
     * | U+00E1  | á     | a           | Latin small letter a with acute        |
     * | U+00E2  | â     | a           | Latin small letter a with circumflex   |
     * | U+00E3  | ã     | a           | Latin small letter a with tilde        |
     * | U+00E4  | ä     | a           | Latin small letter a with diaeresis    |
     * | U+00E5  | å     | a           | Latin small letter a with ring above   |
     * | U+00E6  | æ     | ae          | Latin small letter ae                  |
     * | U+00E7  | ç     | c           | Latin small letter c with cedilla      |
     * | U+00E8  | è     | e           | Latin small letter e with grave        |
     * | U+00E9  | é     | e           | Latin small letter e with acute        |
     * | U+00EA  | ê     | e           | Latin small letter e with circumflex   |
     * | U+00EB  | ë     | e           | Latin small letter e with diaeresis    |
     * | U+00EC  | ì     | i           | Latin small letter i with grave        |
     * | U+00ED  | í     | i           | Latin small letter i with acute        |
     * | U+00EE  | î     | i           | Latin small letter i with circumflex   |
     * | U+00EF  | ï     | i           | Latin small letter i with diaeresis    |
     * | U+00F0  | ð     | d           | Latin small letter Eth                 |
     * | U+00F1  | ñ     | n           | Latin small letter n with tilde        |
     * | U+00F2  | ò     | o           | Latin small letter o with grave        |
     * | U+00F3  | ó     | o           | Latin small letter o with acute        |
     * | U+00F4  | ô     | o           | Latin small letter o with circumflex   |
     * | U+00F5  | õ     | o           | Latin small letter o with tilde        |
     * | U+00F6  | ö     | o           | Latin small letter o with diaeresis    |
     * | U+00F8  | ø     | o           | Latin small letter o with stroke       |
     * | U+00F9  | ù     | u           | Latin small letter u with grave        |
     * | U+00FA  | ú     | u           | Latin small letter u with acute        |
     * | U+00FB  | û     | u           | Latin small letter u with circumflex   |
     * | U+00FC  | ü     | u           | Latin small letter u with diaeresis    |
     * | U+00FD  | ý     | y           | Latin small letter y with acute        |
     * | U+00FE  | þ     | th          | Latin small letter Thorn               |
     * | U+00FF  | ÿ     | y           | Latin small letter y with diaeresis    |
     *
     * Decompositions for Latin Extended-A:
     *
     * |  Code   | Glyph | Replacement |                    Description                    |
     * | ------- | ----- | ----------- | ------------------------------------------------- |
     * | U+0100  | Ā     | A           | Latin capital letter A with macron                |
     * | U+0101  | ā     | a           | Latin small letter a with macron                  |
     * | U+0102  | Ă     | A           | Latin capital letter A with breve                 |
     * | U+0103  | ă     | a           | Latin small letter a with breve                   |
     * | U+0104  | Ą     | A           | Latin capital letter A with ogonek                |
     * | U+0105  | ą     | a           | Latin small letter a with ogonek                  |
     * | U+01006 | Ć     | C           | Latin capital letter C with acute                 |
     * | U+0107  | ć     | c           | Latin small letter c with acute                   |
     * | U+0108  | Ĉ     | C           | Latin capital letter C with circumflex            |
     * | U+0109  | ĉ     | c           | Latin small letter c with circumflex              |
     * | U+010A  | Ċ     | C           | Latin capital letter C with dot above             |
     * | U+010B  | ċ     | c           | Latin small letter c with dot above               |
     * | U+010C  | Č     | C           | Latin capital letter C with caron                 |
     * | U+010D  | č     | c           | Latin small letter c with caron                   |
     * | U+010E  | Ď     | D           | Latin capital letter D with caron                 |
     * | U+010F  | ď     | d           | Latin small letter d with caron                   |
     * | U+0110  | Đ     | D           | Latin capital letter D with stroke                |
     * | U+0111  | đ     | d           | Latin small letter d with stroke                  |
     * | U+0112  | Ē     | E           | Latin capital letter E with macron                |
     * | U+0113  | ē     | e           | Latin small letter e with macron                  |
     * | U+0114  | Ĕ     | E           | Latin capital letter E with breve                 |
     * | U+0115  | ĕ     | e           | Latin small letter e with breve                   |
     * | U+0116  | Ė     | E           | Latin capital letter E with dot above             |
     * | U+0117  | ė     | e           | Latin small letter e with dot above               |
     * | U+0118  | Ę     | E           | Latin capital letter E with ogonek                |
     * | U+0119  | ę     | e           | Latin small letter e with ogonek                  |
     * | U+011A  | Ě     | E           | Latin capital letter E with caron                 |
     * | U+011B  | ě     | e           | Latin small letter e with caron                   |
     * | U+011C  | Ĝ     | G           | Latin capital letter G with circumflex            |
     * | U+011D  | ĝ     | g           | Latin small letter g with circumflex              |
     * | U+011E  | Ğ     | G           | Latin capital letter G with breve                 |
     * | U+011F  | ğ     | g           | Latin small letter g with breve                   |
     * | U+0120  | Ġ     | G           | Latin capital letter G with dot above             |
     * | U+0121  | ġ     | g           | Latin small letter g with dot above               |
     * | U+0122  | Ģ     | G           | Latin capital letter G with cedilla               |
     * | U+0123  | ģ     | g           | Latin small letter g with cedilla                 |
     * | U+0124  | Ĥ     | H           | Latin capital letter H with circumflex            |
     * | U+0125  | ĥ     | h           | Latin small letter h with circumflex              |
     * | U+0126  | Ħ     | H           | Latin capital letter H with stroke                |
     * | U+0127  | ħ     | h           | Latin small letter h with stroke                  |
     * | U+0128  | Ĩ     | I           | Latin capital letter I with tilde                 |
     * | U+0129  | ĩ     | i           | Latin small letter i with tilde                   |
     * | U+012A  | Ī     | I           | Latin capital letter I with macron                |
     * | U+012B  | ī     | i           | Latin small letter i with macron                  |
     * | U+012C  | Ĭ     | I           | Latin capital letter I with breve                 |
     * | U+012D  | ĭ     | i           | Latin small letter i with breve                   |
     * | U+012E  | Į     | I           | Latin capital letter I with ogonek                |
     * | U+012F  | į     | i           | Latin small letter i with ogonek                  |
     * | U+0130  | İ     | I           | Latin capital letter I with dot above             |
     * | U+0131  | ı     | i           | Latin small letter dotless i                      |
     * | U+0132  | Ĳ     | IJ          | Latin capital ligature IJ                         |
     * | U+0133  | ĳ     | ij          | Latin small ligature ij                           |
     * | U+0134  | Ĵ     | J           | Latin capital letter J with circumflex            |
     * | U+0135  | ĵ     | j           | Latin small letter j with circumflex              |
     * | U+0136  | Ķ     | K           | Latin capital letter K with cedilla               |
     * | U+0137  | ķ     | k           | Latin small letter k with cedilla                 |
     * | U+0138  | ĸ     | k           | Latin small letter Kra                            |
     * | U+0139  | Ĺ     | L           | Latin capital letter L with acute                 |
     * | U+013A  | ĺ     | l           | Latin small letter l with acute                   |
     * | U+013B  | Ļ     | L           | Latin capital letter L with cedilla               |
     * | U+013C  | ļ     | l           | Latin small letter l with cedilla                 |
     * | U+013D  | Ľ     | L           | Latin capital letter L with caron                 |
     * | U+013E  | ľ     | l           | Latin small letter l with caron                   |
     * | U+013F  | Ŀ     | L           | Latin capital letter L with middle dot            |
     * | U+0140  | ŀ     | l           | Latin small letter l with middle dot              |
     * | U+0141  | Ł     | L           | Latin capital letter L with stroke                |
     * | U+0142  | ł     | l           | Latin small letter l with stroke                  |
     * | U+0143  | Ń     | N           | Latin capital letter N with acute                 |
     * | U+0144  | ń     | n           | Latin small letter N with acute                   |
     * | U+0145  | Ņ     | N           | Latin capital letter N with cedilla               |
     * | U+0146  | ņ     | n           | Latin small letter n with cedilla                 |
     * | U+0147  | Ň     | N           | Latin capital letter N with caron                 |
     * | U+0148  | ň     | n           | Latin small letter n with caron                   |
     * | U+0149  | ŉ     | n           | Latin small letter n preceded by apostrophe       |
     * | U+014A  | Ŋ     | N           | Latin capital letter Eng                          |
     * | U+014B  | ŋ     | n           | Latin small letter Eng                            |
     * | U+014C  | Ō     | O           | Latin capital letter O with macron                |
     * | U+014D  | ō     | o           | Latin small letter o with macron                  |
     * | U+014E  | Ŏ     | O           | Latin capital letter O with breve                 |
     * | U+014F  | ŏ     | o           | Latin small letter o with breve                   |
     * | U+0150  | Ő     | O           | Latin capital letter O with double acute          |
     * | U+0151  | ő     | o           | Latin small letter o with double acute            |
     * | U+0152  | Œ     | OE          | Latin capital ligature OE                         |
     * | U+0153  | œ     | oe          | Latin small ligature oe                           |
     * | U+0154  | Ŕ     | R           | Latin capital letter R with acute                 |
     * | U+0155  | ŕ     | r           | Latin small letter r with acute                   |
     * | U+0156  | Ŗ     | R           | Latin capital letter R with cedilla               |
     * | U+0157  | ŗ     | r           | Latin small letter r with cedilla                 |
     * | U+0158  | Ř     | R           | Latin capital letter R with caron                 |
     * | U+0159  | ř     | r           | Latin small letter r with caron                   |
     * | U+015A  | Ś     | S           | Latin capital letter S with acute                 |
     * | U+015B  | ś     | s           | Latin small letter s with acute                   |
     * | U+015C  | Ŝ     | S           | Latin capital letter S with circumflex            |
     * | U+015D  | ŝ     | s           | Latin small letter s with circumflex              |
     * | U+015E  | Ş     | S           | Latin capital letter S with cedilla               |
     * | U+015F  | ş     | s           | Latin small letter s with cedilla                 |
     * | U+0160  | Š     | S           | Latin capital letter S with caron                 |
     * | U+0161  | š     | s           | Latin small letter s with caron                   |
     * | U+0162  | Ţ     | T           | Latin capital letter T with cedilla               |
     * | U+0163  | ţ     | t           | Latin small letter t with cedilla                 |
     * | U+0164  | Ť     | T           | Latin capital letter T with caron                 |
     * | U+0165  | ť     | t           | Latin small letter t with caron                   |
     * | U+0166  | Ŧ     | T           | Latin capital letter T with stroke                |
     * | U+0167  | ŧ     | t           | Latin small letter t with stroke                  |
     * | U+0168  | Ũ     | U           | Latin capital letter U with tilde                 |
     * | U+0169  | ũ     | u           | Latin small letter u with tilde                   |
     * | U+016A  | Ū     | U           | Latin capital letter U with macron                |
     * | U+016B  | ū     | u           | Latin small letter u with macron                  |
     * | U+016C  | Ŭ     | U           | Latin capital letter U with breve                 |
     * | U+016D  | ŭ     | u           | Latin small letter u with breve                   |
     * | U+016E  | Ů     | U           | Latin capital letter U with ring above            |
     * | U+016F  | ů     | u           | Latin small letter u with ring above              |
     * | U+0170  | Ű     | U           | Latin capital letter U with double acute          |
     * | U+0171  | ű     | u           | Latin small letter u with double acute            |
     * | U+0172  | Ų     | U           | Latin capital letter U with ogonek                |
     * | U+0173  | ų     | u           | Latin small letter u with ogonek                  |
     * | U+0174  | Ŵ     | W           | Latin capital letter W with circumflex            |
     * | U+0175  | ŵ     | w           | Latin small letter w with circumflex              |
     * | U+0176  | Ŷ     | Y           | Latin capital letter Y with circumflex            |
     * | U+0177  | ŷ     | y           | Latin small letter y with circumflex              |
     * | U+0178  | Ÿ     | Y           | Latin capital letter Y with diaeresis             |
     * | U+0179  | Ź     | Z           | Latin capital letter Z with acute                 |
     * | U+017A  | ź     | z           | Latin small letter z with acute                   |
     * | U+017B  | Ż     | Z           | Latin capital letter Z with dot above             |
     * | U+017C  | ż     | z           | Latin small letter z with dot above               |
     * | U+017D  | Ž     | Z           | Latin capital letter Z with caron                 |
     * | U+017E  | ž     | z           | Latin small letter z with caron                   |
     * | U+017F  | ſ     | s           | Latin small letter long s                         |
     * | U+01A0  | Ơ     | O           | Latin capital letter O with horn                  |
     * | U+01A1  | ơ     | o           | Latin small letter o with horn                    |
     * | U+01AF  | Ư     | U           | Latin capital letter U with horn                  |
     * | U+01B0  | ư     | u           | Latin small letter u with horn                    |
     * | U+01CD  | Ǎ     | A           | Latin capital letter A with caron                 |
     * | U+01CE  | ǎ     | a           | Latin small letter a with caron                   |
     * | U+01CF  | Ǐ     | I           | Latin capital letter I with caron                 |
     * | U+01D0  | ǐ     | i           | Latin small letter i with caron                   |
     * | U+01D1  | Ǒ     | O           | Latin capital letter O with caron                 |
     * | U+01D2  | ǒ     | o           | Latin small letter o with caron                   |
     * | U+01D3  | Ǔ     | U           | Latin capital letter U with caron                 |
     * | U+01D4  | ǔ     | u           | Latin small letter u with caron                   |
     * | U+01D5  | Ǖ     | U           | Latin capital letter U with diaeresis and macron  |
     * | U+01D6  | ǖ     | u           | Latin small letter u with diaeresis and macron    |
     * | U+01D7  | Ǘ     | U           | Latin capital letter U with diaeresis and acute   |
     * | U+01D8  | ǘ     | u           | Latin small letter u with diaeresis and acute     |
     * | U+01D9  | Ǚ     | U           | Latin capital letter U with diaeresis and caron   |
     * | U+01DA  | ǚ     | u           | Latin small letter u with diaeresis and caron     |
     * | U+01DB  | Ǜ     | U           | Latin capital letter U with diaeresis and grave   |
     * | U+01DC  | ǜ     | u           | Latin small letter u with diaeresis and grave     |
     *
     * Decompositions for Latin Extended-B:
     *
     * |   Code   | Glyph | Replacement |                Description                |
     * | -------- | ----- | ----------- | ----------------------------------------- |
     * | U+018F   | Ə     | E           | Latin capital letter Ə                    |
     * | U+0259   | ǝ     | e           | Latin small letter ǝ                      |
     * | U+0218   | Ș     | S           | Latin capital letter S with comma below   |
     * | U+0219   | ș     | s           | Latin small letter s with comma below     |
     * | U+021A   | Ț     | T           | Latin capital letter T with comma below   |
     * | U+021B   | ț     | t           | Latin small letter t with comma below     |
     *
     * Vowels with diacritic (Chinese, Hanyu Pinyin):
     *
     * |   Code   | Glyph | Replacement |                      Description                      |
     * | -------- | ----- | ----------- | ----------------------------------------------------- |
     * | U+0251   | ɑ     | a           | Latin small letter alpha                              |
     * | U+1EA0   | Ạ     | A           | Latin capital letter A with dot below                 |
     * | U+1EA1   | ạ     | a           | Latin small letter a with dot below                   |
     * | U+1EA2   | Ả     | A           | Latin capital letter A with hook above                |
     * | U+1EA3   | ả     | a           | Latin small letter a with hook above                  |
     * | U+1EA4   | Ấ     | A           | Latin capital letter A with circumflex and acute      |
     * | U+1EA5   | ấ     | a           | Latin small letter a with circumflex and acute        |
     * | U+1EA6   | Ầ     | A           | Latin capital letter A with circumflex and grave      |
     * | U+1EA7   | ầ     | a           | Latin small letter a with circumflex and grave        |
     * | U+1EA8   | Ẩ     | A           | Latin capital letter A with circumflex and hook above |
     * | U+1EA9   | ẩ     | a           | Latin small letter a with circumflex and hook above   |
     * | U+1EAA   | Ẫ     | A           | Latin capital letter A with circumflex and tilde      |
     * | U+1EAB   | ẫ     | a           | Latin small letter a with circumflex and tilde        |
     * | U+1EA6   | Ậ     | A           | Latin capital letter A with circumflex and dot below  |
     * | U+1EAD   | ậ     | a           | Latin small letter a with circumflex and dot below    |
     * | U+1EAE   | Ắ     | A           | Latin capital letter A with breve and acute           |
     * | U+1EAF   | ắ     | a           | Latin small letter a with breve and acute             |
     * | U+1EB0   | Ằ     | A           | Latin capital letter A with breve and grave           |
     * | U+1EB1   | ằ     | a           | Latin small letter a with breve and grave             |
     * | U+1EB2   | Ẳ     | A           | Latin capital letter A with breve and hook above      |
     * | U+1EB3   | ẳ     | a           | Latin small letter a with breve and hook above        |
     * | U+1EB4   | Ẵ     | A           | Latin capital letter A with breve and tilde           |
     * | U+1EB5   | ẵ     | a           | Latin small letter a with breve and tilde             |
     * | U+1EB6   | Ặ     | A           | Latin capital letter A with breve and dot below       |
     * | U+1EB7   | ặ     | a           | Latin small letter a with breve and dot below         |
     * | U+1EB8   | Ẹ     | E           | Latin capital letter E with dot below                 |
     * | U+1EB9   | ẹ     | e           | Latin small letter e with dot below                   |
     * | U+1EBA   | Ẻ     | E           | Latin capital letter E with hook above                |
     * | U+1EBB   | ẻ     | e           | Latin small letter e with hook above                  |
     * | U+1EBC   | Ẽ     | E           | Latin capital letter E with tilde                     |
     * | U+1EBD   | ẽ     | e           | Latin small letter e with tilde                       |
     * | U+1EBE   | Ế     | E           | Latin capital letter E with circumflex and acute      |
     * | U+1EBF   | ế     | e           | Latin small letter e with circumflex and acute        |
     * | U+1EC0   | Ề     | E           | Latin capital letter E with circumflex and grave      |
     * | U+1EC1   | ề     | e           | Latin small letter e with circumflex and grave        |
     * | U+1EC2   | Ể     | E           | Latin capital letter E with circumflex and hook above |
     * | U+1EC3   | ể     | e           | Latin small letter e with circumflex and hook above   |
     * | U+1EC4   | Ễ     | E           | Latin capital letter E with circumflex and tilde      |
     * | U+1EC5   | ễ     | e           | Latin small letter e with circumflex and tilde        |
     * | U+1EC6   | Ệ     | E           | Latin capital letter E with circumflex and dot below  |
     * | U+1EC7   | ệ     | e           | Latin small letter e with circumflex and dot below    |
     * | U+1EC8   | Ỉ     | I           | Latin capital letter I with hook above                |
     * | U+1EC9   | ỉ     | i           | Latin small letter i with hook above                  |
     * | U+1ECA   | Ị     | I           | Latin capital letter I with dot below                 |
     * | U+1ECB   | ị     | i           | Latin small letter i with dot below                   |
     * | U+1ECC   | Ọ     | O           | Latin capital letter O with dot below                 |
     * | U+1ECD   | ọ     | o           | Latin small letter o with dot below                   |
     * | U+1ECE   | Ỏ     | O           | Latin capital letter O with hook above                |
     * | U+1ECF   | ỏ     | o           | Latin small letter o with hook above                  |
     * | U+1ED0   | Ố     | O           | Latin capital letter O with circumflex and acute      |
     * | U+1ED1   | ố     | o           | Latin small letter o with circumflex and acute        |
     * | U+1ED2   | Ồ     | O           | Latin capital letter O with circumflex and grave      |
     * | U+1ED3   | ồ     | o           | Latin small letter o with circumflex and grave        |
     * | U+1ED4   | Ổ     | O           | Latin capital letter O with circumflex and hook above |
     * | U+1ED5   | ổ     | o           | Latin small letter o with circumflex and hook above   |
     * | U+1ED6   | Ỗ     | O           | Latin capital letter O with circumflex and tilde      |
     * | U+1ED7   | ỗ     | o           | Latin small letter o with circumflex and tilde        |
     * | U+1ED8   | Ộ     | O           | Latin capital letter O with circumflex and dot below  |
     * | U+1ED9   | ộ     | o           | Latin small letter o with circumflex and dot below    |
     * | U+1EDA   | Ớ     | O           | Latin capital letter O with horn and acute            |
     * | U+1EDB   | ớ     | o           | Latin small letter o with horn and acute              |
     * | U+1EDC   | Ờ     | O           | Latin capital letter O with horn and grave            |
     * | U+1EDD   | ờ     | o           | Latin small letter o with horn and grave              |
     * | U+1EDE   | Ở     | O           | Latin capital letter O with horn and hook above       |
     * | U+1EDF   | ở     | o           | Latin small letter o with horn and hook above         |
     * | U+1EE0   | Ỡ     | O           | Latin capital letter O with horn and tilde            |
     * | U+1EE1   | ỡ     | o           | Latin small letter o with horn and tilde              |
     * | U+1EE2   | Ợ     | O           | Latin capital letter O with horn and dot below        |
     * | U+1EE3   | ợ     | o           | Latin small letter o with horn and dot below          |
     * | U+1EE4   | Ụ     | U           | Latin capital letter U with dot below                 |
     * | U+1EE5   | ụ     | u           | Latin small letter u with dot below                   |
     * | U+1EE6   | Ủ     | U           | Latin capital letter U with hook above                |
     * | U+1EE7   | ủ     | u           | Latin small letter u with hook above                  |
     * | U+1EE8   | Ứ     | U           | Latin capital letter U with horn and acute            |
     * | U+1EE9   | ứ     | u           | Latin small letter u with horn and acute              |
     * | U+1EEA   | Ừ     | U           | Latin capital letter U with horn and grave            |
     * | U+1EEB   | ừ     | u           | Latin small letter u with horn and grave              |
     * | U+1EEC   | Ử     | U           | Latin capital letter U with horn and hook above       |
     * | U+1EED   | ử     | u           | Latin small letter u with horn and hook above         |
     * | U+1EEE   | Ữ     | U           | Latin capital letter U with horn and tilde            |
     * | U+1EEF   | ữ     | u           | Latin small letter u with horn and tilde              |
     * | U+1EF0   | Ự     | U           | Latin capital letter U with horn and dot below        |
     * | U+1EF1   | ự     | u           | Latin small letter u with horn and dot below          |
     * | U+1EF2   | Ỳ     | Y           | Latin capital letter Y with grave                     |
     * | U+1EF3   | ỳ     | y           | Latin small letter y with grave                       |
     * | U+1EF4   | Ỵ     | Y           | Latin capital letter Y with dot below                 |
     * | U+1EF5   | ỵ     | y           | Latin small letter y with dot below                   |
     * | U+1EF6   | Ỷ     | Y           | Latin capital letter Y with hook above                |
     * | U+1EF7   | ỷ     | y           | Latin small letter y with hook above                  |
     * | U+1EF8   | Ỹ     | Y           | Latin capital letter Y with tilde                     |
     * | U+1EF9   | ỹ     | y           | Latin small letter y with tilde                       |
     *
     * German (`de_DE`), German formal (`de_DE_formal`), German (Switzerland) formal (`de_CH`),
     * German (Switzerland) informal (`de_CH_informal`), and German (Austria) (`de_AT`) locales:
     *
     * |   Code   | Glyph | Replacement |               Description               |
     * | -------- | ----- | ----------- | --------------------------------------- |
     * | U+00C4   | Ä     | Ae          | Latin capital letter A with diaeresis   |
     * | U+00E4   | ä     | ae          | Latin small letter a with diaeresis     |
     * | U+00D6   | Ö     | Oe          | Latin capital letter O with diaeresis   |
     * | U+00F6   | ö     | oe          | Latin small letter o with diaeresis     |
     * | U+00DC   | Ü     | Ue          | Latin capital letter U with diaeresis   |
     * | U+00FC   | ü     | ue          | Latin small letter u with diaeresis     |
     * | U+00DF   | ß     | ss          | Latin small letter sharp s              |
     *
     * Danish (`da_DK`) locale:
     *
     * |   Code   | Glyph | Replacement |               Description               |
     * | -------- | ----- | ----------- | --------------------------------------- |
     * | U+00C6   | Æ     | Ae          | Latin capital letter AE                 |
     * | U+00E6   | æ     | ae          | Latin small letter ae                   |
     * | U+00D8   | Ø     | Oe          | Latin capital letter O with stroke      |
     * | U+00F8   | ø     | oe          | Latin small letter o with stroke        |
     * | U+00C5   | Å     | Aa          | Latin capital letter A with ring above  |
     * | U+00E5   | å     | aa          | Latin small letter a with ring above    |
     *
     * Catalan (`ca`) locale:
     *
     * |   Code   | Glyph | Replacement |               Description               |
     * | -------- | ----- | ----------- | --------------------------------------- |
     * | U+00B7   | l·l   | ll          | Flown dot (between two Ls)              |
     *
     * Serbian (`sr_RS`) and Bosnian (`bs_BA`) locales:
     *
     * |   Code   | Glyph | Replacement |               Description               |
     * | -------- | ----- | ----------- | --------------------------------------- |
     * | U+0110   | Đ     | DJ          | Latin capital letter D with stroke      |
     * | U+0111   | đ     | dj          | Latin small letter d with stroke        |
     *
     * @since 1.2.1
     * @since 4.6.0 Added locale support for `de_CH`, `de_CH_informal`, and `ca`.
     * @since 4.7.0 Added locale support for `sr_RS`.
     * @since 4.8.0 Added locale support for `bs_BA`.
     * @since 5.7.0 Added locale support for `de_AT`.
     * @since 6.0.0 Added the `$locale` parameter.
     * @since 6.1.0 Added Unicode NFC encoding normalization support.
     *
     * @param string $text   Text that might have accent characters.
     * @param string $locale Optional. The locale to use for accent removal. Some character
     *                       replacements depend on the locale being used (e.g. 'de_DE').
     *                       Defaults to the current locale.
     * @return string Filtered string with replaced "nice" characters.
     */
    function remove_accents($text, $locale = '')
    {
    }
    /**
     * Sanitizes a filename, replacing whitespace with dashes.
     *
     * Removes special characters that are illegal in filenames on certain
     * operating systems and special characters requiring special escaping
     * to manipulate at the command line. Replaces spaces and consecutive
     * dashes with a single dash. Trims period, dash and underscore from beginning
     * and end of filename. It is not guaranteed that this function will return a
     * filename that is allowed to be uploaded.
     *
     * @since 2.1.0
     *
     * @param string $filename The filename to be sanitized.
     * @return string The sanitized filename.
     */
    function sanitize_file_name($filename)
    {
    }
    /**
     * Sanitizes a username, stripping out unsafe characters.
     *
     * Removes tags, percent-encoded characters, HTML entities, and if strict is enabled,
     * will only keep alphanumeric, _, space, ., -, @. After sanitizing, it passes the username,
     * raw username (the username in the parameter), and the value of $strict as parameters
     * for the {@see 'sanitize_user'} filter.
     *
     * @since 2.0.0
     *
     * @param string $username The username to be sanitized.
     * @param bool   $strict   Optional. If set to true, limits $username to specific characters.
     *                         Default false.
     * @return string The sanitized username, after passing through filters.
     */
    function sanitize_user($username, $strict = \false)
    {
    }
    /**
     * Sanitizes a string key.
     *
     * Keys are used as internal identifiers. Lowercase alphanumeric characters,
     * dashes, and underscores are allowed.
     *
     * @since 3.0.0
     *
     * @param string $key String key.
     * @return string Sanitized key.
     */
    function sanitize_key($key)
    {
    }
    /**
     * Sanitizes a string into a slug, which can be used in URLs or HTML attributes.
     *
     * By default, converts accent characters to ASCII characters and further
     * limits the output to alphanumeric characters, underscore (_) and dash (-)
     * through the {@see 'sanitize_title'} filter.
     *
     * If `$title` is empty and `$fallback_title` is set, the latter will be used.
     *
     * @since 1.0.0
     *
     * @param string $title          The string to be sanitized.
     * @param string $fallback_title Optional. A title to use if $title is empty. Default empty.
     * @param string $context        Optional. The operation for which the string is sanitized.
     *                               When set to 'save', the string runs through remove_accents().
     *                               Default 'save'.
     * @return string The sanitized string.
     */
    function sanitize_title($title, $fallback_title = '', $context = 'save')
    {
    }
    /**
     * Sanitizes a title with the 'query' context.
     *
     * Used for querying the database for a value from URL.
     *
     * @since 3.1.0
     *
     * @param string $title The string to be sanitized.
     * @return string The sanitized string.
     */
    function sanitize_title_for_query($title)
    {
    }
    /**
     * Sanitizes a title, replacing whitespace and a few other characters with dashes.
     *
     * Limits the output to alphanumeric characters, underscore (_) and dash (-).
     * Whitespace becomes a dash.
     *
     * @since 1.2.0
     *
     * @param string $title     The title to be sanitized.
     * @param string $raw_title Optional. Not used. Default empty.
     * @param string $context   Optional. The operation for which the string is sanitized.
     *                          When set to 'save', additional entities are converted to hyphens
     *                          or stripped entirely. Default 'display'.
     * @return string The sanitized title.
     */
    function sanitize_title_with_dashes($title, $raw_title = '', $context = 'display')
    {
    }
    /**
     * Ensures a string is a valid SQL 'order by' clause.
     *
     * Accepts one or more columns, with or without a sort order (ASC / DESC).
     * e.g. 'column_1', 'column_1, column_2', 'column_1 ASC, column_2 DESC' etc.
     *
     * Also accepts 'RAND()'.
     *
     * @since 2.5.1
     *
     * @param string $orderby Order by clause to be validated.
     * @return string|false Returns $orderby if valid, false otherwise.
     */
    function sanitize_sql_orderby($orderby)
    {
    }
    /**
     * Sanitizes an HTML classname to ensure it only contains valid characters.
     *
     * Strips the string down to A-Z,a-z,0-9,_,-. If this results in an empty
     * string then it will return the alternative value supplied.
     *
     * @todo Expand to support the full range of CDATA that a class attribute can contain.
     *
     * @since 2.8.0
     *
     * @param string $classname The classname to be sanitized.
     * @param string $fallback  Optional. The value to return if the sanitization ends up as an empty string.
     *                          Default empty string.
     * @return string The sanitized value.
     */
    function sanitize_html_class($classname, $fallback = '')
    {
    }
    /**
     * Strips out all characters not allowed in a locale name.
     *
     * @since 6.2.1
     *
     * @param string $locale_name The locale name to be sanitized.
     * @return string The sanitized value.
     */
    function sanitize_locale_name($locale_name)
    {
    }
    /**
     * Converts lone & characters into `&#038;` (a.k.a. `&amp;`)
     *
     * @since 0.71
     *
     * @param string $content    String of characters to be converted.
     * @param string $deprecated Not used.
     * @return string Converted string.
     */
    function convert_chars($content, $deprecated = '')
    {
    }
    /**
     * Converts invalid Unicode references range to valid range.
     *
     * @since 4.3.0
     *
     * @param string $content String with entities that need converting.
     * @return string Converted string.
     */
    function convert_invalid_entities($content)
    {
    }
    /**
     * Balances tags if forced to, or if the 'use_balanceTags' option is set to true.
     *
     * @since 0.71
     *
     * @param string $text  Text to be balanced
     * @param bool   $force If true, forces balancing, ignoring the value of the option. Default false.
     * @return string Balanced text
     */
    function balanceTags($text, $force = \false)
    {
    }
    /**
     * Balances tags of string using a modified stack.
     *
     * @since 2.0.4
     * @since 5.3.0 Improve accuracy and add support for custom element tags.
     *
     * @author Leonard Lin <leonard@acm.org>
     * @license GPL
     * @copyright November 4, 2001
     * @version 1.1
     * @todo Make better - change loop condition to $text in 1.2
     * @internal Modified by Scott Reilly (coffee2code) 02 Aug 2004
     *      1.1  Fixed handling of append/stack pop order of end text
     *           Added Cleaning Hooks
     *      1.0  First Version
     *
     * @param string $text Text to be balanced.
     * @return string Balanced text.
     */
    function force_balance_tags($text)
    {
    }
    /**
     * Acts on text which is about to be edited.
     *
     * The $content is run through esc_textarea(), which uses htmlspecialchars()
     * to convert special characters to HTML entities. If `$richedit` is set to true,
     * it is simply a holder for the {@see 'format_to_edit'} filter.
     *
     * @since 0.71
     * @since 4.4.0 The `$richedit` parameter was renamed to `$rich_text` for clarity.
     *
     * @param string $content   The text about to be edited.
     * @param bool   $rich_text Optional. Whether `$content` should be considered rich text,
     *                          in which case it would not be passed through esc_textarea().
     *                          Default false.
     * @return string The text after the filter (and possibly htmlspecialchars()) has been run.
     */
    function format_to_edit($content, $rich_text = \false)
    {
    }
    /**
     * Add leading zeros when necessary.
     *
     * If you set the threshold to '4' and the number is '10', then you will get
     * back '0010'. If you set the threshold to '4' and the number is '5000', then you
     * will get back '5000'.
     *
     * Uses sprintf to append the amount of zeros based on the $threshold parameter
     * and the size of the number. If the number is large enough, then no zeros will
     * be appended.
     *
     * @since 0.71
     *
     * @param int $number     Number to append zeros to if not greater than threshold.
     * @param int $threshold  Digit places number needs to be to not have zeros added.
     * @return string Adds leading zeros to number if needed.
     */
    function zeroise($number, $threshold)
    {
    }
    /**
     * Adds backslashes before letters and before a number at the start of a string.
     *
     * @since 0.71
     *
     * @param string $value Value to which backslashes will be added.
     * @return string String with backslashes inserted.
     */
    function backslashit($value)
    {
    }
    /**
     * Appends a trailing slash.
     *
     * Will remove trailing forward and backslashes if it exists already before adding
     * a trailing forward slash. This prevents double slashing a string or path.
     *
     * The primary use of this is for paths and thus should be used for paths. It is
     * not restricted to paths and offers no specific path support.
     *
     * @since 1.2.0
     *
     * @param string $value Value to which trailing slash will be added.
     * @return string String with trailing slash added.
     */
    function trailingslashit($value)
    {
    }
    /**
     * Removes trailing forward slashes and backslashes if they exist.
     *
     * The primary use of this is for paths and thus should be used for paths. It is
     * not restricted to paths and offers no specific path support.
     *
     * @since 2.2.0
     *
     * @param string $text Value from which trailing slashes will be removed.
     * @return string String without the trailing slashes.
     */
    function untrailingslashit($value)
    {
    }
    /**
     * Adds slashes to a string or recursively adds slashes to strings within an array.
     *
     * @since 0.71
     *
     * @param string|array $gpc String or array of data to slash.
     * @return string|array Slashed `$gpc`.
     * @phpstan-template T
     * @phpstan-param T $gpc
     * @phpstan-return T
     */
    function addslashes_gpc($gpc)
    {
    }
    /**
     * Navigates through an array, object, or scalar, and removes slashes from the values.
     *
     * @since 2.0.0
     *
     * @param mixed $value The value to be stripped.
     * @return mixed Stripped value.
     * @phpstan-template T
     * @phpstan-param T $value
     * @phpstan-return T
     */
    function stripslashes_deep($value)
    {
    }
    /**
     * Callback function for `stripslashes_deep()` which strips slashes from strings.
     *
     * @since 4.4.0
     *
     * @param mixed $value The array or string to be stripped.
     * @return mixed The stripped value.
     * @phpstan-template T
     * @phpstan-param T $value
     * @phpstan-return T
     */
    function stripslashes_from_strings_only($value)
    {
    }
    /**
     * Navigates through an array, object, or scalar, and encodes the values to be used in a URL.
     *
     * @since 2.2.0
     *
     * @param mixed $value The array or string to be encoded.
     * @return mixed The encoded value.
     * @phpstan-template T
     * @phpstan-param T $value
     * @phpstan-return T
     */
    function urlencode_deep($value)
    {
    }
    /**
     * Navigates through an array, object, or scalar, and raw-encodes the values to be used in a URL.
     *
     * @since 3.4.0
     *
     * @param mixed $value The array or string to be encoded.
     * @return mixed The encoded value.
     * @phpstan-template T
     * @phpstan-param T $value
     * @phpstan-return T
     */
    function rawurlencode_deep($value)
    {
    }
    /**
     * Navigates through an array, object, or scalar, and decodes URL-encoded values
     *
     * @since 4.4.0
     *
     * @param mixed $value The array or string to be decoded.
     * @return mixed The decoded value.
     * @phpstan-template T
     * @phpstan-param T $value
     * @phpstan-return T
     */
    function urldecode_deep($value)
    {
    }
    /**
     * Converts email addresses characters to HTML entities to block spam bots.
     *
     * @since 0.71
     *
     * @param string $email_address Email address.
     * @param int    $hex_encoding  Optional. Set to 1 to enable hex encoding.
     * @return string Converted email address.
     */
    function antispambot($email_address, $hex_encoding = 0)
    {
    }
    /**
     * Callback to convert URI match to HTML A element.
     *
     * This function was backported from 2.5.0 to 2.3.2. Regex callback for make_clickable().
     *
     * @since 2.3.2
     * @access private
     *
     * @param array $matches Single Regex Match.
     * @return string HTML A element with URI address.
     */
    function _make_url_clickable_cb($matches)
    {
    }
    /**
     * Callback to convert URL match to HTML A element.
     *
     * This function was backported from 2.5.0 to 2.3.2. Regex callback for make_clickable().
     *
     * @since 2.3.2
     * @access private
     *
     * @param array $matches Single Regex Match.
     * @return string HTML A element with URL address.
     */
    function _make_web_ftp_clickable_cb($matches)
    {
    }
    /**
     * Callback to convert email address match to HTML A element.
     *
     * This function was backported from 2.5.0 to 2.3.2. Regex callback for make_clickable().
     *
     * @since 2.3.2
     * @access private
     *
     * @param array $matches Single Regex Match.
     * @return string HTML A element with email address.
     */
    function _make_email_clickable_cb($matches)
    {
    }
    /**
     * Helper function used to build the "rel" attribute for a URL when creating an anchor using make_clickable().
     *
     * @since 6.2.0
     *
     * @param string $url The URL.
     * @return string The rel attribute for the anchor or an empty string if no rel attribute should be added.
     */
    function _make_clickable_rel_attr($url)
    {
    }
    /**
     * Converts plaintext URI to HTML links.
     *
     * Converts URI, www and ftp, and email addresses. Finishes by fixing links
     * within links.
     *
     * @since 0.71
     *
     * @param string $text Content to convert URIs.
     * @return string Content with converted URIs.
     */
    function make_clickable($text)
    {
    }
    /**
     * Breaks a string into chunks by splitting at whitespace characters.
     *
     * The length of each returned chunk is as close to the specified length goal as possible,
     * with the caveat that each chunk includes its trailing delimiter.
     * Chunks longer than the goal are guaranteed to not have any inner whitespace.
     *
     * Joining the returned chunks with empty delimiters reconstructs the input string losslessly.
     *
     * Input string must have no null characters (or eventual transformations on output chunks must not care about null characters)
     *
     *     _split_str_by_whitespace( "1234 67890 1234 67890a cd 1234   890 123456789 1234567890a    45678   1 3 5 7 90 ", 10 ) ==
     *     array (
     *         0 => '1234 67890 ',  // 11 characters: Perfect split.
     *         1 => '1234 ',        //  5 characters: '1234 67890a' was too long.
     *         2 => '67890a cd ',   // 10 characters: '67890a cd 1234' was too long.
     *         3 => '1234   890 ',  // 11 characters: Perfect split.
     *         4 => '123456789 ',   // 10 characters: '123456789 1234567890a' was too long.
     *         5 => '1234567890a ', // 12 characters: Too long, but no inner whitespace on which to split.
     *         6 => '   45678   ',  // 11 characters: Perfect split.
     *         7 => '1 3 5 7 90 ',  // 11 characters: End of $text.
     *     );
     *
     * @since 3.4.0
     * @access private
     *
     * @param string $text   The string to split.
     * @param int    $goal   The desired chunk length.
     * @return array Numeric array of chunks.
     */
    function _split_str_by_whitespace($text, $goal)
    {
    }
    /**
     * Callback to add a rel attribute to HTML A element.
     *
     * Will remove already existing string before adding to prevent invalidating (X)HTML.
     *
     * @since 5.3.0
     *
     * @param array  $matches Single match.
     * @param string $rel     The rel attribute to add.
     * @return string HTML A element with the added rel attribute.
     */
    function wp_rel_callback($matches, $rel)
    {
    }
    /**
     * Adds `rel="nofollow"` string to all HTML A elements in content.
     *
     * @since 1.5.0
     *
     * @param string $text Content that may contain HTML A elements.
     * @return string Converted content.
     */
    function wp_rel_nofollow($text)
    {
    }
    /**
     * Callback to add `rel="nofollow"` string to HTML A element.
     *
     * @since 2.3.0
     * @deprecated 5.3.0 Use wp_rel_callback()
     *
     * @param array $matches Single match.
     * @return string HTML A Element with `rel="nofollow"`.
     */
    function wp_rel_nofollow_callback($matches)
    {
    }
    /**
     * Adds `rel="nofollow ugc"` string to all HTML A elements in content.
     *
     * @since 5.3.0
     *
     * @param string $text Content that may contain HTML A elements.
     * @return string Converted content.
     */
    function wp_rel_ugc($text)
    {
    }
    /**
     * Adds `rel="noopener"` to all HTML A elements that have a target.
     *
     * @since 5.1.0
     * @since 5.6.0 Removed 'noreferrer' relationship.
     * @deprecated 6.7.0
     *
     * @param string $text Content that may contain HTML A elements.
     * @return string Converted content.
     */
    function wp_targeted_link_rel($text)
    {
    }
    /**
     * Callback to add `rel="noopener"` string to HTML A element.
     *
     * Will not duplicate an existing 'noopener' value to avoid invalidating the HTML.
     *
     * @since 5.1.0
     * @since 5.6.0 Removed 'noreferrer' relationship.
     * @deprecated 6.7.0
     *
     * @param array $matches Single match.
     * @return string HTML A Element with `rel="noopener"` in addition to any existing values.
     */
    function wp_targeted_link_rel_callback($matches)
    {
    }
    /**
     * Adds all filters modifying the rel attribute of targeted links.
     *
     * @since 5.1.0
     * @deprecated 6.7.0
     */
    function wp_init_targeted_link_rel_filters()
    {
    }
    /**
     * Removes all filters modifying the rel attribute of targeted links.
     *
     * @since 5.1.0
     * @deprecated 6.7.0
     */
    function wp_remove_targeted_link_rel_filters()
    {
    }
    /**
     * Converts one smiley code to the icon graphic file equivalent.
     *
     * Callback handler for convert_smilies().
     *
     * Looks up one smiley code in the $wpsmiliestrans global array and returns an
     * `<img>` string for that smiley.
     *
     * @since 2.8.0
     *
     * @global array $wpsmiliestrans
     *
     * @param array $matches Single match. Smiley code to convert to image.
     * @return string Image string for smiley.
     */
    function translate_smiley($matches)
    {
    }
    /**
     * Converts text equivalent of smilies to images.
     *
     * Will only convert smilies if the option 'use_smilies' is true and the global
     * used in the function isn't empty.
     *
     * @since 0.71
     *
     * @global string|array $wp_smiliessearch
     *
     * @param string $text Content to convert smilies from text.
     * @return string Converted content with text smilies replaced with images.
     */
    function convert_smilies($text)
    {
    }
    /**
     * Verifies that an email is valid.
     *
     * Does not grok i18n domains. Not RFC compliant.
     *
     * @since 0.71
     *
     * @param string $email      Email address to verify.
     * @param bool   $deprecated Deprecated.
     * @return string|false Valid email address on success, false on failure.
     */
    function is_email($email, $deprecated = \false)
    {
    }
    /**
     * Converts to ASCII from email subjects.
     *
     * @since 1.2.0
     *
     * @param string $subject Subject line.
     * @return string Converted string to ASCII.
     */
    function wp_iso_descrambler($subject)
    {
    }
    /**
     * Helper function to convert hex encoded chars to ASCII.
     *
     * @since 3.1.0
     * @access private
     *
     * @param array $matches The preg_replace_callback matches array.
     * @return string Converted chars.
     */
    function _wp_iso_convert($matches)
    {
    }
    /**
     * Given a date in the timezone of the site, returns that date in UTC.
     *
     * Requires and returns a date in the Y-m-d H:i:s format.
     * Return format can be overridden using the $format parameter.
     *
     * @since 1.2.0
     *
     * @param string $date_string The date to be converted, in the timezone of the site.
     * @param string $format      The format string for the returned date. Default 'Y-m-d H:i:s'.
     * @return string Formatted version of the date, in UTC.
     */
    function get_gmt_from_date($date_string, $format = 'Y-m-d H:i:s')
    {
    }
    /**
     * Given a date in UTC or GMT timezone, returns that date in the timezone of the site.
     *
     * Requires a date in the Y-m-d H:i:s format.
     * Default return format of 'Y-m-d H:i:s' can be overridden using the `$format` parameter.
     *
     * @since 1.2.0
     *
     * @param string $date_string The date to be converted, in UTC or GMT timezone.
     * @param string $format      The format string for the returned date. Default 'Y-m-d H:i:s'.
     * @return string Formatted version of the date, in the site's timezone.
     */
    function get_date_from_gmt($date_string, $format = 'Y-m-d H:i:s')
    {
    }
    /**
     * Given an ISO 8601 timezone, returns its UTC offset in seconds.
     *
     * @since 1.5.0
     *
     * @param string $timezone Either 'Z' for 0 offset or '±hhmm'.
     * @return int|float The offset in seconds.
     */
    function iso8601_timezone_to_offset($timezone)
    {
    }
    /**
     * Given an ISO 8601 (Ymd\TH:i:sO) date, returns a MySQL DateTime (Y-m-d H:i:s) format used by post_date[_gmt].
     *
     * @since 1.5.0
     *
     * @param string $date_string Date and time in ISO 8601 format {@link https://en.wikipedia.org/wiki/ISO_8601}.
     * @param string $timezone    Optional. If set to 'gmt' returns the result in UTC. Default 'user'.
     * @return string|false The date and time in MySQL DateTime format - Y-m-d H:i:s, or false on failure.
     */
    function iso8601_to_datetime($date_string, $timezone = 'user')
    {
    }
    /**
     * Strips out all characters that are not allowable in an email.
     *
     * @since 1.5.0
     *
     * @param string $email Email address to filter.
     * @return string Filtered email address.
     */
    function sanitize_email($email)
    {
    }
    /**
     * Determines the difference between two timestamps.
     *
     * The difference is returned in a human-readable format such as "1 hour",
     * "5 minutes", "2 days".
     *
     * @since 1.5.0
     * @since 5.3.0 Added support for showing a difference in seconds.
     *
     * @param int $from Unix timestamp from which the difference begins.
     * @param int $to   Optional. Unix timestamp to end the time difference. Default becomes time() if not set.
     * @return string Human-readable time difference.
     */
    function human_time_diff($from, $to = 0)
    {
    }
    /**
     * Generates an excerpt from the content, if needed.
     *
     * Returns a maximum of 55 words with an ellipsis appended if necessary.
     *
     * The 55-word limit can be modified by plugins/themes using the {@see 'excerpt_length'} filter
     * The ' [&hellip;]' string can be modified by plugins/themes using the {@see 'excerpt_more'} filter
     *
     * @since 1.5.0
     * @since 5.2.0 Added the `$post` parameter.
     * @since 6.3.0 Removes footnotes markup from the excerpt content.
     *
     * @param string             $text Optional. The excerpt. If set to empty, an excerpt is generated.
     * @param WP_Post|object|int $post Optional. WP_Post instance or Post ID/object. Default null.
     * @return string The excerpt.
     */
    function wp_trim_excerpt($text = '', $post = \null)
    {
    }
    /**
     * Trims text to a certain number of words.
     *
     * This function is localized. For languages that count 'words' by the individual
     * character (such as East Asian languages), the $num_words argument will apply
     * to the number of individual characters.
     *
     * @since 3.3.0
     *
     * @param string $text      Text to trim.
     * @param int    $num_words Number of words. Default 55.
     * @param string $more      Optional. What to append if $text needs to be trimmed. Default '&hellip;'.
     * @return string Trimmed text.
     */
    function wp_trim_words($text, $num_words = 55, $more = \null)
    {
    }
    /**
     * Converts named entities into numbered entities.
     *
     * @since 1.5.1
     *
     * @param string $text The text within which entities will be converted.
     * @return string Text with converted entities.
     */
    function ent2ncr($text)
    {
    }
    /**
     * Formats text for the editor.
     *
     * Generally the browsers treat everything inside a textarea as text, but
     * it is still a good idea to HTML entity encode `<`, `>` and `&` in the content.
     *
     * The filter {@see 'format_for_editor'} is applied here. If `$text` is empty the
     * filter will be applied to an empty string.
     *
     * @since 4.3.0
     *
     * @see _WP_Editors::editor()
     *
     * @param string $text           The text to be formatted.
     * @param string $default_editor The default editor for the current user.
     *                               It is usually either 'html' or 'tinymce'.
     * @return string The formatted text after filter is applied.
     * @phpstan-param 'html'|'tinymce' $default_editor
     */
    function format_for_editor($text, $default_editor = \null)
    {
    }
    /**
     * Performs a deep string replace operation to ensure the values in $search are no longer present.
     *
     * Repeats the replacement operation until it no longer replaces anything to remove "nested" values
     * e.g. $subject = '%0%0%0DDD', $search ='%0D', $result ='' rather than the '%0%0DD' that
     * str_replace would return
     *
     * @since 2.8.1
     * @access private
     *
     * @param string|array $search  The value being searched for, otherwise known as the needle.
     *                              An array may be used to designate multiple needles.
     * @param string       $subject The string being searched and replaced on, otherwise known as the haystack.
     * @return string The string with the replaced values.
     */
    function _deep_replace($search, $subject)
    {
    }
    /**
     * Escapes data for use in a MySQL query.
     *
     * Usually you should prepare queries using wpdb::prepare().
     * Sometimes, spot-escaping is required or useful. One example
     * is preparing an array for use in an IN clause.
     *
     * NOTE: Since 4.8.3, '%' characters will be replaced with a placeholder string,
     * this prevents certain SQLi attacks from taking place. This change in behavior
     * may cause issues for code that expects the return value of esc_sql() to be usable
     * for other purposes.
     *
     * @since 2.8.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string|array $data Unescaped data.
     * @return string|array Escaped data, in the same type as supplied.
     */
    function esc_sql($data)
    {
    }
    /**
     * Checks and cleans a URL.
     *
     * A number of characters are removed from the URL. If the URL is for displaying
     * (the default behavior) ampersands are also replaced. The {@see 'clean_url'} filter
     * is applied to the returned cleaned URL.
     *
     * @since 2.8.0
     *
     * @param string   $url       The URL to be cleaned.
     * @param string[] $protocols Optional. An array of acceptable protocols.
     *                            Defaults to return value of wp_allowed_protocols().
     * @param string   $_context  Private. Use sanitize_url() for database usage.
     * @return string The cleaned URL after the {@see 'clean_url'} filter is applied.
     *                An empty string is returned if `$url` specifies a protocol other than
     *                those in `$protocols`, or if `$url` contains an empty string.
     */
    function esc_url($url, $protocols = \null, $_context = 'display')
    {
    }
    /**
     * Sanitizes a URL for database or redirect usage.
     *
     * This function is an alias for sanitize_url().
     *
     * @since 2.8.0
     * @since 6.1.0 Turned into an alias for sanitize_url().
     *
     * @see sanitize_url()
     *
     * @param string   $url       The URL to be cleaned.
     * @param string[] $protocols Optional. An array of acceptable protocols.
     *                            Defaults to return value of wp_allowed_protocols().
     * @return string The cleaned URL after sanitize_url() is run.
     */
    function esc_url_raw($url, $protocols = \null)
    {
    }
    /**
     * Sanitizes a URL for database or redirect usage.
     *
     * @since 2.3.1
     * @since 2.8.0 Deprecated in favor of esc_url_raw().
     * @since 5.9.0 Restored (un-deprecated).
     *
     * @see esc_url()
     *
     * @param string   $url       The URL to be cleaned.
     * @param string[] $protocols Optional. An array of acceptable protocols.
     *                            Defaults to return value of wp_allowed_protocols().
     * @return string The cleaned URL after esc_url() is run with the 'db' context.
     */
    function sanitize_url($url, $protocols = \null)
    {
    }
    /**
     * Converts entities, while preserving already-encoded entities.
     *
     * @link https://www.php.net/htmlentities Borrowed from the PHP Manual user notes.
     *
     * @since 1.2.2
     *
     * @param string $text The text to be converted.
     * @return string Converted text.
     */
    function htmlentities2($text)
    {
    }
    /**
     * Escapes single quotes, `"`, `<`, `>`, `&`, and fixes line endings.
     *
     * Escapes text strings for echoing in JS. It is intended to be used for inline JS
     * (in a tag attribute, for example `onclick="..."`). Note that the strings have to
     * be in single quotes. The {@see 'js_escape'} filter is also applied here.
     *
     * @since 2.8.0
     *
     * @param string $text The text to be escaped.
     * @return string Escaped text.
     */
    function esc_js($text)
    {
    }
    /**
     * Escaping for HTML blocks.
     *
     * @since 2.8.0
     *
     * @param string $text
     * @return string
     */
    function esc_html($text)
    {
    }
    /**
     * Escaping for HTML attributes.
     *
     * @since 2.8.0
     *
     * @param string $text
     * @return string
     */
    function esc_attr($text)
    {
    }
    /**
     * Escaping for textarea values.
     *
     * @since 3.1.0
     *
     * @param string $text
     * @return string
     */
    function esc_textarea($text)
    {
    }
    /**
     * Escaping for XML blocks.
     *
     * @since 5.5.0
     *
     * @param string $text Text to escape.
     * @return string Escaped text.
     */
    function esc_xml($text)
    {
    }
    /**
     * Escapes an HTML tag name.
     *
     * @since 2.5.0
     * @since 6.5.5 Allow hyphens in tag names (i.e. custom elements).
     *
     * @param string $tag_name
     * @return string
     */
    function tag_escape($tag_name)
    {
    }
    /**
     * Converts full URL paths to absolute paths.
     *
     * Removes the http or https protocols and the domain. Keeps the path '/' at the
     * beginning, so it isn't a true relative link, but from the web root base.
     *
     * @since 2.1.0
     * @since 4.1.0 Support was added for relative URLs.
     *
     * @param string $link Full URL path.
     * @return string Absolute path.
     */
    function wp_make_link_relative($link)
    {
    }
    /**
     * Sanitizes various option values based on the nature of the option.
     *
     * This is basically a switch statement which will pass $value through a number
     * of functions depending on the $option.
     *
     * @since 2.0.5
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $option The name of the option.
     * @param mixed  $value  The unsanitized value.
     * @return mixed Sanitized value.
     */
    function sanitize_option($option, $value)
    {
    }
    /**
     * Maps a function to all non-iterable elements of an array or an object.
     *
     * This is similar to `array_walk_recursive()` but acts upon objects too.
     *
     * @since 4.4.0
     *
     * @param mixed    $value    The array, object, or scalar.
     * @param callable $callback The function to map onto $value.
     * @return mixed The value with the callback applied to all non-arrays and non-objects inside it.
     */
    function map_deep($value, $callback)
    {
    }
    /**
     * Parses a string into variables to be stored in an array.
     *
     * @since 2.2.1
     *
     * @param string $input_string The string to be parsed.
     * @param array  $result       Variables will be stored in this array.
     * @phpstan-param-out array<int|string, array|string> $result
     */
    function wp_parse_str($input_string, &$result)
    {
    }
    /**
     * Converts lone less than signs.
     *
     * KSES already converts lone greater than signs.
     *
     * @since 2.3.0
     *
     * @param string $content Text to be converted.
     * @return string Converted text.
     */
    function wp_pre_kses_less_than($content)
    {
    }
    /**
     * Callback function used by preg_replace.
     *
     * @since 2.3.0
     *
     * @param string[] $matches Populated by matches to preg_replace.
     * @return string The text returned after esc_html if needed.
     */
    function wp_pre_kses_less_than_callback($matches)
    {
    }
    /**
     * Removes non-allowable HTML from parsed block attribute values when filtering
     * in the post context.
     *
     * @since 5.3.1
     *
     * @param string         $content           Content to be run through KSES.
     * @param array[]|string $allowed_html      An array of allowed HTML elements
     *                                          and attributes, or a context name
     *                                          such as 'post'.
     * @param string[]       $allowed_protocols Array of allowed URL protocols.
     * @return string Filtered text to run through KSES.
     */
    function wp_pre_kses_block_attributes($content, $allowed_html, $allowed_protocols)
    {
    }
    /**
     * WordPress' implementation of PHP sprintf() with filters.
     *
     * @since 2.5.0
     * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
     *              by adding it to the function signature.
     *
     * @link https://www.php.net/sprintf
     *
     * @param string $pattern The string which formatted args are inserted.
     * @param mixed  ...$args Arguments to be formatted into the $pattern string.
     * @return string The formatted string.
     */
    function wp_sprintf($pattern, ...$args)
    {
    }
    /**
     * Localizes list items before the rest of the content.
     *
     * The '%l' must be at the first characters can then contain the rest of the
     * content. The list items will have ', ', ', and', and ' and ' added depending
     * on the amount of list items in the $args parameter.
     *
     * @since 2.5.0
     *
     * @param string $pattern Content containing '%l' at the beginning.
     * @param array  $args    List items to prepend to the content and replace '%l'.
     * @return string Localized list items and rest of the content.
     */
    function wp_sprintf_l($pattern, $args)
    {
    }
    /**
     * Safely extracts not more than the first $count characters from HTML string.
     *
     * UTF-8, tags and entities safe prefix extraction. Entities inside will *NOT*
     * be counted as one character. For example &amp; will be counted as 4, &lt; as
     * 3, etc.
     *
     * @since 2.5.0
     *
     * @param string $str   String to get the excerpt from.
     * @param int    $count Maximum number of characters to take.
     * @param string $more  Optional. What to append if $str needs to be trimmed. Defaults to empty string.
     * @return string The excerpt.
     */
    function wp_html_excerpt($str, $count, $more = \null)
    {
    }
    /**
     * Adds a base URL to relative links in passed content.
     *
     * By default, this function supports the 'src' and 'href' attributes.
     * However, this can be modified via the `$attrs` parameter.
     *
     * @since 2.7.0
     *
     * @global string $_links_add_base
     *
     * @param string   $content String to search for links in.
     * @param string   $base    The base URL to prefix to links.
     * @param string[] $attrs   The attributes which should be processed.
     * @return string The processed content.
     */
    function links_add_base_url($content, $base, $attrs = array('src', 'href'))
    {
    }
    /**
     * Callback to add a base URL to relative links in passed content.
     *
     * @since 2.7.0
     * @access private
     *
     * @global string $_links_add_base
     *
     * @param string $m The matched link.
     * @return string The processed link.
     */
    function _links_add_base($m)
    {
    }
    /**
     * Adds a target attribute to all links in passed content.
     *
     * By default, this function only applies to `<a>` tags.
     * However, this can be modified via the `$tags` parameter.
     *
     * *NOTE:* Any current target attribute will be stripped and replaced.
     *
     * @since 2.7.0
     *
     * @global string $_links_add_target
     *
     * @param string   $content String to search for links in.
     * @param string   $target  The target to add to the links.
     * @param string[] $tags    An array of tags to apply to.
     * @return string The processed content.
     */
    function links_add_target($content, $target = '_blank', $tags = array('a'))
    {
    }
    /**
     * Callback to add a target attribute to all links in passed content.
     *
     * @since 2.7.0
     * @access private
     *
     * @global string $_links_add_target
     *
     * @param string $m The matched link.
     * @return string The processed link.
     */
    function _links_add_target($m)
    {
    }
    /**
     * Normalizes EOL characters and strips duplicate whitespace.
     *
     * @since 2.7.0
     *
     * @param string $str The string to normalize.
     * @return string The normalized string.
     */
    function normalize_whitespace($str)
    {
    }
    /**
     * Properly strips all HTML tags including 'script' and 'style'.
     *
     * This differs from strip_tags() because it removes the contents of
     * the `<script>` and `<style>` tags. E.g. `strip_tags( '<script>something</script>' )`
     * will return 'something'. wp_strip_all_tags() will return an empty string.
     *
     * @since 2.9.0
     *
     * @param string $text          String containing HTML tags
     * @param bool   $remove_breaks Optional. Whether to remove left over line breaks and white space chars
     * @return string The processed string.
     */
    function wp_strip_all_tags($text, $remove_breaks = \false)
    {
    }
    /**
     * Sanitizes a string from user input or from the database.
     *
     * - Checks for invalid UTF-8,
     * - Converts single `<` characters to entities
     * - Strips all tags
     * - Removes line breaks, tabs, and extra whitespace
     * - Strips percent-encoded characters
     *
     * @since 2.9.0
     *
     * @see sanitize_textarea_field()
     * @see wp_check_invalid_utf8()
     * @see wp_strip_all_tags()
     *
     * @param string $str String to sanitize.
     * @return string Sanitized string.
     */
    function sanitize_text_field($str)
    {
    }
    /**
     * Sanitizes a multiline string from user input or from the database.
     *
     * The function is like sanitize_text_field(), but preserves
     * new lines (\n) and other whitespace, which are legitimate
     * input in textarea elements.
     *
     * @see sanitize_text_field()
     *
     * @since 4.7.0
     *
     * @param string $str String to sanitize.
     * @return string Sanitized string.
     */
    function sanitize_textarea_field($str)
    {
    }
    /**
     * Internal helper function to sanitize a string from user input or from the database.
     *
     * @since 4.7.0
     * @access private
     *
     * @param string $str           String to sanitize.
     * @param bool   $keep_newlines Optional. Whether to keep newlines. Default: false.
     * @return string Sanitized string.
     */
    function _sanitize_text_fields($str, $keep_newlines = \false)
    {
    }
    /**
     * i18n-friendly version of basename().
     *
     * @since 3.1.0
     *
     * @param string $path   A path.
     * @param string $suffix If the filename ends in suffix this will also be cut off.
     * @return string
     */
    function wp_basename($path, $suffix = '')
    {
    }
    /**
     * Forever eliminate "Wordpress" from the planet (or at least the little bit we can influence).
     *
     * Violating our coding standards for a good function name.
     *
     * @since 3.0.0
     *
     * @param string $text The text to be modified.
     * @return string The modified text.
     */
    function capital_P_dangit($text)
    {
    }
    /**
     * Sanitizes a mime type
     *
     * @since 3.1.3
     *
     * @param string $mime_type Mime type.
     * @return string Sanitized mime type.
     */
    function sanitize_mime_type($mime_type)
    {
    }
    /**
     * Sanitizes space or carriage return separated URLs that are used to send trackbacks.
     *
     * @since 3.4.0
     *
     * @param string $to_ping Space or carriage return separated URLs
     * @return string URLs starting with the http or https protocol, separated by a carriage return.
     */
    function sanitize_trackback_urls($to_ping)
    {
    }
    /**
     * Adds slashes to a string or recursively adds slashes to strings within an array.
     *
     * This should be used when preparing data for core API that expects slashed data.
     * This should not be used to escape data going directly into an SQL query.
     *
     * @since 3.6.0
     * @since 5.5.0 Non-string values are left untouched.
     *
     * @param string|array $value String or array of data to slash.
     * @return string|array Slashed `$value`, in the same type as supplied.
     * @phpstan-template T
     * @phpstan-param T $value
     * @phpstan-return T
     */
    function wp_slash($value)
    {
    }
    /**
     * Removes slashes from a string or recursively removes slashes from strings within an array.
     *
     * This should be used to remove slashes from data passed to core API that
     * expects data to be unslashed.
     *
     * @since 3.6.0
     *
     * @param string|array $value String or array of data to unslash.
     * @return string|array Unslashed `$value`, in the same type as supplied.
     * @phpstan-template T
     * @phpstan-param T $value
     * @phpstan-return T
     */
    function wp_unslash($value)
    {
    }
    /**
     * Extracts and returns the first URL from passed content.
     *
     * @since 3.6.0
     *
     * @param string $content A string which might contain a URL.
     * @return string|false The found URL.
     */
    function get_url_in_content($content)
    {
    }
    /**
     * Returns the regexp for common whitespace characters.
     *
     * By default, spaces include new lines, tabs, nbsp entities, and the UTF-8 nbsp.
     * This is designed to replace the PCRE \s sequence. In ticket #22692, that
     * sequence was found to be unreliable due to random inclusion of the A0 byte.
     *
     * @since 4.0.0
     *
     * @return string The spaces regexp.
     */
    function wp_spaces_regexp()
    {
    }
    /**
     * Enqueues the important emoji-related styles.
     *
     * @since 6.4.0
     * @phpstan-return void
     */
    function wp_enqueue_emoji_styles()
    {
    }
    /**
     * Prints the inline Emoji detection script if it is not already printed.
     *
     * @since 4.2.0
     * @phpstan-return void
     */
    function print_emoji_detection_script()
    {
    }
    /**
     * Prints inline Emoji detection script.
     *
     * @ignore
     * @since 4.6.0
     * @access private
     */
    function _print_emoji_detection_script()
    {
    }
    /**
     * Converts emoji characters to their equivalent HTML entity.
     *
     * This allows us to store emoji in a DB using the utf8 character set.
     *
     * @since 4.2.0
     *
     * @param string $content The content to encode.
     * @return string The encoded content.
     */
    function wp_encode_emoji($content)
    {
    }
    /**
     * Converts emoji to a static img element.
     *
     * @since 4.2.0
     *
     * @param string $text The content to encode.
     * @return string The encoded content.
     */
    function wp_staticize_emoji($text)
    {
    }
    /**
     * Converts emoji in emails into static images.
     *
     * @since 4.2.0
     *
     * @param array $mail The email data array.
     * @return array The email data array, with emoji in the message staticized.
     */
    function wp_staticize_emoji_for_email($mail)
    {
    }
    /**
     * Returns arrays of emoji data.
     *
     * These arrays are automatically built from the regex in twemoji.js - if they need to be updated,
     * you should update the regex there, then run the `npm run grunt precommit:emoji` job.
     *
     * @since 4.9.0
     * @access private
     *
     * @param string $type Optional. Which array type to return. Accepts 'partials' or 'entities', default 'entities'.
     * @return array An array to match all emoji that WordPress recognises.
     * @phpstan-param 'partials'|'entities' $type
     */
    function _wp_emoji_list($type = 'entities')
    {
    }
    /**
     * Shortens a URL, to be used as link text.
     *
     * @since 1.2.0
     * @since 4.4.0 Moved to wp-includes/formatting.php from wp-admin/includes/misc.php and added $length param.
     *
     * @param string $url    URL to shorten.
     * @param int    $length Optional. Maximum length of the shortened URL. Default 35 characters.
     * @return string Shortened URL.
     */
    function url_shorten($url, $length = 35)
    {
    }
    /**
     * Sanitizes a hex color.
     *
     * Returns either '', a 3 or 6 digit hex color (with #), or nothing.
     * For sanitizing values without a #, see sanitize_hex_color_no_hash().
     *
     * @since 3.4.0
     *
     * @param string $color
     * @return string|void
     */
    function sanitize_hex_color($color)
    {
    }
    /**
     * Sanitizes a hex color without a hash. Use sanitize_hex_color() when possible.
     *
     * Saving hex colors without a hash puts the burden of adding the hash on the
     * UI, which makes it difficult to use or upgrade to other color types such as
     * rgba, hsl, rgb, and HTML color names.
     *
     * Returns either '', a 3 or 6 digit hex color (without a #), or null.
     *
     * @since 3.4.0
     *
     * @param string $color
     * @return string|null
     */
    function sanitize_hex_color_no_hash($color)
    {
    }
    /**
     * Ensures that any hex color is properly hashed.
     * Otherwise, returns value untouched.
     *
     * This method should only be necessary if using sanitize_hex_color_no_hash().
     *
     * @since 3.4.0
     *
     * @param string $color
     * @return string
     */
    function maybe_hash_hex_color($color)
    {
    }
    /**
     * Converts given MySQL date string into a different format.
     *
     *  - `$format` should be a PHP date format string.
     *  - 'U' and 'G' formats will return an integer sum of timestamp with timezone offset.
     *  - `$date` is expected to be local time in MySQL format (`Y-m-d H:i:s`).
     *
     * Historically UTC time could be passed to the function to produce Unix timestamp.
     *
     * If `$translate` is true then the given date and format string will
     * be passed to `wp_date()` for translation.
     *
     * @since 0.71
     *
     * @param string $format    Format of the date to return.
     * @param string $date      Date string to convert.
     * @param bool   $translate Whether the return date should be translated. Default true.
     * @return string|int|false Integer if `$format` is 'U' or 'G', string otherwise.
     *                          False on failure.
     * @phpstan-return ($format is 'G'|'U' ? int|false : string|false)
     */
    function mysql2date($format, $date, $translate = \true)
    {
    }
    /**
     * Retrieves the current time based on specified type.
     *
     *  - The 'mysql' type will return the time in the format for MySQL DATETIME field.
     *  - The 'timestamp' or 'U' types will return the current timestamp or a sum of timestamp
     *    and timezone offset, depending on `$gmt`.
     *  - Other strings will be interpreted as PHP date formats (e.g. 'Y-m-d').
     *
     * If `$gmt` is a truthy value then both types will use GMT time, otherwise the
     * output is adjusted with the GMT offset for the site.
     *
     * @since 1.0.0
     * @since 5.3.0 Now returns an integer if `$type` is 'U'. Previously a string was returned.
     *
     * @param string   $type Type of time to retrieve. Accepts 'mysql', 'timestamp', 'U',
     *                       or PHP date format string (e.g. 'Y-m-d').
     * @param int|bool $gmt  Optional. Whether to use GMT timezone. Default false.
     * @return int|string Integer if `$type` is 'timestamp' or 'U', string otherwise.
     * @phpstan-return ($type is 'timestamp'|'U' ? int : string)
     */
    function current_time($type, $gmt = 0)
    {
    }
    /**
     * Retrieves the current time as an object using the site's timezone.
     *
     * @since 5.3.0
     *
     * @return DateTimeImmutable Date and time object.
     */
    function current_datetime()
    {
    }
    /**
     * Retrieves the timezone of the site as a string.
     *
     * Uses the `timezone_string` option to get a proper timezone name if available,
     * otherwise falls back to a manual UTC ± offset.
     *
     * Example return values:
     *
     *  - 'Europe/Rome'
     *  - 'America/North_Dakota/New_Salem'
     *  - 'UTC'
     *  - '-06:30'
     *  - '+00:00'
     *  - '+08:45'
     *
     * @since 5.3.0
     *
     * @return string PHP timezone name or a ±HH:MM offset.
     */
    function wp_timezone_string()
    {
    }
    /**
     * Retrieves the timezone of the site as a `DateTimeZone` object.
     *
     * Timezone can be based on a PHP timezone string or a ±HH:MM offset.
     *
     * @since 5.3.0
     *
     * @return DateTimeZone Timezone object.
     */
    function wp_timezone()
    {
    }
    /**
     * Retrieves the date in localized format, based on a sum of Unix timestamp and
     * timezone offset in seconds.
     *
     * If the locale specifies the locale month and weekday, then the locale will
     * take over the format for the date. If it isn't, then the date format string
     * will be used instead.
     *
     * Note that due to the way WP typically generates a sum of timestamp and offset
     * with `strtotime()`, it implies offset added at a _current_ time, not at the time
     * the timestamp represents. Storing such timestamps or calculating them differently
     * will lead to invalid output.
     *
     * @since 0.71
     * @since 5.3.0 Converted into a wrapper for wp_date().
     *
     * @param string   $format                Format to display the date.
     * @param int|bool $timestamp_with_offset Optional. A sum of Unix timestamp and timezone offset
     *                                        in seconds. Default false.
     * @param bool     $gmt                   Optional. Whether to use GMT timezone. Only applies
     *                                        if timestamp is not provided. Default false.
     * @return string The date, translated if locale specifies it.
     */
    function date_i18n($format, $timestamp_with_offset = \false, $gmt = \false)
    {
    }
    /**
     * Retrieves the date, in localized format.
     *
     * This is a newer function, intended to replace `date_i18n()` without legacy quirks in it.
     *
     * Note that, unlike `date_i18n()`, this function accepts a true Unix timestamp, not summed
     * with timezone offset.
     *
     * @since 5.3.0
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     *
     * @param string       $format    PHP date format.
     * @param int          $timestamp Optional. Unix timestamp. Defaults to current time.
     * @param DateTimeZone $timezone  Optional. Timezone to output result in. Defaults to timezone
     *                                from site settings.
     * @return string|false The date, translated if locale specifies it. False on invalid timestamp input.
     */
    function wp_date($format, $timestamp = \null, $timezone = \null)
    {
    }
    /**
     * Determines if the date should be declined.
     *
     * If the locale specifies that month names require a genitive case in certain
     * formats (like 'j F Y'), the month name will be replaced with a correct form.
     *
     * @since 4.4.0
     * @since 5.4.0 The `$format` parameter was added.
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     *
     * @param string $date   Formatted date string.
     * @param string $format Optional. Date format to check. Default empty string.
     * @return string The date, declined if locale specifies it.
     */
    function wp_maybe_decline_date($date, $format = '')
    {
    }
    /**
     * Converts float number to format based on the locale.
     *
     * @since 2.3.0
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     *
     * @param float $number   The number to convert based on locale.
     * @param int   $decimals Optional. Precision of the number of decimal places. Default 0.
     * @return string Converted number in string format.
     */
    function number_format_i18n($number, $decimals = 0)
    {
    }
    /**
     * Converts a number of bytes to the largest unit the bytes will fit into.
     *
     * It is easier to read 1 KB than 1024 bytes and 1 MB than 1048576 bytes. Converts
     * number of bytes to human readable number by taking the number of that unit
     * that the bytes will go into it. Supports YB value.
     *
     * Please note that integers in PHP are limited to 32 bits, unless they are on
     * 64 bit architecture, then they have 64 bit size. If you need to place the
     * larger size then what PHP integer type will hold, then use a string. It will
     * be converted to a double, which should always have 64 bit length.
     *
     * Technically the correct unit names for powers of 1024 are KiB, MiB etc.
     *
     * @since 2.3.0
     * @since 6.0.0 Support for PB, EB, ZB, and YB was added.
     *
     * @param int|string $bytes    Number of bytes. Note max integer size for integers.
     * @param int        $decimals Optional. Precision of number of decimal places. Default 0.
     * @return string|false Number string on success, false on failure.
     * @phpstan-return ($bytes is not numeric ? false : ($bytes is int<min, -1>|'0' ? false : string))
     */
    function size_format($bytes, $decimals = 0)
    {
    }
    /**
     * Converts a duration to human readable format.
     *
     * @since 5.1.0
     *
     * @param string $duration Duration will be in string format (HH:ii:ss) OR (ii:ss),
     *                         with a possible prepended negative sign (-).
     * @return string|false A human readable duration string, false on failure.
     */
    function human_readable_duration($duration = '')
    {
    }
    /**
     * Gets the week start and end from the datetime or date string from MySQL.
     *
     * @since 0.71
     *
     * @param string     $mysqlstring   Date or datetime field type from MySQL.
     * @param int|string $start_of_week Optional. Start of the week as an integer. Default empty string.
     * @return int[] {
     *     Week start and end dates as Unix timestamps.
     *
     *     @type int $start The week start date as a Unix timestamp.
     *     @type int $end   The week end date as a Unix timestamp.
     * }
     * @phpstan-return array{
     *   start: int,
     *   end: int,
     * }
     */
    function get_weekstartend($mysqlstring, $start_of_week = '')
    {
    }
    /**
     * Serializes data, if needed.
     *
     * @since 2.0.5
     *
     * @param string|array|object $data Data that might be serialized.
     * @return mixed A scalar data.
     */
    function maybe_serialize($data)
    {
    }
    /**
     * Unserializes data only if it was serialized.
     *
     * @since 2.0.0
     *
     * @param string $data Data that might be unserialized.
     * @return mixed Unserialized data can be any type.
     */
    function maybe_unserialize($data)
    {
    }
    /**
     * Checks value to find if it was serialized.
     *
     * If $data is not a string, then returned value will always be false.
     * Serialized data is always a string.
     *
     * @since 2.0.5
     * @since 6.1.0 Added Enum support.
     *
     * @param string $data   Value to check to see if was serialized.
     * @param bool   $strict Optional. Whether to be strict about the end of the string. Default true.
     * @return bool False if not serialized and true if it was.
     */
    function is_serialized($data, $strict = \true)
    {
    }
    /**
     * Checks whether serialized data is of string type.
     *
     * @since 2.0.5
     *
     * @param string $data Serialized data.
     * @return bool False if not a serialized string, true if it is.
     */
    function is_serialized_string($data)
    {
    }
    /**
     * Retrieves post title from XMLRPC XML.
     *
     * If the title element is not part of the XML, then the default post title from
     * the $post_default_title will be used instead.
     *
     * @since 0.71
     *
     * @global string $post_default_title Default XML-RPC post title.
     *
     * @param string $content XMLRPC XML Request content
     * @return string Post title
     */
    function xmlrpc_getposttitle($content)
    {
    }
    /**
     * Retrieves the post category or categories from XMLRPC XML.
     *
     * If the category element is not found, then the default post category will be
     * used. The return type then would be what $post_default_category. If the
     * category is found, then it will always be an array.
     *
     * @since 0.71
     *
     * @global string $post_default_category Default XML-RPC post category.
     *
     * @param string $content XMLRPC XML Request content
     * @return string|array List of categories or category name.
     */
    function xmlrpc_getpostcategory($content)
    {
    }
    /**
     * XMLRPC XML content without title and category elements.
     *
     * @since 0.71
     *
     * @param string $content XML-RPC XML Request content.
     * @return string XMLRPC XML Request content without title and category elements.
     */
    function xmlrpc_removepostdata($content)
    {
    }
    /**
     * Uses RegEx to extract URLs from arbitrary content.
     *
     * @since 3.7.0
     * @since 6.0.0 Fixes support for HTML entities (Trac 30580).
     *
     * @param string $content Content to extract URLs from.
     * @return string[] Array of URLs found in passed string.
     */
    function wp_extract_urls($content)
    {
    }
    /**
     * Checks content for video and audio links to add as enclosures.
     *
     * Will not add enclosures that have already been added and will
     * remove enclosures that are no longer in the post. This is called as
     * pingbacks and trackbacks.
     *
     * @since 1.5.0
     * @since 5.3.0 The `$content` parameter was made optional, and the `$post` parameter was
     *              updated to accept a post ID or a WP_Post object.
     * @since 5.6.0 The `$content` parameter is no longer optional, but passing `null` to skip it
     *              is still supported.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string|null $content Post content. If `null`, the `post_content` field from `$post` is used.
     * @param int|WP_Post $post    Post ID or post object.
     * @return void|false Void on success, false if the post is not found.
     */
    function do_enclose($content, $post)
    {
    }
    /**
     * Retrieves HTTP Headers from URL.
     *
     * @since 1.5.1
     *
     * @param string $url        URL to retrieve HTTP headers from.
     * @param bool   $deprecated Not Used.
     * @return \WpOrg\Requests\Utility\CaseInsensitiveDictionary|false Headers on success, false on failure.
     */
    function wp_get_http_headers($url, $deprecated = \false)
    {
    }
    /**
     * Determines whether the publish date of the current post in the loop is different
     * from the publish date of the previous post in the loop.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 0.71
     *
     * @global string $currentday  The day of the current post in the loop.
     * @global string $previousday The day of the previous post in the loop.
     *
     * @return int 1 when new day, 0 if not a new day.
     * @phpstan-return 0|1
     */
    function is_new_day()
    {
    }
    /**
     * Builds URL query based on an associative and, or indexed array.
     *
     * This is a convenient function for easily building url queries. It sets the
     * separator to '&' and uses _http_build_query() function.
     *
     * @since 2.3.0
     *
     * @see _http_build_query() Used to build the query
     * @link https://www.php.net/manual/en/function.http-build-query.php for more on what
     *       http_build_query() does.
     *
     * @param array $data URL-encode key/value pairs.
     * @return string URL-encoded string.
     */
    function build_query($data)
    {
    }
    /**
     * From php.net (modified by Mark Jaquith to behave like the native PHP5 function).
     *
     * @since 3.2.0
     * @access private
     *
     * @see https://www.php.net/manual/en/function.http-build-query.php
     *
     * @param array|object $data      An array or object of data. Converted to array.
     * @param string       $prefix    Optional. Numeric index. If set, start parameter numbering with it.
     *                                Default null.
     * @param string       $sep       Optional. Argument separator; defaults to 'arg_separator.output'.
     *                                Default null.
     * @param string       $key       Optional. Used to prefix key name. Default empty string.
     * @param bool         $urlencode Optional. Whether to use urlencode() in the result. Default true.
     * @return string The query string.
     */
    function _http_build_query($data, $prefix = \null, $sep = \null, $key = '', $urlencode = \true)
    {
    }
    /**
     * Retrieves a modified URL query string.
     *
     * You can rebuild the URL and append query variables to the URL query by using this function.
     * There are two ways to use this function; either a single key and value, or an associative array.
     *
     * Using a single key and value:
     *
     *     add_query_arg( 'key', 'value', 'http://example.com' );
     *
     * Using an associative array:
     *
     *     add_query_arg( array(
     *         'key1' => 'value1',
     *         'key2' => 'value2',
     *     ), 'http://example.com' );
     *
     * Omitting the URL from either use results in the current URL being used
     * (the value of `$_SERVER['REQUEST_URI']`).
     *
     * Values are expected to be encoded appropriately with urlencode() or rawurlencode().
     *
     * Setting any query variable's value to boolean false removes the key (see remove_query_arg()).
     *
     * Important: The return value of add_query_arg() is not escaped by default. Output should be
     * late-escaped with esc_url() or similar to help prevent vulnerability to cross-site scripting
     * (XSS) attacks.
     *
     * @since 1.5.0
     * @since 5.3.0 Formalized the existing and already documented parameters
     *              by adding `...$args` to the function signature.
     *
     * @param string|array $key   Either a query variable key, or an associative array of query variables.
     * @param string       $value Optional. Either a query variable value, or a URL to act upon.
     * @param string       $url   Optional. A URL to act upon.
     * @return string New URL query string (unescaped).
     */
    function add_query_arg(...$args)
    {
    }
    /**
     * Removes an item or items from a query string.
     *
     * Important: The return value of remove_query_arg() is not escaped by default. Output should be
     * late-escaped with esc_url() or similar to help prevent vulnerability to cross-site scripting
     * (XSS) attacks.
     *
     * @since 1.5.0
     *
     * @param string|string[] $key   Query key or keys to remove.
     * @param false|string    $query Optional. When false uses the current URL. Default false.
     * @return string New URL query string.
     */
    function remove_query_arg($key, $query = \false)
    {
    }
    /**
     * Returns an array of single-use query variable names that can be removed from a URL.
     *
     * @since 4.4.0
     *
     * @return string[] An array of query variable names to remove from the URL.
     */
    function wp_removable_query_args()
    {
    }
    /**
     * Walks the array while sanitizing the contents.
     *
     * @since 0.71
     * @since 5.5.0 Non-string values are left untouched.
     *
     * @param array $input_array Array to walk while sanitizing contents.
     * @return array Sanitized $input_array.
     */
    function add_magic_quotes($input_array)
    {
    }
    /**
     * HTTP request for URI to retrieve content.
     *
     * @since 1.5.1
     *
     * @see wp_safe_remote_get()
     *
     * @param string $uri URI/URL of web page to retrieve.
     * @return string|false HTTP content. False on failure.
     */
    function wp_remote_fopen($uri)
    {
    }
    /**
     * Sets up the WordPress query.
     *
     * @since 2.0.0
     *
     * @global WP       $wp           Current WordPress environment instance.
     * @global WP_Query $wp_query     WordPress Query object.
     * @global WP_Query $wp_the_query Copy of the WordPress Query object.
     *
     * @param string|array $query_vars Default WP_Query arguments.
     */
    function wp($query_vars = '')
    {
    }
    /**
     * Retrieves the description for the HTTP status.
     *
     * @since 2.3.0
     * @since 3.9.0 Added status codes 418, 428, 429, 431, and 511.
     * @since 4.5.0 Added status codes 308, 421, and 451.
     * @since 5.1.0 Added status code 103.
     * @since 6.6.0 Added status code 425.
     *
     * @global array $wp_header_to_desc
     *
     * @param int $code HTTP status code.
     * @return string Status description if found, an empty string otherwise.
     */
    function get_status_header_desc($code)
    {
    }
    /**
     * Sets HTTP status header.
     *
     * @since 2.0.0
     * @since 4.4.0 Added the `$description` parameter.
     *
     * @see get_status_header_desc()
     *
     * @param int    $code        HTTP status code.
     * @param string $description Optional. A custom description for the HTTP status.
     *                            Defaults to the result of get_status_header_desc() for the given code.
     * @phpstan-return void
     */
    function status_header($code, $description = '')
    {
    }
    /**
     * Gets the HTTP header information to prevent caching.
     *
     * The several different headers cover the different ways cache prevention
     * is handled by different browsers.
     *
     * @since 2.8.0
     * @since 6.3.0 The `Cache-Control` header for logged in users now includes the
     *              `no-store` and `private` directives.
     *
     * @return array The associative array of header names and field values.
     */
    function wp_get_nocache_headers()
    {
    }
    /**
     * Sets the HTTP headers to prevent caching for the different browsers.
     *
     * Different browsers support different nocache headers, so several
     * headers must be sent so that all of them get the point that no
     * caching should occur.
     *
     * @since 2.0.0
     *
     * @see wp_get_nocache_headers()
     * @phpstan-return void
     */
    function nocache_headers()
    {
    }
    /**
     * Sets the HTTP headers for caching for 10 days with JavaScript content type.
     *
     * @since 2.1.0
     */
    function cache_javascript_headers()
    {
    }
    /**
     * Retrieves the number of database queries during the WordPress execution.
     *
     * @since 2.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return int Number of database queries.
     */
    function get_num_queries()
    {
    }
    /**
     * Determines whether input is yes or no.
     *
     * Must be 'y' to be true.
     *
     * @since 1.0.0
     *
     * @param string $yn Character string containing either 'y' (yes) or 'n' (no).
     * @return bool True if 'y', false on anything else.
     * @phpstan-return ($yn is 'y' ? true : false)
     */
    function bool_from_yn($yn)
    {
    }
    /**
     * Loads the feed template from the use of an action hook.
     *
     * If the feed action does not have a hook, then the function will die with a
     * message telling the visitor that the feed is not valid.
     *
     * It is better to only have one hook for each feed.
     *
     * @since 2.1.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     */
    function do_feed()
    {
    }
    /**
     * Loads the RDF RSS 0.91 Feed template.
     *
     * @since 2.1.0
     *
     * @see load_template()
     */
    function do_feed_rdf()
    {
    }
    /**
     * Loads the RSS 1.0 Feed Template.
     *
     * @since 2.1.0
     *
     * @see load_template()
     */
    function do_feed_rss()
    {
    }
    /**
     * Loads either the RSS2 comment feed or the RSS2 posts feed.
     *
     * @since 2.1.0
     *
     * @see load_template()
     *
     * @param bool $for_comments True for the comment feed, false for normal feed.
     */
    function do_feed_rss2($for_comments)
    {
    }
    /**
     * Loads either Atom comment feed or Atom posts feed.
     *
     * @since 2.1.0
     *
     * @see load_template()
     *
     * @param bool $for_comments True for the comment feed, false for normal feed.
     */
    function do_feed_atom($for_comments)
    {
    }
    /**
     * Displays the default robots.txt file content.
     *
     * @since 2.1.0
     * @since 5.3.0 Remove the "Disallow: /" output if search engine visibility is
     *              discouraged in favor of robots meta HTML tag via wp_robots_no_robots()
     *              filter callback.
     */
    function do_robots()
    {
    }
    /**
     * Displays the favicon.ico file content.
     *
     * @since 5.4.0
     * @phpstan-return never
     */
    function do_favicon()
    {
    }
    /**
     * Determines whether WordPress is already installed.
     *
     * The cache will be checked first. If you have a cache plugin, which saves
     * the cache values, then this will work. If you use the default WordPress
     * cache, and the database goes away, then you might have problems.
     *
     * Checks for the 'siteurl' option for whether WordPress is installed.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.1.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return bool Whether the site is already installed.
     */
    function is_blog_installed()
    {
    }
    /**
     * Retrieves URL with nonce added to URL query.
     *
     * @since 2.0.4
     *
     * @param string     $actionurl URL to add nonce action.
     * @param int|string $action    Optional. Nonce action name. Default -1.
     * @param string     $name      Optional. Nonce name. Default '_wpnonce'.
     * @return string Escaped URL with nonce action added.
     * @phpstan-param -1|string $action
     */
    function wp_nonce_url($actionurl, $action = -1, $name = '_wpnonce')
    {
    }
    /**
     * Retrieves or display nonce hidden field for forms.
     *
     * The nonce field is used to validate that the contents of the form came from
     * the location on the current site and not somewhere else. The nonce does not
     * offer absolute protection, but should protect against most cases. It is very
     * important to use nonce field in forms.
     *
     * The $action and $name are optional, but if you want to have better security,
     * it is strongly suggested to set those two parameters. It is easier to just
     * call the function without any parameters, because validation of the nonce
     * doesn't require any parameters, but since crackers know what the default is
     * it won't be difficult for them to find a way around your nonce and cause
     * damage.
     *
     * The input name will be whatever $name value you gave. The input value will be
     * the nonce creation value.
     *
     * @since 2.0.4
     *
     * @param int|string $action  Optional. Action name. Default -1.
     * @param string     $name    Optional. Nonce name. Default '_wpnonce'.
     * @param bool       $referer Optional. Whether to set the referer field for validation. Default true.
     * @param bool       $display Optional. Whether to display or return hidden form field. Default true.
     * @return string Nonce field HTML markup.
     * @phpstan-param -1|string $action
     */
    function wp_nonce_field($action = -1, $name = '_wpnonce', $referer = \true, $display = \true)
    {
    }
    /**
     * Retrieves or displays referer hidden field for forms.
     *
     * The referer link is the current Request URI from the server super global. The
     * input name is '_wp_http_referer', in case you wanted to check manually.
     *
     * @since 2.0.4
     *
     * @param bool $display Optional. Whether to echo or return the referer field. Default true.
     * @return string Referer field HTML markup.
     */
    function wp_referer_field($display = \true)
    {
    }
    /**
     * Retrieves or displays original referer hidden field for forms.
     *
     * The input name is '_wp_original_http_referer' and will be either the same
     * value of wp_referer_field(), if that was posted already or it will be the
     * current page, if it doesn't exist.
     *
     * @since 2.0.4
     *
     * @param bool   $display      Optional. Whether to echo the original http referer. Default true.
     * @param string $jump_back_to Optional. Can be 'previous' or page you want to jump back to.
     *                             Default 'current'.
     * @return string Original referer field.
     */
    function wp_original_referer_field($display = \true, $jump_back_to = 'current')
    {
    }
    /**
     * Retrieves referer from '_wp_http_referer' or HTTP referer.
     *
     * If it's the same as the current request URL, will return false.
     *
     * @since 2.0.4
     *
     * @return string|false Referer URL on success, false on failure.
     */
    function wp_get_referer()
    {
    }
    /**
     * Retrieves unvalidated referer from the '_wp_http_referer' URL query variable or the HTTP referer.
     *
     * If the value of the '_wp_http_referer' URL query variable is not a string then it will be ignored.
     *
     * Do not use for redirects, use wp_get_referer() instead.
     *
     * @since 4.5.0
     *
     * @return string|false Referer URL on success, false on failure.
     */
    function wp_get_raw_referer()
    {
    }
    /**
     * Retrieves original referer that was posted, if it exists.
     *
     * @since 2.0.4
     *
     * @return string|false Original referer URL on success, false on failure.
     */
    function wp_get_original_referer()
    {
    }
    /**
     * Recursive directory creation based on full path.
     *
     * Will attempt to set permissions on folders.
     *
     * @since 2.0.1
     *
     * @param string $target Full path to attempt to create.
     * @return bool Whether the path was created. True if path already exists.
     */
    function wp_mkdir_p($target)
    {
    }
    /**
     * Tests if a given filesystem path is absolute.
     *
     * For example, '/foo/bar', or 'c:\windows'.
     *
     * @since 2.5.0
     *
     * @param string $path File path.
     * @return bool True if path is absolute, false is not absolute.
     */
    function path_is_absolute($path)
    {
    }
    /**
     * Joins two filesystem paths together.
     *
     * For example, 'give me $path relative to $base'. If the $path is absolute,
     * then it the full path is returned.
     *
     * @since 2.5.0
     *
     * @param string $base Base path.
     * @param string $path Path relative to $base.
     * @return string The path with the base or absolute path.
     */
    function path_join($base, $path)
    {
    }
    /**
     * Normalizes a filesystem path.
     *
     * On windows systems, replaces backslashes with forward slashes
     * and forces upper-case drive letters.
     * Allows for two leading slashes for Windows network shares, but
     * ensures that all other duplicate slashes are reduced to a single.
     *
     * @since 3.9.0
     * @since 4.4.0 Ensures upper-case drive letters on Windows systems.
     * @since 4.5.0 Allows for Windows network shares.
     * @since 4.9.7 Allows for PHP file wrappers.
     *
     * @param string $path Path to normalize.
     * @return string Normalized path.
     */
    function wp_normalize_path($path)
    {
    }
    /**
     * Determines a writable directory for temporary files.
     *
     * Function's preference is the return value of sys_get_temp_dir(),
     * followed by your PHP temporary upload directory, followed by WP_CONTENT_DIR,
     * before finally defaulting to /tmp/
     *
     * In the event that this function does not find a writable location,
     * It may be overridden by the WP_TEMP_DIR constant in your wp-config.php file.
     *
     * @since 2.5.0
     *
     * @return string Writable temporary directory.
     */
    function get_temp_dir()
    {
    }
    /**
     * Determines if a directory is writable.
     *
     * This function is used to work around certain ACL issues in PHP primarily
     * affecting Windows Servers.
     *
     * @since 3.6.0
     *
     * @see win_is_writable()
     *
     * @param string $path Path to check for write-ability.
     * @return bool Whether the path is writable.
     */
    function wp_is_writable($path)
    {
    }
    /**
     * Workaround for Windows bug in is_writable() function
     *
     * PHP has issues with Windows ACL's for determine if a
     * directory is writable or not, this works around them by
     * checking the ability to open files rather than relying
     * upon PHP to interpret the OS ACL.
     *
     * @since 2.8.0
     *
     * @see https://bugs.php.net/bug.php?id=27609
     * @see https://bugs.php.net/bug.php?id=30931
     *
     * @param string $path Windows path to check for write-ability.
     * @return bool Whether the path is writable.
     */
    function win_is_writable($path)
    {
    }
    /**
     * Retrieves uploads directory information.
     *
     * Same as wp_upload_dir() but "light weight" as it doesn't attempt to create the uploads directory.
     * Intended for use in themes, when only 'basedir' and 'baseurl' are needed, generally in all cases
     * when not uploading files.
     *
     * @since 4.5.0
     *
     * @see wp_upload_dir()
     *
     * @return array See wp_upload_dir() for description.
     */
    function wp_get_upload_dir()
    {
    }
    /**
     * Returns an array containing the current upload directory's path and URL.
     *
     * Checks the 'upload_path' option, which should be from the web root folder,
     * and if it isn't empty it will be used. If it is empty, then the path will be
     * 'WP_CONTENT_DIR/uploads'. If the 'UPLOADS' constant is defined, then it will
     * override the 'upload_path' option and 'WP_CONTENT_DIR/uploads' path.
     *
     * The upload URL path is set either by the 'upload_url_path' option or by using
     * the 'WP_CONTENT_URL' constant and appending '/uploads' to the path.
     *
     * If the 'uploads_use_yearmonth_folders' is set to true (checkbox if checked in
     * the administration settings panel), then the time will be used. The format
     * will be year first and then month.
     *
     * If the path couldn't be created, then an error will be returned with the key
     * 'error' containing the error message. The error suggests that the parent
     * directory is not writable by the server.
     *
     * @since 2.0.0
     * @uses _wp_upload_dir()
     *
     * @param string|null $time          Optional. Time formatted in 'yyyy/mm'. Default null.
     * @param bool        $create_dir    Optional. Whether to check and create the uploads directory.
     *                                   Default true for backward compatibility.
     * @param bool        $refresh_cache Optional. Whether to refresh the cache. Default false.
     * @return array {
     *     Array of information about the upload directory.
     *
     *     @type string       $path    Base directory and subdirectory or full path to upload directory.
     *     @type string       $url     Base URL and subdirectory or absolute URL to upload directory.
     *     @type string       $subdir  Subdirectory if uploads use year/month folders option is on.
     *     @type string       $basedir Path without subdir.
     *     @type string       $baseurl URL path without subdir.
     *     @type string|false $error   False or error message.
     * }
     * @phpstan-return array{
     *   path: string,
     *   url: string,
     *   subdir: string,
     *   basedir: string,
     *   baseurl: string,
     *   error: string|false,
     * }
     */
    function wp_upload_dir($time = \null, $create_dir = \true, $refresh_cache = \false)
    {
    }
    /**
     * A non-filtered, non-cached version of wp_upload_dir() that doesn't check the path.
     *
     * @since 4.5.0
     * @access private
     *
     * @param string|null $time Optional. Time formatted in 'yyyy/mm'. Default null.
     * @return array See wp_upload_dir()
     */
    function _wp_upload_dir($time = \null)
    {
    }
    /**
     * Gets a filename that is sanitized and unique for the given directory.
     *
     * If the filename is not unique, then a number will be added to the filename
     * before the extension, and will continue adding numbers until the filename
     * is unique.
     *
     * The callback function allows the caller to use their own method to create
     * unique file names. If defined, the callback should take three arguments:
     * - directory, base filename, and extension - and return a unique filename.
     *
     * @since 2.5.0
     *
     * @param string   $dir                      Directory.
     * @param string   $filename                 File name.
     * @param callable $unique_filename_callback Callback. Default null.
     * @return string New filename, if given wasn't unique.
     */
    function wp_unique_filename($dir, $filename, $unique_filename_callback = \null)
    {
    }
    /**
     * Helper function to test if each of an array of file names could conflict with existing files.
     *
     * @since 5.8.1
     * @access private
     *
     * @param string[] $filenames Array of file names to check.
     * @param string   $dir       The directory containing the files.
     * @param array    $files     An array of existing files in the directory. May be empty.
     * @return bool True if the tested file name could match an existing file, false otherwise.
     */
    function _wp_check_alternate_file_names($filenames, $dir, $files)
    {
    }
    /**
     * Helper function to check if a file name could match an existing image sub-size file name.
     *
     * @since 5.3.1
     * @access private
     *
     * @param string $filename The file name to check.
     * @param array  $files    An array of existing files in the directory.
     * @return bool True if the tested file name could match an existing file, false otherwise.
     */
    function _wp_check_existing_file_names($filename, $files)
    {
    }
    /**
     * Creates a file in the upload folder with given content.
     *
     * If there is an error, then the key 'error' will exist with the error message.
     * If success, then the key 'file' will have the unique file path, the 'url' key
     * will have the link to the new file. and the 'error' key will be set to false.
     *
     * This function will not move an uploaded file to the upload folder. It will
     * create a new file with the content in $bits parameter. If you move the upload
     * file, read the content of the uploaded file, and then you can give the
     * filename and content to this function, which will add it to the upload
     * folder.
     *
     * The permissions will be set on the new file automatically by this function.
     *
     * @since 2.0.0
     *
     * @param string      $name       Filename.
     * @param null|string $deprecated Never used. Set to null.
     * @param string      $bits       File content
     * @param string|null $time       Optional. Time formatted in 'yyyy/mm'. Default null.
     * @return array {
     *     Information about the newly-uploaded file.
     *
     *     @type string       $file  Filename of the newly-uploaded file.
     *     @type string       $url   URL of the uploaded file.
     *     @type string       $type  File type.
     *     @type string|false $error Error message, if there has been an error.
     * }
     * @phpstan-return array{
     *   file: string,
     *   url: string,
     *   type: string,
     *   error: string|false,
     * }
     */
    function wp_upload_bits($name, $deprecated, $bits, $time = \null)
    {
    }
    /**
     * Retrieves the file type based on the extension name.
     *
     * @since 2.5.0
     *
     * @param string $ext The extension to search.
     * @return string|void The file type, example: audio, video, document, spreadsheet, etc.
     */
    function wp_ext2type($ext)
    {
    }
    /**
     * Returns first matched extension for the mime-type,
     * as mapped from wp_get_mime_types().
     *
     * @since 5.8.1
     *
     * @param string $mime_type
     *
     * @return string|false
     */
    function wp_get_default_extension_for_mime_type($mime_type)
    {
    }
    /**
     * Retrieves the file type from the file name.
     *
     * You can optionally define the mime array, if needed.
     *
     * @since 2.0.4
     *
     * @param string        $filename File name or path.
     * @param string[]|null $mimes    Optional. Array of allowed mime types keyed by their file extension regex.
     *                                Defaults to the result of get_allowed_mime_types().
     * @return array {
     *     Values for the extension and mime type.
     *
     *     @type string|false $ext  File extension, or false if the file doesn't match a mime type.
     *     @type string|false $type File mime type, or false if the file doesn't match a mime type.
     * }
     * @phpstan-return array{
     *   ext: string|false,
     *   type: string|false,
     * }
     */
    function wp_check_filetype($filename, $mimes = \null)
    {
    }
    /**
     * Attempts to determine the real file type of a file.
     *
     * If unable to, the file name extension will be used to determine type.
     *
     * If it's determined that the extension does not match the file's real type,
     * then the "proper_filename" value will be set with a proper filename and extension.
     *
     * Currently this function only supports renaming images validated via wp_get_image_mime().
     *
     * @since 3.0.0
     *
     * @param string        $file     Full path to the file.
     * @param string        $filename The name of the file (may differ from $file due to $file being
     *                                in a tmp directory).
     * @param string[]|null $mimes    Optional. Array of allowed mime types keyed by their file extension regex.
     *                                Defaults to the result of get_allowed_mime_types().
     * @return array {
     *     Values for the extension, mime type, and corrected filename.
     *
     *     @type string|false $ext             File extension, or false if the file doesn't match a mime type.
     *     @type string|false $type            File mime type, or false if the file doesn't match a mime type.
     *     @type string|false $proper_filename File name with its correct extension, or false if it cannot be determined.
     * }
     * @phpstan-return array{
     *   ext: string|false,
     *   type: string|false,
     *   proper_filename: string|false,
     * }
     */
    function wp_check_filetype_and_ext($file, $filename, $mimes = \null)
    {
    }
    /**
     * Returns the real mime type of an image file.
     *
     * This depends on exif_imagetype() or getimagesize() to determine real mime types.
     *
     * @since 4.7.1
     * @since 5.8.0 Added support for WebP images.
     * @since 6.5.0 Added support for AVIF images.
     * @since 6.7.0 Added support for HEIC images.
     *
     * @param string $file Full path to the file.
     * @return string|false The actual mime type or false if the type cannot be determined.
     */
    function wp_get_image_mime($file)
    {
    }
    /**
     * Retrieves the list of mime types and file extensions.
     *
     * @since 3.5.0
     * @since 4.2.0 Support was added for GIMP (.xcf) files.
     * @since 4.9.2 Support was added for Flac (.flac) files.
     * @since 4.9.6 Support was added for AAC (.aac) files.
     *
     * @return string[] Array of mime types keyed by the file extension regex corresponding to those types.
     */
    function wp_get_mime_types()
    {
    }
    /**
     * Retrieves the list of common file extensions and their types.
     *
     * @since 4.6.0
     *
     * @return array[] Multi-dimensional array of file extensions types keyed by the type of file.
     */
    function wp_get_ext_types()
    {
    }
    /**
     * Wrapper for PHP filesize with filters and casting the result as an integer.
     *
     * @since 6.0.0
     *
     * @link https://www.php.net/manual/en/function.filesize.php
     *
     * @param string $path Path to the file.
     * @return int The size of the file in bytes, or 0 in the event of an error.
     */
    function wp_filesize($path)
    {
    }
    /**
     * Retrieves the list of allowed mime types and file extensions.
     *
     * @since 2.8.6
     *
     * @param int|WP_User $user Optional. User to check. Defaults to current user.
     * @return string[] Array of mime types keyed by the file extension regex corresponding
     *                  to those types.
     */
    function get_allowed_mime_types($user = \null)
    {
    }
    /**
     * Displays "Are You Sure" message to confirm the action being taken.
     *
     * If the action has the nonce explain message, then it will be displayed
     * along with the "Are you sure?" message.
     *
     * @since 2.0.4
     *
     * @param string $action The nonce action.
     */
    function wp_nonce_ays($action)
    {
    }
    /**
     * Kills WordPress execution and displays HTML page with an error message.
     *
     * This function complements the `die()` PHP function. The difference is that
     * HTML will be displayed to the user. It is recommended to use this function
     * only when the execution should not continue any further. It is not recommended
     * to call this function very often, and try to handle as many errors as possible
     * silently or more gracefully.
     *
     * As a shorthand, the desired HTTP response code may be passed as an integer to
     * the `$title` parameter (the default title would apply) or the `$args` parameter.
     *
     * @since 2.0.4
     * @since 4.1.0 The `$title` and `$args` parameters were changed to optionally accept
     *              an integer to be used as the response code.
     * @since 5.1.0 The `$link_url`, `$link_text`, and `$exit` arguments were added.
     * @since 5.3.0 The `$charset` argument was added.
     * @since 5.5.0 The `$text_direction` argument has a priority over get_language_attributes()
     *              in the default handler.
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string|WP_Error  $message Optional. Error message. If this is a WP_Error object,
     *                                  and not an Ajax or XML-RPC request, the error's messages are used.
     *                                  Default empty string.
     * @param string|int       $title   Optional. Error title. If `$message` is a `WP_Error` object,
     *                                  error data with the key 'title' may be used to specify the title.
     *                                  If `$title` is an integer, then it is treated as the response code.
     *                                  Default empty string.
     * @param string|array|int $args {
     *     Optional. Arguments to control behavior. If `$args` is an integer, then it is treated
     *     as the response code. Default empty array.
     *
     *     @type int    $response       The HTTP response code. Default 200 for Ajax requests, 500 otherwise.
     *     @type string $link_url       A URL to include a link to. Only works in combination with $link_text.
     *                                  Default empty string.
     *     @type string $link_text      A label for the link to include. Only works in combination with $link_url.
     *                                  Default empty string.
     *     @type bool   $back_link      Whether to include a link to go back. Default false.
     *     @type string $text_direction The text direction. This is only useful internally, when WordPress is still
     *                                  loading and the site's locale is not set up yet. Accepts 'rtl' and 'ltr'.
     *                                  Default is the value of is_rtl().
     *     @type string $charset        Character set of the HTML output. Default 'utf-8'.
     *     @type string $code           Error code to use. Default is 'wp_die', or the main error code if $message
     *                                  is a WP_Error.
     *     @type bool   $exit           Whether to exit the process after completion. Default true.
     * }
     * @phpstan-param int|array{
     *   response?: int,
     *   link_url?: string,
     *   link_text?: string,
     *   back_link?: bool,
     *   text_direction?: string,
     *   charset?: string,
     *   code?: string,
     *   exit?: bool,
     * } $args
     * @phpstan-return ($args is array{exit: false}&array ? void : never)
     */
    function wp_die($message = '', $title = '', $args = array())
    {
    }
    /**
     * Kills WordPress execution and displays HTML page with an error message.
     *
     * This is the default handler for wp_die(). If you want a custom one,
     * you can override this using the {@see 'wp_die_handler'} filter in wp_die().
     *
     * @since 3.0.0
     * @access private
     *
     * @param string|WP_Error $message Error message or WP_Error object.
     * @param string          $title   Optional. Error title. Default empty string.
     * @param string|array    $args    Optional. Arguments to control behavior. Default empty array.
     */
    function _default_wp_die_handler($message, $title = '', $args = array())
    {
    }
    /**
     * Kills WordPress execution and displays Ajax response with an error message.
     *
     * This is the handler for wp_die() when processing Ajax requests.
     *
     * @since 3.4.0
     * @access private
     *
     * @param string       $message Error message.
     * @param string       $title   Optional. Error title (unused). Default empty string.
     * @param string|array $args    Optional. Arguments to control behavior. Default empty array.
     */
    function _ajax_wp_die_handler($message, $title = '', $args = array())
    {
    }
    /**
     * Kills WordPress execution and displays JSON response with an error message.
     *
     * This is the handler for wp_die() when processing JSON requests.
     *
     * @since 5.1.0
     * @access private
     *
     * @param string       $message Error message.
     * @param string       $title   Optional. Error title. Default empty string.
     * @param string|array $args    Optional. Arguments to control behavior. Default empty array.
     */
    function _json_wp_die_handler($message, $title = '', $args = array())
    {
    }
    /**
     * Kills WordPress execution and displays JSONP response with an error message.
     *
     * This is the handler for wp_die() when processing JSONP requests.
     *
     * @since 5.2.0
     * @access private
     *
     * @param string       $message Error message.
     * @param string       $title   Optional. Error title. Default empty string.
     * @param string|array $args    Optional. Arguments to control behavior. Default empty array.
     */
    function _jsonp_wp_die_handler($message, $title = '', $args = array())
    {
    }
    /**
     * Kills WordPress execution and displays XML response with an error message.
     *
     * This is the handler for wp_die() when processing XMLRPC requests.
     *
     * @since 3.2.0
     * @access private
     *
     * @global wp_xmlrpc_server $wp_xmlrpc_server
     *
     * @param string       $message Error message.
     * @param string       $title   Optional. Error title. Default empty string.
     * @param string|array $args    Optional. Arguments to control behavior. Default empty array.
     */
    function _xmlrpc_wp_die_handler($message, $title = '', $args = array())
    {
    }
    /**
     * Kills WordPress execution and displays XML response with an error message.
     *
     * This is the handler for wp_die() when processing XML requests.
     *
     * @since 5.2.0
     * @access private
     *
     * @param string       $message Error message.
     * @param string       $title   Optional. Error title. Default empty string.
     * @param string|array $args    Optional. Arguments to control behavior. Default empty array.
     */
    function _xml_wp_die_handler($message, $title = '', $args = array())
    {
    }
    /**
     * Kills WordPress execution and displays an error message.
     *
     * This is the handler for wp_die() when processing APP requests.
     *
     * @since 3.4.0
     * @since 5.1.0 Added the $title and $args parameters.
     * @access private
     *
     * @param string       $message Optional. Response to print. Default empty string.
     * @param string       $title   Optional. Error title (unused). Default empty string.
     * @param string|array $args    Optional. Arguments to control behavior. Default empty array.
     */
    function _scalar_wp_die_handler($message = '', $title = '', $args = array())
    {
    }
    /**
     * Processes arguments passed to wp_die() consistently for its handlers.
     *
     * @since 5.1.0
     * @access private
     *
     * @param string|WP_Error $message Error message or WP_Error object.
     * @param string          $title   Optional. Error title. Default empty string.
     * @param string|array    $args    Optional. Arguments to control behavior. Default empty array.
     * @return array {
     *     Processed arguments.
     *
     *     @type string $0 Error message.
     *     @type string $1 Error title.
     *     @type array  $2 Arguments to control behavior.
     * }
     * @phpstan-return array{
     *   0: string,
     *   1: string,
     *   2: array,
     * }
     */
    function _wp_die_process_input($message, $title = '', $args = array())
    {
    }
    /**
     * Encodes a variable into JSON, with some confidence checks.
     *
     * @since 4.1.0
     * @since 5.3.0 No longer handles support for PHP < 5.6.
     * @since 6.5.0 The `$data` parameter has been renamed to `$value` and
     *              the `$options` parameter to `$flags` for parity with PHP.
     *
     * @param mixed $value Variable (usually an array or object) to encode as JSON.
     * @param int   $flags Optional. Options to be passed to json_encode(). Default 0.
     * @param int   $depth Optional. Maximum depth to walk through $value. Must be
     *                     greater than 0. Default 512.
     * @return string|false The JSON encoded string, or false if it cannot be encoded.
     * @phpstan-param int<1, max> $depth
     * @phpstan-return non-empty-string|false
     */
    function wp_json_encode($value, $flags = 0, $depth = 512)
    {
    }
    /**
     * Performs confidence checks on data that shall be encoded to JSON.
     *
     * @ignore
     * @since 4.1.0
     * @access private
     *
     * @see wp_json_encode()
     *
     * @throws Exception If depth limit is reached.
     *
     * @param mixed $value Variable (usually an array or object) to encode as JSON.
     * @param int   $depth Maximum depth to walk through $value. Must be greater than 0.
     * @return mixed The sanitized data that shall be encoded to JSON.
     * @phpstan-template T
     * @phpstan-param T $value
     * @phpstan-param int<1, max> $depth
     * @phpstan-return T
     */
    function _wp_json_sanity_check($value, $depth)
    {
    }
    /**
     * Converts a string to UTF-8, so that it can be safely encoded to JSON.
     *
     * @ignore
     * @since 4.1.0
     * @access private
     *
     * @see _wp_json_sanity_check()
     *
     * @param string $input_string The string which is to be converted.
     * @return string The checked string.
     */
    function _wp_json_convert_string($input_string)
    {
    }
    /**
     * Prepares response data to be serialized to JSON.
     *
     * This supports the JsonSerializable interface for PHP 5.2-5.3 as well.
     *
     * @ignore
     * @since 4.4.0
     * @deprecated 5.3.0 This function is no longer needed as support for PHP 5.2-5.3
     *                   has been dropped.
     * @access private
     *
     * @param mixed $value Native representation.
     * @return bool|int|float|null|string|array Data ready for `json_encode()`.
     */
    function _wp_json_prepare_data($value)
    {
    }
    /**
     * Sends a JSON response back to an Ajax request.
     *
     * @since 3.5.0
     * @since 4.7.0 The `$status_code` parameter was added.
     * @since 5.6.0 The `$flags` parameter was added.
     *
     * @param mixed $response    Variable (usually an array or object) to encode as JSON,
     *                           then print and die.
     * @param int   $status_code Optional. The HTTP status code to output. Default null.
     * @param int   $flags       Optional. Options to be passed to json_encode(). Default 0.
     */
    function wp_send_json($response, $status_code = \null, $flags = 0)
    {
    }
    /**
     * Sends a JSON response back to an Ajax request, indicating success.
     *
     * @since 3.5.0
     * @since 4.7.0 The `$status_code` parameter was added.
     * @since 5.6.0 The `$flags` parameter was added.
     *
     * @param mixed $value       Optional. Data to encode as JSON, then print and die. Default null.
     * @param int   $status_code Optional. The HTTP status code to output. Default null.
     * @param int   $flags       Optional. Options to be passed to json_encode(). Default 0.
     * @phpstan-return never
     */
    function wp_send_json_success($value = \null, $status_code = \null, $flags = 0)
    {
    }
    /**
     * Sends a JSON response back to an Ajax request, indicating failure.
     *
     * If the `$value` parameter is a WP_Error object, the errors
     * within the object are processed and output as an array of error
     * codes and corresponding messages. All other types are output
     * without further processing.
     *
     * @since 3.5.0
     * @since 4.1.0 The `$value` parameter is now processed if a WP_Error object is passed in.
     * @since 4.7.0 The `$status_code` parameter was added.
     * @since 5.6.0 The `$flags` parameter was added.
     *
     * @param mixed $value       Optional. Data to encode as JSON, then print and die. Default null.
     * @param int   $status_code Optional. The HTTP status code to output. Default null.
     * @param int   $flags       Optional. Options to be passed to json_encode(). Default 0.
     * @phpstan-return never
     */
    function wp_send_json_error($value = \null, $status_code = \null, $flags = 0)
    {
    }
    /**
     * Checks that a JSONP callback is a valid JavaScript callback name.
     *
     * Only allows alphanumeric characters and the dot character in callback
     * function names. This helps to mitigate XSS attacks caused by directly
     * outputting user input.
     *
     * @since 4.6.0
     *
     * @param string $callback Supplied JSONP callback function name.
     * @return bool Whether the callback function name is valid.
     */
    function wp_check_jsonp_callback($callback)
    {
    }
    /**
     * Reads and decodes a JSON file.
     *
     * @since 5.9.0
     *
     * @param string $filename Path to the JSON file.
     * @param array  $options  {
     *     Optional. Options to be used with `json_decode()`.
     *
     *     @type bool $associative Optional. When `true`, JSON objects will be returned as associative arrays.
     *                             When `false`, JSON objects will be returned as objects. Default false.
     * }
     *
     * @return mixed Returns the value encoded in JSON in appropriate PHP type.
     *               `null` is returned if the file is not found, or its content can't be decoded.
     * @phpstan-param array{
     *   associative?: bool,
     * } $options
     */
    function wp_json_file_decode($filename, $options = array())
    {
    }
    /**
     * Retrieves the WordPress home page URL.
     *
     * If the constant named 'WP_HOME' exists, then it will be used and returned
     * by the function. This can be used to counter the redirection on your local
     * development environment.
     *
     * @since 2.2.0
     * @access private
     *
     * @see WP_HOME
     *
     * @param string $url URL for the home location.
     * @return string Homepage location.
     */
    function _config_wp_home($url = '')
    {
    }
    /**
     * Retrieves the WordPress site URL.
     *
     * If the constant named 'WP_SITEURL' is defined, then the value in that
     * constant will always be returned. This can be used for debugging a site
     * on your localhost while not having to change the database to your URL.
     *
     * @since 2.2.0
     * @access private
     *
     * @see WP_SITEURL
     *
     * @param string $url URL to set the WordPress site location.
     * @return string The WordPress site URL.
     */
    function _config_wp_siteurl($url = '')
    {
    }
    /**
     * Deletes the fresh site option.
     *
     * @since 4.7.0
     * @access private
     */
    function _delete_option_fresh_site()
    {
    }
    /**
     * Sets the localized direction for MCE plugin.
     *
     * Will only set the direction to 'rtl', if the WordPress locale has
     * the text direction set to 'rtl'.
     *
     * Fills in the 'directionality' setting, enables the 'directionality'
     * plugin, and adds the 'ltr' button to 'toolbar1', formerly
     * 'theme_advanced_buttons1' array keys. These keys are then returned
     * in the $mce_init (TinyMCE settings) array.
     *
     * @since 2.1.0
     * @access private
     *
     * @param array $mce_init MCE settings array.
     * @return array Direction set for 'rtl', if needed by locale.
     */
    function _mce_set_direction($mce_init)
    {
    }
    /**
     * Determines whether WordPress is currently serving a REST API request.
     *
     * The function relies on the 'REST_REQUEST' global. As such, it only returns true when an actual REST _request_ is
     * being made. It does not return true when a REST endpoint is hit as part of another request, e.g. for preloading a
     * REST response. See {@see wp_is_rest_endpoint()} for that purpose.
     *
     * This function should not be called until the {@see 'parse_request'} action, as the constant is only defined then,
     * even for an actual REST request.
     *
     * @since 6.5.0
     *
     * @return bool True if it's a WordPress REST API request, false otherwise.
     */
    function wp_is_serving_rest_request()
    {
    }
    /**
     * Converts smiley code to the icon graphic file equivalent.
     *
     * You can turn off smilies, by going to the write setting screen and unchecking
     * the box, or by setting 'use_smilies' option to false or removing the option.
     *
     * Plugins may override the default smiley list by setting the $wpsmiliestrans
     * to an array, with the key the code the blogger types in and the value the
     * image file.
     *
     * The $wp_smiliessearch global is for the regular expression and is set each
     * time the function is called.
     *
     * The full list of smilies can be found in the function and won't be listed in
     * the description. Probably should create a Codex page for it, so that it is
     * available.
     *
     * @since 2.2.0
     *
     * @global array $wpsmiliestrans
     * @global array $wp_smiliessearch
     * @phpstan-return void
     */
    function smilies_init()
    {
    }
    /**
     * Merges user defined arguments into defaults array.
     *
     * This function is used throughout WordPress to allow for both string or array
     * to be merged into another array.
     *
     * @since 2.2.0
     * @since 2.3.0 `$args` can now also be an object.
     *
     * @param string|array|object $args     Value to merge with $defaults.
     * @param array               $defaults Optional. Array that serves as the defaults.
     *                                      Default empty array.
     * @return array Merged user defined values with defaults.
     */
    function wp_parse_args($args, $defaults = array())
    {
    }
    /**
     * Converts a comma- or space-separated list of scalar values to an array.
     *
     * @since 5.1.0
     *
     * @param array|string $input_list List of values.
     * @return array Array of values.
     * @phpstan-return ($input_list is array ? array<scalar> : list<string>)
     */
    function wp_parse_list($input_list)
    {
    }
    /**
     * Cleans up an array, comma- or space-separated list of IDs.
     *
     * @since 3.0.0
     * @since 5.1.0 Refactored to use wp_parse_list().
     *
     * @param array|string $input_list List of IDs.
     * @return int[] Sanitized array of IDs.
     */
    function wp_parse_id_list($input_list)
    {
    }
    /**
     * Cleans up an array, comma- or space-separated list of slugs.
     *
     * @since 4.7.0
     * @since 5.1.0 Refactored to use wp_parse_list().
     *
     * @param array|string $input_list List of slugs.
     * @return string[] Sanitized array of slugs.
     */
    function wp_parse_slug_list($input_list)
    {
    }
    /**
     * Extracts a slice of an array, given a list of keys.
     *
     * @since 3.1.0
     *
     * @param array $input_array The original array.
     * @param array $keys        The list of keys.
     * @return array The array slice.
     */
    function wp_array_slice_assoc($input_array, $keys)
    {
    }
    /**
     * Sorts the keys of an array alphabetically.
     *
     * The array is passed by reference so it doesn't get returned
     * which mimics the behavior of `ksort()`.
     *
     * @since 6.0.0
     *
     * @param array $input_array The array to sort, passed by reference.
     */
    function wp_recursive_ksort(&$input_array)
    {
    }
    /**
     * Accesses an array in depth based on a path of keys.
     *
     * It is the PHP equivalent of JavaScript's `lodash.get()` and mirroring it may help other components
     * retain some symmetry between client and server implementations.
     *
     * Example usage:
     *
     *     $input_array = array(
     *         'a' => array(
     *             'b' => array(
     *                 'c' => 1,
     *             ),
     *         ),
     *     );
     *     _wp_array_get( $input_array, array( 'a', 'b', 'c' ) );
     *
     * @internal
     *
     * @since 5.6.0
     * @access private
     *
     * @param array $input_array   An array from which we want to retrieve some information.
     * @param array $path          An array of keys describing the path with which to retrieve information.
     * @param mixed $default_value Optional. The return value if the path does not exist within the array,
     *                             or if `$input_array` or `$path` are not arrays. Default null.
     * @return mixed The value from the path specified.
     */
    function _wp_array_get($input_array, $path, $default_value = \null)
    {
    }
    /**
     * Sets an array in depth based on a path of keys.
     *
     * It is the PHP equivalent of JavaScript's `lodash.set()` and mirroring it may help other components
     * retain some symmetry between client and server implementations.
     *
     * Example usage:
     *
     *     $input_array = array();
     *     _wp_array_set( $input_array, array( 'a', 'b', 'c', 1 ) );
     *
     *     $input_array becomes:
     *     array(
     *         'a' => array(
     *             'b' => array(
     *                 'c' => 1,
     *             ),
     *         ),
     *     );
     *
     * @internal
     *
     * @since 5.8.0
     * @access private
     *
     * @param array $input_array An array that we want to mutate to include a specific value in a path.
     * @param array $path        An array of keys describing the path that we want to mutate.
     * @param mixed $value       The value that will be set.
     * @phpstan-return void
     */
    function _wp_array_set(&$input_array, $path, $value = \null)
    {
    }
    /**
     * This function is trying to replicate what
     * lodash's kebabCase (JS library) does in the client.
     *
     * The reason we need this function is that we do some processing
     * in both the client and the server (e.g.: we generate
     * preset classes from preset slugs) that needs to
     * create the same output.
     *
     * We can't remove or update the client's library due to backward compatibility
     * (some of the output of lodash's kebabCase is saved in the post content).
     * We have to make the server behave like the client.
     *
     * Changes to this function should follow updates in the client
     * with the same logic.
     *
     * @link https://github.com/lodash/lodash/blob/4.17/dist/lodash.js#L14369
     * @link https://github.com/lodash/lodash/blob/4.17/dist/lodash.js#L278
     * @link https://github.com/lodash-php/lodash-php/blob/master/src/String/kebabCase.php
     * @link https://github.com/lodash-php/lodash-php/blob/master/src/internal/unicodeWords.php
     *
     * @param string $input_string The string to kebab-case.
     *
     * @return string kebab-cased-string.
     */
    function _wp_to_kebab_case($input_string)
    {
    }
    /**
     * Determines if the variable is a numeric-indexed array.
     *
     * @since 4.4.0
     *
     * @param mixed $data Variable to check.
     * @return bool Whether the variable is a list.
     * @template T of mixed
     * @phpstan-param T $data
     * @phpstan-assert-if-true (T is list ? T : array<int, value-of<T>>) $data
     * @phpstan-return (T is array ? (key-of<T> is int ? true : false) : false)
     */
    function wp_is_numeric_array($data)
    {
    }
    /**
     * Filters a list of objects, based on a set of key => value arguments.
     *
     * Retrieves the objects from the list that match the given arguments.
     * Key represents property name, and value represents property value.
     *
     * If an object has more properties than those specified in arguments,
     * that will not disqualify it. When using the 'AND' operator,
     * any missing properties will disqualify it.
     *
     * When using the `$field` argument, this function can also retrieve
     * a particular field from all matching objects, whereas wp_list_filter()
     * only does the filtering.
     *
     * @since 3.0.0
     * @since 4.7.0 Uses `WP_List_Util` class.
     *
     * @param array       $input_list An array of objects to filter.
     * @param array       $args       Optional. An array of key => value arguments to match
     *                                against each object. Default empty array.
     * @param string      $operator   Optional. The logical operation to perform. 'AND' means
     *                                all elements from the array must match. 'OR' means only
     *                                one element needs to match. 'NOT' means no elements may
     *                                match. Default 'AND'.
     * @param bool|string $field      Optional. A field from the object to place instead
     *                                of the entire object. Default false.
     * @return array A list of objects or object fields.
     */
    function wp_filter_object_list($input_list, $args = array(), $operator = 'and', $field = \false)
    {
    }
    /**
     * Filters a list of objects, based on a set of key => value arguments.
     *
     * Retrieves the objects from the list that match the given arguments.
     * Key represents property name, and value represents property value.
     *
     * If an object has more properties than those specified in arguments,
     * that will not disqualify it. When using the 'AND' operator,
     * any missing properties will disqualify it.
     *
     * If you want to retrieve a particular field from all matching objects,
     * use wp_filter_object_list() instead.
     *
     * @since 3.1.0
     * @since 4.7.0 Uses `WP_List_Util` class.
     * @since 5.9.0 Converted into a wrapper for `wp_filter_object_list()`.
     *
     * @param array  $input_list An array of objects to filter.
     * @param array  $args       Optional. An array of key => value arguments to match
     *                           against each object. Default empty array.
     * @param string $operator   Optional. The logical operation to perform. 'AND' means
     *                           all elements from the array must match. 'OR' means only
     *                           one element needs to match. 'NOT' means no elements may
     *                           match. Default 'AND'.
     * @return array Array of found values.
     */
    function wp_list_filter($input_list, $args = array(), $operator = 'AND')
    {
    }
    /**
     * Plucks a certain field out of each object or array in an array.
     *
     * This has the same functionality and prototype of
     * array_column() (PHP 5.5) but also supports objects.
     *
     * @since 3.1.0
     * @since 4.0.0 $index_key parameter added.
     * @since 4.7.0 Uses `WP_List_Util` class.
     *
     * @param array      $input_list List of objects or arrays.
     * @param int|string $field      Field from the object to place instead of the entire object.
     * @param int|string $index_key  Optional. Field from the object to use as keys for the new array.
     *                               Default null.
     * @return array Array of found values. If `$index_key` is set, an array of found values with keys
     *               corresponding to `$index_key`. If `$index_key` is null, array keys from the original
     *               `$input_list` will be preserved in the results.
     */
    function wp_list_pluck($input_list, $field, $index_key = \null)
    {
    }
    /**
     * Sorts an array of objects or arrays based on one or more orderby arguments.
     *
     * @since 4.7.0
     *
     * @param array        $input_list    An array of objects or arrays to sort.
     * @param string|array $orderby       Optional. Either the field name to order by or an array
     *                                    of multiple orderby fields as `$orderby => $order`.
     *                                    Default empty array.
     * @param string       $order         Optional. Either 'ASC' or 'DESC'. Only used if `$orderby`
     *                                    is a string. Default 'ASC'.
     * @param bool         $preserve_keys Optional. Whether to preserve keys. Default false.
     * @return array The sorted array.
     * @phpstan-param 'ASC'|'DESC' $order
     */
    function wp_list_sort($input_list, $orderby = array(), $order = 'ASC', $preserve_keys = \false)
    {
    }
    /**
     * Determines if Widgets library should be loaded.
     *
     * Checks to make sure that the widgets library hasn't already been loaded.
     * If it hasn't, then it will load the widgets library and run an action hook.
     *
     * @since 2.2.0
     * @phpstan-return void
     */
    function wp_maybe_load_widgets()
    {
    }
    /**
     * Appends the Widgets menu to the themes main menu.
     *
     * @since 2.2.0
     * @since 5.9.3 Don't specify menu order when the active theme is a block theme.
     *
     * @global array $submenu
     * @phpstan-return void
     */
    function wp_widgets_add_menu()
    {
    }
    /**
     * Flushes all output buffers for PHP 5.2.
     *
     * Make sure all output buffers are flushed before our singletons are destroyed.
     *
     * @since 2.2.0
     */
    function wp_ob_end_flush_all()
    {
    }
    /**
     * Loads custom DB error or display WordPress DB error.
     *
     * If a file exists in the wp-content directory named db-error.php, then it will
     * be loaded instead of displaying the WordPress DB error. If it is not found,
     * then the WordPress DB error will be displayed instead.
     *
     * The WordPress DB error sets the HTTP status header to 500 to try to prevent
     * search engines from caching the message. Custom DB messages should do the
     * same.
     *
     * This function was backported to WordPress 2.3.2, but originally was added
     * in WordPress 2.5.0.
     *
     * @since 2.3.2
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     * @phpstan-return never
     */
    function dead_db()
    {
    }
    /**
     * Marks a function as deprecated and inform when it has been used.
     *
     * There is a {@see 'deprecated_function_run'} hook that will be called that can be used
     * to get the backtrace up to what file and function called the deprecated function.
     *
     * The current behavior is to trigger a user error if `WP_DEBUG` is true.
     *
     * This function is to be used in every function that is deprecated.
     *
     * @since 2.5.0
     * @since 5.4.0 This function is no longer marked as "private".
     * @since 5.4.0 The error type is now classified as E_USER_DEPRECATED (used to default to E_USER_NOTICE).
     *
     * @param string $function_name The function that was called.
     * @param string $version       The version of WordPress that deprecated the function.
     * @param string $replacement   Optional. The function that should have been called. Default empty string.
     */
    function _deprecated_function($function_name, $version, $replacement = '')
    {
    }
    /**
     * Marks a constructor as deprecated and informs when it has been used.
     *
     * Similar to _deprecated_function(), but with different strings. Used to
     * remove PHP4-style constructors.
     *
     * The current behavior is to trigger a user error if `WP_DEBUG` is true.
     *
     * This function is to be used in every PHP4-style constructor method that is deprecated.
     *
     * @since 4.3.0
     * @since 4.5.0 Added the `$parent_class` parameter.
     * @since 5.4.0 This function is no longer marked as "private".
     * @since 5.4.0 The error type is now classified as E_USER_DEPRECATED (used to default to E_USER_NOTICE).
     *
     * @param string $class_name   The class containing the deprecated constructor.
     * @param string $version      The version of WordPress that deprecated the function.
     * @param string $parent_class Optional. The parent class calling the deprecated constructor.
     *                             Default empty string.
     */
    function _deprecated_constructor($class_name, $version, $parent_class = '')
    {
    }
    /**
     * Marks a class as deprecated and informs when it has been used.
     *
     * There is a {@see 'deprecated_class_run'} hook that will be called that can be used
     * to get the backtrace up to what file and function called the deprecated class.
     *
     * The current behavior is to trigger a user error if `WP_DEBUG` is true.
     *
     * This function is to be used in the class constructor for every deprecated class.
     * See {@see _deprecated_constructor()} for deprecating PHP4-style constructors.
     *
     * @since 6.4.0
     *
     * @param string $class_name  The name of the class being instantiated.
     * @param string $version     The version of WordPress that deprecated the class.
     * @param string $replacement Optional. The class or function that should have been called.
     *                            Default empty string.
     */
    function _deprecated_class($class_name, $version, $replacement = '')
    {
    }
    /**
     * Marks a file as deprecated and inform when it has been used.
     *
     * There is a {@see 'deprecated_file_included'} hook that will be called that can be used
     * to get the backtrace up to what file and function included the deprecated file.
     *
     * The current behavior is to trigger a user error if `WP_DEBUG` is true.
     *
     * This function is to be used in every file that is deprecated.
     *
     * @since 2.5.0
     * @since 5.4.0 This function is no longer marked as "private".
     * @since 5.4.0 The error type is now classified as E_USER_DEPRECATED (used to default to E_USER_NOTICE).
     *
     * @param string $file        The file that was included.
     * @param string $version     The version of WordPress that deprecated the file.
     * @param string $replacement Optional. The file that should have been included based on ABSPATH.
     *                            Default empty string.
     * @param string $message     Optional. A message regarding the change. Default empty string.
     */
    function _deprecated_file($file, $version, $replacement = '', $message = '')
    {
    }
    /**
     * Marks a function argument as deprecated and inform when it has been used.
     *
     * This function is to be used whenever a deprecated function argument is used.
     * Before this function is called, the argument must be checked for whether it was
     * used by comparing it to its default value or evaluating whether it is empty.
     *
     * For example:
     *
     *     if ( ! empty( $deprecated ) ) {
     *         _deprecated_argument( __FUNCTION__, '3.0.0' );
     *     }
     *
     * There is a {@see 'deprecated_argument_run'} hook that will be called that can be used
     * to get the backtrace up to what file and function used the deprecated argument.
     *
     * The current behavior is to trigger a user error if WP_DEBUG is true.
     *
     * @since 3.0.0
     * @since 5.4.0 This function is no longer marked as "private".
     * @since 5.4.0 The error type is now classified as E_USER_DEPRECATED (used to default to E_USER_NOTICE).
     *
     * @param string $function_name The function that was called.
     * @param string $version       The version of WordPress that deprecated the argument used.
     * @param string $message       Optional. A message regarding the change. Default empty string.
     */
    function _deprecated_argument($function_name, $version, $message = '')
    {
    }
    /**
     * Marks a deprecated action or filter hook as deprecated and throws a notice.
     *
     * Use the {@see 'deprecated_hook_run'} action to get the backtrace describing where
     * the deprecated hook was called.
     *
     * Default behavior is to trigger a user error if `WP_DEBUG` is true.
     *
     * This function is called by the do_action_deprecated() and apply_filters_deprecated()
     * functions, and so generally does not need to be called directly.
     *
     * @since 4.6.0
     * @since 5.4.0 The error type is now classified as E_USER_DEPRECATED (used to default to E_USER_NOTICE).
     * @access private
     *
     * @param string $hook        The hook that was used.
     * @param string $version     The version of WordPress that deprecated the hook.
     * @param string $replacement Optional. The hook that should have been used. Default empty string.
     * @param string $message     Optional. A message regarding the change. Default empty.
     */
    function _deprecated_hook($hook, $version, $replacement = '', $message = '')
    {
    }
    /**
     * Marks something as being incorrectly called.
     *
     * There is a {@see 'doing_it_wrong_run'} hook that will be called that can be used
     * to get the backtrace up to what file and function called the deprecated function.
     *
     * The current behavior is to trigger a user error if `WP_DEBUG` is true.
     *
     * @since 3.1.0
     * @since 5.4.0 This function is no longer marked as "private".
     *
     * @param string $function_name The function that was called.
     * @param string $message       A message explaining what has been done incorrectly.
     * @param string $version       The version of WordPress where the message was added.
     */
    function _doing_it_wrong($function_name, $message, $version)
    {
    }
    /**
     * Generates a user-level error/warning/notice/deprecation message.
     *
     * Generates the message when `WP_DEBUG` is true.
     *
     * @since 6.4.0
     *
     * @param string $function_name The function that triggered the error.
     * @param string $message       The message explaining the error.
     *                              The message can contain allowed HTML 'a' (with href), 'code',
     *                              'br', 'em', and 'strong' tags and http or https protocols.
     *                              If it contains other HTML tags or protocols, the message should be escaped
     *                              before passing to this function to avoid being stripped {@see wp_kses()}.
     * @param int    $error_level   Optional. The designated error type for this error.
     *                              Only works with E_USER family of constants. Default E_USER_NOTICE.
     * @phpstan-param \E_USER_ERROR|\E_USER_WARNING|\E_USER_NOTICE|\E_USER_DEPRECATED $error_level
     * @phpstan-return void
     */
    function wp_trigger_error($function_name, $message, $error_level = \E_USER_NOTICE)
    {
    }
    /**
     * Determines whether the server is running an earlier than 1.5.0 version of lighttpd.
     *
     * @since 2.5.0
     *
     * @return bool Whether the server is running lighttpd < 1.5.0.
     */
    function is_lighttpd_before_150()
    {
    }
    /**
     * Determines whether the specified module exist in the Apache config.
     *
     * @since 2.5.0
     *
     * @global bool $is_apache
     *
     * @param string $mod           The module, e.g. mod_rewrite.
     * @param bool   $default_value Optional. The default return value if the module is not found. Default false.
     * @return bool Whether the specified module is loaded.
     */
    function apache_mod_loaded($mod, $default_value = \false)
    {
    }
    /**
     * Checks if IIS 7+ supports pretty permalinks.
     *
     * @since 2.8.0
     *
     * @global bool $is_iis7
     *
     * @return bool Whether IIS7 supports permalinks.
     */
    function iis7_supports_permalinks()
    {
    }
    /**
     * Validates a file name and path against an allowed set of rules.
     *
     * A return value of `1` means the file path contains directory traversal.
     *
     * A return value of `2` means the file path contains a Windows drive path.
     *
     * A return value of `3` means the file is not in the allowed files list.
     *
     * @since 1.2.0
     *
     * @param string   $file          File path.
     * @param string[] $allowed_files Optional. Array of allowed files. Default empty array.
     * @return int 0 means nothing is wrong, greater than 0 means something was wrong.
     * @phpstan-return ($file is '' ? 0 : ($allowed_files is empty ? 0|1|2 : 0|1|2|3))
     */
    function validate_file($file, $allowed_files = array())
    {
    }
    /**
     * Determines whether to force SSL used for the Administration Screens.
     *
     * @since 2.6.0
     *
     * @param string|bool $force Optional. Whether to force SSL in admin screens. Default null.
     * @return bool True if forced, false if not forced.
     */
    function force_ssl_admin($force = \null)
    {
    }
    /**
     * Guesses the URL for the site.
     *
     * Will remove wp-admin links to retrieve only return URLs not in the wp-admin
     * directory.
     *
     * @since 2.6.0
     *
     * @return string The guessed URL.
     */
    function wp_guess_url()
    {
    }
    /**
     * Temporarily suspends cache additions.
     *
     * Stops more data being added to the cache, but still allows cache retrieval.
     * This is useful for actions, such as imports, when a lot of data would otherwise
     * be almost uselessly added to the cache.
     *
     * Suspension lasts for a single page load at most. Remember to call this
     * function again if you wish to re-enable cache adds earlier.
     *
     * @since 3.3.0
     *
     * @param bool $suspend Optional. Suspends additions if true, re-enables them if false.
     *                      Defaults to not changing the current setting.
     * @return bool The current suspend setting.
     */
    function wp_suspend_cache_addition($suspend = \null)
    {
    }
    /**
     * Suspends cache invalidation.
     *
     * Turns cache invalidation on and off. Useful during imports where you don't want to do
     * invalidations every time a post is inserted. Callers must be sure that what they are
     * doing won't lead to an inconsistent cache when invalidation is suspended.
     *
     * @since 2.7.0
     *
     * @global bool $_wp_suspend_cache_invalidation
     *
     * @param bool $suspend Optional. Whether to suspend or enable cache invalidation. Default true.
     * @return bool The current suspend setting.
     */
    function wp_suspend_cache_invalidation($suspend = \true)
    {
    }
    /**
     * Determines whether a site is the main site of the current network.
     *
     * @since 3.0.0
     * @since 4.9.0 The `$network_id` parameter was added.
     *
     * @param int $site_id    Optional. Site ID to test. Defaults to current site.
     * @param int $network_id Optional. Network ID of the network to check for.
     *                        Defaults to current network.
     * @return bool True if $site_id is the main site of the network, or if not
     *              running Multisite.
     */
    function is_main_site($site_id = \null, $network_id = \null)
    {
    }
    /**
     * Gets the main site ID.
     *
     * @since 4.9.0
     *
     * @param int $network_id Optional. The ID of the network for which to get the main site.
     *                        Defaults to the current network.
     * @return int The ID of the main site.
     */
    function get_main_site_id($network_id = \null)
    {
    }
    /**
     * Determines whether a network is the main network of the Multisite installation.
     *
     * @since 3.7.0
     *
     * @param int $network_id Optional. Network ID to test. Defaults to current network.
     * @return bool True if $network_id is the main network, or if not running Multisite.
     */
    function is_main_network($network_id = \null)
    {
    }
    /**
     * Gets the main network ID.
     *
     * @since 4.3.0
     *
     * @return int The ID of the main network.
     */
    function get_main_network_id()
    {
    }
    /**
     * Determines whether site meta is enabled.
     *
     * This function checks whether the 'blogmeta' database table exists. The result is saved as
     * a setting for the main network, making it essentially a global setting. Subsequent requests
     * will refer to this setting instead of running the query.
     *
     * @since 5.1.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return bool True if site meta is supported, false otherwise.
     */
    function is_site_meta_supported()
    {
    }
    /**
     * Modifies gmt_offset for smart timezone handling.
     *
     * Overrides the gmt_offset option if we have a timezone_string available.
     *
     * @since 2.8.0
     *
     * @return float|false Timezone GMT offset, false otherwise.
     */
    function wp_timezone_override_offset()
    {
    }
    /**
     * Sort-helper for timezones.
     *
     * @since 2.9.0
     * @access private
     *
     * @param array $a
     * @param array $b
     * @return int
     */
    function _wp_timezone_choice_usort_callback($a, $b)
    {
    }
    /**
     * Gives a nicely-formatted list of timezone strings.
     *
     * @since 2.9.0
     * @since 4.7.0 Added the `$locale` parameter.
     *
     * @param string $selected_zone Selected timezone.
     * @param string $locale        Optional. Locale to load the timezones in. Default current site locale.
     * @return string
     */
    function wp_timezone_choice($selected_zone, $locale = \null)
    {
    }
    /**
     * Strips close comment and close php tags from file headers used by WP.
     *
     * @since 2.8.0
     * @access private
     *
     * @see https://core.trac.wordpress.org/ticket/8497
     *
     * @param string $str Header comment to clean up.
     * @return string
     */
    function _cleanup_header_comment($str)
    {
    }
    /**
     * Permanently deletes comments or posts of any type that have held a status
     * of 'trash' for the number of days defined in EMPTY_TRASH_DAYS.
     *
     * The default value of `EMPTY_TRASH_DAYS` is 30 (days).
     *
     * @since 2.9.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function wp_scheduled_delete()
    {
    }
    /**
     * Retrieves metadata from a file.
     *
     * Searches for metadata in the first 8 KB of a file, such as a plugin or theme.
     * Each piece of metadata must be on its own line. Fields can not span multiple
     * lines, the value will get cut at the end of the first line.
     *
     * If the file data is not within that first 8 KB, then the author should correct
     * their plugin file and move the data headers to the top.
     *
     * @link https://codex.wordpress.org/File_Header
     *
     * @since 2.9.0
     *
     * @param string $file            Absolute path to the file.
     * @param array  $default_headers List of headers, in the format `array( 'HeaderKey' => 'Header Name' )`.
     * @param string $context         Optional. If specified adds filter hook {@see 'extra_$context_headers'}.
     *                                Default empty string.
     * @return string[] Array of file header values keyed by header name.
     */
    function get_file_data($file, $default_headers, $context = '')
    {
    }
    /**
     * Returns true.
     *
     * Useful for returning true to filters easily.
     *
     * @since 3.0.0
     *
     * @see __return_false()
     *
     * @return true True.
     */
    function __return_true()
    {
    }
    /**
     * Returns false.
     *
     * Useful for returning false to filters easily.
     *
     * @since 3.0.0
     *
     * @see __return_true()
     *
     * @return false False.
     */
    function __return_false()
    {
    }
    /**
     * Returns 0.
     *
     * Useful for returning 0 to filters easily.
     *
     * @since 3.0.0
     *
     * @return int 0.
     * @phpstan-return 0
     */
    function __return_zero()
    {
    }
    /**
     * Returns an empty array.
     *
     * Useful for returning an empty array to filters easily.
     *
     * @since 3.0.0
     *
     * @return array Empty array.
     * @phpstan-return array{}
     */
    function __return_empty_array()
    {
    }
    /**
     * Returns null.
     *
     * Useful for returning null to filters easily.
     *
     * @since 3.4.0
     *
     * @return null Null value.
     */
    function __return_null()
    {
    }
    /**
     * Returns an empty string.
     *
     * Useful for returning an empty string to filters easily.
     *
     * @since 3.7.0
     *
     * @see __return_null()
     *
     * @return string Empty string.
     * @phpstan-return ''
     */
    function __return_empty_string()
    {
    }
    /**
     * Sends a HTTP header to disable content type sniffing in browsers which support it.
     *
     * @since 3.0.0
     *
     * @see https://blogs.msdn.com/ie/archive/2008/07/02/ie8-security-part-v-comprehensive-protection.aspx
     * @see https://src.chromium.org/viewvc/chrome?view=rev&revision=6985
     */
    function send_nosniff_header()
    {
    }
    /**
     * Returns a MySQL expression for selecting the week number based on the start_of_week option.
     *
     * @ignore
     * @since 3.0.0
     *
     * @param string $column Database column.
     * @return string SQL clause.
     */
    function _wp_mysql_week($column)
    {
    }
    /**
     * Finds hierarchy loops using a callback function that maps object IDs to parent IDs.
     *
     * @since 3.1.0
     * @access private
     *
     * @param callable $callback      Function that accepts ( ID, $callback_args ) and outputs parent_ID.
     * @param int      $start         The ID to start the loop check at.
     * @param int      $start_parent  The parent_ID of $start to use instead of calling $callback( $start ).
     *                                Use null to always use $callback.
     * @param array    $callback_args Optional. Additional arguments to send to $callback. Default empty array.
     * @return array IDs of all members of loop.
     */
    function wp_find_hierarchy_loop($callback, $start, $start_parent, $callback_args = array())
    {
    }
    /**
     * Uses the "The Tortoise and the Hare" algorithm to detect loops.
     *
     * For every step of the algorithm, the hare takes two steps and the tortoise one.
     * If the hare ever laps the tortoise, there must be a loop.
     *
     * @since 3.1.0
     * @access private
     *
     * @param callable $callback      Function that accepts ( ID, callback_arg, ... ) and outputs parent_ID.
     * @param int      $start         The ID to start the loop check at.
     * @param array    $override      Optional. An array of ( ID => parent_ID, ... ) to use instead of $callback.
     *                                Default empty array.
     * @param array    $callback_args Optional. Additional arguments to send to $callback. Default empty array.
     * @param bool     $_return_loop  Optional. Return loop members or just detect presence of loop? Only set
     *                                to true if you already know the given $start is part of a loop (otherwise
     *                                the returned array might include branches). Default false.
     * @return mixed Scalar ID of some arbitrary member of the loop, or array of IDs of all members of loop if
     *               $_return_loop
     */
    function wp_find_hierarchy_loop_tortoise_hare($callback, $start, $override = array(), $callback_args = array(), $_return_loop = \false)
    {
    }
    /**
     * Sends a HTTP header to limit rendering of pages to same origin iframes.
     *
     * @since 3.1.3
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Frame-Options
     */
    function send_frame_options_header()
    {
    }
    /**
     * Retrieves a list of protocols to allow in HTML attributes.
     *
     * @since 3.3.0
     * @since 4.3.0 Added 'webcal' to the protocols array.
     * @since 4.7.0 Added 'urn' to the protocols array.
     * @since 5.3.0 Added 'sms' to the protocols array.
     * @since 5.6.0 Added 'irc6' and 'ircs' to the protocols array.
     *
     * @see wp_kses()
     * @see esc_url()
     *
     * @return string[] Array of allowed protocols. Defaults to an array containing 'http', 'https',
     *                  'ftp', 'ftps', 'mailto', 'news', 'irc', 'irc6', 'ircs', 'gopher', 'nntp', 'feed',
     *                  'telnet', 'mms', 'rtsp', 'sms', 'svn', 'tel', 'fax', 'xmpp', 'webcal', and 'urn'.
     *                  This covers all common link protocols, except for 'javascript' which should not
     *                  be allowed for untrusted users.
     */
    function wp_allowed_protocols()
    {
    }
    /**
     * Returns a comma-separated string or array of functions that have been called to get
     * to the current point in code.
     *
     * @since 3.4.0
     *
     * @see https://core.trac.wordpress.org/ticket/19589
     *
     * @param string $ignore_class Optional. A class to ignore all function calls within - useful
     *                             when you want to just give info about the callee. Default null.
     * @param int    $skip_frames  Optional. A number of stack frames to skip - useful for unwinding
     *                             back to the source of the issue. Default 0.
     * @param bool   $pretty       Optional. Whether you want a comma separated string instead of
     *                             the raw array returned. Default true.
     * @return string|array Either a string containing a reversed comma separated trace or an array
     *                      of individual calls.
     * @phpstan-return ($pretty is true ? string : list<string>)
     */
    function wp_debug_backtrace_summary($ignore_class = \null, $skip_frames = 0, $pretty = \true)
    {
    }
    /**
     * Retrieves IDs that are not already present in the cache.
     *
     * @since 3.4.0
     * @since 6.1.0 This function is no longer marked as "private".
     *
     * @param int[]  $object_ids  Array of IDs.
     * @param string $cache_group The cache group to check against.
     * @return int[] Array of IDs not present in the cache.
     */
    function _get_non_cached_ids($object_ids, $cache_group)
    {
    }
    /**
     * Checks whether the given cache ID is either an integer or an integer-like string.
     *
     * Both `16` and `"16"` are considered valid, other numeric types and numeric strings
     * (`16.3` and `"16.3"`) are considered invalid.
     *
     * @since 6.3.0
     *
     * @param mixed $object_id The cache ID to validate.
     * @return bool Whether the given $object_id is a valid cache ID.
     */
    function _validate_cache_id($object_id)
    {
    }
    /**
     * Tests if the current device has the capability to upload files.
     *
     * @since 3.4.0
     * @access private
     *
     * @return bool Whether the device is able to upload files.
     */
    function _device_can_upload()
    {
    }
    /**
     * Tests if a given path is a stream URL
     *
     * @since 3.5.0
     *
     * @param string $path The resource path or URL.
     * @return bool True if the path is a stream URL.
     */
    function wp_is_stream($path)
    {
    }
    /**
     * Tests if the supplied date is valid for the Gregorian calendar.
     *
     * @since 3.5.0
     *
     * @link https://www.php.net/manual/en/function.checkdate.php
     *
     * @param int    $month       Month number.
     * @param int    $day         Day number.
     * @param int    $year        Year number.
     * @param string $source_date The date to filter.
     * @return bool True if valid date, false if not valid date.
     */
    function wp_checkdate($month, $day, $year, $source_date)
    {
    }
    /**
     * Loads the auth check for monitoring whether the user is still logged in.
     *
     * Can be disabled with remove_action( 'admin_enqueue_scripts', 'wp_auth_check_load' );
     *
     * This is disabled for certain screens where a login screen could cause an
     * inconvenient interruption. A filter called {@see 'wp_auth_check_load'} can be used
     * for fine-grained control.
     *
     * @since 3.6.0
     * @phpstan-return void
     */
    function wp_auth_check_load()
    {
    }
    /**
     * Outputs the HTML that shows the wp-login dialog when the user is no longer logged in.
     *
     * @since 3.6.0
     */
    function wp_auth_check_html()
    {
    }
    /**
     * Checks whether a user is still logged in, for the heartbeat.
     *
     * Send a result that shows a log-in box if the user is no longer logged in,
     * or if their cookie is within the grace period.
     *
     * @since 3.6.0
     *
     * @global int $login_grace_period
     *
     * @param array $response  The Heartbeat response.
     * @return array The Heartbeat response with 'wp-auth-check' value set.
     */
    function wp_auth_check($response)
    {
    }
    /**
     * Returns RegEx body to liberally match an opening HTML tag.
     *
     * Matches an opening HTML tag that:
     * 1. Is self-closing or
     * 2. Has no body but has a closing tag of the same name or
     * 3. Contains a body and a closing tag of the same name
     *
     * Note: this RegEx does not balance inner tags and does not attempt
     * to produce valid HTML
     *
     * @since 3.6.0
     *
     * @param string $tag An HTML tag name. Example: 'video'.
     * @return string Tag RegEx.
     */
    function get_tag_regex($tag)
    {
    }
    /**
     * Indicates if a given slug for a character set represents the UTF-8
     * text encoding. If not provided, examines the current blog's charset.
     *
     * A charset is considered to represent UTF-8 if it is a case-insensitive
     * match of "UTF-8" with or without the hyphen.
     *
     * Example:
     *
     *     true  === is_utf8_charset( 'UTF-8' );
     *     true  === is_utf8_charset( 'utf8' );
     *     false === is_utf8_charset( 'latin1' );
     *     false === is_utf8_charset( 'UTF 8' );
     *
     *     // Only strings match.
     *     false === is_utf8_charset( [ 'charset' => 'utf-8' ] );
     *
     *     // Without a given charset, it depends on the site option "blog_charset".
     *     $is_utf8 = is_utf8_charset();
     *
     * @since 6.6.0
     * @since 6.6.1 A wrapper for _is_utf8_charset
     *
     * @see _is_utf8_charset
     *
     * @param string|null $blog_charset Optional. Slug representing a text character encoding, or "charset".
     *                                  E.g. "UTF-8", "Windows-1252", "ISO-8859-1", "SJIS".
     *                                  Default value is to infer from "blog_charset" option.
     * @return bool Whether the slug represents the UTF-8 encoding.
     */
    function is_utf8_charset($blog_charset = \null)
    {
    }
    /**
     * Retrieves a canonical form of the provided charset appropriate for passing to PHP
     * functions such as htmlspecialchars() and charset HTML attributes.
     *
     * @since 3.6.0
     * @access private
     *
     * @see https://core.trac.wordpress.org/ticket/23688
     *
     * @param string $charset A charset name, e.g. "UTF-8", "Windows-1252", "SJIS".
     * @return string The canonical form of the charset.
     */
    function _canonical_charset($charset)
    {
    }
    /**
     * Sets the mbstring internal encoding to a binary safe encoding when func_overload
     * is enabled.
     *
     * When mbstring.func_overload is in use for multi-byte encodings, the results from
     * strlen() and similar functions respect the utf8 characters, causing binary data
     * to return incorrect lengths.
     *
     * This function overrides the mbstring encoding to a binary-safe encoding, and
     * resets it to the users expected encoding afterwards through the
     * `reset_mbstring_encoding` function.
     *
     * It is safe to recursively call this function, however each
     * `mbstring_binary_safe_encoding()` call must be followed up with an equal number
     * of `reset_mbstring_encoding()` calls.
     *
     * @since 3.7.0
     *
     * @see reset_mbstring_encoding()
     *
     * @param bool $reset Optional. Whether to reset the encoding back to a previously-set encoding.
     *                    Default false.
     * @phpstan-return void
     */
    function mbstring_binary_safe_encoding($reset = \false)
    {
    }
    /**
     * Resets the mbstring internal encoding to a users previously set encoding.
     *
     * @see mbstring_binary_safe_encoding()
     *
     * @since 3.7.0
     */
    function reset_mbstring_encoding()
    {
    }
    /**
     * Filters/validates a variable as a boolean.
     *
     * Alternative to `filter_var( $value, FILTER_VALIDATE_BOOLEAN )`.
     *
     * @since 4.0.0
     *
     * @param mixed $value Boolean value to validate.
     * @return bool Whether the value is validated.
     */
    function wp_validate_boolean($value)
    {
    }
    /**
     * Deletes a file.
     *
     * @since 4.2.0
     * @since 6.7.0 A return value was added.
     *
     * @param string $file The path to the file to delete.
     * @return bool True on success, false on failure.
     */
    function wp_delete_file($file)
    {
    }
    /**
     * Deletes a file if its path is within the given directory.
     *
     * @since 4.9.7
     *
     * @param string $file      Absolute path to the file to delete.
     * @param string $directory Absolute path to a directory.
     * @return bool True on success, false on failure.
     */
    function wp_delete_file_from_directory($file, $directory)
    {
    }
    /**
     * Outputs a small JS snippet on preview tabs/windows to remove `window.name` when a user is navigating to another page.
     *
     * This prevents reusing the same tab for a preview when the user has navigated away.
     *
     * @since 4.3.0
     *
     * @global WP_Post $post Global post object.
     * @phpstan-return void
     */
    function wp_post_preview_js()
    {
    }
    /**
     * Parses and formats a MySQL datetime (Y-m-d H:i:s) for ISO8601 (Y-m-d\TH:i:s).
     *
     * Explicitly strips timezones, as datetimes are not saved with any timezone
     * information. Including any information on the offset could be misleading.
     *
     * Despite historical function name, the output does not conform to RFC3339 format,
     * which must contain timezone.
     *
     * @since 4.4.0
     *
     * @param string $date_string Date string to parse and format.
     * @return string Date formatted for ISO8601 without time zone.
     */
    function mysql_to_rfc3339($date_string)
    {
    }
    /**
     * Attempts to raise the PHP memory limit for memory intensive processes.
     *
     * Only allows raising the existing limit and prevents lowering it.
     *
     * @since 4.6.0
     *
     * @param string $context Optional. Context in which the function is called. Accepts either 'admin',
     *                        'image', 'cron', or an arbitrary other context. If an arbitrary context is passed,
     *                        the similarly arbitrary {@see '$context_memory_limit'} filter will be
     *                        invoked. Default 'admin'.
     * @return int|string|false The limit that was set or false on failure.
     */
    function wp_raise_memory_limit($context = 'admin')
    {
    }
    /**
     * Generates a random UUID (version 4).
     *
     * @since 4.7.0
     *
     * @return string UUID.
     */
    function wp_generate_uuid4()
    {
    }
    /**
     * Validates that a UUID is valid.
     *
     * @since 4.9.0
     *
     * @param mixed $uuid    UUID to check.
     * @param int   $version Specify which version of UUID to check against. Default is none,
     *                       to accept any UUID version. Otherwise, only version allowed is `4`.
     * @return bool The string is a valid UUID or false on failure.
     */
    function wp_is_uuid($uuid, $version = \null)
    {
    }
    /**
     * Gets unique ID.
     *
     * This is a PHP implementation of Underscore's uniqueId method. A static variable
     * contains an integer that is incremented with each call. This number is returned
     * with the optional prefix. As such the returned value is not universally unique,
     * but it is unique across the life of the PHP process.
     *
     * @since 5.0.3
     *
     * @param string $prefix Prefix for the returned ID.
     * @return string Unique ID.
     * @phpstan-return ($prefix is empty ? numeric-string : ($prefix is numeric ? numeric-string : string))
     */
    function wp_unique_id($prefix = '')
    {
    }
    /**
     * Generates an incremental ID that is independent per each different prefix.
     *
     * It is similar to `wp_unique_id`, but each prefix has its own internal ID
     * counter to make each prefix independent from each other. The ID starts at 1
     * and increments on each call. The returned value is not universally unique,
     * but it is unique across the life of the PHP process and it's stable per
     * prefix.
     *
     * @since 6.4.0
     *
     * @param string $prefix Optional. Prefix for the returned ID. Default empty string.
     * @return string Incremental ID per prefix.
     */
    function wp_unique_prefixed_id($prefix = '')
    {
    }
    /**
     * Gets last changed date for the specified cache group.
     *
     * @since 4.7.0
     *
     * @param string $group Where the cache contents are grouped.
     * @return string UNIX timestamp with microseconds representing when the group was last changed.
     */
    function wp_cache_get_last_changed($group)
    {
    }
    /**
     * Sets last changed date for the specified cache group to now.
     *
     * @since 6.3.0
     *
     * @param string $group Where the cache contents are grouped.
     * @return string UNIX timestamp when the group was last changed.
     */
    function wp_cache_set_last_changed($group)
    {
    }
    /**
     * Sends an email to the old site admin email address when the site admin email address changes.
     *
     * @since 4.9.0
     *
     * @param string $old_email   The old site admin email address.
     * @param string $new_email   The new site admin email address.
     * @param string $option_name The relevant database option name.
     * @phpstan-return void
     */
    function wp_site_admin_email_change_notification($old_email, $new_email, $option_name)
    {
    }
    /**
     * Returns an anonymized IPv4 or IPv6 address.
     *
     * @since 4.9.6 Abstracted from `WP_Community_Events::get_unsafe_client_ip()`.
     *
     * @param string $ip_addr       The IPv4 or IPv6 address to be anonymized.
     * @param bool   $ipv6_fallback Optional. Whether to return the original IPv6 address if the needed functions
     *                              to anonymize it are not present. Default false, return `::` (unspecified address).
     * @return string  The anonymized IP address.
     */
    function wp_privacy_anonymize_ip($ip_addr, $ipv6_fallback = \false)
    {
    }
    /**
     * Returns uniform "anonymous" data by type.
     *
     * @since 4.9.6
     *
     * @param string $type The type of data to be anonymized.
     * @param string $data Optional. The data to be anonymized. Default empty string.
     * @return string The anonymous data for the requested type.
     */
    function wp_privacy_anonymize_data($type, $data = '')
    {
    }
    /**
     * Returns the directory used to store personal data export files.
     *
     * @since 4.9.6
     *
     * @see wp_privacy_exports_url
     *
     * @return string Exports directory.
     */
    function wp_privacy_exports_dir()
    {
    }
    /**
     * Returns the URL of the directory used to store personal data export files.
     *
     * @since 4.9.6
     *
     * @see wp_privacy_exports_dir
     *
     * @return string Exports directory URL.
     */
    function wp_privacy_exports_url()
    {
    }
    /**
     * Schedules a `WP_Cron` job to delete expired export files.
     *
     * @since 4.9.6
     * @phpstan-return void
     */
    function wp_schedule_delete_old_privacy_export_files()
    {
    }
    /**
     * Cleans up export files older than three days old.
     *
     * The export files are stored in `wp-content/uploads`, and are therefore publicly
     * accessible. A CSPRN is appended to the filename to mitigate the risk of an
     * unauthorized person downloading the file, but it is still possible. Deleting
     * the file after the data subject has had a chance to delete it adds an additional
     * layer of protection.
     *
     * @since 4.9.6
     * @phpstan-return void
     */
    function wp_privacy_delete_old_export_files()
    {
    }
    /**
     * Gets the URL to learn more about updating the PHP version the site is running on.
     *
     * This URL can be overridden by specifying an environment variable `WP_UPDATE_PHP_URL` or by using the
     * {@see 'wp_update_php_url'} filter. Providing an empty string is not allowed and will result in the
     * default URL being used. Furthermore the page the URL links to should preferably be localized in the
     * site language.
     *
     * @since 5.1.0
     *
     * @return string URL to learn more about updating PHP.
     */
    function wp_get_update_php_url()
    {
    }
    /**
     * Gets the default URL to learn more about updating the PHP version the site is running on.
     *
     * Do not use this function to retrieve this URL. Instead, use {@see wp_get_update_php_url()} when relying on the URL.
     * This function does not allow modifying the returned URL, and is only used to compare the actually used URL with the
     * default one.
     *
     * @since 5.1.0
     * @access private
     *
     * @return string Default URL to learn more about updating PHP.
     */
    function wp_get_default_update_php_url()
    {
    }
    /**
     * Prints the default annotation for the web host altering the "Update PHP" page URL.
     *
     * This function is to be used after {@see wp_get_update_php_url()} to display a consistent
     * annotation if the web host has altered the default "Update PHP" page URL.
     *
     * @since 5.1.0
     * @since 5.2.0 Added the `$before` and `$after` parameters.
     * @since 6.4.0 Added the `$display` parameter.
     *
     * @param string $before  Markup to output before the annotation. Default `<p class="description">`.
     * @param string $after   Markup to output after the annotation. Default `</p>`.
     * @param bool   $display Whether to echo or return the markup. Default `true` for echo.
     *
     * @return string|void
     */
    function wp_update_php_annotation($before = '<p class="description">', $after = '</p>', $display = \true)
    {
    }
    /**
     * Returns the default annotation for the web hosting altering the "Update PHP" page URL.
     *
     * This function is to be used after {@see wp_get_update_php_url()} to return a consistent
     * annotation if the web host has altered the default "Update PHP" page URL.
     *
     * @since 5.2.0
     *
     * @return string Update PHP page annotation. An empty string if no custom URLs are provided.
     */
    function wp_get_update_php_annotation()
    {
    }
    /**
     * Gets the URL for directly updating the PHP version the site is running on.
     *
     * A URL will only be returned if the `WP_DIRECT_UPDATE_PHP_URL` environment variable is specified or
     * by using the {@see 'wp_direct_php_update_url'} filter. This allows hosts to send users directly to
     * the page where they can update PHP to a newer version.
     *
     * @since 5.1.1
     *
     * @return string URL for directly updating PHP or empty string.
     */
    function wp_get_direct_php_update_url()
    {
    }
    /**
     * Displays a button directly linking to a PHP update process.
     *
     * This provides hosts with a way for users to be sent directly to their PHP update process.
     *
     * The button is only displayed if a URL is returned by `wp_get_direct_php_update_url()`.
     *
     * @since 5.1.1
     * @phpstan-return void
     */
    function wp_direct_php_update_button()
    {
    }
    /**
     * Gets the URL to learn more about updating the site to use HTTPS.
     *
     * This URL can be overridden by specifying an environment variable `WP_UPDATE_HTTPS_URL` or by using the
     * {@see 'wp_update_https_url'} filter. Providing an empty string is not allowed and will result in the
     * default URL being used. Furthermore the page the URL links to should preferably be localized in the
     * site language.
     *
     * @since 5.7.0
     *
     * @return string URL to learn more about updating to HTTPS.
     */
    function wp_get_update_https_url()
    {
    }
    /**
     * Gets the default URL to learn more about updating the site to use HTTPS.
     *
     * Do not use this function to retrieve this URL. Instead, use {@see wp_get_update_https_url()} when relying on the URL.
     * This function does not allow modifying the returned URL, and is only used to compare the actually used URL with the
     * default one.
     *
     * @since 5.7.0
     * @access private
     *
     * @return string Default URL to learn more about updating to HTTPS.
     */
    function wp_get_default_update_https_url()
    {
    }
    /**
     * Gets the URL for directly updating the site to use HTTPS.
     *
     * A URL will only be returned if the `WP_DIRECT_UPDATE_HTTPS_URL` environment variable is specified or
     * by using the {@see 'wp_direct_update_https_url'} filter. This allows hosts to send users directly to
     * the page where they can update their site to use HTTPS.
     *
     * @since 5.7.0
     *
     * @return string URL for directly updating to HTTPS or empty string.
     */
    function wp_get_direct_update_https_url()
    {
    }
    /**
     * Gets the size of a directory.
     *
     * A helper function that is used primarily to check whether
     * a blog has exceeded its allowed upload space.
     *
     * @since MU (3.0.0)
     * @since 5.2.0 $max_execution_time parameter added.
     *
     * @param string $directory Full path of a directory.
     * @param int    $max_execution_time Maximum time to run before giving up. In seconds.
     *                                   The timeout is global and is measured from the moment WordPress started to load.
     * @return int|false|null Size in bytes if a valid directory. False if not. Null if timeout.
     */
    function get_dirsize($directory, $max_execution_time = \null)
    {
    }
    /**
     * Gets the size of a directory recursively.
     *
     * Used by get_dirsize() to get a directory size when it contains other directories.
     *
     * @since MU (3.0.0)
     * @since 4.3.0 The `$exclude` parameter was added.
     * @since 5.2.0 The `$max_execution_time` parameter was added.
     * @since 5.6.0 The `$directory_cache` parameter was added.
     *
     * @param string          $directory          Full path of a directory.
     * @param string|string[] $exclude            Optional. Full path of a subdirectory to exclude from the total,
     *                                            or array of paths. Expected without trailing slash(es).
     *                                            Default null.
     * @param int             $max_execution_time Optional. Maximum time to run before giving up. In seconds.
     *                                            The timeout is global and is measured from the moment
     *                                            WordPress started to load. Defaults to the value of
     *                                            `max_execution_time` PHP setting.
     * @param array           $directory_cache    Optional. Array of cached directory paths.
     *                                            Defaults to the value of `dirsize_cache` transient.
     * @return int|false|null Size in bytes if a valid directory. False if not. Null if timeout.
     */
    function recurse_dirsize($directory, $exclude = \null, $max_execution_time = \null, &$directory_cache = \null)
    {
    }
    /**
     * Cleans directory size cache used by recurse_dirsize().
     *
     * Removes the current directory and all parent directories from the `dirsize_cache` transient.
     *
     * @since 5.6.0
     * @since 5.9.0 Added input validation with a notice for invalid input.
     *
     * @param string $path Full path of a directory or file.
     * @phpstan-return void
     */
    function clean_dirsize_cache($path)
    {
    }
    /**
     * Returns the current WordPress version.
     *
     * Returns an unmodified value of `$wp_version`. Some plugins modify the global
     * in an attempt to improve security through obscurity. This practice can cause
     * errors in WordPress, so the ability to get an unmodified version is needed.
     *
     * @since 6.7.0
     *
     * @return string The current WordPress version.
     */
    function wp_get_wp_version()
    {
    }
    /**
     * Checks compatibility with the current WordPress version.
     *
     * @since 5.2.0
     *
     * @global string $_wp_tests_wp_version The WordPress version string. Used only in Core tests.
     *
     * @param string $required Minimum required WordPress version.
     * @return bool True if required version is compatible or empty, false if not.
     */
    function is_wp_version_compatible($required)
    {
    }
    /**
     * Checks compatibility with the current PHP version.
     *
     * @since 5.2.0
     *
     * @param string $required Minimum required PHP version.
     * @return bool True if required version is compatible or empty, false if not.
     */
    function is_php_version_compatible($required)
    {
    }
    /**
     * Checks if two numbers are nearly the same.
     *
     * This is similar to using `round()` but the precision is more fine-grained.
     *
     * @since 5.3.0
     *
     * @param int|float $expected  The expected value.
     * @param int|float $actual    The actual number.
     * @param int|float $precision Optional. The allowed variation. Default 1.
     * @return bool Whether the numbers match within the specified precision.
     */
    function wp_fuzzy_number_match($expected, $actual, $precision = 1)
    {
    }
    /**
     * Creates and returns the markup for an admin notice.
     *
     * @since 6.4.0
     *
     * @param string $message The message.
     * @param array  $args {
     *     Optional. An array of arguments for the admin notice. Default empty array.
     *
     *     @type string   $type               Optional. The type of admin notice.
     *                                        For example, 'error', 'success', 'warning', 'info'.
     *                                        Default empty string.
     *     @type bool     $dismissible        Optional. Whether the admin notice is dismissible. Default false.
     *     @type string   $id                 Optional. The value of the admin notice's ID attribute. Default empty string.
     *     @type string[] $additional_classes Optional. A string array of class names. Default empty array.
     *     @type string[] $attributes         Optional. Additional attributes for the notice div. Default empty array.
     *     @type bool     $paragraph_wrap     Optional. Whether to wrap the message in paragraph tags. Default true.
     * }
     * @return string The markup for an admin notice.
     * @phpstan-param array{
     *   type?: string,
     *   dismissible?: bool,
     *   id?: string,
     *   additional_classes?: string[],
     *   attributes?: string[],
     *   paragraph_wrap?: bool,
     * } $args
     */
    function wp_get_admin_notice($message, $args = array())
    {
    }
    /**
     * Outputs an admin notice.
     *
     * @since 6.4.0
     *
     * @param string $message The message to output.
     * @param array  $args {
     *     Optional. An array of arguments for the admin notice. Default empty array.
     *
     *     @type string   $type               Optional. The type of admin notice.
     *                                        For example, 'error', 'success', 'warning', 'info'.
     *                                        Default empty string.
     *     @type bool     $dismissible        Optional. Whether the admin notice is dismissible. Default false.
     *     @type string   $id                 Optional. The value of the admin notice's ID attribute. Default empty string.
     *     @type string[] $additional_classes Optional. A string array of class names. Default empty array.
     *     @type string[] $attributes         Optional. Additional attributes for the notice div. Default empty array.
     *     @type bool     $paragraph_wrap     Optional. Whether to wrap the message in paragraph tags. Default true.
     * }
     * @phpstan-param array{
     *   type?: string,
     *   dismissible?: bool,
     *   id?: string,
     *   additional_classes?: string[],
     *   attributes?: string[],
     *   paragraph_wrap?: bool,
     * } $args
     */
    function wp_admin_notice($message, $args = array())
    {
    }
    /**
     * Checks if a mime type is for a HEIC/HEIF image.
     *
     * @since 6.7.0
     *
     * @param string $mime_type The mime type to check.
     * @return bool Whether the mime type is for a HEIC/HEIF image.
     */
    function wp_is_heic_image_mime_type($mime_type)
    {
    }
    /**
     * Initializes $wp_scripts if it has not been set.
     *
     * @since 4.2.0
     *
     * @global WP_Scripts $wp_scripts
     *
     * @return WP_Scripts WP_Scripts instance.
     */
    function wp_scripts()
    {
    }
    /**
     * Helper function to output a _doing_it_wrong message when applicable.
     *
     * @ignore
     * @since 4.2.0
     * @since 5.5.0 Added the `$handle` parameter.
     *
     * @param string $function_name Function name.
     * @param string $handle        Optional. Name of the script or stylesheet that was
     *                              registered or enqueued too early. Default empty.
     * @phpstan-return void
     */
    function _wp_scripts_maybe_doing_it_wrong($function_name, $handle = '')
    {
    }
    /**
     * Prints scripts in document head that are in the $handles queue.
     *
     * Called by admin-header.php and {@see 'wp_head'} hook. Since it is called by wp_head on every page load,
     * the function does not instantiate the WP_Scripts object unless script names are explicitly passed.
     * Makes use of already-instantiated `$wp_scripts` global if present. Use provided {@see 'wp_print_scripts'}
     * hook to register/enqueue new scripts.
     *
     * @see WP_Scripts::do_item()
     * @since 2.1.0
     *
     * @global WP_Scripts $wp_scripts The WP_Scripts object for printing scripts.
     *
     * @param string|string[]|false $handles Optional. Scripts to be printed. Default 'false'.
     * @return string[] On success, an array of handles of processed WP_Dependencies items; otherwise, an empty array.
     */
    function wp_print_scripts($handles = \false)
    {
    }
    /**
     * Adds extra code to a registered script.
     *
     * Code will only be added if the script is already in the queue.
     * Accepts a string `$data` containing the code. If two or more code blocks
     * are added to the same script `$handle`, they will be printed in the order
     * they were added, i.e. the latter added code can redeclare the previous.
     *
     * @since 4.5.0
     *
     * @see WP_Scripts::add_inline_script()
     *
     * @param string $handle   Name of the script to add the inline script to.
     * @param string $data     String containing the JavaScript to be added.
     * @param string $position Optional. Whether to add the inline script before the handle
     *                         or after. Default 'after'.
     * @return bool True on success, false on failure.
     */
    function wp_add_inline_script($handle, $data, $position = 'after')
    {
    }
    /**
     * Registers a new script.
     *
     * Registers a script to be enqueued later using the wp_enqueue_script() function.
     *
     * @see WP_Dependencies::add()
     * @see WP_Dependencies::add_data()
     *
     * @since 2.1.0
     * @since 4.3.0 A return value was added.
     * @since 6.3.0 The $in_footer parameter of type boolean was overloaded to be an $args parameter of type array.
     *
     * @param string           $handle    Name of the script. Should be unique.
     * @param string|false     $src       Full URL of the script, or path of the script relative to the WordPress root directory.
     *                                    If source is set to false, script is an alias of other scripts it depends on.
     * @param string[]         $deps      Optional. An array of registered script handles this script depends on. Default empty array.
     * @param string|bool|null $ver       Optional. String specifying script version number, if it has one, which is added to the URL
     *                                    as a query string for cache busting purposes. If version is set to false, a version
     *                                    number is automatically added equal to current installed WordPress version.
     *                                    If set to null, no version is added.
     * @param array|bool       $args     {
     *     Optional. An array of additional script loading strategies. Default empty array.
     *     Otherwise, it may be a boolean in which case it determines whether the script is printed in the footer. Default false.
     *
     *     @type string    $strategy     Optional. If provided, may be either 'defer' or 'async'.
     *     @type bool      $in_footer    Optional. Whether to print the script in the footer. Default 'false'.
     * }
     * @return bool Whether the script has been registered. True on success, false on failure.
     * @phpstan-param bool|array{
     *   strategy?: string,
     *   in_footer?: bool,
     * } $args
     */
    function wp_register_script($handle, $src, $deps = array(), $ver = \false, $args = array())
    {
    }
    /**
     * Localizes a script.
     *
     * Works only if the script has already been registered.
     *
     * Accepts an associative array `$l10n` and creates a JavaScript object:
     *
     *     "$object_name": {
     *         key: value,
     *         key: value,
     *         ...
     *     }
     *
     * @see WP_Scripts::localize()
     * @link https://core.trac.wordpress.org/ticket/11520
     *
     * @since 2.2.0
     *
     * @todo Documentation cleanup
     *
     * @param string $handle      Script handle the data will be attached to.
     * @param string $object_name Name for the JavaScript object. Passed directly, so it should be qualified JS variable.
     *                            Example: '/[a-zA-Z0-9_]+/'.
     * @param array  $l10n        The data itself. The data can be either a single or multi-dimensional array.
     * @return bool True if the script was successfully localized, false otherwise.
     */
    function wp_localize_script($handle, $object_name, $l10n)
    {
    }
    /**
     * Sets translated strings for a script.
     *
     * Works only if the script has already been registered.
     *
     * @see WP_Scripts::set_translations()
     * @since 5.0.0
     * @since 5.1.0 The `$domain` parameter was made optional.
     *
     * @global WP_Scripts $wp_scripts The WP_Scripts object for printing scripts.
     *
     * @param string $handle Script handle the textdomain will be attached to.
     * @param string $domain Optional. Text domain. Default 'default'.
     * @param string $path   Optional. The full file path to the directory containing translation files.
     * @return bool True if the text domain was successfully localized, false otherwise.
     */
    function wp_set_script_translations($handle, $domain = 'default', $path = '')
    {
    }
    /**
     * Removes a registered script.
     *
     * Note: there are intentional safeguards in place to prevent critical admin scripts,
     * such as jQuery core, from being unregistered.
     *
     * @see WP_Dependencies::remove()
     *
     * @since 2.1.0
     *
     * @global string $pagenow The filename of the current screen.
     *
     * @param string $handle Name of the script to be removed.
     * @phpstan-return void
     */
    function wp_deregister_script($handle)
    {
    }
    /**
     * Enqueues a script.
     *
     * Registers the script if `$src` provided (does NOT overwrite), and enqueues it.
     *
     * @see WP_Dependencies::add()
     * @see WP_Dependencies::add_data()
     * @see WP_Dependencies::enqueue()
     *
     * @since 2.1.0
     * @since 6.3.0 The $in_footer parameter of type boolean was overloaded to be an $args parameter of type array.
     *
     * @param string           $handle    Name of the script. Should be unique.
     * @param string           $src       Full URL of the script, or path of the script relative to the WordPress root directory.
     *                                    Default empty.
     * @param string[]         $deps      Optional. An array of registered script handles this script depends on. Default empty array.
     * @param string|bool|null $ver       Optional. String specifying script version number, if it has one, which is added to the URL
     *                                    as a query string for cache busting purposes. If version is set to false, a version
     *                                    number is automatically added equal to current installed WordPress version.
     *                                    If set to null, no version is added.
     * @param array|bool       $args     {
     *     Optional. An array of additional script loading strategies. Default empty array.
     *     Otherwise, it may be a boolean in which case it determines whether the script is printed in the footer. Default false.
     *
     *     @type string    $strategy     Optional. If provided, may be either 'defer' or 'async'.
     *     @type bool      $in_footer    Optional. Whether to print the script in the footer. Default 'false'.
     * }
     * @phpstan-param bool|array{
     *   strategy?: string,
     *   in_footer?: bool,
     * } $args
     */
    function wp_enqueue_script($handle, $src = '', $deps = array(), $ver = \false, $args = array())
    {
    }
    /**
     * Removes a previously enqueued script.
     *
     * @see WP_Dependencies::dequeue()
     *
     * @since 3.1.0
     *
     * @param string $handle Name of the script to be removed.
     */
    function wp_dequeue_script($handle)
    {
    }
    /**
     * Determines whether a script has been added to the queue.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.8.0
     * @since 3.5.0 'enqueued' added as an alias of the 'queue' list.
     *
     * @param string $handle Name of the script.
     * @param string $status Optional. Status of the script to check. Default 'enqueued'.
     *                       Accepts 'enqueued', 'registered', 'queue', 'to_do', and 'done'.
     * @return bool Whether the script is queued.
     * @phpstan-param 'enqueued'|'registered'|'queue'|'to_do'|'done' $status
     */
    function wp_script_is($handle, $status = 'enqueued')
    {
    }
    /**
     * Adds metadata to a script.
     *
     * Works only if the script has already been registered.
     *
     * Possible values for $key and $value:
     * 'conditional' string Comments for IE 6, lte IE 7, etc.
     *
     * @since 4.2.0
     *
     * @see WP_Dependencies::add_data()
     *
     * @param string $handle Name of the script.
     * @param string $key    Name of data point for which we're storing a value.
     * @param mixed  $value  String containing the data to be added.
     * @return bool True on success, false on failure.
     */
    function wp_script_add_data($handle, $key, $value)
    {
    }
    /**
     * Initializes $wp_styles if it has not been set.
     *
     * @since 4.2.0
     *
     * @global WP_Styles $wp_styles
     *
     * @return WP_Styles WP_Styles instance.
     */
    function wp_styles()
    {
    }
    /**
     * Displays styles that are in the $handles queue.
     *
     * Passing an empty array to $handles prints the queue,
     * passing an array with one string prints that style,
     * and passing an array of strings prints those styles.
     *
     * @since 2.6.0
     *
     * @global WP_Styles $wp_styles The WP_Styles object for printing styles.
     *
     * @param string|bool|array $handles Styles to be printed. Default 'false'.
     * @return string[] On success, an array of handles of processed WP_Dependencies items; otherwise, an empty array.
     */
    function wp_print_styles($handles = \false)
    {
    }
    /**
     * Adds extra CSS styles to a registered stylesheet.
     *
     * Styles will only be added if the stylesheet is already in the queue.
     * Accepts a string $data containing the CSS. If two or more CSS code blocks
     * are added to the same stylesheet $handle, they will be printed in the order
     * they were added, i.e. the latter added styles can redeclare the previous.
     *
     * @see WP_Styles::add_inline_style()
     *
     * @since 3.3.0
     *
     * @param string $handle Name of the stylesheet to add the extra styles to.
     * @param string $data   String containing the CSS styles to be added.
     * @return bool True on success, false on failure.
     */
    function wp_add_inline_style($handle, $data)
    {
    }
    /**
     * Registers a CSS stylesheet.
     *
     * @see WP_Dependencies::add()
     * @link https://www.w3.org/TR/CSS2/media.html#media-types List of CSS media types.
     *
     * @since 2.6.0
     * @since 4.3.0 A return value was added.
     *
     * @param string           $handle Name of the stylesheet. Should be unique.
     * @param string|false     $src    Full URL of the stylesheet, or path of the stylesheet relative to the WordPress root directory.
     *                                 If source is set to false, stylesheet is an alias of other stylesheets it depends on.
     * @param string[]         $deps   Optional. An array of registered stylesheet handles this stylesheet depends on. Default empty array.
     * @param string|bool|null $ver    Optional. String specifying stylesheet version number, if it has one, which is added to the URL
     *                                 as a query string for cache busting purposes. If version is set to false, a version
     *                                 number is automatically added equal to current installed WordPress version.
     *                                 If set to null, no version is added.
     * @param string           $media  Optional. The media for which this stylesheet has been defined.
     *                                 Default 'all'. Accepts media types like 'all', 'print' and 'screen', or media queries like
     *                                 '(orientation: portrait)' and '(max-width: 640px)'.
     * @return bool Whether the style has been registered. True on success, false on failure.
     */
    function wp_register_style($handle, $src, $deps = array(), $ver = \false, $media = 'all')
    {
    }
    /**
     * Removes a registered stylesheet.
     *
     * @see WP_Dependencies::remove()
     *
     * @since 2.1.0
     *
     * @param string $handle Name of the stylesheet to be removed.
     */
    function wp_deregister_style($handle)
    {
    }
    /**
     * Enqueues a CSS stylesheet.
     *
     * Registers the style if source provided (does NOT overwrite) and enqueues.
     *
     * @see WP_Dependencies::add()
     * @see WP_Dependencies::enqueue()
     * @link https://www.w3.org/TR/CSS2/media.html#media-types List of CSS media types.
     *
     * @since 2.6.0
     *
     * @param string           $handle Name of the stylesheet. Should be unique.
     * @param string           $src    Full URL of the stylesheet, or path of the stylesheet relative to the WordPress root directory.
     *                                 Default empty.
     * @param string[]         $deps   Optional. An array of registered stylesheet handles this stylesheet depends on. Default empty array.
     * @param string|bool|null $ver    Optional. String specifying stylesheet version number, if it has one, which is added to the URL
     *                                 as a query string for cache busting purposes. If version is set to false, a version
     *                                 number is automatically added equal to current installed WordPress version.
     *                                 If set to null, no version is added.
     * @param string           $media  Optional. The media for which this stylesheet has been defined.
     *                                 Default 'all'. Accepts media types like 'all', 'print' and 'screen', or media queries like
     *                                 '(orientation: portrait)' and '(max-width: 640px)'.
     */
    function wp_enqueue_style($handle, $src = '', $deps = array(), $ver = \false, $media = 'all')
    {
    }
    /**
     * Removes a previously enqueued CSS stylesheet.
     *
     * @see WP_Dependencies::dequeue()
     *
     * @since 3.1.0
     *
     * @param string $handle Name of the stylesheet to be removed.
     */
    function wp_dequeue_style($handle)
    {
    }
    /**
     * Checks whether a CSS stylesheet has been added to the queue.
     *
     * @since 2.8.0
     *
     * @param string $handle Name of the stylesheet.
     * @param string $status Optional. Status of the stylesheet to check. Default 'enqueued'.
     *                       Accepts 'enqueued', 'registered', 'queue', 'to_do', and 'done'.
     * @return bool Whether style is queued.
     * @phpstan-param 'enqueued'|'registered'|'queue'|'to_do'|'done' $status
     */
    function wp_style_is($handle, $status = 'enqueued')
    {
    }
    /**
     * Adds metadata to a CSS stylesheet.
     *
     * Works only if the stylesheet has already been registered.
     *
     * Possible values for $key and $value:
     * 'conditional' string      Comments for IE 6, lte IE 7 etc.
     * 'rtl'         bool|string To declare an RTL stylesheet.
     * 'suffix'      string      Optional suffix, used in combination with RTL.
     * 'alt'         bool        For rel="alternate stylesheet".
     * 'title'       string      For preferred/alternate stylesheets.
     * 'path'        string      The absolute path to a stylesheet. Stylesheet will
     *                           load inline when 'path' is set.
     *
     * @see WP_Dependencies::add_data()
     *
     * @since 3.6.0
     * @since 5.8.0 Added 'path' as an official value for $key.
     *              See {@see wp_maybe_inline_styles()}.
     *
     * @param string $handle Name of the stylesheet.
     * @param string $key    Name of data point for which we're storing a value.
     *                       Accepts 'conditional', 'rtl' and 'suffix', 'alt', 'title' and 'path'.
     * @param mixed  $value  String containing the CSS data to be added.
     * @return bool True on success, false on failure.
     * @phpstan-param 'conditional'|'rtl'|'suffix'|'alt'|'title'|'path' $key
     */
    function wp_style_add_data($handle, $key, $value)
    {
    }
    /**
     * Loads header template.
     *
     * Includes the header template for a theme or if a name is specified then a
     * specialized header will be included.
     *
     * For the parameter, if the file is called "header-special.php" then specify
     * "special".
     *
     * @since 1.5.0
     * @since 5.5.0 A return value was added.
     * @since 5.5.0 The `$args` parameter was added.
     *
     * @param string $name The name of the specialized header.
     * @param array  $args Optional. Additional arguments passed to the header template.
     *                     Default empty array.
     * @return void|false Void on success, false if the template does not exist.
     */
    function get_header($name = \null, $args = array())
    {
    }
    /**
     * Loads footer template.
     *
     * Includes the footer template for a theme or if a name is specified then a
     * specialized footer will be included.
     *
     * For the parameter, if the file is called "footer-special.php" then specify
     * "special".
     *
     * @since 1.5.0
     * @since 5.5.0 A return value was added.
     * @since 5.5.0 The `$args` parameter was added.
     *
     * @param string $name The name of the specialized footer.
     * @param array  $args Optional. Additional arguments passed to the footer template.
     *                     Default empty array.
     * @return void|false Void on success, false if the template does not exist.
     */
    function get_footer($name = \null, $args = array())
    {
    }
    /**
     * Loads sidebar template.
     *
     * Includes the sidebar template for a theme or if a name is specified then a
     * specialized sidebar will be included.
     *
     * For the parameter, if the file is called "sidebar-special.php" then specify
     * "special".
     *
     * @since 1.5.0
     * @since 5.5.0 A return value was added.
     * @since 5.5.0 The `$args` parameter was added.
     *
     * @param string $name The name of the specialized sidebar.
     * @param array  $args Optional. Additional arguments passed to the sidebar template.
     *                     Default empty array.
     * @return void|false Void on success, false if the template does not exist.
     */
    function get_sidebar($name = \null, $args = array())
    {
    }
    /**
     * Loads a template part into a template.
     *
     * Provides a simple mechanism for child themes to overload reusable sections of code
     * in the theme.
     *
     * Includes the named template part for a theme or if a name is specified then a
     * specialized part will be included. If the theme contains no {slug}.php file
     * then no template will be included.
     *
     * The template is included using require, not require_once, so you may include the
     * same template part multiple times.
     *
     * For the $name parameter, if the file is called "{slug}-special.php" then specify
     * "special".
     *
     * @since 3.0.0
     * @since 5.5.0 A return value was added.
     * @since 5.5.0 The `$args` parameter was added.
     *
     * @param string      $slug The slug name for the generic template.
     * @param string|null $name Optional. The name of the specialized template.
     * @param array       $args Optional. Additional arguments passed to the template.
     *                          Default empty array.
     * @return void|false Void on success, false if the template does not exist.
     */
    function get_template_part($slug, $name = \null, $args = array())
    {
    }
    /**
     * Displays search form.
     *
     * Will first attempt to locate the searchform.php file in either the child or
     * the parent, then load it. If it doesn't exist, then the default search form
     * will be displayed. The default search form is HTML, which will be displayed.
     * There is a filter applied to the search form HTML in order to edit or replace
     * it. The filter is {@see 'get_search_form'}.
     *
     * This function is primarily used by themes which want to hardcode the search
     * form into the sidebar and also by the search widget in WordPress.
     *
     * There is also an action that is called whenever the function is run called,
     * {@see 'pre_get_search_form'}. This can be useful for outputting JavaScript that the
     * search relies on or various formatting that applies to the beginning of the
     * search. To give a few examples of what it can be used for.
     *
     * @since 2.7.0
     * @since 5.2.0 The `$args` array parameter was added in place of an `$echo` boolean flag.
     *
     * @param array $args {
     *     Optional. Array of display arguments.
     *
     *     @type bool   $echo       Whether to echo or return the form. Default true.
     *     @type string $aria_label ARIA label for the search form. Useful to distinguish
     *                              multiple search forms on the same page and improve
     *                              accessibility. Default empty.
     * }
     * @return void|string Void if 'echo' argument is true, search form HTML if 'echo' is false.
     * @phpstan-param array{
     *   echo?: bool,
     *   aria_label?: string,
     * } $args
     */
    function get_search_form($args = array())
    {
    }
    /**
     * Displays the Log In/Out link.
     *
     * Displays a link, which allows users to navigate to the Log In page to log in
     * or log out depending on whether they are currently logged in.
     *
     * @since 1.5.0
     *
     * @param string $redirect Optional path to redirect to on login/logout.
     * @param bool   $display  Default to echo and not return the link.
     * @return void|string Void if `$display` argument is true, log in/out link if `$display` is false.
     * @phpstan-return ($display is true ? void : string)
     */
    function wp_loginout($redirect = '', $display = \true)
    {
    }
    /**
     * Retrieves the logout URL.
     *
     * Returns the URL that allows the user to log out of the site.
     *
     * @since 2.7.0
     *
     * @param string $redirect Path to redirect to on logout.
     * @return string The logout URL. Note: HTML-encoded via esc_html() in wp_nonce_url().
     */
    function wp_logout_url($redirect = '')
    {
    }
    /**
     * Retrieves the login URL.
     *
     * @since 2.7.0
     *
     * @param string $redirect     Path to redirect to on log in.
     * @param bool   $force_reauth Whether to force reauthorization, even if a cookie is present.
     *                             Default false.
     * @return string The login URL. Not HTML-encoded.
     */
    function wp_login_url($redirect = '', $force_reauth = \false)
    {
    }
    /**
     * Returns the URL that allows the user to register on the site.
     *
     * @since 3.6.0
     *
     * @return string User registration URL.
     */
    function wp_registration_url()
    {
    }
    /**
     * Provides a simple login form for use anywhere within WordPress.
     *
     * The login form HTML is echoed by default. Pass a false value for `$echo` to return it instead.
     *
     * @since 3.0.0
     * @since 6.6.0 Added `required_username` and `required_password` arguments.
     *
     * @param array $args {
     *     Optional. Array of options to control the form output. Default empty array.
     *
     *     @type bool   $echo              Whether to display the login form or return the form HTML code.
     *                                     Default true (echo).
     *     @type string $redirect          URL to redirect to. Must be absolute, as in "https://example.com/mypage/".
     *                                     Default is to redirect back to the request URI.
     *     @type string $form_id           ID attribute value for the form. Default 'loginform'.
     *     @type string $label_username    Label for the username or email address field. Default 'Username or Email Address'.
     *     @type string $label_password    Label for the password field. Default 'Password'.
     *     @type string $label_remember    Label for the remember field. Default 'Remember Me'.
     *     @type string $label_log_in      Label for the submit button. Default 'Log In'.
     *     @type string $id_username       ID attribute value for the username field. Default 'user_login'.
     *     @type string $id_password       ID attribute value for the password field. Default 'user_pass'.
     *     @type string $id_remember       ID attribute value for the remember field. Default 'rememberme'.
     *     @type string $id_submit         ID attribute value for the submit button. Default 'wp-submit'.
     *     @type bool   $remember          Whether to display the "rememberme" checkbox in the form.
     *     @type string $value_username    Default value for the username field. Default empty.
     *     @type bool   $value_remember    Whether the "Remember Me" checkbox should be checked by default.
     *                                     Default false (unchecked).
     *     @type bool   $required_username Whether the username field has the 'required' attribute.
     *                                     Default false.
     *     @type bool   $required_password Whether the password field has the 'required' attribute.
     *                                     Default false.
     *
     * }
     * @return void|string Void if 'echo' argument is true, login form HTML if 'echo' is false.
     * @phpstan-param array{
     *   echo?: bool,
     *   redirect?: string,
     *   form_id?: string,
     *   label_username?: string,
     *   label_password?: string,
     *   label_remember?: string,
     *   label_log_in?: string,
     *   id_username?: string,
     *   id_password?: string,
     *   id_remember?: string,
     *   id_submit?: string,
     *   remember?: bool,
     *   value_username?: string,
     *   value_remember?: bool,
     *   required_username?: bool,
     *   required_password?: bool,
     * } $args
     */
    function wp_login_form($args = array())
    {
    }
    /**
     * Returns the URL that allows the user to reset the lost password.
     *
     * @since 2.8.0
     *
     * @param string $redirect Path to redirect to on login.
     * @return string Lost password URL.
     */
    function wp_lostpassword_url($redirect = '')
    {
    }
    /**
     * Displays the Registration or Admin link.
     *
     * Display a link which allows the user to navigate to the registration page if
     * not logged in and registration is enabled or to the dashboard if logged in.
     *
     * @since 1.5.0
     *
     * @param string $before  Text to output before the link. Default `<li>`.
     * @param string $after   Text to output after the link. Default `</li>`.
     * @param bool   $display Default to echo and not return the link.
     * @return void|string Void if `$display` argument is true, registration or admin link
     *                     if `$display` is false.
     * @phpstan-return ($display is true ? void : string)
     */
    function wp_register($before = '<li>', $after = '</li>', $display = \true)
    {
    }
    /**
     * Theme container function for the 'wp_meta' action.
     *
     * The {@see 'wp_meta'} action can have several purposes, depending on how you use it,
     * but one purpose might have been to allow for theme switching.
     *
     * @since 1.5.0
     *
     * @link https://core.trac.wordpress.org/ticket/1458 Explanation of 'wp_meta' action.
     */
    function wp_meta()
    {
    }
    /**
     * Displays information about the current site.
     *
     * @since 0.71
     *
     * @see get_bloginfo() For possible `$show` values
     *
     * @param string $show Optional. Site information to display. Default empty.
     */
    function bloginfo($show = '')
    {
    }
    /**
     * Retrieves information about the current site.
     *
     * Possible values for `$show` include:
     *
     * - 'name' - Site title (set in Settings > General)
     * - 'description' - Site tagline (set in Settings > General)
     * - 'wpurl' - The WordPress address (URL) (set in Settings > General)
     * - 'url' - The Site address (URL) (set in Settings > General)
     * - 'admin_email' - Admin email (set in Settings > General)
     * - 'charset' - The "Encoding for pages and feeds"  (set in Settings > Reading)
     * - 'version' - The current WordPress version
     * - 'html_type' - The Content-Type (default: "text/html"). Themes and plugins
     *   can override the default value using the {@see 'pre_option_html_type'} filter
     * - 'text_direction' - The text direction determined by the site's language. is_rtl()
     *   should be used instead
     * - 'language' - Language code for the current site
     * - 'stylesheet_url' - URL to the stylesheet for the active theme. An active child theme
     *   will take precedence over this value
     * - 'stylesheet_directory' - Directory path for the active theme.  An active child theme
     *   will take precedence over this value
     * - 'template_url' / 'template_directory' - URL of the active theme's directory. An active
     *   child theme will NOT take precedence over this value
     * - 'pingback_url' - The pingback XML-RPC file URL (xmlrpc.php)
     * - 'atom_url' - The Atom feed URL (/feed/atom)
     * - 'rdf_url' - The RDF/RSS 1.0 feed URL (/feed/rdf)
     * - 'rss_url' - The RSS 0.92 feed URL (/feed/rss)
     * - 'rss2_url' - The RSS 2.0 feed URL (/feed)
     * - 'comments_atom_url' - The comments Atom feed URL (/comments/feed)
     * - 'comments_rss2_url' - The comments RSS 2.0 feed URL (/comments/feed)
     *
     * Some `$show` values are deprecated and will be removed in future versions.
     * These options will trigger the _deprecated_argument() function.
     *
     * Deprecated arguments include:
     *
     * - 'siteurl' - Use 'url' instead
     * - 'home' - Use 'url' instead
     *
     * @since 0.71
     *
     * @global string $wp_version The WordPress version string.
     *
     * @param string $show   Optional. Site info to retrieve. Default empty (site name).
     * @param string $filter Optional. How to filter what is retrieved. Default 'raw'.
     * @return string Mostly string values, might be empty.
     */
    function get_bloginfo($show = '', $filter = 'raw')
    {
    }
    /**
     * Returns the Site Icon URL.
     *
     * @since 4.3.0
     *
     * @param int    $size    Optional. Size of the site icon. Default 512 (pixels).
     * @param string $url     Optional. Fallback url if no site icon is found. Default empty.
     * @param int    $blog_id Optional. ID of the blog to get the site icon for. Default current blog.
     * @return string Site Icon URL.
     */
    function get_site_icon_url($size = 512, $url = '', $blog_id = 0)
    {
    }
    /**
     * Displays the Site Icon URL.
     *
     * @since 4.3.0
     *
     * @param int    $size    Optional. Size of the site icon. Default 512 (pixels).
     * @param string $url     Optional. Fallback url if no site icon is found. Default empty.
     * @param int    $blog_id Optional. ID of the blog to get the site icon for. Default current blog.
     */
    function site_icon_url($size = 512, $url = '', $blog_id = 0)
    {
    }
    /**
     * Determines whether the site has a Site Icon.
     *
     * @since 4.3.0
     *
     * @param int $blog_id Optional. ID of the blog in question. Default current blog.
     * @return bool Whether the site has a site icon or not.
     */
    function has_site_icon($blog_id = 0)
    {
    }
    /**
     * Determines whether the site has a custom logo.
     *
     * @since 4.5.0
     *
     * @param int $blog_id Optional. ID of the blog in question. Default is the ID of the current blog.
     * @return bool Whether the site has a custom logo or not.
     */
    function has_custom_logo($blog_id = 0)
    {
    }
    /**
     * Returns a custom logo, linked to home unless the theme supports removing the link on the home page.
     *
     * @since 4.5.0
     * @since 5.5.0 Added option to remove the link on the home page with `unlink-homepage-logo` theme support
     *              for the `custom-logo` theme feature.
     * @since 5.5.1 Disabled lazy-loading by default.
     *
     * @param int $blog_id Optional. ID of the blog in question. Default is the ID of the current blog.
     * @return string Custom logo markup.
     */
    function get_custom_logo($blog_id = 0)
    {
    }
    /**
     * Displays a custom logo, linked to home unless the theme supports removing the link on the home page.
     *
     * @since 4.5.0
     *
     * @param int $blog_id Optional. ID of the blog in question. Default is the ID of the current blog.
     */
    function the_custom_logo($blog_id = 0)
    {
    }
    /**
     * Returns document title for the current page.
     *
     * @since 4.4.0
     *
     * @global int $page  Page number of a single post.
     * @global int $paged Page number of a list of posts.
     *
     * @return string Tag with the document title.
     */
    function wp_get_document_title()
    {
    }
    /**
     * Displays title tag with content.
     *
     * @since 4.1.0
     * @since 4.4.0 Improved title output replaced `wp_title()`.
     * @access private
     * @phpstan-return void
     */
    function _wp_render_title_tag()
    {
    }
    /**
     * Displays or retrieves page title for all areas of blog.
     *
     * By default, the page title will display the separator before the page title,
     * so that the blog title will be before the page title. This is not good for
     * title display, since the blog title shows up on most tabs and not what is
     * important, which is the page that the user is looking at.
     *
     * There are also SEO benefits to having the blog title after or to the 'right'
     * of the page title. However, it is mostly common sense to have the blog title
     * to the right with most browsers supporting tabs. You can achieve this by
     * using the seplocation parameter and setting the value to 'right'. This change
     * was introduced around 2.5.0, in case backward compatibility of themes is
     * important.
     *
     * @since 1.0.0
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     *
     * @param string $sep         Optional. How to separate the various items within the page title.
     *                            Default '&raquo;'.
     * @param bool   $display     Optional. Whether to display or retrieve title. Default true.
     * @param string $seplocation Optional. Location of the separator (either 'left' or 'right').
     * @return string|void String when `$display` is false, nothing otherwise.
     * @phpstan-param 'left'|'right' $seplocation
     * @phpstan-return ($display is true ? void : string)
     */
    function wp_title($sep = '&raquo;', $display = \true, $seplocation = '')
    {
    }
    /**
     * Displays or retrieves page title for post.
     *
     * This is optimized for single.php template file for displaying the post title.
     *
     * It does not support placing the separator after the title, but by leaving the
     * prefix parameter empty, you can set the title separator manually. The prefix
     * does not automatically place a space between the prefix, so if there should
     * be a space, the parameter value will need to have it at the end.
     *
     * @since 0.71
     *
     * @param string $prefix  Optional. What to display before the title.
     * @param bool   $display Optional. Whether to display or retrieve title. Default true.
     * @return string|void Title when retrieving.
     * @phpstan-return ($display is true ? void : string|void)
     */
    function single_post_title($prefix = '', $display = \true)
    {
    }
    /**
     * Displays or retrieves title for a post type archive.
     *
     * This is optimized for archive.php and archive-{$post_type}.php template files
     * for displaying the title of the post type.
     *
     * @since 3.1.0
     *
     * @param string $prefix  Optional. What to display before the title.
     * @param bool   $display Optional. Whether to display or retrieve title. Default true.
     * @return string|void Title when retrieving, null when displaying or failure.
     * @phpstan-return ($display is true ? void : string|void)
     */
    function post_type_archive_title($prefix = '', $display = \true)
    {
    }
    /**
     * Displays or retrieves page title for category archive.
     *
     * Useful for category template files for displaying the category page title.
     * The prefix does not automatically place a space between the prefix, so if
     * there should be a space, the parameter value will need to have it at the end.
     *
     * @since 0.71
     *
     * @param string $prefix  Optional. What to display before the title.
     * @param bool   $display Optional. Whether to display or retrieve title. Default true.
     * @return string|void Title when retrieving.
     * @phpstan-return ($display is true ? void : string|void)
     */
    function single_cat_title($prefix = '', $display = \true)
    {
    }
    /**
     * Displays or retrieves page title for tag post archive.
     *
     * Useful for tag template files for displaying the tag page title. The prefix
     * does not automatically place a space between the prefix, so if there should
     * be a space, the parameter value will need to have it at the end.
     *
     * @since 2.3.0
     *
     * @param string $prefix  Optional. What to display before the title.
     * @param bool   $display Optional. Whether to display or retrieve title. Default true.
     * @return string|void Title when retrieving.
     * @phpstan-return ($display is true ? void : string|void)
     */
    function single_tag_title($prefix = '', $display = \true)
    {
    }
    /**
     * Displays or retrieves page title for taxonomy term archive.
     *
     * Useful for taxonomy term template files for displaying the taxonomy term page title.
     * The prefix does not automatically place a space between the prefix, so if there should
     * be a space, the parameter value will need to have it at the end.
     *
     * @since 3.1.0
     *
     * @param string $prefix  Optional. What to display before the title.
     * @param bool   $display Optional. Whether to display or retrieve title. Default true.
     * @return string|void Title when retrieving.
     * @phpstan-return ($display is true ? void : string|void)
     */
    function single_term_title($prefix = '', $display = \true)
    {
    }
    /**
     * Displays or retrieves page title for post archive based on date.
     *
     * Useful for when the template only needs to display the month and year,
     * if either are available. The prefix does not automatically place a space
     * between the prefix, so if there should be a space, the parameter value
     * will need to have it at the end.
     *
     * @since 0.71
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     *
     * @param string $prefix  Optional. What to display before the title.
     * @param bool   $display Optional. Whether to display or retrieve title. Default true.
     * @return string|false|void False if there's no valid title for the month. Title when retrieving.
     * @phpstan-return ($display is true ? false|void : false|string)
     */
    function single_month_title($prefix = '', $display = \true)
    {
    }
    /**
     * Displays the archive title based on the queried object.
     *
     * @since 4.1.0
     *
     * @see get_the_archive_title()
     *
     * @param string $before Optional. Content to prepend to the title. Default empty.
     * @param string $after  Optional. Content to append to the title. Default empty.
     */
    function the_archive_title($before = '', $after = '')
    {
    }
    /**
     * Retrieves the archive title based on the queried object.
     *
     * @since 4.1.0
     * @since 5.5.0 The title part is wrapped in a `<span>` element.
     *
     * @return string Archive title.
     */
    function get_the_archive_title()
    {
    }
    /**
     * Displays category, tag, term, or author description.
     *
     * @since 4.1.0
     *
     * @see get_the_archive_description()
     *
     * @param string $before Optional. Content to prepend to the description. Default empty.
     * @param string $after  Optional. Content to append to the description. Default empty.
     */
    function the_archive_description($before = '', $after = '')
    {
    }
    /**
     * Retrieves the description for an author, post type, or term archive.
     *
     * @since 4.1.0
     * @since 4.7.0 Added support for author archives.
     * @since 4.9.0 Added support for post type archives.
     *
     * @see term_description()
     *
     * @return string Archive description.
     */
    function get_the_archive_description()
    {
    }
    /**
     * Retrieves the description for a post type archive.
     *
     * @since 4.9.0
     *
     * @return string The post type description.
     */
    function get_the_post_type_description()
    {
    }
    /**
     * Retrieves archive link content based on predefined or custom code.
     *
     * The format can be one of four styles. The 'link' for head element, 'option'
     * for use in the select element, 'html' for use in list (either ol or ul HTML
     * elements). Custom content is also supported using the before and after
     * parameters.
     *
     * The 'link' format uses the `<link>` HTML element with the **archives**
     * relationship. The before and after parameters are not used. The text
     * parameter is used to describe the link.
     *
     * The 'option' format uses the option HTML element for use in select element.
     * The value is the url parameter and the before and after parameters are used
     * between the text description.
     *
     * The 'html' format, which is the default, uses the li HTML element for use in
     * the list HTML elements. The before parameter is before the link and the after
     * parameter is after the closing link.
     *
     * The custom format uses the before parameter before the link ('a' HTML
     * element) and the after parameter after the closing link tag. If the above
     * three values for the format are not used, then custom format is assumed.
     *
     * @since 1.0.0
     * @since 5.2.0 Added the `$selected` parameter.
     *
     * @param string $url      URL to archive.
     * @param string $text     Archive text description.
     * @param string $format   Optional. Can be 'link', 'option', 'html', or custom. Default 'html'.
     * @param string $before   Optional. Content to prepend to the description. Default empty.
     * @param string $after    Optional. Content to append to the description. Default empty.
     * @param bool   $selected Optional. Set to true if the current page is the selected archive page.
     * @return string HTML link content for archive.
     */
    function get_archives_link($url, $text, $format = 'html', $before = '', $after = '', $selected = \false)
    {
    }
    /**
     * Displays archive links based on type and format.
     *
     * @since 1.2.0
     * @since 4.4.0 The `$post_type` argument was added.
     * @since 5.2.0 The `$year`, `$monthnum`, `$day`, and `$w` arguments were added.
     *
     * @see get_archives_link()
     *
     * @global wpdb      $wpdb      WordPress database abstraction object.
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     *
     * @param string|array $args {
     *     Default archive links arguments. Optional.
     *
     *     @type string     $type            Type of archive to retrieve. Accepts 'daily', 'weekly', 'monthly',
     *                                       'yearly', 'postbypost', or 'alpha'. Both 'postbypost' and 'alpha'
     *                                       display the same archive link list as well as post titles instead
     *                                       of displaying dates. The difference between the two is that 'alpha'
     *                                       will order by post title and 'postbypost' will order by post date.
     *                                       Default 'monthly'.
     *     @type string|int $limit           Number of links to limit the query to. Default empty (no limit).
     *     @type string     $format          Format each link should take using the $before and $after args.
     *                                       Accepts 'link' (`<link>` tag), 'option' (`<option>` tag), 'html'
     *                                       (`<li>` tag), or a custom format, which generates a link anchor
     *                                       with $before preceding and $after succeeding. Default 'html'.
     *     @type string     $before          Markup to prepend to the beginning of each link. Default empty.
     *     @type string     $after           Markup to append to the end of each link. Default empty.
     *     @type bool       $show_post_count Whether to display the post count alongside the link. Default false.
     *     @type bool|int   $echo            Whether to echo or return the links list. Default 1|true to echo.
     *     @type string     $order           Whether to use ascending or descending order. Accepts 'ASC', or 'DESC'.
     *                                       Default 'DESC'.
     *     @type string     $post_type       Post type. Default 'post'.
     *     @type string     $year            Year. Default current year.
     *     @type string     $monthnum        Month number. Default current month number.
     *     @type string     $day             Day. Default current day.
     *     @type string     $w               Week. Default current week.
     * }
     * @return void|string Void if 'echo' argument is true, archive links if 'echo' is false.
     * @phpstan-param array{
     *   type?: string,
     *   limit?: string|int,
     *   format?: string,
     *   before?: string,
     *   after?: string,
     *   show_post_count?: bool,
     *   echo?: bool|int,
     *   order?: string,
     *   post_type?: string,
     *   year?: string,
     *   monthnum?: string,
     *   day?: string,
     *   w?: string,
     * } $args
     * @phpstan-return ($args is array{echo: false|0}&array ? string|void : void)
     */
    function wp_get_archives($args = '')
    {
    }
    /**
     * Gets number of days since the start of the week.
     *
     * @since 1.5.0
     *
     * @param int $num Number of day.
     * @return float Days since the start of the week.
     */
    function calendar_week_mod($num)
    {
    }
    /**
     * Displays calendar with days that have posts as links.
     *
     * The calendar is cached, which will be retrieved, if it exists. If there are
     * no posts for the month, then it will not be displayed.
     *
     * @since 1.0.0
     *
     * @global wpdb      $wpdb      WordPress database abstraction object.
     * @global int       $m
     * @global int       $monthnum
     * @global int       $year
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     * @global array     $posts
     *
     * @param bool $initial Optional. Whether to use initial calendar names. Default true.
     * @param bool $display Optional. Whether to display the calendar output. Default true.
     * @return void|string Void if `$display` argument is true, calendar HTML if `$display` is false.
     * @phpstan-return ($display is true ? void : string)
     */
    function get_calendar($initial = \true, $display = \true)
    {
    }
    /**
     * Purges the cached results of get_calendar.
     *
     * @see get_calendar()
     * @since 2.1.0
     */
    function delete_get_calendar_cache()
    {
    }
    /**
     * Displays all of the allowed tags in HTML format with attributes.
     *
     * This is useful for displaying in the comment area, which elements and
     * attributes are supported. As well as any plugins which want to display it.
     *
     * @since 1.0.1
     * @since 4.4.0 No longer used in core.
     *
     * @global array $allowedtags
     *
     * @return string HTML allowed tags entity encoded.
     */
    function allowed_tags()
    {
    }
    /**
     * Outputs the date in iso8601 format for xml files.
     *
     * @since 1.0.0
     */
    function the_date_xml()
    {
    }
    /**
     * Displays or retrieves the date the current post was written (once per date)
     *
     * Will only output the date if the current post's date is different from the
     * previous one output.
     *
     * i.e. Only one date listing will show per day worth of posts shown in the loop, even if the
     * function is called several times for each post.
     *
     * HTML output can be filtered with 'the_date'.
     * Date string output can be filtered with 'get_the_date'.
     *
     * @since 0.71
     *
     * @global string $currentday  The day of the current post in the loop.
     * @global string $previousday The day of the previous post in the loop.
     *
     * @param string $format  Optional. PHP date format. Defaults to the 'date_format' option.
     * @param string $before  Optional. Output before the date. Default empty.
     * @param string $after   Optional. Output after the date. Default empty.
     * @param bool   $display Optional. Whether to echo the date or return it. Default true.
     * @return string|void String if retrieving.
     * @phpstan-return ($display is true ? void : string)
     */
    function the_date($format = '', $before = '', $after = '', $display = \true)
    {
    }
    /**
     * Retrieves the date on which the post was written.
     *
     * Unlike the_date() this function will always return the date.
     * Modify output with the {@see 'get_the_date'} filter.
     *
     * @since 3.0.0
     *
     * @param string      $format Optional. PHP date format. Defaults to the 'date_format' option.
     * @param int|WP_Post $post   Optional. Post ID or WP_Post object. Default current post.
     * @return string|int|false Date the current post was written. False on failure.
     */
    function get_the_date($format = '', $post = \null)
    {
    }
    /**
     * Displays the date on which the post was last modified.
     *
     * @since 2.1.0
     *
     * @param string $format  Optional. PHP date format. Defaults to the 'date_format' option.
     * @param string $before  Optional. Output before the date. Default empty.
     * @param string $after   Optional. Output after the date. Default empty.
     * @param bool   $display Optional. Whether to echo the date or return it. Default true.
     * @return string|void String if retrieving.
     * @phpstan-return ($display is true ? void : string)
     */
    function the_modified_date($format = '', $before = '', $after = '', $display = \true)
    {
    }
    /**
     * Retrieves the date on which the post was last modified.
     *
     * @since 2.1.0
     * @since 4.6.0 Added the `$post` parameter.
     *
     * @param string      $format Optional. PHP date format. Defaults to the 'date_format' option.
     * @param int|WP_Post $post   Optional. Post ID or WP_Post object. Default current post.
     * @return string|int|false Date the current post was modified. False on failure.
     */
    function get_the_modified_date($format = '', $post = \null)
    {
    }
    /**
     * Displays the time at which the post was written.
     *
     * @since 0.71
     *
     * @param string $format Optional. Format to use for retrieving the time the post
     *                       was written. Accepts 'G', 'U', or PHP date format.
     *                       Defaults to the 'time_format' option.
     */
    function the_time($format = '')
    {
    }
    /**
     * Retrieves the time at which the post was written.
     *
     * @since 1.5.0
     *
     * @param string      $format Optional. Format to use for retrieving the time the post
     *                            was written. Accepts 'G', 'U', or PHP date format.
     *                            Defaults to the 'time_format' option.
     * @param int|WP_Post $post   Post ID or post object. Default is global `$post` object.
     * @return string|int|false Formatted date string or Unix timestamp if `$format` is 'U' or 'G'.
     *                          False on failure.
     */
    function get_the_time($format = '', $post = \null)
    {
    }
    /**
     * Retrieves the time at which the post was written.
     *
     * @since 2.0.0
     *
     * @param string      $format    Optional. Format to use for retrieving the time the post
     *                               was written. Accepts 'G', 'U', or PHP date format. Default 'U'.
     * @param bool        $gmt       Optional. Whether to retrieve the GMT time. Default false.
     * @param int|WP_Post $post      Post ID or post object. Default is global `$post` object.
     * @param bool        $translate Whether to translate the time string. Default false.
     * @return string|int|false Formatted date string or Unix timestamp if `$format` is 'U' or 'G'.
     *                          False on failure.
     */
    function get_post_time($format = 'U', $gmt = \false, $post = \null, $translate = \false)
    {
    }
    /**
     * Retrieves post published or modified time as a `DateTimeImmutable` object instance.
     *
     * The object will be set to the timezone from WordPress settings.
     *
     * For legacy reasons, this function allows to choose to instantiate from local or UTC time in database.
     * Normally this should make no difference to the result. However, the values might get out of sync in database,
     * typically because of timezone setting changes. The parameter ensures the ability to reproduce backwards
     * compatible behaviors in such cases.
     *
     * @since 5.3.0
     *
     * @param int|WP_Post $post   Optional. Post ID or post object. Default is global `$post` object.
     * @param string      $field  Optional. Published or modified time to use from database. Accepts 'date' or 'modified'.
     *                            Default 'date'.
     * @param string      $source Optional. Local or UTC time to use from database. Accepts 'local' or 'gmt'.
     *                            Default 'local'.
     * @return DateTimeImmutable|false Time object on success, false on failure.
     * @phpstan-param 'date'|'modified' $field
     * @phpstan-param 'local'|'gmt' $source
     */
    function get_post_datetime($post = \null, $field = 'date', $source = 'local')
    {
    }
    /**
     * Retrieves post published or modified time as a Unix timestamp.
     *
     * Note that this function returns a true Unix timestamp, not summed with timezone offset
     * like older WP functions.
     *
     * @since 5.3.0
     *
     * @param int|WP_Post $post  Optional. Post ID or post object. Default is global `$post` object.
     * @param string      $field Optional. Published or modified time to use from database. Accepts 'date' or 'modified'.
     *                           Default 'date'.
     * @return int|false Unix timestamp on success, false on failure.
     * @phpstan-param 'date'|'modified' $field
     */
    function get_post_timestamp($post = \null, $field = 'date')
    {
    }
    /**
     * Displays the time at which the post was last modified.
     *
     * @since 2.0.0
     *
     * @param string $format Optional. Format to use for retrieving the time the post
     *                       was modified. Accepts 'G', 'U', or PHP date format.
     *                       Defaults to the 'time_format' option.
     */
    function the_modified_time($format = '')
    {
    }
    /**
     * Retrieves the time at which the post was last modified.
     *
     * @since 2.0.0
     * @since 4.6.0 Added the `$post` parameter.
     *
     * @param string      $format Optional. Format to use for retrieving the time the post
     *                            was modified. Accepts 'G', 'U', or PHP date format.
     *                            Defaults to the 'time_format' option.
     * @param int|WP_Post $post   Optional. Post ID or WP_Post object. Default current post.
     * @return string|int|false Formatted date string or Unix timestamp. False on failure.
     */
    function get_the_modified_time($format = '', $post = \null)
    {
    }
    /**
     * Retrieves the time at which the post was last modified.
     *
     * @since 2.0.0
     *
     * @param string      $format    Optional. Format to use for retrieving the time the post
     *                               was modified. Accepts 'G', 'U', or PHP date format. Default 'U'.
     * @param bool        $gmt       Optional. Whether to retrieve the GMT time. Default false.
     * @param int|WP_Post $post      Post ID or post object. Default is global `$post` object.
     * @param bool        $translate Whether to translate the time string. Default false.
     * @return string|int|false Formatted date string or Unix timestamp if `$format` is 'U' or 'G'.
     *                          False on failure.
     */
    function get_post_modified_time($format = 'U', $gmt = \false, $post = \null, $translate = \false)
    {
    }
    /**
     * Displays the weekday on which the post was written.
     *
     * @since 0.71
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     * @phpstan-return void
     */
    function the_weekday()
    {
    }
    /**
     * Displays the weekday on which the post was written.
     *
     * Will only output the weekday if the current post's weekday is different from
     * the previous one output.
     *
     * @since 0.71
     *
     * @global WP_Locale $wp_locale       WordPress date and time locale object.
     * @global string    $currentday      The day of the current post in the loop.
     * @global string    $previousweekday The day of the previous post in the loop.
     *
     * @param string $before Optional. Output before the date. Default empty.
     * @param string $after  Optional. Output after the date. Default empty.
     * @phpstan-return void
     */
    function the_weekday_date($before = '', $after = '')
    {
    }
    /**
     * Fires the wp_head action.
     *
     * See {@see 'wp_head'}.
     *
     * @since 1.2.0
     */
    function wp_head()
    {
    }
    /**
     * Fires the wp_footer action.
     *
     * See {@see 'wp_footer'}.
     *
     * @since 1.5.1
     */
    function wp_footer()
    {
    }
    /**
     * Fires the wp_body_open action.
     *
     * See {@see 'wp_body_open'}.
     *
     * @since 5.2.0
     */
    function wp_body_open()
    {
    }
    /**
     * Displays the links to the general feeds.
     *
     * @since 2.8.0
     *
     * @param array $args Optional arguments.
     * @phpstan-return void
     */
    function feed_links($args = array())
    {
    }
    /**
     * Displays the links to the extra feeds such as category feeds.
     *
     * @since 2.8.0
     *
     * @param array $args Optional arguments.
     */
    function feed_links_extra($args = array())
    {
    }
    /**
     * Displays the link to the Really Simple Discovery service endpoint.
     *
     * @link http://archipelago.phrasewise.com/rsd
     * @since 2.0.0
     */
    function rsd_link()
    {
    }
    /**
     * Displays a referrer `strict-origin-when-cross-origin` meta tag.
     *
     * Outputs a referrer `strict-origin-when-cross-origin` meta tag that tells the browser not to send
     * the full URL as a referrer to other sites when cross-origin assets are loaded.
     *
     * Typical usage is as a {@see 'wp_head'} callback:
     *
     *     add_action( 'wp_head', 'wp_strict_cross_origin_referrer' );
     *
     * @since 5.7.0
     */
    function wp_strict_cross_origin_referrer()
    {
    }
    /**
     * Displays site icon meta tags.
     *
     * @since 4.3.0
     *
     * @link https://www.whatwg.org/specs/web-apps/current-work/multipage/links.html#rel-icon HTML5 specification link icon.
     * @phpstan-return void
     */
    function wp_site_icon()
    {
    }
    /**
     * Prints resource hints to browsers for pre-fetching, pre-rendering
     * and pre-connecting to websites.
     *
     * Gives hints to browsers to prefetch specific pages or render them
     * in the background, to perform DNS lookups or to begin the connection
     * handshake (DNS, TCP, TLS) in the background.
     *
     * These performance improving indicators work by using `<link rel"…">`.
     *
     * @since 4.6.0
     */
    function wp_resource_hints()
    {
    }
    /**
     * Prints resource preloads directives to browsers.
     *
     * Gives directive to browsers to preload specific resources that website will
     * need very soon, this ensures that they are available earlier and are less
     * likely to block the page's render. Preload directives should not be used for
     * non-render-blocking elements, as then they would compete with the
     * render-blocking ones, slowing down the render.
     *
     * These performance improving indicators work by using `<link rel="preload">`.
     *
     * @link https://developer.mozilla.org/en-US/docs/Web/HTML/Link_types/preload
     * @link https://web.dev/preload-responsive-images/
     *
     * @since 6.1.0
     * @phpstan-return void
     */
    function wp_preload_resources()
    {
    }
    /**
     * Retrieves a list of unique hosts of all enqueued scripts and styles.
     *
     * @since 4.6.0
     *
     * @global WP_Scripts $wp_scripts The WP_Scripts object for printing scripts.
     * @global WP_Styles  $wp_styles  The WP_Styles object for printing styles.
     *
     * @return string[] A list of unique hosts of enqueued scripts and styles.
     */
    function wp_dependencies_unique_hosts()
    {
    }
    /**
     * Determines whether the user can access the visual editor.
     *
     * Checks if the user can access the visual editor and that it's supported by the user's browser.
     *
     * @since 2.0.0
     *
     * @global bool $wp_rich_edit Whether the user can access the visual editor.
     * @global bool $is_gecko     Whether the browser is Gecko-based.
     * @global bool $is_opera     Whether the browser is Opera.
     * @global bool $is_safari    Whether the browser is Safari.
     * @global bool $is_chrome    Whether the browser is Chrome.
     * @global bool $is_IE        Whether the browser is Internet Explorer.
     * @global bool $is_edge      Whether the browser is Microsoft Edge.
     *
     * @return bool True if the user can access the visual editor, false otherwise.
     */
    function user_can_richedit()
    {
    }
    /**
     * Finds out which editor should be displayed by default.
     *
     * Works out which of the editors to display as the current editor for a
     * user. The 'html' setting is for the "Text" editor tab.
     *
     * @since 2.5.0
     *
     * @return string Either 'tinymce', 'html', or 'test'
     * @phpstan-return 'tinymce'|'html'|'test'
     */
    function wp_default_editor()
    {
    }
    /**
     * Renders an editor.
     *
     * Using this function is the proper way to output all needed components for both TinyMCE and Quicktags.
     * _WP_Editors should not be used directly. See https://core.trac.wordpress.org/ticket/17144.
     *
     * NOTE: Once initialized the TinyMCE editor cannot be safely moved in the DOM. For that reason
     * running wp_editor() inside of a meta box is not a good idea unless only Quicktags is used.
     * On the post edit screen several actions can be used to include additional editors
     * containing TinyMCE: 'edit_page_form', 'edit_form_advanced' and 'dbx_post_sidebar'.
     * See https://core.trac.wordpress.org/ticket/19173 for more information.
     *
     * @see _WP_Editors::editor()
     * @see _WP_Editors::parse_settings()
     * @since 3.3.0
     *
     * @param string $content   Initial content for the editor.
     * @param string $editor_id HTML ID attribute value for the textarea and TinyMCE.
     *                          Should not contain square brackets.
     * @param array  $settings  See _WP_Editors::parse_settings() for description.
     * @phpstan-param array{
     *   wpautop?: bool,
     *   media_buttons?: bool,
     *   default_editor?: string,
     *   drag_drop_upload?: bool,
     *   textarea_name?: string,
     *   textarea_rows?: int,
     *   tabindex?: string|int,
     *   tabfocus_elements?: string,
     *   editor_css?: string,
     *   editor_class?: string,
     *   teeny?: bool,
     *   dfw?: bool,
     *   tinymce?: bool|array,
     *   quicktags?: bool|array,
     * } $settings See _WP_Editors::parse_settings()
     */
    function wp_editor($content, $editor_id, $settings = array())
    {
    }
    /**
     * Outputs the editor scripts, stylesheets, and default settings.
     *
     * The editor can be initialized when needed after page load.
     * See wp.editor.initialize() in wp-admin/js/editor.js for initialization options.
     *
     * @uses _WP_Editors
     * @since 4.8.0
     */
    function wp_enqueue_editor()
    {
    }
    /**
     * Enqueues assets needed by the code editor for the given settings.
     *
     * @since 4.9.0
     *
     * @see wp_enqueue_editor()
     * @see wp_get_code_editor_settings();
     * @see _WP_Editors::parse_settings()
     *
     * @param array $args {
     *     Args.
     *
     *     @type string   $type       The MIME type of the file to be edited.
     *     @type string   $file       Filename to be edited. Extension is used to sniff the type. Can be supplied as alternative to `$type` param.
     *     @type WP_Theme $theme      Theme being edited when on the theme file editor.
     *     @type string   $plugin     Plugin being edited when on the plugin file editor.
     *     @type array    $codemirror Additional CodeMirror setting overrides.
     *     @type array    $csslint    CSSLint rule overrides.
     *     @type array    $jshint     JSHint rule overrides.
     *     @type array    $htmlhint   HTMLHint rule overrides.
     * }
     * @return array|false Settings for the enqueued code editor, or false if the editor was not enqueued.
     * @phpstan-param array{
     *   type?: string,
     *   file?: string,
     *   theme?: WP_Theme,
     *   plugin?: string,
     *   codemirror?: array,
     *   csslint?: array,
     *   jshint?: array,
     *   htmlhint?: array,
     * } $args
     */
    function wp_enqueue_code_editor($args)
    {
    }
    /**
     * Generates and returns code editor settings.
     *
     * @since 5.0.0
     *
     * @see wp_enqueue_code_editor()
     *
     * @param array $args {
     *     Args.
     *
     *     @type string   $type       The MIME type of the file to be edited.
     *     @type string   $file       Filename to be edited. Extension is used to sniff the type. Can be supplied as alternative to `$type` param.
     *     @type WP_Theme $theme      Theme being edited when on the theme file editor.
     *     @type string   $plugin     Plugin being edited when on the plugin file editor.
     *     @type array    $codemirror Additional CodeMirror setting overrides.
     *     @type array    $csslint    CSSLint rule overrides.
     *     @type array    $jshint     JSHint rule overrides.
     *     @type array    $htmlhint   HTMLHint rule overrides.
     * }
     * @return array|false Settings for the code editor.
     * @phpstan-param array{
     *   type?: string,
     *   file?: string,
     *   theme?: WP_Theme,
     *   plugin?: string,
     *   codemirror?: array,
     *   csslint?: array,
     *   jshint?: array,
     *   htmlhint?: array,
     * } $args
     */
    function wp_get_code_editor_settings($args)
    {
    }
    /**
     * Retrieves the contents of the search WordPress query variable.
     *
     * The search query string is passed through esc_attr() to ensure that it is safe
     * for placing in an HTML attribute.
     *
     * @since 2.3.0
     *
     * @param bool $escaped Whether the result is escaped. Default true.
     *                      Only use when you are later escaping it. Do not use unescaped.
     * @return string
     */
    function get_search_query($escaped = \true)
    {
    }
    /**
     * Displays the contents of the search query variable.
     *
     * The search query string is passed through esc_attr() to ensure that it is safe
     * for placing in an HTML attribute.
     *
     * @since 2.1.0
     */
    function the_search_query()
    {
    }
    /**
     * Gets the language attributes for the 'html' tag.
     *
     * Builds up a set of HTML attributes containing the text direction and language
     * information for the page.
     *
     * @since 4.3.0
     *
     * @param string $doctype Optional. The type of HTML document. Accepts 'xhtml' or 'html'. Default 'html'.
     * @return string A space-separated list of language attributes.
     * @phpstan-param 'xhtml'|'html' $doctype
     */
    function get_language_attributes($doctype = 'html')
    {
    }
    /**
     * Displays the language attributes for the 'html' tag.
     *
     * Builds up a set of HTML attributes containing the text direction and language
     * information for the page.
     *
     * @since 2.1.0
     * @since 4.3.0 Converted into a wrapper for get_language_attributes().
     *
     * @param string $doctype Optional. The type of HTML document. Accepts 'xhtml' or 'html'. Default 'html'.
     * @phpstan-param 'xhtml'|'html' $doctype
     */
    function language_attributes($doctype = 'html')
    {
    }
    /**
     * Retrieves paginated links for archive post pages.
     *
     * Technically, the function can be used to create paginated link list for any
     * area. The 'base' argument is used to reference the url, which will be used to
     * create the paginated links. The 'format' argument is then used for replacing
     * the page number. It is however, most likely and by default, to be used on the
     * archive post pages.
     *
     * The 'type' argument controls format of the returned value. The default is
     * 'plain', which is just a string with the links separated by a newline
     * character. The other possible values are either 'array' or 'list'. The
     * 'array' value will return an array of the paginated link list to offer full
     * control of display. The 'list' value will place all of the paginated links in
     * an unordered HTML list.
     *
     * The 'total' argument is the total amount of pages and is an integer. The
     * 'current' argument is the current page number and is also an integer.
     *
     * An example of the 'base' argument is "http://example.com/all_posts.php%_%"
     * and the '%_%' is required. The '%_%' will be replaced by the contents of in
     * the 'format' argument. An example for the 'format' argument is "?page=%#%"
     * and the '%#%' is also required. The '%#%' will be replaced with the page
     * number.
     *
     * You can include the previous and next links in the list by setting the
     * 'prev_next' argument to true, which it is by default. You can set the
     * previous text, by using the 'prev_text' argument. You can set the next text
     * by setting the 'next_text' argument.
     *
     * If the 'show_all' argument is set to true, then it will show all of the pages
     * instead of a short list of the pages near the current page. By default, the
     * 'show_all' is set to false and controlled by the 'end_size' and 'mid_size'
     * arguments. The 'end_size' argument is how many numbers on either the start
     * and the end list edges, by default is 1. The 'mid_size' argument is how many
     * numbers to either side of current page, but not including current page.
     *
     * It is possible to add query vars to the link by using the 'add_args' argument
     * and see add_query_arg() for more information.
     *
     * The 'before_page_number' and 'after_page_number' arguments allow users to
     * augment the links themselves. Typically this might be to add context to the
     * numbered links so that screen reader users understand what the links are for.
     * The text strings are added before and after the page number - within the
     * anchor tag.
     *
     * @since 2.1.0
     * @since 4.9.0 Added the `aria_current` argument.
     *
     * @global WP_Query   $wp_query   WordPress Query object.
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string|array $args {
     *     Optional. Array or string of arguments for generating paginated links for archives.
     *
     *     @type string $base               Base of the paginated url. Default empty.
     *     @type string $format             Format for the pagination structure. Default empty.
     *     @type int    $total              The total amount of pages. Default is the value WP_Query's
     *                                      `max_num_pages` or 1.
     *     @type int    $current            The current page number. Default is 'paged' query var or 1.
     *     @type string $aria_current       The value for the aria-current attribute. Possible values are 'page',
     *                                      'step', 'location', 'date', 'time', 'true', 'false'. Default is 'page'.
     *     @type bool   $show_all           Whether to show all pages. Default false.
     *     @type int    $end_size           How many numbers on either the start and the end list edges.
     *                                      Default 1.
     *     @type int    $mid_size           How many numbers to either side of the current pages. Default 2.
     *     @type bool   $prev_next          Whether to include the previous and next links in the list. Default true.
     *     @type string $prev_text          The previous page text. Default '&laquo; Previous'.
     *     @type string $next_text          The next page text. Default 'Next &raquo;'.
     *     @type string $type               Controls format of the returned value. Possible values are 'plain',
     *                                      'array' and 'list'. Default is 'plain'.
     *     @type array  $add_args           An array of query args to add. Default false.
     *     @type string $add_fragment       A string to append to each link. Default empty.
     *     @type string $before_page_number A string to appear before the page number. Default empty.
     *     @type string $after_page_number  A string to append after the page number. Default empty.
     * }
     * @return string|string[]|void String of page links or array of page links, depending on 'type' argument.
     *                              Void if total number of pages is less than 2.
     * @phpstan-param array{
     *   base?: string,
     *   format?: string,
     *   total?: int,
     *   current?: int,
     *   aria_current?: string,
     *   show_all?: bool,
     *   end_size?: int,
     *   mid_size?: int,
     *   prev_next?: bool,
     *   prev_text?: string,
     *   next_text?: string,
     *   type?: string,
     *   add_args?: array,
     *   add_fragment?: string,
     *   before_page_number?: string,
     *   after_page_number?: string,
     * } $args
     * @phpstan-return ($args is array{total: int<min, 1>}&array ? void : ($args is array{type: 'array'}&array ? list<string> : string))
     */
    function paginate_links($args = '')
    {
    }
    /**
     * Registers an admin color scheme css file.
     *
     * Allows a plugin to register a new admin color scheme. For example:
     *
     *     wp_admin_css_color( 'classic', __( 'Classic' ), admin_url( "css/colors-classic.css" ), array(
     *         '#07273E', '#14568A', '#D54E21', '#2683AE'
     *     ) );
     *
     * @since 2.5.0
     *
     * @global array $_wp_admin_css_colors
     *
     * @param string $key    The unique key for this theme.
     * @param string $name   The name of the theme.
     * @param string $url    The URL of the CSS file containing the color scheme.
     * @param array  $colors Optional. An array of CSS color definition strings which are used
     *                       to give the user a feel for the theme.
     * @param array  $icons {
     *     Optional. CSS color definitions used to color any SVG icons.
     *
     *     @type string $base    SVG icon base color.
     *     @type string $focus   SVG icon color on focus.
     *     @type string $current SVG icon color of current admin menu link.
     * }
     * @phpstan-param array{
     *   base?: string,
     *   focus?: string,
     *   current?: string,
     * } $icons
     */
    function wp_admin_css_color($key, $name, $url, $colors = array(), $icons = array())
    {
    }
    /**
     * Registers the default admin color schemes.
     *
     * Registers the initial set of eight color schemes in the Profile section
     * of the dashboard which allows for styling the admin menu and toolbar.
     *
     * @see wp_admin_css_color()
     *
     * @since 3.0.0
     */
    function register_admin_color_schemes()
    {
    }
    /**
     * Displays the URL of a WordPress admin CSS file.
     *
     * @see WP_Styles::_css_href() and its {@see 'style_loader_src'} filter.
     *
     * @since 2.3.0
     *
     * @param string $file file relative to wp-admin/ without its ".css" extension.
     * @return string
     */
    function wp_admin_css_uri($file = 'wp-admin')
    {
    }
    /**
     * Enqueues or directly prints a stylesheet link to the specified CSS file.
     *
     * "Intelligently" decides to enqueue or to print the CSS file. If the
     * {@see 'wp_print_styles'} action has *not* yet been called, the CSS file will be
     * enqueued. If the {@see 'wp_print_styles'} action has been called, the CSS link will
     * be printed. Printing may be forced by passing true as the $force_echo
     * (second) parameter.
     *
     * For backward compatibility with WordPress 2.3 calling method: If the $file
     * (first) parameter does not correspond to a registered CSS file, we assume
     * $file is a file relative to wp-admin/ without its ".css" extension. A
     * stylesheet link to that generated URL is printed.
     *
     * @since 2.3.0
     *
     * @param string $file       Optional. Style handle name or file name (without ".css" extension) relative
     *                           to wp-admin/. Defaults to 'wp-admin'.
     * @param bool   $force_echo Optional. Force the stylesheet link to be printed rather than enqueued.
     * @phpstan-return void
     */
    function wp_admin_css($file = 'wp-admin', $force_echo = \false)
    {
    }
    /**
     * Enqueues the default ThickBox js and css.
     *
     * If any of the settings need to be changed, this can be done with another js
     * file similar to media-upload.js. That file should
     * require array('thickbox') to ensure it is loaded after.
     *
     * @since 2.5.0
     */
    function add_thickbox()
    {
    }
    /**
     * Displays the XHTML generator that is generated on the wp_head hook.
     *
     * See {@see 'wp_head'}.
     *
     * @since 2.5.0
     */
    function wp_generator()
    {
    }
    /**
     * Displays the generator XML or Comment for RSS, ATOM, etc.
     *
     * Returns the correct generator type for the requested output format. Allows
     * for a plugin to filter generators overall the {@see 'the_generator'} filter.
     *
     * @since 2.5.0
     *
     * @param string $type The type of generator to output - (html|xhtml|atom|rss2|rdf|comment|export).
     */
    function the_generator($type)
    {
    }
    /**
     * Creates the generator XML or Comment for RSS, ATOM, etc.
     *
     * Returns the correct generator type for the requested output format. Allows
     * for a plugin to filter generators on an individual basis using the
     * {@see 'get_the_generator_$type'} filter.
     *
     * @since 2.5.0
     *
     * @param string $type The type of generator to return - (html|xhtml|atom|rss2|rdf|comment|export).
     * @return string|void The HTML content for the generator.
     */
    function get_the_generator($type = '')
    {
    }
    /**
     * Outputs the HTML checked attribute.
     *
     * Compares the first two arguments and if identical marks as checked.
     *
     * @since 1.0.0
     *
     * @param mixed $checked One of the values to compare.
     * @param mixed $current Optional. The other value to compare if not just true.
     *                       Default true.
     * @param bool  $display Optional. Whether to echo or just return the string.
     *                       Default true.
     * @return string HTML attribute or empty string.
     */
    function checked($checked, $current = \true, $display = \true)
    {
    }
    /**
     * Outputs the HTML selected attribute.
     *
     * Compares the first two arguments and if identical marks as selected.
     *
     * @since 1.0.0
     *
     * @param mixed $selected One of the values to compare.
     * @param mixed $current  Optional. The other value to compare if not just true.
     *                        Default true.
     * @param bool  $display  Optional. Whether to echo or just return the string.
     *                        Default true.
     * @return string HTML attribute or empty string.
     */
    function selected($selected, $current = \true, $display = \true)
    {
    }
    /**
     * Outputs the HTML disabled attribute.
     *
     * Compares the first two arguments and if identical marks as disabled.
     *
     * @since 3.0.0
     *
     * @param mixed $disabled One of the values to compare.
     * @param mixed $current  Optional. The other value to compare if not just true.
     *                        Default true.
     * @param bool  $display  Optional. Whether to echo or just return the string.
     *                        Default true.
     * @return string HTML attribute or empty string.
     */
    function disabled($disabled, $current = \true, $display = \true)
    {
    }
    /**
     * Outputs the HTML readonly attribute.
     *
     * Compares the first two arguments and if identical marks as readonly.
     *
     * @since 5.9.0
     *
     * @param mixed $readonly_value One of the values to compare.
     * @param mixed $current        Optional. The other value to compare if not just true.
     *                              Default true.
     * @param bool  $display        Optional. Whether to echo or just return the string.
     *                              Default true.
     * @return string HTML attribute or empty string.
     */
    function wp_readonly($readonly_value, $current = \true, $display = \true)
    {
    }
    /**
     * Private helper function for checked, selected, disabled and readonly.
     *
     * Compares the first two arguments and if identical marks as `$type`.
     *
     * @since 2.8.0
     * @access private
     *
     * @param mixed  $helper  One of the values to compare.
     * @param mixed  $current The other value to compare if not just true.
     * @param bool   $display Whether to echo or just return the string.
     * @param string $type    The type of checked|selected|disabled|readonly we are doing.
     * @return string HTML attribute or empty string.
     */
    function __checked_selected_helper($helper, $current, $display, $type)
    {
    }
    /**
     * Assigns a visual indicator for required form fields.
     *
     * @since 6.1.0
     *
     * @return string Indicator glyph wrapped in a `span` tag.
     */
    function wp_required_field_indicator()
    {
    }
    /**
     * Creates a message to explain required form fields.
     *
     * @since 6.1.0
     *
     * @return string Message text and glyph wrapped in a `span` tag.
     */
    function wp_required_field_message()
    {
    }
    /**
     * Default settings for heartbeat.
     *
     * Outputs the nonce used in the heartbeat XHR.
     *
     * @since 3.6.0
     *
     * @param array $settings
     * @return array Heartbeat settings.
     */
    function wp_heartbeat_settings($settings)
    {
    }
    /**
     * Gets the settings resulting of merging core, theme, and user data.
     *
     * @since 5.9.0
     *
     * @param array $path    Path to the specific setting to retrieve. Optional.
     *                       If empty, will return all settings.
     * @param array $context {
     *     Metadata to know where to retrieve the $path from. Optional.
     *
     *     @type string $block_name Which block to retrieve the settings from.
     *                              If empty, it'll return the settings for the global context.
     *     @type string $origin     Which origin to take data from.
     *                              Valid values are 'all' (core, theme, and user) or 'base' (core and theme).
     *                              If empty or unknown, 'all' is used.
     * }
     * @return mixed The settings array or individual setting value to retrieve.
     * @phpstan-param array{
     *   block_name?: string,
     *   origin?: string,
     * } $context
     */
    function wp_get_global_settings($path = array(), $context = array())
    {
    }
    /**
     * Gets the styles resulting of merging core, theme, and user data.
     *
     * @since 5.9.0
     * @since 6.3.0 the internal link format "var:preset|color|secondary" is resolved
     *              to "var(--wp--preset--font-size--small)" so consumers don't have to.
     * @since 6.3.0 `transforms` is now usable in the `context` parameter. In case [`transforms`]['resolve_variables']
     *              is defined, variables are resolved to their value in the styles.
     *
     * @param array $path    Path to the specific style to retrieve. Optional.
     *                       If empty, will return all styles.
     * @param array $context {
     *     Metadata to know where to retrieve the $path from. Optional.
     *
     *     @type string $block_name Which block to retrieve the styles from.
     *                              If empty, it'll return the styles for the global context.
     *     @type string $origin     Which origin to take data from.
     *                              Valid values are 'all' (core, theme, and user) or 'base' (core and theme).
     *                              If empty or unknown, 'all' is used.
     *     @type array $transforms Which transformation(s) to apply.
     *                              Valid value is array( 'resolve-variables' ).
     *                              If defined, variables are resolved to their value in the styles.
     * }
     * @return mixed The styles array or individual style value to retrieve.
     * @phpstan-param array{
     *   block_name?: string,
     *   origin?: string,
     *   transforms?: array,
     * } $context
     */
    function wp_get_global_styles($path = array(), $context = array())
    {
    }
    /**
     * Returns the stylesheet resulting of merging core, theme, and user data.
     *
     * @since 5.9.0
     * @since 6.1.0 Added 'base-layout-styles' support.
     * @since 6.6.0 Resolves relative paths in theme.json styles to theme absolute paths.
     *
     * @param array $types Optional. Types of styles to load.
     *                     It accepts as values 'variables', 'presets', 'styles', 'base-layout-styles'.
     *                     If empty, it'll load the following:
     *                     - for themes without theme.json: 'variables', 'presets', 'base-layout-styles'.
     *                     - for themes with theme.json: 'variables', 'presets', 'styles'.
     * @return string Stylesheet.
     */
    function wp_get_global_stylesheet($types = array())
    {
    }
    /**
     * Adds global style rules to the inline style for each block.
     *
     * @since 6.1.0
     * @since 6.7.0 Resolve relative paths in block styles.
     *
     * @global WP_Styles $wp_styles
     */
    function wp_add_global_styles_for_blocks()
    {
    }
    /**
     * Gets the block name from a given theme.json path.
     *
     * @since 6.3.0
     * @access private
     *
     * @param array $path An array of keys describing the path to a property in theme.json.
     * @return string Identified block name, or empty string if none found.
     */
    function wp_get_block_name_from_theme_json_path($path)
    {
    }
    /**
     * Checks whether a theme or its parent has a theme.json file.
     *
     * @since 6.2.0
     *
     * @return bool Returns true if theme or its parent has a theme.json file, false otherwise.
     */
    function wp_theme_has_theme_json()
    {
    }
    /**
     * Cleans the caches under the theme_json group.
     *
     * @since 6.2.0
     */
    function wp_clean_theme_json_cache()
    {
    }
    /**
     * Returns the current theme's wanted patterns (slugs) to be
     * registered from Pattern Directory.
     *
     * @since 6.3.0
     *
     * @return string[]
     */
    function wp_get_theme_directory_pattern_slugs()
    {
    }
    /**
     * Returns the metadata for the custom templates defined by the theme via theme.json.
     *
     * @since 6.4.0
     *
     * @return array Associative array of `$template_name => $template_data` pairs,
     *               with `$template_data` having "title" and "postTypes" fields.
     */
    function wp_get_theme_data_custom_templates()
    {
    }
    /**
     * Returns the metadata for the template parts defined by the theme.
     *
     * @since 6.4.0
     *
     * @return array Associative array of `$part_name => $part_data` pairs,
     *               with `$part_data` having "title" and "area" fields.
     */
    function wp_get_theme_data_template_parts()
    {
    }
    /**
     * Determines the CSS selector for the block type and property provided,
     * returning it if available.
     *
     * @since 6.3.0
     *
     * @param WP_Block_Type $block_type The block's type.
     * @param string|array  $target     The desired selector's target, `root` or array path.
     * @param boolean       $fallback   Whether to fall back to broader selector.
     *
     * @return string|null CSS selector or `null` if no selector available.
     */
    function wp_get_block_css_selector($block_type, $target = 'root', $fallback = \false)
    {
    }
    /**
     * Returns the initialized WP_Http Object
     *
     * @since 2.7.0
     * @access private
     *
     * @return WP_Http HTTP Transport object.
     */
    function _wp_http_get_object()
    {
    }
    /**
     * Retrieves the raw response from a safe HTTP request.
     *
     * This function is ideal when the HTTP request is being made to an arbitrary
     * URL. The URL, and every URL it redirects to, are validated with wp_http_validate_url()
     * to avoid Server Side Request Forgery attacks (SSRF).
     *
     * @since 3.6.0
     *
     * @see wp_remote_request() For more information on the response array format.
     * @see WP_Http::request() For default arguments information.
     * @see wp_http_validate_url() For more information about how the URL is validated.
     *
     * @link https://owasp.org/www-community/attacks/Server_Side_Request_Forgery
     *
     * @param string $url  URL to retrieve.
     * @param array  $args Optional. Request arguments. Default empty array.
     *                     See WP_Http::request() for information on accepted arguments.
     * @return array|WP_Error The response or WP_Error on failure.
     *                        See WP_Http::request() for information on return value.
     * @phpstan-param array{
     *   method?: string,
     *   timeout?: float,
     *   redirection?: int,
     *   httpversion?: string,
     *   user-agent?: string,
     *   reject_unsafe_urls?: bool,
     *   blocking?: bool,
     *   headers?: string|array,
     *   cookies?: array,
     *   body?: string|array,
     *   compress?: bool,
     *   decompress?: bool,
     *   sslverify?: bool,
     *   sslcertificates?: string,
     *   stream?: bool,
     *   filename?: string,
     *   limit_response_size?: int,
     * } $args See WP_Http::request()
     * @phpstan-return array{headers: \WpOrg\Requests\Utility\CaseInsensitiveDictionary, body: string, response: array{code: int, message: string}, cookies: array<int, \WP_Http_Cookie>, filename: string|null, http_response: \WP_HTTP_Requests_Response}|\WP_Error
     */
    function wp_safe_remote_request($url, $args = array())
    {
    }
    /**
     * Retrieves the raw response from a safe HTTP request using the GET method.
     *
     * This function is ideal when the HTTP request is being made to an arbitrary
     * URL. The URL, and every URL it redirects to, are validated with wp_http_validate_url()
     * to avoid Server Side Request Forgery attacks (SSRF).
     *
     * @since 3.6.0
     *
     * @see wp_remote_request() For more information on the response array format.
     * @see WP_Http::request() For default arguments information.
     * @see wp_http_validate_url() For more information about how the URL is validated.
     *
     * @link https://owasp.org/www-community/attacks/Server_Side_Request_Forgery
     *
     * @param string $url  URL to retrieve.
     * @param array  $args Optional. Request arguments. Default empty array.
     *                     See WP_Http::request() for information on accepted arguments.
     * @return array|WP_Error The response or WP_Error on failure.
     *                        See WP_Http::request() for information on return value.
     * @phpstan-param array{
     *   method?: string,
     *   timeout?: float,
     *   redirection?: int,
     *   httpversion?: string,
     *   user-agent?: string,
     *   reject_unsafe_urls?: bool,
     *   blocking?: bool,
     *   headers?: string|array,
     *   cookies?: array,
     *   body?: string|array,
     *   compress?: bool,
     *   decompress?: bool,
     *   sslverify?: bool,
     *   sslcertificates?: string,
     *   stream?: bool,
     *   filename?: string,
     *   limit_response_size?: int,
     * } $args See WP_Http::request()
     * @phpstan-return array{headers: \WpOrg\Requests\Utility\CaseInsensitiveDictionary, body: string, response: array{code: int, message: string}, cookies: array<int, \WP_Http_Cookie>, filename: string|null, http_response: \WP_HTTP_Requests_Response}|\WP_Error
     */
    function wp_safe_remote_get($url, $args = array())
    {
    }
    /**
     * Retrieves the raw response from a safe HTTP request using the POST method.
     *
     * This function is ideal when the HTTP request is being made to an arbitrary
     * URL. The URL, and every URL it redirects to, are validated with wp_http_validate_url()
     * to avoid Server Side Request Forgery attacks (SSRF).
     *
     * @since 3.6.0
     *
     * @see wp_remote_request() For more information on the response array format.
     * @see WP_Http::request() For default arguments information.
     * @see wp_http_validate_url() For more information about how the URL is validated.
     *
     * @link https://owasp.org/www-community/attacks/Server_Side_Request_Forgery
     *
     * @param string $url  URL to retrieve.
     * @param array  $args Optional. Request arguments. Default empty array.
     *                     See WP_Http::request() for information on accepted arguments.
     * @return array|WP_Error The response or WP_Error on failure.
     *                        See WP_Http::request() for information on return value.
     * @phpstan-param array{
     *   method?: string,
     *   timeout?: float,
     *   redirection?: int,
     *   httpversion?: string,
     *   user-agent?: string,
     *   reject_unsafe_urls?: bool,
     *   blocking?: bool,
     *   headers?: string|array,
     *   cookies?: array,
     *   body?: string|array,
     *   compress?: bool,
     *   decompress?: bool,
     *   sslverify?: bool,
     *   sslcertificates?: string,
     *   stream?: bool,
     *   filename?: string,
     *   limit_response_size?: int,
     * } $args See WP_Http::request()
     * @phpstan-return array{headers: \WpOrg\Requests\Utility\CaseInsensitiveDictionary, body: string, response: array{code: int, message: string}, cookies: array<int, \WP_Http_Cookie>, filename: string|null, http_response: \WP_HTTP_Requests_Response}|\WP_Error
     */
    function wp_safe_remote_post($url, $args = array())
    {
    }
    /**
     * Retrieves the raw response from a safe HTTP request using the HEAD method.
     *
     * This function is ideal when the HTTP request is being made to an arbitrary
     * URL. The URL, and every URL it redirects to, are validated with wp_http_validate_url()
     * to avoid Server Side Request Forgery attacks (SSRF).
     *
     * @since 3.6.0
     *
     * @see wp_remote_request() For more information on the response array format.
     * @see WP_Http::request() For default arguments information.
     * @see wp_http_validate_url() For more information about how the URL is validated.
     *
     * @link https://owasp.org/www-community/attacks/Server_Side_Request_Forgery
     *
     * @param string $url  URL to retrieve.
     * @param array  $args Optional. Request arguments. Default empty array.
     *                     See WP_Http::request() for information on accepted arguments.
     * @return array|WP_Error The response or WP_Error on failure.
     *                        See WP_Http::request() for information on return value.
     * @phpstan-param array{
     *   method?: string,
     *   timeout?: float,
     *   redirection?: int,
     *   httpversion?: string,
     *   user-agent?: string,
     *   reject_unsafe_urls?: bool,
     *   blocking?: bool,
     *   headers?: string|array,
     *   cookies?: array,
     *   body?: string|array,
     *   compress?: bool,
     *   decompress?: bool,
     *   sslverify?: bool,
     *   sslcertificates?: string,
     *   stream?: bool,
     *   filename?: string,
     *   limit_response_size?: int,
     * } $args See WP_Http::request()
     * @phpstan-return array{headers: \WpOrg\Requests\Utility\CaseInsensitiveDictionary, body: string, response: array{code: int, message: string}, cookies: array<int, \WP_Http_Cookie>, filename: string|null, http_response: \WP_HTTP_Requests_Response}|\WP_Error
     */
    function wp_safe_remote_head($url, $args = array())
    {
    }
    /**
     * Performs an HTTP request and returns its response.
     *
     * There are other API functions available which abstract away the HTTP method:
     *
     *  - Default 'GET'  for wp_remote_get()
     *  - Default 'POST' for wp_remote_post()
     *  - Default 'HEAD' for wp_remote_head()
     *
     * @since 2.7.0
     *
     * @see WP_Http::request() For information on default arguments.
     *
     * @param string $url  URL to retrieve.
     * @param array  $args Optional. Request arguments. Default empty array.
     *                     See WP_Http::request() for information on accepted arguments.
     * @return array|WP_Error The response array or a WP_Error on failure.
     *                        See WP_Http::request() for information on return value.
     * @phpstan-param array{
     *   method?: string,
     *   timeout?: float,
     *   redirection?: int,
     *   httpversion?: string,
     *   user-agent?: string,
     *   reject_unsafe_urls?: bool,
     *   blocking?: bool,
     *   headers?: string|array,
     *   cookies?: array,
     *   body?: string|array,
     *   compress?: bool,
     *   decompress?: bool,
     *   sslverify?: bool,
     *   sslcertificates?: string,
     *   stream?: bool,
     *   filename?: string,
     *   limit_response_size?: int,
     * } $args See WP_Http::request()
     * @phpstan-return array{headers: \WpOrg\Requests\Utility\CaseInsensitiveDictionary, body: string, response: array{code: int, message: string}, cookies: array<int, \WP_Http_Cookie>, filename: string|null, http_response: \WP_HTTP_Requests_Response}|\WP_Error
     */
    function wp_remote_request($url, $args = array())
    {
    }
    /**
     * Performs an HTTP request using the GET method and returns its response.
     *
     * @since 2.7.0
     *
     * @see wp_remote_request() For more information on the response array format.
     * @see WP_Http::request() For default arguments information.
     *
     * @param string $url  URL to retrieve.
     * @param array  $args Optional. Request arguments. Default empty array.
     *                     See WP_Http::request() for information on accepted arguments.
     * @return array|WP_Error The response or WP_Error on failure.
     *                        See WP_Http::request() for information on return value.
     * @phpstan-param array{
     *   method?: string,
     *   timeout?: float,
     *   redirection?: int,
     *   httpversion?: string,
     *   user-agent?: string,
     *   reject_unsafe_urls?: bool,
     *   blocking?: bool,
     *   headers?: string|array,
     *   cookies?: array,
     *   body?: string|array,
     *   compress?: bool,
     *   decompress?: bool,
     *   sslverify?: bool,
     *   sslcertificates?: string,
     *   stream?: bool,
     *   filename?: string,
     *   limit_response_size?: int,
     * } $args See WP_Http::request()
     * @phpstan-return array{headers: \WpOrg\Requests\Utility\CaseInsensitiveDictionary, body: string, response: array{code: int, message: string}, cookies: array<int, \WP_Http_Cookie>, filename: string|null, http_response: \WP_HTTP_Requests_Response}|\WP_Error
     */
    function wp_remote_get($url, $args = array())
    {
    }
    /**
     * Performs an HTTP request using the POST method and returns its response.
     *
     * @since 2.7.0
     *
     * @see wp_remote_request() For more information on the response array format.
     * @see WP_Http::request() For default arguments information.
     *
     * @param string $url  URL to retrieve.
     * @param array  $args Optional. Request arguments. Default empty array.
     *                     See WP_Http::request() for information on accepted arguments.
     * @return array|WP_Error The response or WP_Error on failure.
     *                        See WP_Http::request() for information on return value.
     * @phpstan-param array{
     *   method?: string,
     *   timeout?: float,
     *   redirection?: int,
     *   httpversion?: string,
     *   user-agent?: string,
     *   reject_unsafe_urls?: bool,
     *   blocking?: bool,
     *   headers?: string|array,
     *   cookies?: array,
     *   body?: string|array,
     *   compress?: bool,
     *   decompress?: bool,
     *   sslverify?: bool,
     *   sslcertificates?: string,
     *   stream?: bool,
     *   filename?: string,
     *   limit_response_size?: int,
     * } $args See WP_Http::request()
     * @phpstan-return array{headers: \WpOrg\Requests\Utility\CaseInsensitiveDictionary, body: string, response: array{code: int, message: string}, cookies: array<int, \WP_Http_Cookie>, filename: string|null, http_response: \WP_HTTP_Requests_Response}|\WP_Error
     */
    function wp_remote_post($url, $args = array())
    {
    }
    /**
     * Performs an HTTP request using the HEAD method and returns its response.
     *
     * @since 2.7.0
     *
     * @see wp_remote_request() For more information on the response array format.
     * @see WP_Http::request() For default arguments information.
     *
     * @param string $url  URL to retrieve.
     * @param array  $args Optional. Request arguments. Default empty array.
     *                     See WP_Http::request() for information on accepted arguments.
     * @return array|WP_Error The response or WP_Error on failure.
     *                        See WP_Http::request() for information on return value.
     * @phpstan-param array{
     *   method?: string,
     *   timeout?: float,
     *   redirection?: int,
     *   httpversion?: string,
     *   user-agent?: string,
     *   reject_unsafe_urls?: bool,
     *   blocking?: bool,
     *   headers?: string|array,
     *   cookies?: array,
     *   body?: string|array,
     *   compress?: bool,
     *   decompress?: bool,
     *   sslverify?: bool,
     *   sslcertificates?: string,
     *   stream?: bool,
     *   filename?: string,
     *   limit_response_size?: int,
     * } $args See WP_Http::request()
     * @phpstan-return array{headers: \WpOrg\Requests\Utility\CaseInsensitiveDictionary, body: string, response: array{code: int, message: string}, cookies: array<int, \WP_Http_Cookie>, filename: string|null, http_response: \WP_HTTP_Requests_Response}|\WP_Error
     */
    function wp_remote_head($url, $args = array())
    {
    }
    /**
     * Retrieves only the headers from the raw response.
     *
     * @since 2.7.0
     * @since 4.6.0 Return value changed from an array to an WpOrg\Requests\Utility\CaseInsensitiveDictionary instance.
     *
     * @see \WpOrg\Requests\Utility\CaseInsensitiveDictionary
     *
     * @param array|WP_Error $response HTTP response.
     * @return \WpOrg\Requests\Utility\CaseInsensitiveDictionary|array The headers of the response, or empty array
     *                                                                 if incorrect parameter given.
     */
    function wp_remote_retrieve_headers($response)
    {
    }
    /**
     * Retrieves a single header by name from the raw response.
     *
     * @since 2.7.0
     *
     * @param array|WP_Error $response HTTP response.
     * @param string         $header   Header name to retrieve value from.
     * @return array|string The header(s) value(s). Array if multiple headers with the same name are retrieved.
     *                      Empty string if incorrect parameter given, or if the header doesn't exist.
     */
    function wp_remote_retrieve_header($response, $header)
    {
    }
    /**
     * Retrieves only the response code from the raw response.
     *
     * Will return an empty string if incorrect parameter value is given.
     *
     * @since 2.7.0
     *
     * @param array|WP_Error $response HTTP response.
     * @return int|string The response code as an integer. Empty string if incorrect parameter given.
     */
    function wp_remote_retrieve_response_code($response)
    {
    }
    /**
     * Retrieves only the response message from the raw response.
     *
     * Will return an empty string if incorrect parameter value is given.
     *
     * @since 2.7.0
     *
     * @param array|WP_Error $response HTTP response.
     * @return string The response message. Empty string if incorrect parameter given.
     */
    function wp_remote_retrieve_response_message($response)
    {
    }
    /**
     * Retrieves only the body from the raw response.
     *
     * @since 2.7.0
     *
     * @param array|WP_Error $response HTTP response.
     * @return string The body of the response. Empty string if no body or incorrect parameter given.
     */
    function wp_remote_retrieve_body($response)
    {
    }
    /**
     * Retrieves only the cookies from the raw response.
     *
     * @since 4.4.0
     *
     * @param array|WP_Error $response HTTP response.
     * @return WP_Http_Cookie[] An array of `WP_Http_Cookie` objects from the response.
     *                          Empty array if there are none, or the response is a WP_Error.
     */
    function wp_remote_retrieve_cookies($response)
    {
    }
    /**
     * Retrieves a single cookie by name from the raw response.
     *
     * @since 4.4.0
     *
     * @param array|WP_Error $response HTTP response.
     * @param string         $name     The name of the cookie to retrieve.
     * @return WP_Http_Cookie|string The `WP_Http_Cookie` object, or empty string
     *                               if the cookie is not present in the response.
     */
    function wp_remote_retrieve_cookie($response, $name)
    {
    }
    /**
     * Retrieves a single cookie's value by name from the raw response.
     *
     * @since 4.4.0
     *
     * @param array|WP_Error $response HTTP response.
     * @param string         $name     The name of the cookie to retrieve.
     * @return string The value of the cookie, or empty string
     *                if the cookie is not present in the response.
     */
    function wp_remote_retrieve_cookie_value($response, $name)
    {
    }
    /**
     * Determines if there is an HTTP Transport that can process this request.
     *
     * @since 3.2.0
     *
     * @param array  $capabilities Array of capabilities to test or a wp_remote_request() $args array.
     * @param string $url          Optional. If given, will check if the URL requires SSL and adds
     *                             that requirement to the capabilities array.
     *
     * @return bool
     */
    function wp_http_supports($capabilities = array(), $url = \null)
    {
    }
    /**
     * Gets the HTTP Origin of the current request.
     *
     * @since 3.4.0
     *
     * @return string URL of the origin. Empty string if no origin.
     */
    function get_http_origin()
    {
    }
    /**
     * Retrieves list of allowed HTTP origins.
     *
     * @since 3.4.0
     *
     * @return string[] Array of origin URLs.
     */
    function get_allowed_http_origins()
    {
    }
    /**
     * Determines if the HTTP origin is an authorized one.
     *
     * @since 3.4.0
     *
     * @param string|null $origin Origin URL. If not provided, the value of get_http_origin() is used.
     * @return string Origin URL if allowed, empty string if not.
     */
    function is_allowed_http_origin($origin = \null)
    {
    }
    /**
     * Sends Access-Control-Allow-Origin and related headers if the current request
     * is from an allowed origin.
     *
     * If the request is an OPTIONS request, the script exits with either access
     * control headers sent, or a 403 response if the origin is not allowed. For
     * other request methods, you will receive a return value.
     *
     * @since 3.4.0
     *
     * @return string|false Returns the origin URL if headers are sent. Returns false
     *                      if headers are not sent.
     */
    function send_origin_headers()
    {
    }
    /**
     * Validates a URL for safe use in the HTTP API.
     *
     * Examples of URLs that are considered unsafe:
     *
     * - ftp://example.com/caniload.php - Invalid protocol - only http and https are allowed.
     * - http:///example.com/caniload.php - Malformed URL.
     * - http://user:pass@example.com/caniload.php - Login information.
     * - http://example.invalid/caniload.php - Invalid hostname, as the IP cannot be looked up in DNS.
     *
     * Examples of URLs that are considered unsafe by default:
     *
     * - http://192.168.0.1/caniload.php - IPs from LAN networks.
     *   This can be changed with the {@see 'http_request_host_is_external'} filter.
     * - http://198.143.164.252:81/caniload.php - By default, only 80, 443, and 8080 ports are allowed.
     *   This can be changed with the {@see 'http_allowed_safe_ports'} filter.
     *
     * @since 3.5.2
     *
     * @param string $url Request URL.
     * @return string|false URL or false on failure.
     */
    function wp_http_validate_url($url)
    {
    }
    /**
     * Marks allowed redirect hosts safe for HTTP requests as well.
     *
     * Attached to the {@see 'http_request_host_is_external'} filter.
     *
     * @since 3.6.0
     *
     * @param bool   $is_external
     * @param string $host
     * @return bool
     */
    function allowed_http_request_hosts($is_external, $host)
    {
    }
    /**
     * Adds any domain in a multisite installation for safe HTTP requests to the
     * allowed list.
     *
     * Attached to the {@see 'http_request_host_is_external'} filter.
     *
     * @since 3.6.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param bool   $is_external
     * @param string $host
     * @return bool
     */
    function ms_allowed_http_request_hosts($is_external, $host)
    {
    }
    /**
     * A wrapper for PHP's parse_url() function that handles consistency in the return values
     * across PHP versions.
     *
     * Across various PHP versions, schemeless URLs containing a ":" in the query
     * are being handled inconsistently. This function works around those differences.
     *
     * @since 4.4.0
     * @since 4.7.0 The `$component` parameter was added for parity with PHP's `parse_url()`.
     *
     * @link https://www.php.net/manual/en/function.parse-url.php
     *
     * @param string $url       The URL to parse.
     * @param int    $component The specific component to retrieve. Use one of the PHP
     *                          predefined constants to specify which one.
     *                          Defaults to -1 (= return all parts as an array).
     * @return mixed False on parse failure; Array of URL components on success;
     *               When a specific component has been requested: null if the component
     *               doesn't exist in the given URL; a string or - in the case of
     *               PHP_URL_PORT - integer when it does. See parse_url()'s return values.
     */
    function wp_parse_url($url, $component = -1)
    {
    }
    /**
     * Retrieves a specific component from a parsed URL array.
     *
     * @internal
     *
     * @since 4.7.0
     * @access private
     *
     * @link https://www.php.net/manual/en/function.parse-url.php
     *
     * @param array|false $url_parts The parsed URL. Can be false if the URL failed to parse.
     * @param int         $component The specific component to retrieve. Use one of the PHP
     *                               predefined constants to specify which one.
     *                               Defaults to -1 (= return all parts as an array).
     * @return mixed False on parse failure; Array of URL components on success;
     *               When a specific component has been requested: null if the component
     *               doesn't exist in the given URL; a string or - in the case of
     *               PHP_URL_PORT - integer when it does. See parse_url()'s return values.
     */
    function _get_component_from_parsed_url_array($url_parts, $component = -1)
    {
    }
    /**
     * Translates a PHP_URL_* constant to the named array keys PHP uses.
     *
     * @internal
     *
     * @since 4.7.0
     * @access private
     *
     * @link https://www.php.net/manual/en/url.constants.php
     *
     * @param int $constant PHP_URL_* constant.
     * @return string|false The named key or false.
     */
    function _wp_translate_php_url_constant_to_key($constant)
    {
    }
    /**
     * Checks whether the website is using HTTPS.
     *
     * This is based on whether both the home and site URL are using HTTPS.
     *
     * @since 5.7.0
     * @see wp_is_home_url_using_https()
     * @see wp_is_site_url_using_https()
     *
     * @return bool True if using HTTPS, false otherwise.
     */
    function wp_is_using_https()
    {
    }
    /**
     * Checks whether the current site URL is using HTTPS.
     *
     * @since 5.7.0
     * @see home_url()
     *
     * @return bool True if using HTTPS, false otherwise.
     */
    function wp_is_home_url_using_https()
    {
    }
    /**
     * Checks whether the current site's URL where WordPress is stored is using HTTPS.
     *
     * This checks the URL where WordPress application files (e.g. wp-blog-header.php or the wp-admin/ folder)
     * are accessible.
     *
     * @since 5.7.0
     * @see site_url()
     *
     * @return bool True if using HTTPS, false otherwise.
     */
    function wp_is_site_url_using_https()
    {
    }
    /**
     * Checks whether HTTPS is supported for the server and domain.
     *
     * @since 5.7.0
     *
     * @return bool True if HTTPS is supported, false otherwise.
     */
    function wp_is_https_supported()
    {
    }
    /**
     * Runs a remote HTTPS request to detect whether HTTPS supported, and stores potential errors.
     *
     * This internal function is called by a regular Cron hook to ensure HTTPS support is detected and maintained.
     *
     * @since 6.4.0
     * @access private
     */
    function wp_get_https_detection_errors()
    {
    }
    /**
     * Checks whether a given HTML string is likely an output from this WordPress site.
     *
     * This function attempts to check for various common WordPress patterns whether they are included in the HTML string.
     * Since any of these actions may be disabled through third-party code, this function may also return null to indicate
     * that it was not possible to determine ownership.
     *
     * @since 5.7.0
     * @access private
     *
     * @param string $html Full HTML output string, e.g. from a HTTP response.
     * @return bool|null True/false for whether HTML was generated by this site, null if unable to determine.
     */
    function wp_is_local_html_output($html)
    {
    }
    /**
     * Checks whether WordPress should replace old HTTP URLs to the site with their HTTPS counterpart.
     *
     * If a WordPress site had its URL changed from HTTP to HTTPS, by default this will return `true`, causing WordPress to
     * add frontend filters to replace insecure site URLs that may be present in older database content. The
     * {@see 'wp_should_replace_insecure_home_url'} filter can be used to modify that behavior.
     *
     * @since 5.7.0
     *
     * @return bool True if insecure URLs should replaced, false otherwise.
     */
    function wp_should_replace_insecure_home_url()
    {
    }
    /**
     * Replaces insecure HTTP URLs to the site in the given content, if configured to do so.
     *
     * This function replaces all occurrences of the HTTP version of the site's URL with its HTTPS counterpart, if
     * determined via {@see wp_should_replace_insecure_home_url()}.
     *
     * @since 5.7.0
     *
     * @param string $content Content to replace URLs in.
     * @return string Filtered content.
     */
    function wp_replace_insecure_home_url($content)
    {
    }
    /**
     * Update the 'home' and 'siteurl' option to use the HTTPS variant of their URL.
     *
     * If this update does not result in WordPress recognizing that the site is now using HTTPS (e.g. due to constants
     * overriding the URLs used), the changes will be reverted. In such a case the function will return false.
     *
     * @since 5.7.0
     *
     * @return bool True on success, false on failure.
     */
    function wp_update_urls_to_https()
    {
    }
    /**
     * Updates the 'https_migration_required' option if needed when the given URL has been updated from HTTP to HTTPS.
     *
     * If this is a fresh site, a migration will not be required, so the option will be set as `false`.
     *
     * This is hooked into the {@see 'update_option_home'} action.
     *
     * @since 5.7.0
     * @access private
     *
     * @param mixed $old_url Previous value of the URL option.
     * @param mixed $new_url New value of the URL option.
     * @phpstan-return void
     */
    function wp_update_https_migration_required($old_url, $new_url)
    {
    }
    /**
     * Retrieves the main WP_Interactivity_API instance.
     *
     * It provides access to the WP_Interactivity_API instance, creating one if it
     * doesn't exist yet.
     *
     * @since 6.5.0
     *
     * @global WP_Interactivity_API $wp_interactivity
     *
     * @return WP_Interactivity_API The main WP_Interactivity_API instance.
     */
    function wp_interactivity() : \WP_Interactivity_API
    {
    }
    /**
     * Processes the interactivity directives contained within the HTML content
     * and updates the markup accordingly.
     *
     * @since 6.5.0
     *
     * @param string $html The HTML content to process.
     * @return string The processed HTML content. It returns the original content when the HTML contains unbalanced tags.
     */
    function wp_interactivity_process_directives(string $html) : string
    {
    }
    /**
     * Gets and/or sets the initial state of an Interactivity API store for a
     * given namespace.
     *
     * If state for that store namespace already exists, it merges the new
     * provided state with the existing one.
     *
     * The namespace can be omitted inside derived state getters, using the
     * namespace where the getter is defined.
     *
     * @since 6.5.0
     * @since 6.6.0 The namespace can be omitted when called inside derived state getters.
     *
     * @param string $store_namespace The unique store namespace identifier.
     * @param array  $state           Optional. The array that will be merged with the existing state for the specified
     *                                store namespace.
     * @return array The state for the specified store namespace. This will be the updated state if a $state argument was
     *               provided.
     */
    function wp_interactivity_state(?string $store_namespace = \null, array $state = array()) : array
    {
    }
    /**
     * Gets and/or sets the configuration of the Interactivity API for a given
     * store namespace.
     *
     * If configuration for that store namespace exists, it merges the new
     * provided configuration with the existing one.
     *
     * @since 6.5.0
     *
     * @param string $store_namespace The unique store namespace identifier.
     * @param array  $config          Optional. The array that will be merged with the existing configuration for the
     *                                specified store namespace.
     * @return array The configuration for the specified store namespace. This will be the updated configuration if a
     *               $config argument was provided.
     */
    function wp_interactivity_config(string $store_namespace, array $config = array()) : array
    {
    }
    /**
     * Generates a `data-wp-context` directive attribute by encoding a context
     * array.
     *
     * This helper function simplifies the creation of `data-wp-context` directives
     * by providing a way to pass an array of data, which encodes into a JSON string
     * safe for direct use as a HTML attribute value.
     *
     * Example:
     *
     *     <div <?php echo wp_interactivity_data_wp_context( array( 'isOpen' => true, 'count' => 0 ) ); ?>>
     *
     * @since 6.5.0
     *
     * @param array  $context         The array of context data to encode.
     * @param string $store_namespace Optional. The unique store namespace identifier.
     * @return string A complete `data-wp-context` directive with a JSON encoded value representing the context array and
     *                the store namespace if specified.
     */
    function wp_interactivity_data_wp_context(array $context, string $store_namespace = '') : string
    {
    }
    /**
     * Gets the current Interactivity API context for a given namespace.
     *
     * The function should be used only during directive processing. If the
     * `$store_namespace` parameter is omitted, it uses the current namespace value
     * on the internal namespace stack.
     *
     * It returns an empty array when the specified namespace is not defined.
     *
     * @since 6.6.0
     *
     * @param string $store_namespace Optional. The unique store namespace identifier.
     * @return array The context for the specified store namespace.
     */
    function wp_interactivity_get_context(?string $store_namespace = \null) : array
    {
    }
    /**
     * Returns an array representation of the current element being processed.
     *
     * The function should be used only during directive processing.
     *
     * @since 6.7.0
     *
     * @return array{attributes: array<string, string|bool>}|null Current element.
     */
    function wp_interactivity_get_element() : ?array
    {
    }
    function get_file($path)
    {
    }
    /**
     * Filters text content and strips out disallowed HTML.
     *
     * This function makes sure that only the allowed HTML element names, attribute
     * names, attribute values, and HTML entities will occur in the given text string.
     *
     * This function expects unslashed data.
     *
     * @see wp_kses_post() for specifically filtering post content and fields.
     * @see wp_allowed_protocols() for the default allowed protocols in link URLs.
     *
     * @since 1.0.0
     *
     * @param string         $content           Text content to filter.
     * @param array[]|string $allowed_html      An array of allowed HTML elements and attributes,
     *                                          or a context name such as 'post'. See wp_kses_allowed_html()
     *                                          for the list of accepted context names.
     * @param string[]       $allowed_protocols Optional. Array of allowed URL protocols.
     *                                          Defaults to the result of wp_allowed_protocols().
     * @return string Filtered content containing only the allowed HTML.
     */
    function wp_kses($content, $allowed_html, $allowed_protocols = array())
    {
    }
    /**
     * Filters one HTML attribute and ensures its value is allowed.
     *
     * This function can escape data in some situations where `wp_kses()` must strip the whole attribute.
     *
     * @since 4.2.3
     *
     * @param string $attr    The 'whole' attribute, including name and value.
     * @param string $element The HTML element name to which the attribute belongs.
     * @return string Filtered attribute.
     */
    function wp_kses_one_attr($attr, $element)
    {
    }
    /**
     * Returns an array of allowed HTML tags and attributes for a given context.
     *
     * @since 3.5.0
     * @since 5.0.1 `form` removed as allowable HTML tag.
     *
     * @global array $allowedposttags
     * @global array $allowedtags
     * @global array $allowedentitynames
     *
     * @param string|array $context The context for which to retrieve tags. Allowed values are 'post',
     *                              'strip', 'data', 'entities', or the name of a field filter such as
     *                              'pre_user_description', or an array of allowed HTML elements and attributes.
     * @return array Array of allowed HTML tags and their allowed attributes.
     */
    function wp_kses_allowed_html($context = '')
    {
    }
    /**
     * You add any KSES hooks here.
     *
     * There is currently only one KSES WordPress hook, {@see 'pre_kses'}, and it is called here.
     * All parameters are passed to the hooks and expected to receive a string.
     *
     * @since 1.0.0
     *
     * @param string         $content           Content to filter through KSES.
     * @param array[]|string $allowed_html      An array of allowed HTML elements and attributes,
     *                                          or a context name such as 'post'. See wp_kses_allowed_html()
     *                                          for the list of accepted context names.
     * @param string[]       $allowed_protocols Array of allowed URL protocols.
     * @return string Filtered content through {@see 'pre_kses'} hook.
     */
    function wp_kses_hook($content, $allowed_html, $allowed_protocols)
    {
    }
    /**
     * Returns the version number of KSES.
     *
     * @since 1.0.0
     *
     * @return string KSES version number.
     */
    function wp_kses_version()
    {
    }
    /**
     * Searches for HTML tags, no matter how malformed.
     *
     * It also matches stray `>` characters.
     *
     * @since 1.0.0
     * @since 6.6.0 Recognize additional forms of invalid HTML which convert into comments.
     *
     * @global array[]|string $pass_allowed_html      An array of allowed HTML elements and attributes,
     *                                                or a context name such as 'post'.
     * @global string[]       $pass_allowed_protocols Array of allowed URL protocols.
     *
     * @param string         $content           Content to filter.
     * @param array[]|string $allowed_html      An array of allowed HTML elements and attributes,
     *                                          or a context name such as 'post'. See wp_kses_allowed_html()
     *                                          for the list of accepted context names.
     * @param string[]       $allowed_protocols Array of allowed URL protocols.
     * @return string Content with fixed HTML tags
     */
    function wp_kses_split($content, $allowed_html, $allowed_protocols)
    {
    }
    /**
     * Returns an array of HTML attribute names whose value contains a URL.
     *
     * This function returns a list of all HTML attributes that must contain
     * a URL according to the HTML specification.
     *
     * This list includes URI attributes both allowed and disallowed by KSES.
     *
     * @link https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes
     *
     * @since 5.0.1
     *
     * @return string[] HTML attribute names whose value contains a URL.
     */
    function wp_kses_uri_attributes()
    {
    }
    /**
     * Callback for `wp_kses_split()`.
     *
     * @since 3.1.0
     * @access private
     * @ignore
     *
     * @global array[]|string $pass_allowed_html      An array of allowed HTML elements and attributes,
     *                                                or a context name such as 'post'.
     * @global string[]       $pass_allowed_protocols Array of allowed URL protocols.
     *
     * @param array $matches preg_replace regexp matches
     * @return string
     */
    function _wp_kses_split_callback($matches)
    {
    }
    /**
     * Callback for `wp_kses_split()` for fixing malformed HTML tags.
     *
     * This function does a lot of work. It rejects some very malformed things like
     * `<:::>`. It returns an empty string, if the element isn't allowed (look ma, no
     * `strip_tags()`!). Otherwise it splits the tag into an element and an attribute
     * list.
     *
     * After the tag is split into an element and an attribute list, it is run
     * through another filter which will remove illegal attributes and once that is
     * completed, will be returned.
     *
     * @access private
     * @ignore
     * @since 1.0.0
     * @since 6.6.0 Recognize additional forms of invalid HTML which convert into comments.
     *
     * @param string         $content           Content to filter.
     * @param array[]|string $allowed_html      An array of allowed HTML elements and attributes,
     *                                          or a context name such as 'post'. See wp_kses_allowed_html()
     *                                          for the list of accepted context names.
     * @param string[]       $allowed_protocols Array of allowed URL protocols.
     *
     * @return string Fixed HTML element
     */
    function wp_kses_split2($content, $allowed_html, $allowed_protocols)
    {
    }
    /**
     * Removes all attributes, if none are allowed for this element.
     *
     * If some are allowed it calls `wp_kses_hair()` to split them further, and then
     * it builds up new HTML code from the data that `wp_kses_hair()` returns. It also
     * removes `<` and `>` characters, if there are any left. One more thing it does
     * is to check if the tag has a closing XHTML slash, and if it does, it puts one
     * in the returned code as well.
     *
     * An array of allowed values can be defined for attributes. If the attribute value
     * doesn't fall into the list, the attribute will be removed from the tag.
     *
     * Attributes can be marked as required. If a required attribute is not present,
     * KSES will remove all attributes from the tag. As KSES doesn't match opening and
     * closing tags, it's not possible to safely remove the tag itself, the safest
     * fallback is to strip all attributes from the tag, instead.
     *
     * @since 1.0.0
     * @since 5.9.0 Added support for an array of allowed values for attributes.
     *              Added support for required attributes.
     *
     * @param string         $element           HTML element/tag.
     * @param string         $attr              HTML attributes from HTML element to closing HTML element tag.
     * @param array[]|string $allowed_html      An array of allowed HTML elements and attributes,
     *                                          or a context name such as 'post'. See wp_kses_allowed_html()
     *                                          for the list of accepted context names.
     * @param string[]       $allowed_protocols Array of allowed URL protocols.
     * @return string Sanitized HTML element.
     */
    function wp_kses_attr($element, $attr, $allowed_html, $allowed_protocols)
    {
    }
    /**
     * Determines whether an attribute is allowed.
     *
     * @since 4.2.3
     * @since 5.0.0 Added support for `data-*` wildcard attributes.
     *
     * @param string $name         The attribute name. Passed by reference. Returns empty string when not allowed.
     * @param string $value        The attribute value. Passed by reference. Returns a filtered value.
     * @param string $whole        The `name=value` input. Passed by reference. Returns filtered input.
     * @param string $vless        Whether the attribute is valueless. Use 'y' or 'n'.
     * @param string $element      The name of the element to which this attribute belongs.
     * @param array  $allowed_html The full list of allowed elements and attributes.
     * @return bool Whether or not the attribute is allowed.
     */
    function wp_kses_attr_check(&$name, &$value, &$whole, $vless, $element, $allowed_html)
    {
    }
    /**
     * Builds an attribute list from string containing attributes.
     *
     * This function does a lot of work. It parses an attribute list into an array
     * with attribute data, and tries to do the right thing even if it gets weird
     * input. It will add quotes around attribute values that don't have any quotes
     * or apostrophes around them, to make it easier to produce HTML code that will
     * conform to W3C's HTML specification. It will also remove bad URL protocols
     * from attribute values. It also reduces duplicate attributes by using the
     * attribute defined first (`foo='bar' foo='baz'` will result in `foo='bar'`).
     *
     * @since 1.0.0
     *
     * @param string   $attr              Attribute list from HTML element to closing HTML element tag.
     * @param string[] $allowed_protocols Array of allowed URL protocols.
     * @return array[] Array of attribute information after parsing.
     */
    function wp_kses_hair($attr, $allowed_protocols)
    {
    }
    /**
     * Finds all attributes of an HTML element.
     *
     * Does not modify input.  May return "evil" output.
     *
     * Based on `wp_kses_split2()` and `wp_kses_attr()`.
     *
     * @since 4.2.3
     *
     * @param string $element HTML element.
     * @return array|false List of attributes found in the element. Returns false on failure.
     */
    function wp_kses_attr_parse($element)
    {
    }
    /**
     * Builds an attribute list from string containing attributes.
     *
     * Does not modify input.  May return "evil" output.
     * In case of unexpected input, returns false instead of stripping things.
     *
     * Based on `wp_kses_hair()` but does not return a multi-dimensional array.
     *
     * @since 4.2.3
     *
     * @param string $attr Attribute list from HTML element to closing HTML element tag.
     * @return array|false List of attributes found in $attr. Returns false on failure.
     */
    function wp_kses_hair_parse($attr)
    {
    }
    /**
     * Performs different checks for attribute values.
     *
     * The currently implemented checks are "maxlen", "minlen", "maxval", "minval",
     * and "valueless".
     *
     * @since 1.0.0
     *
     * @param string $value      Attribute value.
     * @param string $vless      Whether the attribute is valueless. Use 'y' or 'n'.
     * @param string $checkname  What $checkvalue is checking for.
     * @param mixed  $checkvalue What constraint the value should pass.
     * @return bool Whether check passes.
     */
    function wp_kses_check_attr_val($value, $vless, $checkname, $checkvalue)
    {
    }
    /**
     * Sanitizes a string and removed disallowed URL protocols.
     *
     * This function removes all non-allowed protocols from the beginning of the
     * string. It ignores whitespace and the case of the letters, and it does
     * understand HTML entities. It does its work recursively, so it won't be
     * fooled by a string like `javascript:javascript:alert(57)`.
     *
     * @since 1.0.0
     *
     * @param string   $content           Content to filter bad protocols from.
     * @param string[] $allowed_protocols Array of allowed URL protocols.
     * @return string Filtered content.
     */
    function wp_kses_bad_protocol($content, $allowed_protocols)
    {
    }
    /**
     * Removes any invalid control characters in a text string.
     *
     * Also removes any instance of the `\0` string.
     *
     * @since 1.0.0
     *
     * @param string $content Content to filter null characters from.
     * @param array  $options Set 'slash_zero' => 'keep' when '\0' is allowed. Default is 'remove'.
     * @return string Filtered content.
     */
    function wp_kses_no_null($content, $options = \null)
    {
    }
    /**
     * Strips slashes from in front of quotes.
     *
     * This function changes the character sequence `\"` to just `"`. It leaves all other
     * slashes alone. The quoting from `preg_replace(//e)` requires this.
     *
     * @since 1.0.0
     *
     * @param string $content String to strip slashes from.
     * @return string Fixed string with quoted slashes.
     */
    function wp_kses_stripslashes($content)
    {
    }
    /**
     * Converts the keys of an array to lowercase.
     *
     * @since 1.0.0
     *
     * @param array $inarray Unfiltered array.
     * @return array Fixed array with all lowercase keys.
     */
    function wp_kses_array_lc($inarray)
    {
    }
    /**
     * Handles parsing errors in `wp_kses_hair()`.
     *
     * The general plan is to remove everything to and including some whitespace,
     * but it deals with quotes and apostrophes as well.
     *
     * @since 1.0.0
     *
     * @param string $attr
     * @return string
     */
    function wp_kses_html_error($attr)
    {
    }
    /**
     * Sanitizes content from bad protocols and other characters.
     *
     * This function searches for URL protocols at the beginning of the string, while
     * handling whitespace and HTML entities.
     *
     * @since 1.0.0
     *
     * @param string   $content           Content to check for bad protocols.
     * @param string[] $allowed_protocols Array of allowed URL protocols.
     * @param int      $count             Depth of call recursion to this function.
     * @return string Sanitized content.
     */
    function wp_kses_bad_protocol_once($content, $allowed_protocols, $count = 1)
    {
    }
    /**
     * Callback for `wp_kses_bad_protocol_once()` regular expression.
     *
     * This function processes URL protocols, checks to see if they're in the
     * list of allowed protocols or not, and returns different data depending
     * on the answer.
     *
     * @access private
     * @ignore
     * @since 1.0.0
     *
     * @param string   $scheme            URI scheme to check against the list of allowed protocols.
     * @param string[] $allowed_protocols Array of allowed URL protocols.
     * @return string Sanitized content.
     */
    function wp_kses_bad_protocol_once2($scheme, $allowed_protocols)
    {
    }
    /**
     * Converts and fixes HTML entities.
     *
     * This function normalizes HTML entities. It will convert `AT&T` to the correct
     * `AT&amp;T`, `&#00058;` to `&#058;`, `&#XYZZY;` to `&amp;#XYZZY;` and so on.
     *
     * When `$context` is set to 'xml', HTML entities are converted to their code points.  For
     * example, `AT&T&hellip;&#XYZZY;` is converted to `AT&amp;T…&amp;#XYZZY;`.
     *
     * @since 1.0.0
     * @since 5.5.0 Added `$context` parameter.
     *
     * @param string $content Content to normalize entities.
     * @param string $context Context for normalization. Can be either 'html' or 'xml'.
     *                        Default 'html'.
     * @return string Content with normalized entities.
     * @phpstan-param 'html'|'xml' $context
     */
    function wp_kses_normalize_entities($content, $context = 'html')
    {
    }
    /**
     * Callback for `wp_kses_normalize_entities()` regular expression.
     *
     * This function only accepts valid named entity references, which are finite,
     * case-sensitive, and highly scrutinized by HTML and XML validators.
     *
     * @since 3.0.0
     *
     * @global array $allowedentitynames
     *
     * @param array $matches preg_replace_callback() matches array.
     * @return string Correctly encoded entity.
     */
    function wp_kses_named_entities($matches)
    {
    }
    /**
     * Callback for `wp_kses_normalize_entities()` regular expression.
     *
     * This function only accepts valid named entity references, which are finite,
     * case-sensitive, and highly scrutinized by XML validators.  HTML named entity
     * references are converted to their code points.
     *
     * @since 5.5.0
     *
     * @global array $allowedentitynames
     * @global array $allowedxmlentitynames
     *
     * @param array $matches preg_replace_callback() matches array.
     * @return string Correctly encoded entity.
     */
    function wp_kses_xml_named_entities($matches)
    {
    }
    /**
     * Callback for `wp_kses_normalize_entities()` regular expression.
     *
     * This function helps `wp_kses_normalize_entities()` to only accept 16-bit
     * values and nothing more for `&#number;` entities.
     *
     * @access private
     * @ignore
     * @since 1.0.0
     *
     * @param array $matches `preg_replace_callback()` matches array.
     * @return string Correctly encoded entity.
     */
    function wp_kses_normalize_entities2($matches)
    {
    }
    /**
     * Callback for `wp_kses_normalize_entities()` for regular expression.
     *
     * This function helps `wp_kses_normalize_entities()` to only accept valid Unicode
     * numeric entities in hex form.
     *
     * @since 2.7.0
     * @access private
     * @ignore
     *
     * @param array $matches `preg_replace_callback()` matches array.
     * @return string Correctly encoded entity.
     */
    function wp_kses_normalize_entities3($matches)
    {
    }
    /**
     * Determines if a Unicode codepoint is valid.
     *
     * @since 2.7.0
     *
     * @param int $i Unicode codepoint.
     * @return bool Whether or not the codepoint is a valid Unicode codepoint.
     */
    function valid_unicode($i)
    {
    }
    /**
     * Converts all numeric HTML entities to their named counterparts.
     *
     * This function decodes numeric HTML entities (`&#65;` and `&#x41;`).
     * It doesn't do anything with named entities like `&auml;`, but we don't
     * need them in the allowed URL protocols system anyway.
     *
     * @since 1.0.0
     *
     * @param string $content Content to change entities.
     * @return string Content after decoded entities.
     */
    function wp_kses_decode_entities($content)
    {
    }
    /**
     * Regex callback for `wp_kses_decode_entities()`.
     *
     * @since 2.9.0
     * @access private
     * @ignore
     *
     * @param array $matches preg match
     * @return string
     */
    function _wp_kses_decode_entities_chr($matches)
    {
    }
    /**
     * Regex callback for `wp_kses_decode_entities()`.
     *
     * @since 2.9.0
     * @access private
     * @ignore
     *
     * @param array $matches preg match
     * @return string
     */
    function _wp_kses_decode_entities_chr_hexdec($matches)
    {
    }
    /**
     * Sanitize content with allowed HTML KSES rules.
     *
     * This function expects slashed data.
     *
     * @since 1.0.0
     *
     * @param string $data Content to filter, expected to be escaped with slashes.
     * @return string Filtered content.
     */
    function wp_filter_kses($data)
    {
    }
    /**
     * Sanitize content with allowed HTML KSES rules.
     *
     * This function expects unslashed data.
     *
     * @since 2.9.0
     *
     * @param string $data Content to filter, expected to not be escaped.
     * @return string Filtered content.
     */
    function wp_kses_data($data)
    {
    }
    /**
     * Sanitizes content for allowed HTML tags for post content.
     *
     * Post content refers to the page contents of the 'post' type and not `$_POST`
     * data from forms.
     *
     * This function expects slashed data.
     *
     * @since 2.0.0
     *
     * @param string $data Post content to filter, expected to be escaped with slashes.
     * @return string Filtered post content with allowed HTML tags and attributes intact.
     */
    function wp_filter_post_kses($data)
    {
    }
    /**
     * Sanitizes global styles user content removing unsafe rules.
     *
     * @since 5.9.0
     *
     * @param string $data Post content to filter.
     * @return string Filtered post content with unsafe rules removed.
     */
    function wp_filter_global_styles_post($data)
    {
    }
    /**
     * Sanitizes content for allowed HTML tags for post content.
     *
     * Post content refers to the page contents of the 'post' type and not `$_POST`
     * data from forms.
     *
     * This function expects unslashed data.
     *
     * @since 2.9.0
     *
     * @param string $data Post content to filter.
     * @return string Filtered post content with allowed HTML tags and attributes intact.
     */
    function wp_kses_post($data)
    {
    }
    /**
     * Navigates through an array, object, or scalar, and sanitizes content for
     * allowed HTML tags for post content.
     *
     * @since 4.4.2
     *
     * @see map_deep()
     *
     * @param mixed $data The array, object, or scalar value to inspect.
     * @return mixed The filtered content.
     */
    function wp_kses_post_deep($data)
    {
    }
    /**
     * Strips all HTML from a text string.
     *
     * This function expects slashed data.
     *
     * @since 2.1.0
     *
     * @param string $data Content to strip all HTML from.
     * @return string Filtered content without any HTML.
     */
    function wp_filter_nohtml_kses($data)
    {
    }
    /**
     * Adds all KSES input form content filters.
     *
     * All hooks have default priority. The `wp_filter_kses()` function is added to
     * the 'pre_comment_content' and 'title_save_pre' hooks.
     *
     * The `wp_filter_post_kses()` function is added to the 'content_save_pre',
     * 'excerpt_save_pre', and 'content_filtered_save_pre' hooks.
     *
     * @since 2.0.0
     */
    function kses_init_filters()
    {
    }
    /**
     * Removes all KSES input form content filters.
     *
     * A quick procedural method to removing all of the filters that KSES uses for
     * content in WordPress Loop.
     *
     * Does not remove the `kses_init()` function from {@see 'init'} hook (priority is
     * default). Also does not remove `kses_init()` function from {@see 'set_current_user'}
     * hook (priority is also default).
     *
     * @since 2.0.6
     */
    function kses_remove_filters()
    {
    }
    /**
     * Sets up most of the KSES filters for input form content.
     *
     * First removes all of the KSES filters in case the current user does not need
     * to have KSES filter the content. If the user does not have `unfiltered_html`
     * capability, then KSES filters are added.
     *
     * @since 2.0.0
     */
    function kses_init()
    {
    }
    /**
     * Filters an inline style attribute and removes disallowed rules.
     *
     * @since 2.8.1
     * @since 4.4.0 Added support for `min-height`, `max-height`, `min-width`, and `max-width`.
     * @since 4.6.0 Added support for `list-style-type`.
     * @since 5.0.0 Added support for `background-image`.
     * @since 5.1.0 Added support for `text-transform`.
     * @since 5.2.0 Added support for `background-position` and `grid-template-columns`.
     * @since 5.3.0 Added support for `grid`, `flex` and `column` layout properties.
     *              Extended `background-*` support for individual properties.
     * @since 5.3.1 Added support for gradient backgrounds.
     * @since 5.7.1 Added support for `object-position`.
     * @since 5.8.0 Added support for `calc()` and `var()` values.
     * @since 6.1.0 Added support for `min()`, `max()`, `minmax()`, `clamp()`,
     *              nested `var()` values, and assigning values to CSS variables.
     *              Added support for `object-fit`, `gap`, `column-gap`, `row-gap`, and `flex-wrap`.
     *              Extended `margin-*` and `padding-*` support for logical properties.
     * @since 6.2.0 Added support for `aspect-ratio`, `position`, `top`, `right`, `bottom`, `left`,
     *              and `z-index` CSS properties.
     * @since 6.3.0 Extended support for `filter` to accept a URL and added support for repeat().
     *              Added support for `box-shadow`.
     * @since 6.4.0 Added support for `writing-mode`.
     * @since 6.5.0 Added support for `background-repeat`.
     * @since 6.6.0 Added support for `grid-column`, `grid-row`, and `container-type`.
     *
     * @param string $css        A string of CSS rules.
     * @param string $deprecated Not used.
     * @return string Filtered string of CSS rules.
     */
    function safecss_filter_attr($css, $deprecated = '')
    {
    }
    /**
     * Helper function to add global attributes to a tag in the allowed HTML list.
     *
     * @since 3.5.0
     * @since 5.0.0 Added support for `data-*` wildcard attributes.
     * @since 6.0.0 Added `dir`, `lang`, and `xml:lang` to global attributes.
     * @since 6.3.0 Added `aria-controls`, `aria-current`, and `aria-expanded` attributes.
     * @since 6.4.0 Added `aria-live` and `hidden` attributes.
     *
     * @access private
     * @ignore
     *
     * @param array $value An array of attributes.
     * @return array The array of attributes with global attributes added.
     */
    function _wp_add_global_attributes($value)
    {
    }
    /**
     * Helper function to check if this is a safe PDF URL.
     *
     * @since 5.9.0
     * @access private
     * @ignore
     *
     * @param string $url The URL to check.
     * @return bool True if the URL is safe, false otherwise.
     */
    function _wp_kses_allow_pdf_objects($url)
    {
    }
    /**
     * Retrieves the current locale.
     *
     * If the locale is set, then it will filter the locale in the {@see 'locale'}
     * filter hook and return the value.
     *
     * If the locale is not set already, then the WPLANG constant is used if it is
     * defined. Then it is filtered through the {@see 'locale'} filter hook and
     * the value for the locale global set and the locale is returned.
     *
     * The process to get the locale should only be done once, but the locale will
     * always be filtered using the {@see 'locale'} hook.
     *
     * @since 1.5.0
     *
     * @global string $locale           The current locale.
     * @global string $wp_local_package Locale code of the package.
     *
     * @return string The locale of the blog or from the {@see 'locale'} hook.
     */
    function get_locale()
    {
    }
    /**
     * Retrieves the locale of a user.
     *
     * If the user has a locale set to a non-empty string then it will be
     * returned. Otherwise it returns the locale of get_locale().
     *
     * @since 4.7.0
     *
     * @param int|WP_User $user User's ID or a WP_User object. Defaults to current user.
     * @return string The locale of the user.
     */
    function get_user_locale($user = 0)
    {
    }
    /**
     * Determines the current locale desired for the request.
     *
     * @since 5.0.0
     *
     * @global string $pagenow The filename of the current screen.
     *
     * @return string The determined locale.
     */
    function determine_locale()
    {
    }
    /**
     * Retrieves the translation of $text.
     *
     * If there is no translation, or the text domain isn't loaded, the original text is returned.
     *
     * *Note:* Don't use translate() directly, use __() or related functions.
     *
     * @since 2.2.0
     * @since 5.5.0 Introduced `gettext-{$domain}` filter.
     *
     * @param string $text   Text to translate.
     * @param string $domain Optional. Text domain. Unique identifier for retrieving translated strings.
     *                       Default 'default'.
     * @return string Translated text.
     */
    function translate($text, $domain = 'default')
    {
    }
    /**
     * Removes last item on a pipe-delimited string.
     *
     * Meant for removing the last item in a string, such as 'Role name|User role'. The original
     * string will be returned if no pipe '|' characters are found in the string.
     *
     * @since 2.8.0
     *
     * @param string $text A pipe-delimited string.
     * @return string Either $text or everything before the last pipe.
     */
    function before_last_bar($text)
    {
    }
    /**
     * Retrieves the translation of $text in the context defined in $context.
     *
     * If there is no translation, or the text domain isn't loaded, the original text is returned.
     *
     * *Note:* Don't use translate_with_gettext_context() directly, use _x() or related functions.
     *
     * @since 2.8.0
     * @since 5.5.0 Introduced `gettext_with_context-{$domain}` filter.
     *
     * @param string $text    Text to translate.
     * @param string $context Context information for the translators.
     * @param string $domain  Optional. Text domain. Unique identifier for retrieving translated strings.
     *                        Default 'default'.
     * @return string Translated text on success, original text on failure.
     */
    function translate_with_gettext_context($text, $context, $domain = 'default')
    {
    }
    /**
     * Retrieves the translation of $text.
     *
     * If there is no translation, or the text domain isn't loaded, the original text is returned.
     *
     * @since 2.1.0
     *
     * @param string $text   Text to translate.
     * @param string $domain Optional. Text domain. Unique identifier for retrieving translated strings.
     *                       Default 'default'.
     * @return string Translated text.
     */
    function __($text, $domain = 'default')
    {
    }
    /**
     * Retrieves the translation of $text and escapes it for safe use in an attribute.
     *
     * If there is no translation, or the text domain isn't loaded, the original text is returned.
     *
     * @since 2.8.0
     *
     * @param string $text   Text to translate.
     * @param string $domain Optional. Text domain. Unique identifier for retrieving translated strings.
     *                       Default 'default'.
     * @return string Translated text on success, original text on failure.
     */
    function esc_attr__($text, $domain = 'default')
    {
    }
    /**
     * Retrieves the translation of $text and escapes it for safe use in HTML output.
     *
     * If there is no translation, or the text domain isn't loaded, the original text
     * is escaped and returned.
     *
     * @since 2.8.0
     *
     * @param string $text   Text to translate.
     * @param string $domain Optional. Text domain. Unique identifier for retrieving translated strings.
     *                       Default 'default'.
     * @return string Translated text.
     */
    function esc_html__($text, $domain = 'default')
    {
    }
    /**
     * Displays translated text.
     *
     * @since 1.2.0
     *
     * @param string $text   Text to translate.
     * @param string $domain Optional. Text domain. Unique identifier for retrieving translated strings.
     *                       Default 'default'.
     */
    function _e($text, $domain = 'default')
    {
    }
    /**
     * Displays translated text that has been escaped for safe use in an attribute.
     *
     * Encodes `< > & " '` (less than, greater than, ampersand, double quote, single quote).
     * Will never double encode entities.
     *
     * If you need the value for use in PHP, use esc_attr__().
     *
     * @since 2.8.0
     *
     * @param string $text   Text to translate.
     * @param string $domain Optional. Text domain. Unique identifier for retrieving translated strings.
     *                       Default 'default'.
     */
    function esc_attr_e($text, $domain = 'default')
    {
    }
    /**
     * Displays translated text that has been escaped for safe use in HTML output.
     *
     * If there is no translation, or the text domain isn't loaded, the original text
     * is escaped and displayed.
     *
     * If you need the value for use in PHP, use esc_html__().
     *
     * @since 2.8.0
     *
     * @param string $text   Text to translate.
     * @param string $domain Optional. Text domain. Unique identifier for retrieving translated strings.
     *                       Default 'default'.
     */
    function esc_html_e($text, $domain = 'default')
    {
    }
    /**
     * Retrieves translated string with gettext context.
     *
     * Quite a few times, there will be collisions with similar translatable text
     * found in more than two places, but with different translated context.
     *
     * By including the context in the pot file, translators can translate the two
     * strings differently.
     *
     * @since 2.8.0
     *
     * @param string $text    Text to translate.
     * @param string $context Context information for the translators.
     * @param string $domain  Optional. Text domain. Unique identifier for retrieving translated strings.
     *                        Default 'default'.
     * @return string Translated context string without pipe.
     */
    function _x($text, $context, $domain = 'default')
    {
    }
    /**
     * Displays translated string with gettext context.
     *
     * @since 3.0.0
     *
     * @param string $text    Text to translate.
     * @param string $context Context information for the translators.
     * @param string $domain  Optional. Text domain. Unique identifier for retrieving translated strings.
     *                        Default 'default'.
     */
    function _ex($text, $context, $domain = 'default')
    {
    }
    /**
     * Translates string with gettext context, and escapes it for safe use in an attribute.
     *
     * If there is no translation, or the text domain isn't loaded, the original text
     * is escaped and returned.
     *
     * @since 2.8.0
     *
     * @param string $text    Text to translate.
     * @param string $context Context information for the translators.
     * @param string $domain  Optional. Text domain. Unique identifier for retrieving translated strings.
     *                        Default 'default'.
     * @return string Translated text.
     */
    function esc_attr_x($text, $context, $domain = 'default')
    {
    }
    /**
     * Translates string with gettext context, and escapes it for safe use in HTML output.
     *
     * If there is no translation, or the text domain isn't loaded, the original text
     * is escaped and returned.
     *
     * @since 2.9.0
     *
     * @param string $text    Text to translate.
     * @param string $context Context information for the translators.
     * @param string $domain  Optional. Text domain. Unique identifier for retrieving translated strings.
     *                        Default 'default'.
     * @return string Translated text.
     */
    function esc_html_x($text, $context, $domain = 'default')
    {
    }
    /**
     * Translates and retrieves the singular or plural form based on the supplied number.
     *
     * Used when you want to use the appropriate form of a string based on whether a
     * number is singular or plural.
     *
     * Example:
     *
     *     printf( _n( '%s person', '%s people', $count, 'text-domain' ), number_format_i18n( $count ) );
     *
     * @since 2.8.0
     * @since 5.5.0 Introduced `ngettext-{$domain}` filter.
     *
     * @param string $single The text to be used if the number is singular.
     * @param string $plural The text to be used if the number is plural.
     * @param int    $number The number to compare against to use either the singular or plural form.
     * @param string $domain Optional. Text domain. Unique identifier for retrieving translated strings.
     *                       Default 'default'.
     * @return string The translated singular or plural form.
     */
    function _n($single, $plural, $number, $domain = 'default')
    {
    }
    /**
     * Translates and retrieves the singular or plural form based on the supplied number, with gettext context.
     *
     * This is a hybrid of _n() and _x(). It supports context and plurals.
     *
     * Used when you want to use the appropriate form of a string with context based on whether a
     * number is singular or plural.
     *
     * Example of a generic phrase which is disambiguated via the context parameter:
     *
     *     printf( _nx( '%s group', '%s groups', $people, 'group of people', 'text-domain' ), number_format_i18n( $people ) );
     *     printf( _nx( '%s group', '%s groups', $animals, 'group of animals', 'text-domain' ), number_format_i18n( $animals ) );
     *
     * @since 2.8.0
     * @since 5.5.0 Introduced `ngettext_with_context-{$domain}` filter.
     *
     * @param string $single  The text to be used if the number is singular.
     * @param string $plural  The text to be used if the number is plural.
     * @param int    $number  The number to compare against to use either the singular or plural form.
     * @param string $context Context information for the translators.
     * @param string $domain  Optional. Text domain. Unique identifier for retrieving translated strings.
     *                        Default 'default'.
     * @return string The translated singular or plural form.
     */
    function _nx($single, $plural, $number, $context, $domain = 'default')
    {
    }
    /**
     * Registers plural strings in POT file, but does not translate them.
     *
     * Used when you want to keep structures with translatable plural
     * strings and use them later when the number is known.
     *
     * Example:
     *
     *     $message = _n_noop( '%s post', '%s posts', 'text-domain' );
     *     ...
     *     printf( translate_nooped_plural( $message, $count, 'text-domain' ), number_format_i18n( $count ) );
     *
     * @since 2.5.0
     *
     * @param string $singular Singular form to be localized.
     * @param string $plural   Plural form to be localized.
     * @param string $domain   Optional. Text domain. Unique identifier for retrieving translated strings.
     *                         Default null.
     * @return array {
     *     Array of translation information for the strings.
     *
     *     @type string      $0        Singular form to be localized. No longer used.
     *     @type string      $1        Plural form to be localized. No longer used.
     *     @type string      $singular Singular form to be localized.
     *     @type string      $plural   Plural form to be localized.
     *     @type null        $context  Context information for the translators.
     *     @type string|null $domain   Text domain.
     * }
     * @phpstan-return array{
     *   0: string,
     *   1: string,
     *   singular: string,
     *   plural: string,
     *   context: null,
     *   domain: string|null,
     * }
     */
    function _n_noop($singular, $plural, $domain = \null)
    {
    }
    /**
     * Registers plural strings with gettext context in POT file, but does not translate them.
     *
     * Used when you want to keep structures with translatable plural
     * strings and use them later when the number is known.
     *
     * Example of a generic phrase which is disambiguated via the context parameter:
     *
     *     $messages = array(
     *          'people'  => _nx_noop( '%s group', '%s groups', 'people', 'text-domain' ),
     *          'animals' => _nx_noop( '%s group', '%s groups', 'animals', 'text-domain' ),
     *     );
     *     ...
     *     $message = $messages[ $type ];
     *     printf( translate_nooped_plural( $message, $count, 'text-domain' ), number_format_i18n( $count ) );
     *
     * @since 2.8.0
     *
     * @param string $singular Singular form to be localized.
     * @param string $plural   Plural form to be localized.
     * @param string $context  Context information for the translators.
     * @param string $domain   Optional. Text domain. Unique identifier for retrieving translated strings.
     *                         Default null.
     * @return array {
     *     Array of translation information for the strings.
     *
     *     @type string      $0        Singular form to be localized. No longer used.
     *     @type string      $1        Plural form to be localized. No longer used.
     *     @type string      $2        Context information for the translators. No longer used.
     *     @type string      $singular Singular form to be localized.
     *     @type string      $plural   Plural form to be localized.
     *     @type string      $context  Context information for the translators.
     *     @type string|null $domain   Text domain.
     * }
     * @phpstan-return array{
     *   0: string,
     *   1: string,
     *   2: string,
     *   singular: string,
     *   plural: string,
     *   context: string,
     *   domain: string|null,
     * }
     */
    function _nx_noop($singular, $plural, $context, $domain = \null)
    {
    }
    /**
     * Translates and returns the singular or plural form of a string that's been registered
     * with _n_noop() or _nx_noop().
     *
     * Used when you want to use a translatable plural string once the number is known.
     *
     * Example:
     *
     *     $message = _n_noop( '%s post', '%s posts', 'text-domain' );
     *     ...
     *     printf( translate_nooped_plural( $message, $count, 'text-domain' ), number_format_i18n( $count ) );
     *
     * @since 3.1.0
     *
     * @param array  $nooped_plural {
     *     Array that is usually a return value from _n_noop() or _nx_noop().
     *
     *     @type string      $singular Singular form to be localized.
     *     @type string      $plural   Plural form to be localized.
     *     @type string|null $context  Context information for the translators.
     *     @type string|null $domain   Text domain.
     * }
     * @param int    $count         Number of objects.
     * @param string $domain        Optional. Text domain. Unique identifier for retrieving translated strings. If $nooped_plural contains
     *                              a text domain passed to _n_noop() or _nx_noop(), it will override this value. Default 'default'.
     * @return string Either $singular or $plural translated text.
     * @phpstan-param array{
     *   singular?: string,
     *   plural?: string,
     *   context?: string|null,
     *   domain?: string|null,
     * } $nooped_plural
     */
    function translate_nooped_plural($nooped_plural, $count, $domain = 'default')
    {
    }
    /**
     * Loads a .mo file into the text domain $domain.
     *
     * If the text domain already exists, the translations will be merged. If both
     * sets have the same string, the translation from the original value will be taken.
     *
     * On success, the .mo file will be placed in the $l10n global by $domain
     * and will be a MO object.
     *
     * @since 1.5.0
     * @since 6.1.0 Added the `$locale` parameter.
     *
     * @global MO[]                   $l10n                   An array of all currently loaded text domains.
     * @global MO[]                   $l10n_unloaded          An array of all text domains that have been unloaded again.
     * @global WP_Textdomain_Registry $wp_textdomain_registry WordPress Textdomain Registry.
     *
     * @param string $domain Text domain. Unique identifier for retrieving translated strings.
     * @param string $mofile Path to the .mo file.
     * @param string $locale Optional. Locale. Default is the current locale.
     * @return bool True on success, false on failure.
     */
    function load_textdomain($domain, $mofile, $locale = \null)
    {
    }
    /**
     * Unloads translations for a text domain.
     *
     * @since 3.0.0
     * @since 6.1.0 Added the `$reloadable` parameter.
     *
     * @global MO[] $l10n          An array of all currently loaded text domains.
     * @global MO[] $l10n_unloaded An array of all text domains that have been unloaded again.
     *
     * @param string $domain     Text domain. Unique identifier for retrieving translated strings.
     * @param bool   $reloadable Whether the text domain can be loaded just-in-time again.
     * @return bool Whether textdomain was unloaded.
     */
    function unload_textdomain($domain, $reloadable = \false)
    {
    }
    /**
     * Loads default translated strings based on locale.
     *
     * Loads the .mo file in WP_LANG_DIR constant path from WordPress root.
     * The translated (.mo) file is named based on the locale.
     *
     * @see load_textdomain()
     *
     * @since 1.5.0
     *
     * @param string $locale Optional. Locale to load. Default is the value of get_locale().
     * @return bool Whether the textdomain was loaded.
     */
    function load_default_textdomain($locale = \null)
    {
    }
    /**
     * Loads a plugin's translated strings.
     *
     * If the path is not given then it will be the root of the plugin directory.
     *
     * The .mo file should be named based on the text domain with a dash, and then the locale exactly.
     *
     * @since 1.5.0
     * @since 4.6.0 The function now tries to load the .mo file from the languages directory first.
     * @since 6.7.0 Translations are no longer immediately loaded, but handed off to the just-in-time loading mechanism.
     *
     * @global WP_Textdomain_Registry $wp_textdomain_registry WordPress Textdomain Registry.
     * @global array<string, WP_Translations|NOOP_Translations> $l10n An array of all currently loaded text domains.
     *
     * @param string       $domain          Unique identifier for retrieving translated strings
     * @param string|false $deprecated      Optional. Deprecated. Use the $plugin_rel_path parameter instead.
     *                                      Default false.
     * @param string|false $plugin_rel_path Optional. Relative path to WP_PLUGIN_DIR where the .mo file resides.
     *                                      Default false.
     * @return bool True when textdomain is successfully loaded, false otherwise.
     */
    function load_plugin_textdomain($domain, $deprecated = \false, $plugin_rel_path = \false)
    {
    }
    /**
     * Loads the translated strings for a plugin residing in the mu-plugins directory.
     *
     * @since 3.0.0
     * @since 4.6.0 The function now tries to load the .mo file from the languages directory first.
     * @since 6.7.0 Translations are no longer immediately loaded, but handed off to the just-in-time loading mechanism.
     *
     * @global WP_Textdomain_Registry $wp_textdomain_registry WordPress Textdomain Registry.
     * @global array<string, WP_Translations|NOOP_Translations> $l10n An array of all currently loaded text domains.
     *
     * @param string $domain             Text domain. Unique identifier for retrieving translated strings.
     * @param string $mu_plugin_rel_path Optional. Relative to `WPMU_PLUGIN_DIR` directory in which the .mo
     *                                   file resides. Default empty string.
     * @return bool True when textdomain is successfully loaded, false otherwise.
     */
    function load_muplugin_textdomain($domain, $mu_plugin_rel_path = '')
    {
    }
    /**
     * Loads the theme's translated strings.
     *
     * If the current locale exists as a .mo file in the theme's root directory, it
     * will be included in the translated strings by the $domain.
     *
     * The .mo files must be named based on the locale exactly.
     *
     * @since 1.5.0
     * @since 4.6.0 The function now tries to load the .mo file from the languages directory first.
     * @since 6.7.0 Translations are no longer immediately loaded, but handed off to the just-in-time loading mechanism.
     *
     * @global WP_Textdomain_Registry $wp_textdomain_registry WordPress Textdomain Registry.
     * @global array<string, WP_Translations|NOOP_Translations> $l10n An array of all currently loaded text domains.
     *
     * @param string       $domain Text domain. Unique identifier for retrieving translated strings.
     * @param string|false $path   Optional. Path to the directory containing the .mo file.
     *                             Default false.
     * @return bool True when textdomain is successfully loaded, false otherwise.
     */
    function load_theme_textdomain($domain, $path = \false)
    {
    }
    /**
     * Loads the child theme's translated strings.
     *
     * If the current locale exists as a .mo file in the child theme's
     * root directory, it will be included in the translated strings by the $domain.
     *
     * The .mo files must be named based on the locale exactly.
     *
     * @since 2.9.0
     *
     * @param string       $domain Text domain. Unique identifier for retrieving translated strings.
     * @param string|false $path   Optional. Path to the directory containing the .mo file.
     *                             Default false.
     * @return bool True when the theme textdomain is successfully loaded, false otherwise.
     */
    function load_child_theme_textdomain($domain, $path = \false)
    {
    }
    /**
     * Loads the script translated strings.
     *
     * @since 5.0.0
     * @since 5.0.2 Uses load_script_translations() to load translation data.
     * @since 5.1.0 The `$domain` parameter was made optional.
     *
     * @see WP_Scripts::set_translations()
     *
     * @param string $handle Name of the script to register a translation domain to.
     * @param string $domain Optional. Text domain. Default 'default'.
     * @param string $path   Optional. The full file path to the directory containing translation files.
     * @return string|false The translated strings in JSON encoding on success,
     *                      false if the script textdomain could not be loaded.
     */
    function load_script_textdomain($handle, $domain = 'default', $path = '')
    {
    }
    /**
     * Loads the translation data for the given script handle and text domain.
     *
     * @since 5.0.2
     *
     * @param string|false $file   Path to the translation file to load. False if there isn't one.
     * @param string       $handle Name of the script to register a translation domain to.
     * @param string       $domain The text domain.
     * @return string|false The JSON-encoded translated strings for the given script handle and text domain.
     *                      False if there are none.
     */
    function load_script_translations($file, $handle, $domain)
    {
    }
    /**
     * Loads plugin and theme text domains just-in-time.
     *
     * When a textdomain is encountered for the first time, we try to load
     * the translation file from `wp-content/languages`, removing the need
     * to call load_plugin_textdomain() or load_theme_textdomain().
     *
     * @since 4.6.0
     * @access private
     *
     * @global MO[]                   $l10n_unloaded          An array of all text domains that have been unloaded again.
     * @global WP_Textdomain_Registry $wp_textdomain_registry WordPress Textdomain Registry.
     *
     * @param string $domain Text domain. Unique identifier for retrieving translated strings.
     * @return bool True when the textdomain is successfully loaded, false otherwise.
     */
    function _load_textdomain_just_in_time($domain)
    {
    }
    /**
     * Returns the Translations instance for a text domain.
     *
     * If there isn't one, returns empty Translations instance.
     *
     * @since 2.8.0
     *
     * @global MO[] $l10n An array of all currently loaded text domains.
     *
     * @param string $domain Text domain. Unique identifier for retrieving translated strings.
     * @return Translations|NOOP_Translations A Translations instance.
     */
    function get_translations_for_domain($domain)
    {
    }
    /**
     * Determines whether there are translations for the text domain.
     *
     * @since 3.0.0
     *
     * @global MO[] $l10n An array of all currently loaded text domains.
     *
     * @param string $domain Text domain. Unique identifier for retrieving translated strings.
     * @return bool Whether there are translations.
     */
    function is_textdomain_loaded($domain)
    {
    }
    /**
     * Translates role name.
     *
     * Since the role names are in the database and not in the source there
     * are dummy gettext calls to get them into the POT file and this function
     * properly translates them back.
     *
     * The before_last_bar() call is needed, because older installations keep the roles
     * using the old context format: 'Role name|User role' and just skipping the
     * content after the last bar is easier than fixing them in the DB. New installations
     * won't suffer from that problem.
     *
     * @since 2.8.0
     * @since 5.2.0 Added the `$domain` parameter.
     *
     * @param string $name   The role name.
     * @param string $domain Optional. Text domain. Unique identifier for retrieving translated strings.
     *                       Default 'default'.
     * @return string Translated role name on success, original name on failure.
     */
    function translate_user_role($name, $domain = 'default')
    {
    }
    /**
     * Gets all available languages based on the presence of *.mo and *.l10n.php files in a given directory.
     *
     * The default directory is WP_LANG_DIR.
     *
     * @since 3.0.0
     * @since 4.7.0 The results are now filterable with the {@see 'get_available_languages'} filter.
     * @since 6.5.0 The initial file list is now cached and also takes into account *.l10n.php files.
     *
     * @global WP_Textdomain_Registry $wp_textdomain_registry WordPress Textdomain Registry.
     *
     * @param string $dir A directory to search for language files.
     *                    Default WP_LANG_DIR.
     * @return string[] An array of language codes or an empty array if no languages are present.
     *                  Language codes are formed by stripping the file extension from the language file names.
     */
    function get_available_languages($dir = \null)
    {
    }
    /**
     * Gets installed translations.
     *
     * Looks in the wp-content/languages directory for translations of
     * plugins or themes.
     *
     * @since 3.7.0
     *
     * @global WP_Textdomain_Registry $wp_textdomain_registry WordPress Textdomain Registry.
     *
     * @param string $type What to search for. Accepts 'plugins', 'themes', 'core'.
     * @return array Array of language data.
     */
    function wp_get_installed_translations($type)
    {
    }
    /**
     * Extracts headers from a PO file.
     *
     * @since 3.7.0
     *
     * @param string $po_file Path to PO file.
     * @return string[] Array of PO file header values keyed by header name.
     */
    function wp_get_pomo_file_data($po_file)
    {
    }
    /**
     * Extracts headers from a PHP translation file.
     *
     * @since 6.6.0
     *
     * @param string $php_file Path to a `.l10n.php` file.
     * @return string[] Array of file header values keyed by header name.
     */
    function wp_get_l10n_php_file_data($php_file)
    {
    }
    /**
     * Displays or returns a Language selector.
     *
     * @since 4.0.0
     * @since 4.3.0 Introduced the `echo` argument.
     * @since 4.7.0 Introduced the `show_option_site_default` argument.
     * @since 5.1.0 Introduced the `show_option_en_us` argument.
     * @since 5.9.0 Introduced the `explicit_option_en_us` argument.
     *
     * @see get_available_languages()
     * @see wp_get_available_translations()
     *
     * @param string|array $args {
     *     Optional. Array or string of arguments for outputting the language selector.
     *
     *     @type string   $id                           ID attribute of the select element. Default 'locale'.
     *     @type string   $name                         Name attribute of the select element. Default 'locale'.
     *     @type string[] $languages                    List of installed languages, contain only the locales.
     *                                                  Default empty array.
     *     @type array    $translations                 List of available translations. Default result of
     *                                                  wp_get_available_translations().
     *     @type string   $selected                     Language which should be selected. Default empty.
     *     @type bool|int $echo                         Whether to echo the generated markup. Accepts 0, 1, or their
     *                                                  boolean equivalents. Default 1.
     *     @type bool     $show_available_translations  Whether to show available translations. Default true.
     *     @type bool     $show_option_site_default     Whether to show an option to fall back to the site's locale. Default false.
     *     @type bool     $show_option_en_us            Whether to show an option for English (United States). Default true.
     *     @type bool     $explicit_option_en_us        Whether the English (United States) option uses an explicit value of en_US
     *                                                  instead of an empty value. Default false.
     * }
     * @return string HTML dropdown list of languages.
     * @phpstan-param array{
     *   id?: string,
     *   name?: string,
     *   languages?: string[],
     *   translations?: array,
     *   selected?: string,
     *   echo?: bool|int,
     *   show_available_translations?: bool,
     *   show_option_site_default?: bool,
     *   show_option_en_us?: bool,
     *   explicit_option_en_us?: bool,
     * } $args
     * @phpstan-return ($args is array{id: null|''}&array ? void : ($args is array{name: null|''}&array ? void : string))
     */
    function wp_dropdown_languages($args = array())
    {
    }
    /**
     * Determines whether the current locale is right-to-left (RTL).
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 3.0.0
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     *
     * @return bool Whether locale is RTL.
     */
    function is_rtl()
    {
    }
    /**
     * Switches the translations according to the given locale.
     *
     * @since 4.7.0
     *
     * @global WP_Locale_Switcher $wp_locale_switcher WordPress locale switcher object.
     *
     * @param string $locale The locale.
     * @return bool True on success, false on failure.
     */
    function switch_to_locale($locale)
    {
    }
    /**
     * Switches the translations according to the given user's locale.
     *
     * @since 6.2.0
     *
     * @global WP_Locale_Switcher $wp_locale_switcher WordPress locale switcher object.
     *
     * @param int $user_id User ID.
     * @return bool True on success, false on failure.
     */
    function switch_to_user_locale($user_id)
    {
    }
    /**
     * Restores the translations according to the previous locale.
     *
     * @since 4.7.0
     *
     * @global WP_Locale_Switcher $wp_locale_switcher WordPress locale switcher object.
     *
     * @return string|false Locale on success, false on error.
     */
    function restore_previous_locale()
    {
    }
    /**
     * Restores the translations according to the original locale.
     *
     * @since 4.7.0
     *
     * @global WP_Locale_Switcher $wp_locale_switcher WordPress locale switcher object.
     *
     * @return string|false Locale on success, false on error.
     */
    function restore_current_locale()
    {
    }
    /**
     * Determines whether switch_to_locale() is in effect.
     *
     * @since 4.7.0
     *
     * @global WP_Locale_Switcher $wp_locale_switcher WordPress locale switcher object.
     *
     * @return bool True if the locale has been switched, false otherwise.
     */
    function is_locale_switched()
    {
    }
    /**
     * Translates the provided settings value using its i18n schema.
     *
     * @since 5.9.0
     * @access private
     *
     * @param string|string[]|array[]|object $i18n_schema I18n schema for the setting.
     * @param string|string[]|array[]        $settings    Value for the settings.
     * @param string                         $textdomain  Textdomain to use with translations.
     *
     * @return string|string[]|array[] Translated settings.
     */
    function translate_settings_using_i18n_schema($i18n_schema, $settings, $textdomain)
    {
    }
    /**
     * Retrieves the list item separator based on the locale.
     *
     * @since 6.0.0
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     *
     * @return string Locale-specific list item separator.
     */
    function wp_get_list_item_separator()
    {
    }
    /**
     * Retrieves the word count type based on the locale.
     *
     * @since 6.2.0
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     *
     * @return string Locale-specific word count type. Possible values are `characters_excluding_spaces`,
     *                `characters_including_spaces`, or `words`. Defaults to `words`.
     */
    function wp_get_word_count_type()
    {
    }
    /**
     * Returns a boolean to indicate whether a translation exists for a given string with optional text domain and locale.
     *
     * @since 6.7.0
     *
     * @param string  $singular   Singular translation to check.
     * @param string  $textdomain Optional. Text domain. Default 'default'.
     * @param ?string $locale     Optional. Locale. Default current locale.
     * @return bool  True if the translation exists, false otherwise.
     */
    function has_translation(string $singular, string $textdomain = 'default', ?string $locale = \null) : bool
    {
    }
    /**
     * Displays the permalink for the current post.
     *
     * @since 1.2.0
     * @since 4.4.0 Added the `$post` parameter.
     *
     * @param int|WP_Post $post Optional. Post ID or post object. Default is the global `$post`.
     */
    function the_permalink($post = 0)
    {
    }
    /**
     * Retrieves a trailing-slashed string if the site is set for adding trailing slashes.
     *
     * Conditionally adds a trailing slash if the permalink structure has a trailing
     * slash, strips the trailing slash if not. The string is passed through the
     * {@see 'user_trailingslashit'} filter. Will remove trailing slash from string, if
     * site is not set to have them.
     *
     * @since 2.2.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string $url         URL with or without a trailing slash.
     * @param string $type_of_url Optional. The type of URL being considered (e.g. single, category, etc)
     *                            for use in the filter. Default empty string.
     * @return string The URL with the trailing slash appended or stripped.
     */
    function user_trailingslashit($url, $type_of_url = '')
    {
    }
    /**
     * Displays the permalink anchor for the current post.
     *
     * The permalink mode title will use the post title for the 'a' element 'id'
     * attribute. The id mode uses 'post-' with the post ID for the 'id' attribute.
     *
     * @since 0.71
     *
     * @param string $mode Optional. Permalink mode. Accepts 'title' or 'id'. Default 'id'.
     * @phpstan-param 'title'|'id' $mode
     */
    function permalink_anchor($mode = 'id')
    {
    }
    /**
     * Determine whether post should always use a plain permalink structure.
     *
     * @since 5.7.0
     *
     * @param WP_Post|int|null $post   Optional. Post ID or post object. Defaults to global $post.
     * @param bool|null        $sample Optional. Whether to force consideration based on sample links.
     *                                 If omitted, a sample link is generated if a post object is passed
     *                                 with the filter property set to 'sample'.
     * @return bool Whether to use a plain permalink structure.
     */
    function wp_force_plain_post_permalink($post = \null, $sample = \null)
    {
    }
    /**
     * Retrieves the full permalink for the current post or post ID.
     *
     * This function is an alias for get_permalink().
     *
     * @since 3.9.0
     *
     * @see get_permalink()
     *
     * @param int|WP_Post $post      Optional. Post ID or post object. Default is the global `$post`.
     * @param bool        $leavename Optional. Whether to keep post name or page name. Default false.
     * @return string|false The permalink URL. False if the post does not exist.
     * @phpstan-return ($post is \WP_Post ? string : string|false)
     */
    function get_the_permalink($post = 0, $leavename = \false)
    {
    }
    /**
     * Retrieves the full permalink for the current post or post ID.
     *
     * @since 1.0.0
     *
     * @param int|WP_Post $post      Optional. Post ID or post object. Default is the global `$post`.
     * @param bool        $leavename Optional. Whether to keep post name or page name. Default false.
     * @return string|false The permalink URL. False if the post does not exist.
     * @phpstan-return ($post is \WP_Post ? string : string|false)
     */
    function get_permalink($post = 0, $leavename = \false)
    {
    }
    /**
     * Retrieves the permalink for a post of a custom post type.
     *
     * @since 3.0.0
     * @since 6.1.0 Returns false if the post does not exist.
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param int|WP_Post $post      Optional. Post ID or post object. Default is the global `$post`.
     * @param bool        $leavename Optional. Whether to keep post name. Default false.
     * @param bool        $sample    Optional. Is it a sample permalink. Default false.
     * @return string|false The post permalink URL. False if the post does not exist.
     * @phpstan-return ($post is \WP_Post ? string : string|false)
     */
    function get_post_permalink($post = 0, $leavename = \false, $sample = \false)
    {
    }
    /**
     * Retrieves the permalink for the current page or page ID.
     *
     * Respects page_on_front. Use this one.
     *
     * @since 1.5.0
     *
     * @param int|WP_Post $post      Optional. Post ID or object. Default uses the global `$post`.
     * @param bool        $leavename Optional. Whether to keep the page name. Default false.
     * @param bool        $sample    Optional. Whether it should be treated as a sample permalink.
     *                               Default false.
     * @return string The page permalink.
     */
    function get_page_link($post = \false, $leavename = \false, $sample = \false)
    {
    }
    /**
     * Retrieves the page permalink.
     *
     * Ignores page_on_front. Internal use only.
     *
     * @since 2.1.0
     * @access private
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param int|WP_Post $post      Optional. Post ID or object. Default uses the global `$post`.
     * @param bool        $leavename Optional. Whether to keep the page name. Default false.
     * @param bool        $sample    Optional. Whether it should be treated as a sample permalink.
     *                               Default false.
     * @return string The page permalink.
     */
    function _get_page_link($post = \false, $leavename = \false, $sample = \false)
    {
    }
    /**
     * Retrieves the permalink for an attachment.
     *
     * This can be used in the WordPress Loop or outside of it.
     *
     * @since 2.0.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param int|WP_Post $post      Optional. Post ID or object. Default uses the global `$post`.
     * @param bool        $leavename Optional. Whether to keep the page name. Default false.
     * @return string The attachment permalink.
     */
    function get_attachment_link($post = \null, $leavename = \false)
    {
    }
    /**
     * Retrieves the permalink for the year archives.
     *
     * @since 1.5.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param int|false $year Integer of year. False for current year.
     * @return string The permalink for the specified year archive.
     */
    function get_year_link($year)
    {
    }
    /**
     * Retrieves the permalink for the month archives with year.
     *
     * @since 1.0.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param int|false $year  Integer of year. False for current year.
     * @param int|false $month Integer of month. False for current month.
     * @return string The permalink for the specified month and year archive.
     */
    function get_month_link($year, $month)
    {
    }
    /**
     * Retrieves the permalink for the day archives with year and month.
     *
     * @since 1.0.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param int|false $year  Integer of year. False for current year.
     * @param int|false $month Integer of month. False for current month.
     * @param int|false $day   Integer of day. False for current day.
     * @return string The permalink for the specified day, month, and year archive.
     */
    function get_day_link($year, $month, $day)
    {
    }
    /**
     * Displays the permalink for the feed type.
     *
     * @since 3.0.0
     *
     * @param string $anchor The link's anchor text.
     * @param string $feed   Optional. Feed type. Possible values include 'rss2', 'atom'.
     *                       Default is the value of get_default_feed().
     */
    function the_feed_link($anchor, $feed = '')
    {
    }
    /**
     * Retrieves the permalink for the feed type.
     *
     * @since 1.5.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string $feed Optional. Feed type. Possible values include 'rss2', 'atom'.
     *                     Default is the value of get_default_feed().
     * @return string The feed permalink.
     */
    function get_feed_link($feed = '')
    {
    }
    /**
     * Retrieves the permalink for the post comments feed.
     *
     * @since 2.2.0
     *
     * @param int    $post_id Optional. Post ID. Default is the ID of the global `$post`.
     * @param string $feed    Optional. Feed type. Possible values include 'rss2', 'atom'.
     *                        Default is the value of get_default_feed().
     * @return string The permalink for the comments feed for the given post on success, empty string on failure.
     */
    function get_post_comments_feed_link($post_id = 0, $feed = '')
    {
    }
    /**
     * Displays the comment feed link for a post.
     *
     * Prints out the comment feed link for a post. Link text is placed in the
     * anchor. If no link text is specified, default text is used. If no post ID is
     * specified, the current post is used.
     *
     * @since 2.5.0
     *
     * @param string $link_text Optional. Descriptive link text. Default 'Comments Feed'.
     * @param int    $post_id   Optional. Post ID. Default is the ID of the global `$post`.
     * @param string $feed      Optional. Feed type. Possible values include 'rss2', 'atom'.
     *                          Default is the value of get_default_feed().
     */
    function post_comments_feed_link($link_text = '', $post_id = '', $feed = '')
    {
    }
    /**
     * Retrieves the feed link for a given author.
     *
     * Returns a link to the feed for all posts by a given author. A specific feed
     * can be requested or left blank to get the default feed.
     *
     * @since 2.5.0
     *
     * @param int    $author_id Author ID.
     * @param string $feed      Optional. Feed type. Possible values include 'rss2', 'atom'.
     *                          Default is the value of get_default_feed().
     * @return string Link to the feed for the author specified by $author_id.
     */
    function get_author_feed_link($author_id, $feed = '')
    {
    }
    /**
     * Retrieves the feed link for a category.
     *
     * Returns a link to the feed for all posts in a given category. A specific feed
     * can be requested or left blank to get the default feed.
     *
     * @since 2.5.0
     *
     * @param int|WP_Term|object $cat  The ID or category object whose feed link will be retrieved.
     * @param string             $feed Optional. Feed type. Possible values include 'rss2', 'atom'.
     *                                 Default is the value of get_default_feed().
     * @return string Link to the feed for the category specified by `$cat`.
     */
    function get_category_feed_link($cat, $feed = '')
    {
    }
    /**
     * Retrieves the feed link for a term.
     *
     * Returns a link to the feed for all posts in a given term. A specific feed
     * can be requested or left blank to get the default feed.
     *
     * @since 3.0.0
     *
     * @param int|WP_Term|object $term     The ID or term object whose feed link will be retrieved.
     * @param string             $taxonomy Optional. Taxonomy of `$term_id`.
     * @param string             $feed     Optional. Feed type. Possible values include 'rss2', 'atom'.
     *                                     Default is the value of get_default_feed().
     * @return string|false Link to the feed for the term specified by `$term` and `$taxonomy`.
     */
    function get_term_feed_link($term, $taxonomy = '', $feed = '')
    {
    }
    /**
     * Retrieves the permalink for a tag feed.
     *
     * @since 2.3.0
     *
     * @param int|WP_Term|object $tag  The ID or term object whose feed link will be retrieved.
     * @param string             $feed Optional. Feed type. Possible values include 'rss2', 'atom'.
     *                                 Default is the value of get_default_feed().
     * @return string                  The feed permalink for the given tag.
     */
    function get_tag_feed_link($tag, $feed = '')
    {
    }
    /**
     * Retrieves the edit link for a tag.
     *
     * @since 2.7.0
     *
     * @param int|WP_Term|object $tag      The ID or term object whose edit link will be retrieved.
     * @param string             $taxonomy Optional. Taxonomy slug. Default 'post_tag'.
     * @return string The edit tag link URL for the given tag.
     */
    function get_edit_tag_link($tag, $taxonomy = 'post_tag')
    {
    }
    /**
     * Displays or retrieves the edit link for a tag with formatting.
     *
     * @since 2.7.0
     *
     * @param string  $link   Optional. Anchor text. If empty, default is 'Edit This'. Default empty.
     * @param string  $before Optional. Display before edit link. Default empty.
     * @param string  $after  Optional. Display after edit link. Default empty.
     * @param WP_Term $tag    Optional. Term object. If null, the queried object will be inspected.
     *                        Default null.
     */
    function edit_tag_link($link = '', $before = '', $after = '', $tag = \null)
    {
    }
    /**
     * Retrieves the URL for editing a given term.
     *
     * @since 3.1.0
     * @since 4.5.0 The `$taxonomy` parameter was made optional.
     *
     * @param int|WP_Term|object $term        The ID or term object whose edit link will be retrieved.
     * @param string             $taxonomy    Optional. Taxonomy. Defaults to the taxonomy of the term identified
     *                                        by `$term`.
     * @param string             $object_type Optional. The object type. Used to highlight the proper post type
     *                                        menu on the linked page. Defaults to the first object_type associated
     *                                        with the taxonomy.
     * @return string|null The edit term link URL for the given term, or null on failure.
     */
    function get_edit_term_link($term, $taxonomy = '', $object_type = '')
    {
    }
    /**
     * Displays or retrieves the edit term link with formatting.
     *
     * @since 3.1.0
     *
     * @param string           $link    Optional. Anchor text. If empty, default is 'Edit This'. Default empty.
     * @param string           $before  Optional. Display before edit link. Default empty.
     * @param string           $after   Optional. Display after edit link. Default empty.
     * @param int|WP_Term|null $term    Optional. Term ID or object. If null, the queried object will be inspected. Default null.
     * @param bool             $display Optional. Whether or not to echo the return. Default true.
     * @return string|void HTML content.
     * @phpstan-return ($display is true ? void : string|void)
     */
    function edit_term_link($link = '', $before = '', $after = '', $term = \null, $display = \true)
    {
    }
    /**
     * Retrieves the permalink for a search.
     *
     * @since 3.0.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string $query Optional. The query string to use. If empty the current query is used. Default empty.
     * @return string The search permalink.
     */
    function get_search_link($query = '')
    {
    }
    /**
     * Retrieves the permalink for the search results feed.
     *
     * @since 2.5.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string $search_query Optional. Search query. Default empty.
     * @param string $feed         Optional. Feed type. Possible values include 'rss2', 'atom'.
     *                             Default is the value of get_default_feed().
     * @return string The search results feed permalink.
     */
    function get_search_feed_link($search_query = '', $feed = '')
    {
    }
    /**
     * Retrieves the permalink for the search results comments feed.
     *
     * @since 2.5.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string $search_query Optional. Search query. Default empty.
     * @param string $feed         Optional. Feed type. Possible values include 'rss2', 'atom'.
     *                             Default is the value of get_default_feed().
     * @return string The comments feed search results permalink.
     */
    function get_search_comments_feed_link($search_query = '', $feed = '')
    {
    }
    /**
     * Retrieves the permalink for a post type archive.
     *
     * @since 3.1.0
     * @since 4.5.0 Support for posts was added.
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string $post_type Post type.
     * @return string|false The post type archive permalink. False if the post type
     *                      does not exist or does not have an archive.
     */
    function get_post_type_archive_link($post_type)
    {
    }
    /**
     * Retrieves the permalink for a post type archive feed.
     *
     * @since 3.1.0
     *
     * @param string $post_type Post type.
     * @param string $feed      Optional. Feed type. Possible values include 'rss2', 'atom'.
     *                          Default is the value of get_default_feed().
     * @return string|false The post type feed permalink. False if the post type
     *                      does not exist or does not have an archive.
     */
    function get_post_type_archive_feed_link($post_type, $feed = '')
    {
    }
    /**
     * Retrieves the URL used for the post preview.
     *
     * Allows additional query args to be appended.
     *
     * @since 4.4.0
     *
     * @param int|WP_Post $post         Optional. Post ID or `WP_Post` object. Defaults to global `$post`.
     * @param array       $query_args   Optional. Array of additional query args to be appended to the link.
     *                                  Default empty array.
     * @param string      $preview_link Optional. Base preview link to be used if it should differ from the
     *                                  post permalink. Default empty.
     * @return string|null URL used for the post preview, or null if the post does not exist.
     */
    function get_preview_post_link($post = \null, $query_args = array(), $preview_link = '')
    {
    }
    /**
     * Retrieves the edit post link for post.
     *
     * Can be used within the WordPress loop or outside of it. Can be used with
     * pages, posts, attachments, revisions, global styles, templates, and template parts.
     *
     * @since 2.3.0
     * @since 6.3.0 Adds custom link for wp_navigation post types.
     *              Adds custom links for wp_template_part and wp_template post types.
     *
     * @param int|WP_Post $post    Optional. Post ID or post object. Default is the global `$post`.
     * @param string      $context Optional. How to output the '&' character. Default '&amp;'.
     * @return string|null The edit post link for the given post. Null if the post type does not exist
     *                     or does not allow an editing UI.
     */
    function get_edit_post_link($post = 0, $context = 'display')
    {
    }
    /**
     * Displays the edit post link for post.
     *
     * @since 1.0.0
     * @since 4.4.0 The `$css_class` argument was added.
     *
     * @param string      $text      Optional. Anchor text. If null, default is 'Edit This'. Default null.
     * @param string      $before    Optional. Display before edit link. Default empty.
     * @param string      $after     Optional. Display after edit link. Default empty.
     * @param int|WP_Post $post      Optional. Post ID or post object. Default is the global `$post`.
     * @param string      $css_class Optional. Add custom class to link. Default 'post-edit-link'.
     * @phpstan-return void
     */
    function edit_post_link($text = \null, $before = '', $after = '', $post = 0, $css_class = 'post-edit-link')
    {
    }
    /**
     * Retrieves the delete posts link for post.
     *
     * Can be used within the WordPress loop or outside of it, with any post type.
     *
     * @since 2.9.0
     *
     * @param int|WP_Post $post         Optional. Post ID or post object. Default is the global `$post`.
     * @param string      $deprecated   Not used.
     * @param bool        $force_delete Optional. Whether to bypass Trash and force deletion. Default false.
     * @return string|void The delete post link URL for the given post.
     */
    function get_delete_post_link($post = 0, $deprecated = '', $force_delete = \false)
    {
    }
    /**
     * Retrieves the edit comment link.
     *
     * @since 2.3.0
     * @since 6.7.0 The $context parameter was added.
     *
     * @param int|WP_Comment $comment_id Optional. Comment ID or WP_Comment object.
     * @param string         $context    Optional. Context in which the URL should be used. Either 'display',
     *                                   to include HTML entities, or 'url'. Default 'display'.
     * @return string|void The edit comment link URL for the given comment, or void if the comment id does not exist or
     *                     the current user is not allowed to edit it.
     */
    function get_edit_comment_link($comment_id = 0, $context = 'display')
    {
    }
    /**
     * Displays the edit comment link with formatting.
     *
     * @since 1.0.0
     *
     * @param string $text   Optional. Anchor text. If null, default is 'Edit This'. Default null.
     * @param string $before Optional. Display before edit link. Default empty.
     * @param string $after  Optional. Display after edit link. Default empty.
     * @phpstan-return void
     */
    function edit_comment_link($text = \null, $before = '', $after = '')
    {
    }
    /**
     * Displays the edit bookmark link.
     *
     * @since 2.7.0
     *
     * @param int|stdClass $link Optional. Bookmark ID. Default is the ID of the current bookmark.
     * @return string|void The edit bookmark link URL.
     */
    function get_edit_bookmark_link($link = 0)
    {
    }
    /**
     * Displays the edit bookmark link anchor content.
     *
     * @since 2.7.0
     *
     * @param string $link     Optional. Anchor text. If empty, default is 'Edit This'. Default empty.
     * @param string $before   Optional. Display before edit link. Default empty.
     * @param string $after    Optional. Display after edit link. Default empty.
     * @param int    $bookmark Optional. Bookmark ID. Default is the current bookmark.
     * @phpstan-return void
     */
    function edit_bookmark_link($link = '', $before = '', $after = '', $bookmark = \null)
    {
    }
    /**
     * Retrieves the edit user link.
     *
     * @since 3.5.0
     *
     * @param int $user_id Optional. User ID. Defaults to the current user.
     * @return string URL to edit user page or empty string.
     */
    function get_edit_user_link($user_id = \null)
    {
    }
    /**
     * Retrieves the previous post that is adjacent to the current post.
     *
     * @since 1.5.0
     *
     * @param bool         $in_same_term   Optional. Whether post should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded term IDs.
     *                                     Default empty.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     * @return WP_Post|null|string Post object if successful. Null if global `$post` is not set.
     *                             Empty string if no corresponding post exists.
     */
    function get_previous_post($in_same_term = \false, $excluded_terms = '', $taxonomy = 'category')
    {
    }
    /**
     * Retrieves the next post that is adjacent to the current post.
     *
     * @since 1.5.0
     *
     * @param bool         $in_same_term   Optional. Whether post should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded term IDs.
     *                                     Default empty.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     * @return WP_Post|null|string Post object if successful. Null if global `$post` is not set.
     *                             Empty string if no corresponding post exists.
     */
    function get_next_post($in_same_term = \false, $excluded_terms = '', $taxonomy = 'category')
    {
    }
    /**
     * Retrieves the adjacent post.
     *
     * Can either be next or previous post.
     *
     * @since 2.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param bool         $in_same_term   Optional. Whether post should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded term IDs.
     *                                     Default empty string.
     * @param bool         $previous       Optional. Whether to retrieve previous post.
     *                                     Default true.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     * @return WP_Post|null|string Post object if successful. Null if global `$post` is not set.
     *                             Empty string if no corresponding post exists.
     */
    function get_adjacent_post($in_same_term = \false, $excluded_terms = '', $previous = \true, $taxonomy = 'category')
    {
    }
    /**
     * Retrieves the adjacent post relational link.
     *
     * Can either be next or previous post relational link.
     *
     * @since 2.8.0
     *
     * @param string       $title          Optional. Link title format. Default '%title'.
     * @param bool         $in_same_term   Optional. Whether link should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded term IDs.
     *                                     Default empty.
     * @param bool         $previous       Optional. Whether to display link to previous or next post.
     *                                     Default true.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     * @return string|void The adjacent post relational link URL.
     */
    function get_adjacent_post_rel_link($title = '%title', $in_same_term = \false, $excluded_terms = '', $previous = \true, $taxonomy = 'category')
    {
    }
    /**
     * Displays the relational links for the posts adjacent to the current post.
     *
     * @since 2.8.0
     *
     * @param string       $title          Optional. Link title format. Default '%title'.
     * @param bool         $in_same_term   Optional. Whether link should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded term IDs.
     *                                     Default empty.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     */
    function adjacent_posts_rel_link($title = '%title', $in_same_term = \false, $excluded_terms = '', $taxonomy = 'category')
    {
    }
    /**
     * Displays relational links for the posts adjacent to the current post for single post pages.
     *
     * This is meant to be attached to actions like 'wp_head'. Do not call this directly in plugins
     * or theme templates.
     *
     * @since 3.0.0
     * @since 5.6.0 No longer used in core.
     *
     * @see adjacent_posts_rel_link()
     * @phpstan-return void
     */
    function adjacent_posts_rel_link_wp_head()
    {
    }
    /**
     * Displays the relational link for the next post adjacent to the current post.
     *
     * @since 2.8.0
     *
     * @see get_adjacent_post_rel_link()
     *
     * @param string       $title          Optional. Link title format. Default '%title'.
     * @param bool         $in_same_term   Optional. Whether link should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded term IDs.
     *                                     Default empty.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     */
    function next_post_rel_link($title = '%title', $in_same_term = \false, $excluded_terms = '', $taxonomy = 'category')
    {
    }
    /**
     * Displays the relational link for the previous post adjacent to the current post.
     *
     * @since 2.8.0
     *
     * @see get_adjacent_post_rel_link()
     *
     * @param string       $title          Optional. Link title format. Default '%title'.
     * @param bool         $in_same_term   Optional. Whether link should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded term IDs.
     *                                     Default true.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     */
    function prev_post_rel_link($title = '%title', $in_same_term = \false, $excluded_terms = '', $taxonomy = 'category')
    {
    }
    /**
     * Retrieves the boundary post.
     *
     * Boundary being either the first or last post by publish date within the constraints specified
     * by `$in_same_term` or `$excluded_terms`.
     *
     * @since 2.8.0
     *
     * @param bool         $in_same_term   Optional. Whether returned post should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded term IDs.
     *                                     Default empty.
     * @param bool         $start          Optional. Whether to retrieve first or last post.
     *                                     Default true.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     * @return array|null Array containing the boundary post object if successful, null otherwise.
     */
    function get_boundary_post($in_same_term = \false, $excluded_terms = '', $start = \true, $taxonomy = 'category')
    {
    }
    /**
     * Retrieves the previous post link that is adjacent to the current post.
     *
     * @since 3.7.0
     *
     * @param string       $format         Optional. Link anchor format. Default '&laquo; %link'.
     * @param string       $link           Optional. Link permalink format. Default '%title'.
     * @param bool         $in_same_term   Optional. Whether link should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded term IDs.
     *                                     Default empty.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     * @return string The link URL of the previous post in relation to the current post.
     */
    function get_previous_post_link($format = '&laquo; %link', $link = '%title', $in_same_term = \false, $excluded_terms = '', $taxonomy = 'category')
    {
    }
    /**
     * Displays the previous post link that is adjacent to the current post.
     *
     * @since 1.5.0
     *
     * @see get_previous_post_link()
     *
     * @param string       $format         Optional. Link anchor format. Default '&laquo; %link'.
     * @param string       $link           Optional. Link permalink format. Default '%title'.
     * @param bool         $in_same_term   Optional. Whether link should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded term IDs.
     *                                     Default empty.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     */
    function previous_post_link($format = '&laquo; %link', $link = '%title', $in_same_term = \false, $excluded_terms = '', $taxonomy = 'category')
    {
    }
    /**
     * Retrieves the next post link that is adjacent to the current post.
     *
     * @since 3.7.0
     *
     * @param string       $format         Optional. Link anchor format. Default '&laquo; %link'.
     * @param string       $link           Optional. Link permalink format. Default '%title'.
     * @param bool         $in_same_term   Optional. Whether link should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded term IDs.
     *                                     Default empty.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     * @return string The link URL of the next post in relation to the current post.
     */
    function get_next_post_link($format = '%link &raquo;', $link = '%title', $in_same_term = \false, $excluded_terms = '', $taxonomy = 'category')
    {
    }
    /**
     * Displays the next post link that is adjacent to the current post.
     *
     * @since 1.5.0
     *
     * @see get_next_post_link()
     *
     * @param string       $format         Optional. Link anchor format. Default '&laquo; %link'.
     * @param string       $link           Optional. Link permalink format. Default '%title'.
     * @param bool         $in_same_term   Optional. Whether link should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded term IDs.
     *                                     Default empty.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     */
    function next_post_link($format = '%link &raquo;', $link = '%title', $in_same_term = \false, $excluded_terms = '', $taxonomy = 'category')
    {
    }
    /**
     * Retrieves the adjacent post link.
     *
     * Can be either next post link or previous.
     *
     * @since 3.7.0
     *
     * @param string       $format         Link anchor format.
     * @param string       $link           Link permalink format.
     * @param bool         $in_same_term   Optional. Whether link should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded terms IDs.
     *                                     Default empty.
     * @param bool         $previous       Optional. Whether to display link to previous or next post.
     *                                     Default true.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     * @return string The link URL of the previous or next post in relation to the current post.
     */
    function get_adjacent_post_link($format, $link, $in_same_term = \false, $excluded_terms = '', $previous = \true, $taxonomy = 'category')
    {
    }
    /**
     * Displays the adjacent post link.
     *
     * Can be either next post link or previous.
     *
     * @since 2.5.0
     *
     * @param string       $format         Link anchor format.
     * @param string       $link           Link permalink format.
     * @param bool         $in_same_term   Optional. Whether link should be in the same taxonomy term.
     *                                     Default false.
     * @param int[]|string $excluded_terms Optional. Array or comma-separated list of excluded category IDs.
     *                                     Default empty.
     * @param bool         $previous       Optional. Whether to display link to previous or next post.
     *                                     Default true.
     * @param string       $taxonomy       Optional. Taxonomy, if `$in_same_term` is true. Default 'category'.
     */
    function adjacent_post_link($format, $link, $in_same_term = \false, $excluded_terms = '', $previous = \true, $taxonomy = 'category')
    {
    }
    /**
     * Retrieves the link for a page number.
     *
     * @since 1.5.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param int  $pagenum Optional. Page number. Default 1.
     * @param bool $escape  Optional. Whether to escape the URL for display, with esc_url().
     *                      If set to false, prepares the URL with sanitize_url(). Default true.
     * @return string The link URL for the given page number.
     */
    function get_pagenum_link($pagenum = 1, $escape = \true)
    {
    }
    /**
     * Retrieves the next posts page link.
     *
     * Backported from 2.1.3 to 2.0.10.
     *
     * @since 2.0.10
     *
     * @global int $paged
     *
     * @param int $max_page Optional. Max pages. Default 0.
     * @return string|void The link URL for next posts page.
     */
    function get_next_posts_page_link($max_page = 0)
    {
    }
    /**
     * Displays or retrieves the next posts page link.
     *
     * @since 0.71
     *
     * @param int  $max_page Optional. Max pages. Default 0.
     * @param bool $display  Optional. Whether to echo the link. Default true.
     * @return string|void The link URL for next posts page if `$display = false`.
     * @phpstan-return ($display is true ? void : string)
     */
    function next_posts($max_page = 0, $display = \true)
    {
    }
    /**
     * Retrieves the next posts page link.
     *
     * @since 2.7.0
     *
     * @global int      $paged
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string $label    Content for link text.
     * @param int    $max_page Optional. Max pages. Default 0.
     * @return string|void HTML-formatted next posts page link.
     */
    function get_next_posts_link($label = \null, $max_page = 0)
    {
    }
    /**
     * Displays the next posts page link.
     *
     * @since 0.71
     *
     * @param string $label    Content for link text.
     * @param int    $max_page Optional. Max pages. Default 0.
     */
    function next_posts_link($label = \null, $max_page = 0)
    {
    }
    /**
     * Retrieves the previous posts page link.
     *
     * Will only return string, if not on a single page or post.
     *
     * Backported to 2.0.10 from 2.1.3.
     *
     * @since 2.0.10
     *
     * @global int $paged
     *
     * @return string|void The link for the previous posts page.
     */
    function get_previous_posts_page_link()
    {
    }
    /**
     * Displays or retrieves the previous posts page link.
     *
     * @since 0.71
     *
     * @param bool $display Optional. Whether to echo the link. Default true.
     * @return string|void The previous posts page link if `$display = false`.
     * @phpstan-return ($display is true ? void : string)
     */
    function previous_posts($display = \true)
    {
    }
    /**
     * Retrieves the previous posts page link.
     *
     * @since 2.7.0
     *
     * @global int $paged
     *
     * @param string $label Optional. Previous page link text.
     * @return string|void HTML-formatted previous page link.
     */
    function get_previous_posts_link($label = \null)
    {
    }
    /**
     * Displays the previous posts page link.
     *
     * @since 0.71
     *
     * @param string $label Optional. Previous page link text.
     */
    function previous_posts_link($label = \null)
    {
    }
    /**
     * Retrieves the post pages link navigation for previous and next pages.
     *
     * @since 2.8.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string|array $args {
     *     Optional. Arguments to build the post pages link navigation.
     *
     *     @type string $sep      Separator character. Default '&#8212;'.
     *     @type string $prelabel Link text to display for the previous page link.
     *                            Default '&laquo; Previous Page'.
     *     @type string $nxtlabel Link text to display for the next page link.
     *                            Default 'Next Page &raquo;'.
     * }
     * @return string The posts link navigation.
     * @phpstan-param array{
     *   sep?: string,
     *   prelabel?: string,
     *   nxtlabel?: string,
     * } $args
     */
    function get_posts_nav_link($args = array())
    {
    }
    /**
     * Displays the post pages link navigation for previous and next pages.
     *
     * @since 0.71
     *
     * @param string $sep      Optional. Separator for posts navigation links. Default empty.
     * @param string $prelabel Optional. Label for previous pages. Default empty.
     * @param string $nxtlabel Optional Label for next pages. Default empty.
     */
    function posts_nav_link($sep = '', $prelabel = '', $nxtlabel = '')
    {
    }
    /**
     * Retrieves the navigation to next/previous post, when applicable.
     *
     * @since 4.1.0
     * @since 4.4.0 Introduced the `in_same_term`, `excluded_terms`, and `taxonomy` arguments.
     * @since 5.3.0 Added the `aria_label` parameter.
     * @since 5.5.0 Added the `class` parameter.
     *
     * @param array $args {
     *     Optional. Default post navigation arguments. Default empty array.
     *
     *     @type string       $prev_text          Anchor text to display in the previous post link.
     *                                            Default '%title'.
     *     @type string       $next_text          Anchor text to display in the next post link.
     *                                            Default '%title'.
     *     @type bool         $in_same_term       Whether link should be in the same taxonomy term.
     *                                            Default false.
     *     @type int[]|string $excluded_terms     Array or comma-separated list of excluded term IDs.
     *                                            Default empty.
     *     @type string       $taxonomy           Taxonomy, if `$in_same_term` is true. Default 'category'.
     *     @type string       $screen_reader_text Screen reader text for the nav element.
     *                                            Default 'Post navigation'.
     *     @type string       $aria_label         ARIA label text for the nav element. Default 'Posts'.
     *     @type string       $class              Custom class for the nav element. Default 'post-navigation'.
     * }
     * @return string Markup for post links.
     * @phpstan-param array{
     *   prev_text?: string,
     *   next_text?: string,
     *   in_same_term?: bool,
     *   excluded_terms?: int[]|string,
     *   taxonomy?: string,
     *   screen_reader_text?: string,
     *   aria_label?: string,
     *   class?: string,
     * } $args
     */
    function get_the_post_navigation($args = array())
    {
    }
    /**
     * Displays the navigation to next/previous post, when applicable.
     *
     * @since 4.1.0
     *
     * @param array $args Optional. See get_the_post_navigation() for available arguments.
     *                    Default empty array.
     * @phpstan-param array{
     *   prev_text?: string,
     *   next_text?: string,
     *   in_same_term?: bool,
     *   excluded_terms?: int[]|string,
     *   taxonomy?: string,
     *   screen_reader_text?: string,
     *   aria_label?: string,
     *   class?: string,
     * } $args See get_the_post_navigation()
     */
    function the_post_navigation($args = array())
    {
    }
    /**
     * Returns the navigation to next/previous set of posts, when applicable.
     *
     * @since 4.1.0
     * @since 5.3.0 Added the `aria_label` parameter.
     * @since 5.5.0 Added the `class` parameter.
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param array $args {
     *     Optional. Default posts navigation arguments. Default empty array.
     *
     *     @type string $prev_text          Anchor text to display in the previous posts link.
     *                                      Default 'Older posts'.
     *     @type string $next_text          Anchor text to display in the next posts link.
     *                                      Default 'Newer posts'.
     *     @type string $screen_reader_text Screen reader text for the nav element.
     *                                      Default 'Posts navigation'.
     *     @type string $aria_label         ARIA label text for the nav element. Default 'Posts'.
     *     @type string $class              Custom class for the nav element. Default 'posts-navigation'.
     * }
     * @return string Markup for posts links.
     * @phpstan-param array{
     *   prev_text?: string,
     *   next_text?: string,
     *   screen_reader_text?: string,
     *   aria_label?: string,
     *   class?: string,
     * } $args
     */
    function get_the_posts_navigation($args = array())
    {
    }
    /**
     * Displays the navigation to next/previous set of posts, when applicable.
     *
     * @since 4.1.0
     *
     * @param array $args Optional. See get_the_posts_navigation() for available arguments.
     *                    Default empty array.
     * @phpstan-param array{
     *   prev_text?: string,
     *   next_text?: string,
     *   screen_reader_text?: string,
     *   aria_label?: string,
     *   class?: string,
     * } $args See get_the_posts_navigation()
     */
    function the_posts_navigation($args = array())
    {
    }
    /**
     * Retrieves a paginated navigation to next/previous set of posts, when applicable.
     *
     * @since 4.1.0
     * @since 5.3.0 Added the `aria_label` parameter.
     * @since 5.5.0 Added the `class` parameter.
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param array $args {
     *     Optional. Default pagination arguments, see paginate_links().
     *
     *     @type string $screen_reader_text Screen reader text for navigation element.
     *                                      Default 'Posts pagination'.
     *     @type string $aria_label         ARIA label text for the nav element. Default 'Posts pagination'.
     *     @type string $class              Custom class for the nav element. Default 'pagination'.
     * }
     * @return string Markup for pagination links.
     * @phpstan-param array{
     *   screen_reader_text?: string,
     *   aria_label?: string,
     *   class?: string,
     *   base?: string,
     *   format?: string,
     *   total?: int,
     *   current?: int,
     *   aria_current?: string,
     *   show_all?: bool,
     *   end_size?: int,
     *   mid_size?: int,
     *   prev_next?: bool,
     *   prev_text?: string,
     *   next_text?: string,
     *   type?: string,
     *   add_args?: array,
     *   add_fragment?: string,
     *   before_page_number?: string,
     *   after_page_number?: string,
     * } $args
     */
    function get_the_posts_pagination($args = array())
    {
    }
    /**
     * Displays a paginated navigation to next/previous set of posts, when applicable.
     *
     * @since 4.1.0
     *
     * @param array $args Optional. See get_the_posts_pagination() for available arguments.
     *                    Default empty array.
     * @phpstan-param array{
     *   screen_reader_text?: string,
     *   aria_label?: string,
     *   class?: string,
     *   base?: string,
     *   format?: string,
     *   total?: int,
     *   current?: int,
     *   aria_current?: string,
     *   show_all?: bool,
     *   end_size?: int,
     *   mid_size?: int,
     *   prev_next?: bool,
     *   prev_text?: string,
     *   next_text?: string,
     *   type?: string,
     *   add_args?: array,
     *   add_fragment?: string,
     *   before_page_number?: string,
     *   after_page_number?: string,
     * } $args See get_the_posts_pagination()
     */
    function the_posts_pagination($args = array())
    {
    }
    /**
     * Wraps passed links in navigational markup.
     *
     * @since 4.1.0
     * @since 5.3.0 Added the `aria_label` parameter.
     * @access private
     *
     * @param string $links              Navigational links.
     * @param string $css_class          Optional. Custom class for the nav element.
     *                                   Default 'posts-navigation'.
     * @param string $screen_reader_text Optional. Screen reader text for the nav element.
     *                                   Default 'Posts navigation'.
     * @param string $aria_label         Optional. ARIA label for the nav element.
     *                                   Defaults to the value of `$screen_reader_text`.
     * @return string Navigation template tag.
     */
    function _navigation_markup($links, $css_class = 'posts-navigation', $screen_reader_text = '', $aria_label = '')
    {
    }
    /**
     * Retrieves the comments page number link.
     *
     * @since 2.7.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param int $pagenum  Optional. Page number. Default 1.
     * @param int $max_page Optional. The maximum number of comment pages. Default 0.
     * @return string The comments page number link URL.
     */
    function get_comments_pagenum_link($pagenum = 1, $max_page = 0)
    {
    }
    /**
     * Retrieves the link to the next comments page.
     *
     * @since 2.7.1
     * @since 6.7.0 Added the `page` parameter.
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string   $label    Optional. Label for link text. Default empty.
     * @param int      $max_page Optional. Max page. Default 0.
     * @param int|null $page     Optional. Page number. Default null.
     * @return string|void HTML-formatted link for the next page of comments.
     */
    function get_next_comments_link($label = '', $max_page = 0, $page = \null)
    {
    }
    /**
     * Displays the link to the next comments page.
     *
     * @since 2.7.0
     *
     * @param string $label    Optional. Label for link text. Default empty.
     * @param int    $max_page Optional. Max page. Default 0.
     */
    function next_comments_link($label = '', $max_page = 0)
    {
    }
    /**
     * Retrieves the link to the previous comments page.
     *
     * @since 2.7.1
     * @since 6.7.0 Added the `page` parameter.
     *
     * @param string   $label Optional. Label for comments link text. Default empty.
     * @param int|null $page  Optional. Page number. Default null.
     * @return string|void HTML-formatted link for the previous page of comments.
     */
    function get_previous_comments_link($label = '', $page = \null)
    {
    }
    /**
     * Displays the link to the previous comments page.
     *
     * @since 2.7.0
     *
     * @param string $label Optional. Label for comments link text. Default empty.
     */
    function previous_comments_link($label = '')
    {
    }
    /**
     * Displays or retrieves pagination links for the comments on the current post.
     *
     * @see paginate_links()
     * @since 2.7.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string|array $args Optional args. See paginate_links(). Default empty array.
     * @return void|string|array Void if 'echo' argument is true and 'type' is not an array,
     *                           or if the query is not for an existing single post of any post type.
     *                           Otherwise, markup for comment page links or array of comment page links,
     *                           depending on 'type' argument.
     * @phpstan-param array{
     *   base?: string,
     *   format?: string,
     *   total?: int,
     *   current?: int,
     *   aria_current?: string,
     *   show_all?: bool,
     *   end_size?: int,
     *   mid_size?: int,
     *   prev_next?: bool,
     *   prev_text?: string,
     *   next_text?: string,
     *   type?: string,
     *   add_args?: array,
     *   add_fragment?: string,
     *   before_page_number?: string,
     *   after_page_number?: string,
     * } $args See paginate_links()
     */
    function paginate_comments_links($args = array())
    {
    }
    /**
     * Retrieves navigation to next/previous set of comments, when applicable.
     *
     * @since 4.4.0
     * @since 5.3.0 Added the `aria_label` parameter.
     * @since 5.5.0 Added the `class` parameter.
     *
     * @param array $args {
     *     Optional. Default comments navigation arguments.
     *
     *     @type string $prev_text          Anchor text to display in the previous comments link.
     *                                      Default 'Older comments'.
     *     @type string $next_text          Anchor text to display in the next comments link.
     *                                      Default 'Newer comments'.
     *     @type string $screen_reader_text Screen reader text for the nav element. Default 'Comments navigation'.
     *     @type string $aria_label         ARIA label text for the nav element. Default 'Comments'.
     *     @type string $class              Custom class for the nav element. Default 'comment-navigation'.
     * }
     * @return string Markup for comments links.
     * @phpstan-param array{
     *   prev_text?: string,
     *   next_text?: string,
     *   screen_reader_text?: string,
     *   aria_label?: string,
     *   class?: string,
     * } $args
     */
    function get_the_comments_navigation($args = array())
    {
    }
    /**
     * Displays navigation to next/previous set of comments, when applicable.
     *
     * @since 4.4.0
     *
     * @param array $args See get_the_comments_navigation() for available arguments. Default empty array.
     * @phpstan-param array{
     *   prev_text?: string,
     *   next_text?: string,
     *   screen_reader_text?: string,
     *   aria_label?: string,
     *   class?: string,
     * } $args See get_the_comments_navigation()
     */
    function the_comments_navigation($args = array())
    {
    }
    /**
     * Retrieves a paginated navigation to next/previous set of comments, when applicable.
     *
     * @since 4.4.0
     * @since 5.3.0 Added the `aria_label` parameter.
     * @since 5.5.0 Added the `class` parameter.
     *
     * @see paginate_comments_links()
     *
     * @param array $args {
     *     Optional. Default pagination arguments.
     *
     *     @type string $screen_reader_text Screen reader text for the nav element. Default 'Comments pagination'.
     *     @type string $aria_label         ARIA label text for the nav element. Default 'Comments pagination'.
     *     @type string $class              Custom class for the nav element. Default 'comments-pagination'.
     * }
     * @return string Markup for pagination links.
     * @phpstan-param array{
     *   screen_reader_text?: string,
     *   aria_label?: string,
     *   class?: string,
     * } $args
     */
    function get_the_comments_pagination($args = array())
    {
    }
    /**
     * Displays a paginated navigation to next/previous set of comments, when applicable.
     *
     * @since 4.4.0
     *
     * @param array $args See get_the_comments_pagination() for available arguments. Default empty array.
     * @phpstan-param array{
     *   screen_reader_text?: string,
     *   aria_label?: string,
     *   class?: string,
     * } $args See get_the_comments_pagination()
     */
    function the_comments_pagination($args = array())
    {
    }
    /**
     * Retrieves the URL for the current site where the front end is accessible.
     *
     * Returns the 'home' option with the appropriate protocol. The protocol will be 'https'
     * if is_ssl() evaluates to true; otherwise, it will be the same as the 'home' option.
     * If `$scheme` is 'http' or 'https', is_ssl() is overridden.
     *
     * @since 3.0.0
     *
     * @param string      $path   Optional. Path relative to the home URL. Default empty.
     * @param string|null $scheme Optional. Scheme to give the home URL context. Accepts
     *                            'http', 'https', 'relative', 'rest', or null. Default null.
     * @return string Home URL link with optional path appended.
     */
    function home_url($path = '', $scheme = \null)
    {
    }
    /**
     * Retrieves the URL for a given site where the front end is accessible.
     *
     * Returns the 'home' option with the appropriate protocol. The protocol will be 'https'
     * if is_ssl() evaluates to true; otherwise, it will be the same as the 'home' option.
     * If `$scheme` is 'http' or 'https', is_ssl() is overridden.
     *
     * @since 3.0.0
     *
     * @param int|null    $blog_id Optional. Site ID. Default null (current site).
     * @param string      $path    Optional. Path relative to the home URL. Default empty.
     * @param string|null $scheme  Optional. Scheme to give the home URL context. Accepts
     *                             'http', 'https', 'relative', 'rest', or null. Default null.
     * @return string Home URL link with optional path appended.
     */
    function get_home_url($blog_id = \null, $path = '', $scheme = \null)
    {
    }
    /**
     * Retrieves the URL for the current site where WordPress application files
     * (e.g. wp-blog-header.php or the wp-admin/ folder) are accessible.
     *
     * Returns the 'site_url' option with the appropriate protocol, 'https' if
     * is_ssl() and 'http' otherwise. If $scheme is 'http' or 'https', is_ssl() is
     * overridden.
     *
     * @since 3.0.0
     *
     * @param string      $path   Optional. Path relative to the site URL. Default empty.
     * @param string|null $scheme Optional. Scheme to give the site URL context. See set_url_scheme().
     * @return string Site URL link with optional path appended.
     */
    function site_url($path = '', $scheme = \null)
    {
    }
    /**
     * Retrieves the URL for a given site where WordPress application files
     * (e.g. wp-blog-header.php or the wp-admin/ folder) are accessible.
     *
     * Returns the 'site_url' option with the appropriate protocol, 'https' if
     * is_ssl() and 'http' otherwise. If `$scheme` is 'http' or 'https',
     * `is_ssl()` is overridden.
     *
     * @since 3.0.0
     *
     * @param int|null    $blog_id Optional. Site ID. Default null (current site).
     * @param string      $path    Optional. Path relative to the site URL. Default empty.
     * @param string|null $scheme  Optional. Scheme to give the site URL context. Accepts
     *                             'http', 'https', 'login', 'login_post', 'admin', or
     *                             'relative'. Default null.
     * @return string Site URL link with optional path appended.
     */
    function get_site_url($blog_id = \null, $path = '', $scheme = \null)
    {
    }
    /**
     * Retrieves the URL to the admin area for the current site.
     *
     * @since 2.6.0
     *
     * @param string $path   Optional. Path relative to the admin URL. Default empty.
     * @param string $scheme The scheme to use. Default is 'admin', which obeys force_ssl_admin() and is_ssl().
     *                       'http' or 'https' can be passed to force those schemes.
     * @return string Admin URL link with optional path appended.
     */
    function admin_url($path = '', $scheme = 'admin')
    {
    }
    /**
     * Retrieves the URL to the admin area for a given site.
     *
     * @since 3.0.0
     *
     * @param int|null $blog_id Optional. Site ID. Default null (current site).
     * @param string   $path    Optional. Path relative to the admin URL. Default empty.
     * @param string   $scheme  Optional. The scheme to use. Accepts 'http' or 'https',
     *                          to force those schemes. Default 'admin', which obeys
     *                          force_ssl_admin() and is_ssl().
     * @return string Admin URL link with optional path appended.
     * @phpstan-param 'http'|'https' $scheme
     */
    function get_admin_url($blog_id = \null, $path = '', $scheme = 'admin')
    {
    }
    /**
     * Retrieves the URL to the includes directory.
     *
     * @since 2.6.0
     *
     * @param string      $path   Optional. Path relative to the includes URL. Default empty.
     * @param string|null $scheme Optional. Scheme to give the includes URL context. Accepts
     *                            'http', 'https', or 'relative'. Default null.
     * @return string Includes URL link with optional path appended.
     */
    function includes_url($path = '', $scheme = \null)
    {
    }
    /**
     * Retrieves the URL to the content directory.
     *
     * @since 2.6.0
     *
     * @param string $path Optional. Path relative to the content URL. Default empty.
     * @return string Content URL link with optional path appended.
     */
    function content_url($path = '')
    {
    }
    /**
     * Retrieves a URL within the plugins or mu-plugins directory.
     *
     * Defaults to the plugins directory URL if no arguments are supplied.
     *
     * @since 2.6.0
     *
     * @param string $path   Optional. Extra path appended to the end of the URL, including
     *                       the relative directory if $plugin is supplied. Default empty.
     * @param string $plugin Optional. A full path to a file inside a plugin or mu-plugin.
     *                       The URL will be relative to its directory. Default empty.
     *                       Typically this is done by passing `__FILE__` as the argument.
     * @return string Plugins URL link with optional paths appended.
     */
    function plugins_url($path = '', $plugin = '')
    {
    }
    /**
     * Retrieves the site URL for the current network.
     *
     * Returns the site URL with the appropriate protocol, 'https' if
     * is_ssl() and 'http' otherwise. If $scheme is 'http' or 'https', is_ssl() is
     * overridden.
     *
     * @since 3.0.0
     *
     * @see set_url_scheme()
     *
     * @param string      $path   Optional. Path relative to the site URL. Default empty.
     * @param string|null $scheme Optional. Scheme to give the site URL context. Accepts
     *                            'http', 'https', or 'relative'. Default null.
     * @return string Site URL link with optional path appended.
     */
    function network_site_url($path = '', $scheme = \null)
    {
    }
    /**
     * Retrieves the home URL for the current network.
     *
     * Returns the home URL with the appropriate protocol, 'https' is_ssl()
     * and 'http' otherwise. If `$scheme` is 'http' or 'https', `is_ssl()` is
     * overridden.
     *
     * @since 3.0.0
     *
     * @param string      $path   Optional. Path relative to the home URL. Default empty.
     * @param string|null $scheme Optional. Scheme to give the home URL context. Accepts
     *                            'http', 'https', or 'relative'. Default null.
     * @return string Home URL link with optional path appended.
     */
    function network_home_url($path = '', $scheme = \null)
    {
    }
    /**
     * Retrieves the URL to the admin area for the network.
     *
     * @since 3.0.0
     *
     * @param string $path   Optional path relative to the admin URL. Default empty.
     * @param string $scheme Optional. The scheme to use. Default is 'admin', which obeys force_ssl_admin()
     *                       and is_ssl(). 'http' or 'https' can be passed to force those schemes.
     * @return string Admin URL link with optional path appended.
     */
    function network_admin_url($path = '', $scheme = 'admin')
    {
    }
    /**
     * Retrieves the URL to the admin area for the current user.
     *
     * @since 3.0.0
     *
     * @param string $path   Optional. Path relative to the admin URL. Default empty.
     * @param string $scheme Optional. The scheme to use. Default is 'admin', which obeys force_ssl_admin()
     *                       and is_ssl(). 'http' or 'https' can be passed to force those schemes.
     * @return string Admin URL link with optional path appended.
     */
    function user_admin_url($path = '', $scheme = 'admin')
    {
    }
    /**
     * Retrieves the URL to the admin area for either the current site or the network depending on context.
     *
     * @since 3.1.0
     *
     * @param string $path   Optional. Path relative to the admin URL. Default empty.
     * @param string $scheme Optional. The scheme to use. Default is 'admin', which obeys force_ssl_admin()
     *                       and is_ssl(). 'http' or 'https' can be passed to force those schemes.
     * @return string Admin URL link with optional path appended.
     */
    function self_admin_url($path = '', $scheme = 'admin')
    {
    }
    /**
     * Sets the scheme for a URL.
     *
     * @since 3.4.0
     * @since 4.4.0 The 'rest' scheme was added.
     *
     * @param string      $url    Absolute URL that includes a scheme
     * @param string|null $scheme Optional. Scheme to give $url. Currently 'http', 'https', 'login',
     *                            'login_post', 'admin', 'relative', 'rest', 'rpc', or null. Default null.
     * @return string URL with chosen scheme.
     */
    function set_url_scheme($url, $scheme = \null)
    {
    }
    /**
     * Retrieves the URL to the user's dashboard.
     *
     * If a user does not belong to any site, the global user dashboard is used. If the user
     * belongs to the current site, the dashboard for the current site is returned. If the user
     * cannot edit the current site, the dashboard to the user's primary site is returned.
     *
     * @since 3.1.0
     *
     * @param int    $user_id Optional. User ID. Defaults to current user.
     * @param string $path    Optional path relative to the dashboard. Use only paths known to
     *                        both site and user admins. Default empty.
     * @param string $scheme  The scheme to use. Default is 'admin', which obeys force_ssl_admin()
     *                        and is_ssl(). 'http' or 'https' can be passed to force those schemes.
     * @return string Dashboard URL link with optional path appended.
     */
    function get_dashboard_url($user_id = 0, $path = '', $scheme = 'admin')
    {
    }
    /**
     * Retrieves the URL to the user's profile editor.
     *
     * @since 3.1.0
     *
     * @param int    $user_id Optional. User ID. Defaults to current user.
     * @param string $scheme  Optional. The scheme to use. Default is 'admin', which obeys force_ssl_admin()
     *                        and is_ssl(). 'http' or 'https' can be passed to force those schemes.
     * @return string Dashboard URL link with optional path appended.
     */
    function get_edit_profile_url($user_id = 0, $scheme = 'admin')
    {
    }
    /**
     * Returns the canonical URL for a post.
     *
     * When the post is the same as the current requested page the function will handle the
     * pagination arguments too.
     *
     * @since 4.6.0
     *
     * @param int|WP_Post $post Optional. Post ID or object. Default is global `$post`.
     * @return string|false The canonical URL. False if the post does not exist
     *                      or has not been published yet.
     */
    function wp_get_canonical_url($post = \null)
    {
    }
    /**
     * Outputs rel=canonical for singular queries.
     *
     * @since 2.9.0
     * @since 4.6.0 Adjusted to use `wp_get_canonical_url()`.
     * @phpstan-return void
     */
    function rel_canonical()
    {
    }
    /**
     * Returns a shortlink for a post, page, attachment, or site.
     *
     * This function exists to provide a shortlink tag that all themes and plugins can target.
     * A plugin must hook in to provide the actual shortlinks. Default shortlink support is
     * limited to providing ?p= style links for posts. Plugins can short-circuit this function
     * via the {@see 'pre_get_shortlink'} filter or filter the output via the {@see 'get_shortlink'}
     * filter.
     *
     * @since 3.0.0
     *
     * @param int    $id          Optional. A post or site ID. Default is 0, which means the current post or site.
     * @param string $context     Optional. Whether the ID is a 'site' ID, 'post' ID, or 'media' ID. If 'post',
     *                            the post_type of the post is consulted. If 'query', the current query is consulted
     *                            to determine the ID and context. Default 'post'.
     * @param bool   $allow_slugs Optional. Whether to allow post slugs in the shortlink. It is up to the plugin how
     *                            and whether to honor this. Default true.
     * @return string A shortlink or an empty string if no shortlink exists for the requested resource or if shortlinks
     *                are not enabled.
     */
    function wp_get_shortlink($id = 0, $context = 'post', $allow_slugs = \true)
    {
    }
    /**
     * Injects rel=shortlink into the head if a shortlink is defined for the current page.
     *
     * Attached to the {@see 'wp_head'} action.
     *
     * @since 3.0.0
     * @phpstan-return void
     */
    function wp_shortlink_wp_head()
    {
    }
    /**
     * Sends a Link: rel=shortlink header if a shortlink is defined for the current page.
     *
     * Attached to the {@see 'wp'} action.
     *
     * @since 3.0.0
     * @phpstan-return void
     */
    function wp_shortlink_header()
    {
    }
    /**
     * Displays the shortlink for a post.
     *
     * Must be called from inside "The Loop"
     *
     * Call like the_shortlink( __( 'Shortlinkage FTW' ) )
     *
     * @since 3.0.0
     *
     * @param string $text   Optional The link text or HTML to be displayed. Defaults to 'This is the short link.'
     * @param string $title  Optional The tooltip for the link. Must be sanitized. Defaults to the sanitized post title.
     * @param string $before Optional HTML to display before the link. Default empty.
     * @param string $after  Optional HTML to display after the link. Default empty.
     */
    function the_shortlink($text = '', $title = '', $before = '', $after = '')
    {
    }
    /**
     * Retrieves the avatar URL.
     *
     * @since 4.2.0
     *
     * @param mixed $id_or_email The avatar to retrieve a URL for. Accepts a user ID, Gravatar MD5 hash,
     *                           user email, WP_User object, WP_Post object, or WP_Comment object.
     * @param array $args {
     *     Optional. Arguments to use instead of the default arguments.
     *
     *     @type int    $size           Height and width of the avatar in pixels. Default 96.
     *     @type string $default        URL for the default image or a default type. Accepts:
     *                                  - '404' (return a 404 instead of a default image)
     *                                  - 'retro' (a 8-bit arcade-style pixelated face)
     *                                  - 'robohash' (a robot)
     *                                  - 'monsterid' (a monster)
     *                                  - 'wavatar' (a cartoon face)
     *                                  - 'identicon' (the "quilt", a geometric pattern)
     *                                  - 'mystery', 'mm', or 'mysteryman' (The Oyster Man)
     *                                  - 'blank' (transparent GIF)
     *                                  - 'gravatar_default' (the Gravatar logo)
     *                                  Default is the value of the 'avatar_default' option,
     *                                  with a fallback of 'mystery'.
     *     @type bool   $force_default  Whether to always show the default image, never the Gravatar.
     *                                  Default false.
     *     @type string $rating         What rating to display avatars up to. Accepts:
     *                                  - 'G' (suitable for all audiences)
     *                                  - 'PG' (possibly offensive, usually for audiences 13 and above)
     *                                  - 'R' (intended for adult audiences above 17)
     *                                  - 'X' (even more mature than above)
     *                                  Default is the value of the 'avatar_rating' option.
     *     @type string $scheme         URL scheme to use. See set_url_scheme() for accepted values.
     *                                  Default null.
     *     @type array  $processed_args When the function returns, the value will be the processed/sanitized $args
     *                                  plus a "found_avatar" guess. Pass as a reference. Default null.
     * }
     * @return string|false The URL of the avatar on success, false on failure.
     * @phpstan-param array{
     *   size?: int,
     *   default?: string,
     *   force_default?: bool,
     *   rating?: string,
     *   scheme?: string,
     *   processed_args?: array,
     * } $args
     */
    function get_avatar_url($id_or_email, $args = \null)
    {
    }
    /**
     * Check if this comment type allows avatars to be retrieved.
     *
     * @since 5.1.0
     *
     * @param string $comment_type Comment type to check.
     * @return bool Whether the comment type is allowed for retrieving avatars.
     */
    function is_avatar_comment_type($comment_type)
    {
    }
    /**
     * Retrieves default data about the avatar.
     *
     * @since 4.2.0
     * @since 6.7.0 Gravatar URLs always use HTTPS.
     *
     * @param mixed $id_or_email The avatar to retrieve. Accepts a user ID, Gravatar MD5 hash,
     *                           user email, WP_User object, WP_Post object, or WP_Comment object.
     * @param array $args {
     *     Optional. Arguments to use instead of the default arguments.
     *
     *     @type int    $size           Height and width of the avatar in pixels. Default 96.
     *     @type int    $height         Display height of the avatar in pixels. Defaults to $size.
     *     @type int    $width          Display width of the avatar in pixels. Defaults to $size.
     *     @type string $default        URL for the default image or a default type. Accepts:
     *                                  - '404' (return a 404 instead of a default image)
     *                                  - 'retro' (a 8-bit arcade-style pixelated face)
     *                                  - 'robohash' (a robot)
     *                                  - 'monsterid' (a monster)
     *                                  - 'wavatar' (a cartoon face)
     *                                  - 'identicon' (the "quilt", a geometric pattern)
     *                                  - 'mystery', 'mm', or 'mysteryman' (The Oyster Man)
     *                                  - 'blank' (transparent GIF)
     *                                  - 'gravatar_default' (the Gravatar logo)
     *                                  Default is the value of the 'avatar_default' option,
     *                                  with a fallback of 'mystery'.
     *     @type bool   $force_default  Whether to always show the default image, never the Gravatar.
     *                                  Default false.
     *     @type string $rating         What rating to display avatars up to. Accepts:
     *                                  - 'G' (suitable for all audiences)
     *                                  - 'PG' (possibly offensive, usually for audiences 13 and above)
     *                                  - 'R' (intended for adult audiences above 17)
     *                                  - 'X' (even more mature than above)
     *                                  Default is the value of the 'avatar_rating' option.
     *     @type string $scheme         URL scheme to use. See set_url_scheme() for accepted values.
     *                                  For Gravatars this setting is ignored and HTTPS is used to avoid
     *                                  unnecessary redirects. The setting is retained for systems using
     *                                  the {@see 'pre_get_avatar_data'} filter to customize avatars.
     *                                  Default null.
     *     @type array  $processed_args When the function returns, the value will be the processed/sanitized $args
     *                                  plus a "found_avatar" guess. Pass as a reference. Default null.
     *     @type string $extra_attr     HTML attributes to insert in the IMG element. Is not sanitized.
     *                                  Default empty.
     * }
     * @return array {
     *     Along with the arguments passed in `$args`, this will contain a couple of extra arguments.
     *
     *     @type bool         $found_avatar True if an avatar was found for this user,
     *                                      false or not set if none was found.
     *     @type string|false $url          The URL of the avatar that was found, or false.
     * }
     * @phpstan-param array{
     *   size?: int,
     *   height?: int,
     *   width?: int,
     *   default?: string,
     *   force_default?: bool,
     *   rating?: string,
     *   scheme?: string,
     *   processed_args?: array,
     *   extra_attr?: string,
     * } $args
     * @phpstan-return array{
     *   found_avatar: bool,
     *   url: string|false,
     * }
     */
    function get_avatar_data($id_or_email, $args = \null)
    {
    }
    /**
     * Retrieves the URL of a file in the theme.
     *
     * Searches in the stylesheet directory before the template directory so themes
     * which inherit from a parent theme can just override one file.
     *
     * @since 4.7.0
     *
     * @param string $file Optional. File to search for in the stylesheet directory.
     * @return string The URL of the file.
     */
    function get_theme_file_uri($file = '')
    {
    }
    /**
     * Retrieves the URL of a file in the parent theme.
     *
     * @since 4.7.0
     *
     * @param string $file Optional. File to return the URL for in the template directory.
     * @return string The URL of the file.
     */
    function get_parent_theme_file_uri($file = '')
    {
    }
    /**
     * Retrieves the path of a file in the theme.
     *
     * Searches in the stylesheet directory before the template directory so themes
     * which inherit from a parent theme can just override one file.
     *
     * @since 4.7.0
     *
     * @param string $file Optional. File to search for in the stylesheet directory.
     * @return string The path of the file.
     */
    function get_theme_file_path($file = '')
    {
    }
    /**
     * Retrieves the path of a file in the parent theme.
     *
     * @since 4.7.0
     *
     * @param string $file Optional. File to return the path for in the template directory.
     * @return string The path of the file.
     */
    function get_parent_theme_file_path($file = '')
    {
    }
    /**
     * Retrieves the URL to the privacy policy page.
     *
     * @since 4.9.6
     *
     * @return string The URL to the privacy policy page. Empty string if it doesn't exist.
     */
    function get_privacy_policy_url()
    {
    }
    /**
     * Displays the privacy policy link with formatting, when applicable.
     *
     * @since 4.9.6
     *
     * @param string $before Optional. Display before privacy policy link. Default empty.
     * @param string $after  Optional. Display after privacy policy link. Default empty.
     */
    function the_privacy_policy_link($before = '', $after = '')
    {
    }
    /**
     * Returns the privacy policy link with formatting, when applicable.
     *
     * @since 4.9.6
     * @since 6.2.0 Added 'privacy-policy' rel attribute.
     *
     * @param string $before Optional. Display before privacy policy link. Default empty.
     * @param string $after  Optional. Display after privacy policy link. Default empty.
     * @return string Markup for the link and surrounding elements. Empty string if it
     *                doesn't exist.
     */
    function get_the_privacy_policy_link($before = '', $after = '')
    {
    }
    /**
     * Returns an array of URL hosts which are considered to be internal hosts.
     *
     * By default the list of internal hosts is comprised of the host name of
     * the site's home_url() (as parsed by wp_parse_url()).
     *
     * This list is used when determining if a specified URL is a link to a page on
     * the site itself or a link offsite (to an external host). This is used, for
     * example, when determining if the "nofollow" attribute should be applied to a
     * link.
     *
     * @see wp_is_internal_link
     *
     * @since 6.2.0
     *
     * @return string[] An array of URL hosts.
     */
    function wp_internal_hosts()
    {
    }
    /**
     * Determines whether or not the specified URL is of a host included in the internal hosts list.
     *
     * @see wp_internal_hosts()
     *
     * @since 6.2.0
     *
     * @param string $link The URL to test.
     * @return bool Returns true for internal URLs and false for all other URLs.
     */
    function wp_is_internal_link($link)
    {
    }
    /**
     * Returns the HTTP protocol sent by the server.
     *
     * @since 4.4.0
     *
     * @return string The HTTP protocol. Default: HTTP/1.0.
     */
    function wp_get_server_protocol()
    {
    }
    /**
     * Fixes `$_SERVER` variables for various setups.
     *
     * @since 3.0.0
     * @access private
     *
     * @global string $PHP_SELF The filename of the currently executing script,
     *                          relative to the document root.
     */
    function wp_fix_server_vars()
    {
    }
    /**
     * Populates the Basic Auth server details from the Authorization header.
     *
     * Some servers running in CGI or FastCGI mode don't pass the Authorization
     * header on to WordPress.  If it's been rewritten to the `HTTP_AUTHORIZATION` header,
     * fill in the proper $_SERVER variables instead.
     *
     * @since 5.6.0
     * @phpstan-return void
     */
    function wp_populate_basic_auth_from_authorization_header()
    {
    }
    /**
     * Checks for the required PHP version, and the mysqli extension or
     * a database drop-in.
     *
     * Dies if requirements are not met.
     *
     * @since 3.0.0
     * @access private
     *
     * @global string $required_php_version The required PHP version string.
     * @global string $wp_version           The WordPress version string.
     */
    function wp_check_php_mysql_versions()
    {
    }
    /**
     * Retrieves the current environment type.
     *
     * The type can be set via the `WP_ENVIRONMENT_TYPE` global system variable,
     * or a constant of the same name.
     *
     * Possible values are 'local', 'development', 'staging', and 'production'.
     * If not set, the type defaults to 'production'.
     *
     * @since 5.5.0
     * @since 5.5.1 Added the 'local' type.
     * @since 5.5.1 Removed the ability to alter the list of types.
     *
     * @return string The current environment type.
     */
    function wp_get_environment_type()
    {
    }
    /**
     * Retrieves the current development mode.
     *
     * The development mode affects how certain parts of the WordPress application behave,
     * which is relevant when developing for WordPress.
     *
     * Development mode can be set via the `WP_DEVELOPMENT_MODE` constant in `wp-config.php`.
     * Possible values are 'core', 'plugin', 'theme', 'all', or an empty string to disable
     * development mode. 'all' is a special value to signify that all three development modes
     * ('core', 'plugin', and 'theme') are enabled.
     *
     * Development mode is considered separately from `WP_DEBUG` and wp_get_environment_type().
     * It does not affect debugging output, but rather functional nuances in WordPress.
     *
     * This function retrieves the currently set development mode value. To check whether
     * a specific development mode is enabled, use wp_is_development_mode().
     *
     * @since 6.3.0
     *
     * @return string The current development mode.
     */
    function wp_get_development_mode()
    {
    }
    /**
     * Checks whether the site is in the given development mode.
     *
     * @since 6.3.0
     *
     * @param string $mode Development mode to check for. Either 'core', 'plugin', 'theme', or 'all'.
     * @return bool True if the given mode is covered by the current development mode, false otherwise.
     * @phpstan-param 'core'|'plugin'|'theme'|'all' $mode
     */
    function wp_is_development_mode($mode)
    {
    }
    /**
     * Ensures all of WordPress is not loaded when handling a favicon.ico request.
     *
     * Instead, send the headers for a zero-length favicon and bail.
     *
     * @since 3.0.0
     * @deprecated 5.4.0 Deprecated in favor of do_favicon().
     */
    function wp_favicon_request()
    {
    }
    /**
     * Dies with a maintenance message when conditions are met.
     *
     * The default message can be replaced by using a drop-in (maintenance.php in
     * the wp-content directory).
     *
     * @since 3.0.0
     * @access private
     * @phpstan-return void
     */
    function wp_maintenance()
    {
    }
    /**
     * Checks if maintenance mode is enabled.
     *
     * Checks for a file in the WordPress root directory named ".maintenance".
     * This file will contain the variable $upgrading, set to the time the file
     * was created. If the file was created less than 10 minutes ago, WordPress
     * is in maintenance mode.
     *
     * @since 5.5.0
     *
     * @global int $upgrading The Unix timestamp marking when upgrading WordPress began.
     *
     * @return bool True if maintenance mode is enabled, false otherwise.
     */
    function wp_is_maintenance_mode()
    {
    }
    /**
     * Gets the time elapsed so far during this PHP script.
     *
     * @since 5.8.0
     *
     * @return float Seconds since the PHP script started.
     */
    function timer_float()
    {
    }
    /**
     * Starts the WordPress micro-timer.
     *
     * @since 0.71
     * @access private
     *
     * @global float $timestart Unix timestamp set at the beginning of the page load.
     * @see timer_stop()
     *
     * @return bool Always returns true.
     */
    function timer_start()
    {
    }
    /**
     * Retrieves or displays the time from the page start to when function is called.
     *
     * @since 0.71
     *
     * @global float   $timestart Seconds from when timer_start() is called.
     * @global float   $timeend   Seconds from when function is called.
     *
     * @param int|bool $display   Whether to echo or return the results. Accepts 0|false for return,
     *                            1|true for echo. Default 0|false.
     * @param int      $precision The number of digits from the right of the decimal to display.
     *                            Default 3.
     * @return string The "second.microsecond" finished time calculation. The number is formatted
     *                for human consumption, both localized and rounded.
     */
    function timer_stop($display = 0, $precision = 3)
    {
    }
    /**
     * Sets PHP error reporting based on WordPress debug settings.
     *
     * Uses three constants: `WP_DEBUG`, `WP_DEBUG_DISPLAY`, and `WP_DEBUG_LOG`.
     * All three can be defined in wp-config.php. By default, `WP_DEBUG` and
     * `WP_DEBUG_LOG` are set to false, and `WP_DEBUG_DISPLAY` is set to true.
     *
     * When `WP_DEBUG` is true, all PHP notices are reported. WordPress will also
     * display internal notices: when a deprecated WordPress function, function
     * argument, or file is used. Deprecated code may be removed from a later
     * version.
     *
     * It is strongly recommended that plugin and theme developers use `WP_DEBUG`
     * in their development environments.
     *
     * `WP_DEBUG_DISPLAY` and `WP_DEBUG_LOG` perform no function unless `WP_DEBUG`
     * is true.
     *
     * When `WP_DEBUG_DISPLAY` is true, WordPress will force errors to be displayed.
     * `WP_DEBUG_DISPLAY` defaults to true. Defining it as null prevents WordPress
     * from changing the global configuration setting. Defining `WP_DEBUG_DISPLAY`
     * as false will force errors to be hidden.
     *
     * When `WP_DEBUG_LOG` is true, errors will be logged to `wp-content/debug.log`.
     * When `WP_DEBUG_LOG` is a valid path, errors will be logged to the specified file.
     *
     * Errors are never displayed for XML-RPC, REST, `ms-files.php`, and Ajax requests.
     *
     * @since 3.0.0
     * @since 5.1.0 `WP_DEBUG_LOG` can be a file path.
     * @access private
     * @phpstan-return void
     */
    function wp_debug_mode()
    {
    }
    /**
     * Sets the location of the language directory.
     *
     * To set directory manually, define the `WP_LANG_DIR` constant
     * in wp-config.php.
     *
     * If the language directory exists within `WP_CONTENT_DIR`, it
     * is used. Otherwise the language directory is assumed to live
     * in `WPINC`.
     *
     * @since 3.0.0
     * @access private
     */
    function wp_set_lang_dir()
    {
    }
    /**
     * Loads the database class file and instantiates the `$wpdb` global.
     *
     * @since 2.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     * @phpstan-return void
     */
    function require_wp_db()
    {
    }
    /**
     * Sets the database table prefix and the format specifiers for database
     * table columns.
     *
     * Columns not listed here default to `%s`.
     *
     * @since 3.0.0
     * @access private
     *
     * @global wpdb   $wpdb         WordPress database abstraction object.
     * @global string $table_prefix The database table prefix.
     */
    function wp_set_wpdb_vars()
    {
    }
    /**
     * Toggles `$_wp_using_ext_object_cache` on and off without directly
     * touching global.
     *
     * @since 3.7.0
     *
     * @global bool $_wp_using_ext_object_cache
     *
     * @param bool $using Whether external object cache is being used.
     * @return bool The current 'using' setting.
     */
    function wp_using_ext_object_cache($using = \null)
    {
    }
    /**
     * Starts the WordPress object cache.
     *
     * If an object-cache.php file exists in the wp-content directory,
     * it uses that drop-in as an external object cache.
     *
     * @since 3.0.0
     * @access private
     *
     * @global array $wp_filter Stores all of the filters.
     */
    function wp_start_object_cache()
    {
    }
    /**
     * Redirects to the installer if WordPress is not installed.
     *
     * Dies with an error message when Multisite is enabled.
     *
     * @since 3.0.0
     * @access private
     * @phpstan-return void
     */
    function wp_not_installed()
    {
    }
    /**
     * Retrieves an array of must-use plugin files.
     *
     * The default directory is wp-content/mu-plugins. To change the default
     * directory manually, define `WPMU_PLUGIN_DIR` and `WPMU_PLUGIN_URL`
     * in wp-config.php.
     *
     * @since 3.0.0
     * @access private
     *
     * @return string[] Array of absolute paths of files to include.
     */
    function wp_get_mu_plugins()
    {
    }
    /**
     * Retrieves an array of active and valid plugin files.
     *
     * While upgrading or installing WordPress, no plugins are returned.
     *
     * The default directory is `wp-content/plugins`. To change the default
     * directory manually, define `WP_PLUGIN_DIR` and `WP_PLUGIN_URL`
     * in `wp-config.php`.
     *
     * @since 3.0.0
     * @access private
     *
     * @return string[] Array of paths to plugin files relative to the plugins directory.
     */
    function wp_get_active_and_valid_plugins()
    {
    }
    /**
     * Filters a given list of plugins, removing any paused plugins from it.
     *
     * @since 5.2.0
     *
     * @global WP_Paused_Extensions_Storage $_paused_plugins
     *
     * @param string[] $plugins Array of absolute plugin main file paths.
     * @return string[] Filtered array of plugins, without any paused plugins.
     */
    function wp_skip_paused_plugins(array $plugins)
    {
    }
    /**
     * Retrieves an array of active and valid themes.
     *
     * While upgrading or installing WordPress, no themes are returned.
     *
     * @since 5.1.0
     * @access private
     *
     * @global string $pagenow            The filename of the current screen.
     * @global string $wp_stylesheet_path Path to current theme's stylesheet directory.
     * @global string $wp_template_path   Path to current theme's template directory.
     *
     * @return string[] Array of absolute paths to theme directories.
     */
    function wp_get_active_and_valid_themes()
    {
    }
    /**
     * Filters a given list of themes, removing any paused themes from it.
     *
     * @since 5.2.0
     *
     * @global WP_Paused_Extensions_Storage $_paused_themes
     *
     * @param string[] $themes Array of absolute theme directory paths.
     * @return string[] Filtered array of absolute paths to themes, without any paused themes.
     */
    function wp_skip_paused_themes(array $themes)
    {
    }
    /**
     * Determines whether WordPress is in Recovery Mode.
     *
     * In this mode, plugins or themes that cause WSODs will be paused.
     *
     * @since 5.2.0
     *
     * @return bool
     */
    function wp_is_recovery_mode()
    {
    }
    /**
     * Determines whether we are currently on an endpoint that should be protected against WSODs.
     *
     * @since 5.2.0
     *
     * @global string $pagenow The filename of the current screen.
     *
     * @return bool True if the current endpoint should be protected.
     */
    function is_protected_endpoint()
    {
    }
    /**
     * Determines whether we are currently handling an Ajax action that should be protected against WSODs.
     *
     * @since 5.2.0
     *
     * @return bool True if the current Ajax action should be protected.
     */
    function is_protected_ajax_action()
    {
    }
    /**
     * Sets internal encoding.
     *
     * In most cases the default internal encoding is latin1, which is
     * of no use, since we want to use the `mb_` functions for `utf-8` strings.
     *
     * @since 3.0.0
     * @access private
     */
    function wp_set_internal_encoding()
    {
    }
    /**
     * Adds magic quotes to `$_GET`, `$_POST`, `$_COOKIE`, and `$_SERVER`.
     *
     * Also forces `$_REQUEST` to be `$_GET + $_POST`. If `$_SERVER`,
     * `$_COOKIE`, or `$_ENV` are needed, use those superglobals directly.
     *
     * @since 3.0.0
     * @access private
     */
    function wp_magic_quotes()
    {
    }
    /**
     * Runs just before PHP shuts down execution.
     *
     * @since 1.2.0
     * @access private
     */
    function shutdown_action_hook()
    {
    }
    /**
     * Clones an object.
     *
     * @since 2.7.0
     * @deprecated 3.2.0
     *
     * @param object $input_object The object to clone.
     * @return object The cloned object.
     */
    function wp_clone($input_object)
    {
    }
    /**
     * Determines whether the current request is for the login screen.
     *
     * @since 6.1.0
     *
     * @see wp_login_url()
     *
     * @return bool True if inside WordPress login screen, false otherwise.
     */
    function is_login()
    {
    }
    /**
     * Determines whether the current request is for an administrative interface page.
     *
     * Does not check if the user is an administrator; use current_user_can()
     * for checking roles and capabilities.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.1
     *
     * @global WP_Screen $current_screen WordPress current screen object.
     *
     * @return bool True if inside WordPress administration interface, false otherwise.
     */
    function is_admin()
    {
    }
    /**
     * Determines whether the current request is for a site's administrative interface.
     *
     * e.g. `/wp-admin/`
     *
     * Does not check if the user is an administrator; use current_user_can()
     * for checking roles and capabilities.
     *
     * @since 3.1.0
     *
     * @global WP_Screen $current_screen WordPress current screen object.
     *
     * @return bool True if inside WordPress site administration pages.
     */
    function is_blog_admin()
    {
    }
    /**
     * Determines whether the current request is for the network administrative interface.
     *
     * e.g. `/wp-admin/network/`
     *
     * Does not check if the user is an administrator; use current_user_can()
     * for checking roles and capabilities.
     *
     * Does not check if the site is a Multisite network; use is_multisite()
     * for checking if Multisite is enabled.
     *
     * @since 3.1.0
     *
     * @global WP_Screen $current_screen WordPress current screen object.
     *
     * @return bool True if inside WordPress network administration pages.
     */
    function is_network_admin()
    {
    }
    /**
     * Determines whether the current request is for a user admin screen.
     *
     * e.g. `/wp-admin/user/`
     *
     * Does not check if the user is an administrator; use current_user_can()
     * for checking roles and capabilities.
     *
     * @since 3.1.0
     *
     * @global WP_Screen $current_screen WordPress current screen object.
     *
     * @return bool True if inside WordPress user administration pages.
     */
    function is_user_admin()
    {
    }
    /**
     * Determines whether Multisite is enabled.
     *
     * @since 3.0.0
     *
     * @return bool True if Multisite is enabled, false otherwise.
     */
    function is_multisite()
    {
    }
    /**
     * Converts a value to non-negative integer.
     *
     * @since 2.5.0
     *
     * @param mixed $maybeint Data you wish to have converted to a non-negative integer.
     * @return int A non-negative integer.
     * @phpstan-template T of int
     * @phpstan-param T|scalar|array|resource|null $maybeint
     * @phpstan-return ($maybeint is T&int<0, max> ? T : ($maybeint is int<min, -1> ? int<1, max> : ($maybeint is empty ? 0 : ($maybeint is numeric-string ? int<0, max> : ($maybeint is string ? 0 : ($maybeint is true|non-empty-array ? 1 : ($maybeint is bool ? 0|1 : int<0, max>)))))))
     */
    function absint($maybeint)
    {
    }
    /**
     * Retrieves the current site ID.
     *
     * @since 3.1.0
     *
     * @global int $blog_id
     *
     * @return int Site ID.
     */
    function get_current_blog_id()
    {
    }
    /**
     * Retrieves the current network ID.
     *
     * @since 4.6.0
     *
     * @return int The ID of the current network.
     */
    function get_current_network_id()
    {
    }
    /**
     * Attempts an early load of translations.
     *
     * Used for errors encountered during the initial loading process, before
     * the locale has been properly detected and loaded.
     *
     * Designed for unusual load sequences (like setup-config.php) or for when
     * the script will then terminate with an error, otherwise there is a risk
     * that a file can be double-included.
     *
     * @since 3.4.0
     * @access private
     *
     * @global WP_Textdomain_Registry $wp_textdomain_registry WordPress Textdomain Registry.
     * @global WP_Locale              $wp_locale              WordPress date and time locale object.
     * @phpstan-return void
     */
    function wp_load_translations_early()
    {
    }
    /**
     * Checks or sets whether WordPress is in "installation" mode.
     *
     * If the `WP_INSTALLING` constant is defined during the bootstrap, `wp_installing()` will default to `true`.
     *
     * @since 4.4.0
     *
     * @param bool $is_installing Optional. True to set WP into Installing mode, false to turn Installing mode off.
     *                            Omit this parameter if you only want to fetch the current status.
     * @return bool True if WP is installing, otherwise false. When a `$is_installing` is passed, the function will
     *              report whether WP was in installing mode prior to the change to `$is_installing`.
     */
    function wp_installing($is_installing = \null)
    {
    }
    /**
     * Determines if SSL is used.
     *
     * @since 2.6.0
     * @since 4.6.0 Moved from functions.php to load.php.
     *
     * @return bool True if SSL, otherwise false.
     */
    function is_ssl()
    {
    }
    /**
     * Converts a shorthand byte value to an integer byte value.
     *
     * @since 2.3.0
     * @since 4.6.0 Moved from media.php to load.php.
     *
     * @link https://www.php.net/manual/en/function.ini-get.php
     * @link https://www.php.net/manual/en/faq.using.php#faq.using.shorthandbytes
     *
     * @param string $value A (PHP ini) byte value, either shorthand or ordinary.
     * @return int An integer byte value.
     */
    function wp_convert_hr_to_bytes($value)
    {
    }
    /**
     * Determines whether a PHP ini value is changeable at runtime.
     *
     * @since 4.6.0
     *
     * @link https://www.php.net/manual/en/function.ini-get-all.php
     *
     * @param string $setting The name of the ini setting to check.
     * @return bool True if the value is changeable at runtime. False otherwise.
     */
    function wp_is_ini_value_changeable($setting)
    {
    }
    /**
     * Determines whether the current request is a WordPress Ajax request.
     *
     * @since 4.7.0
     *
     * @return bool True if it's a WordPress Ajax request, false otherwise.
     */
    function wp_doing_ajax()
    {
    }
    /**
     * Determines whether the current request should use themes.
     *
     * @since 5.1.0
     *
     * @return bool True if themes should be used, false otherwise.
     */
    function wp_using_themes()
    {
    }
    /**
     * Determines whether the current request is a WordPress cron request.
     *
     * @since 4.8.0
     *
     * @return bool True if it's a WordPress cron request, false otherwise.
     */
    function wp_doing_cron()
    {
    }
    /**
     * Checks whether the given variable is a WordPress Error.
     *
     * Returns whether `$thing` is an instance of the `WP_Error` class.
     *
     * @since 2.1.0
     *
     * @param mixed $thing The variable to check.
     * @return bool Whether the variable is an instance of WP_Error.
     * @phpstan-assert-if-true \WP_Error $thing
     * @phpstan-return ($thing is \WP_Error ? true : false)
     */
    function is_wp_error($thing)
    {
    }
    /**
     * Determines whether file modifications are allowed.
     *
     * @since 4.8.0
     *
     * @param string $context The usage context.
     * @return bool True if file modification is allowed, false otherwise.
     */
    function wp_is_file_mod_allowed($context)
    {
    }
    /**
     * Starts scraping edited file errors.
     *
     * @since 4.9.0
     * @phpstan-return void
     */
    function wp_start_scraping_edited_file_errors()
    {
    }
    /**
     * Finalizes scraping for edited file errors.
     *
     * @since 4.9.0
     *
     * @param string $scrape_key Scrape key.
     */
    function wp_finalize_scraping_edited_file_errors($scrape_key)
    {
    }
    /**
     * Checks whether current request is a JSON request, or is expecting a JSON response.
     *
     * @since 5.0.0
     *
     * @return bool True if `Accepts` or `Content-Type` headers contain `application/json`.
     *              False otherwise.
     */
    function wp_is_json_request()
    {
    }
    /**
     * Checks whether current request is a JSONP request, or is expecting a JSONP response.
     *
     * @since 5.2.0
     *
     * @return bool True if JSONP request, false otherwise.
     */
    function wp_is_jsonp_request()
    {
    }
    /**
     * Checks whether a string is a valid JSON Media Type.
     *
     * @since 5.6.0
     *
     * @param string $media_type A Media Type string to check.
     * @return bool True if string is a valid JSON Media Type.
     */
    function wp_is_json_media_type($media_type)
    {
    }
    /**
     * Checks whether current request is an XML request, or is expecting an XML response.
     *
     * @since 5.2.0
     *
     * @return bool True if `Accepts` or `Content-Type` headers contain `text/xml`
     *              or one of the related MIME types. False otherwise.
     */
    function wp_is_xml_request()
    {
    }
    /**
     * Checks if this site is protected by HTTP Basic Auth.
     *
     * At the moment, this merely checks for the present of Basic Auth credentials. Therefore, calling
     * this function with a context different from the current context may give inaccurate results.
     * In a future release, this evaluation may be made more robust.
     *
     * Currently, this is only used by Application Passwords to prevent a conflict since it also utilizes
     * Basic Auth.
     *
     * @since 5.6.1
     *
     * @global string $pagenow The filename of the current screen.
     *
     * @param string $context The context to check for protection. Accepts 'login', 'admin', and 'front'.
     *                        Defaults to the current context.
     * @return bool Whether the site is protected by Basic Auth.
     * @phpstan-param 'login'|'admin'|'front' $context
     */
    function wp_is_site_protected_by_basic_auth($context = '')
    {
    }
    /**
     * Outputs the markup for an audio tag to be used in an Underscore template
     * when data.model is passed.
     *
     * @since 3.9.0
     */
    function wp_underscore_audio_template()
    {
    }
    /**
     * Outputs the markup for a video tag to be used in an Underscore template
     * when data.model is passed.
     *
     * @since 3.9.0
     */
    function wp_underscore_video_template()
    {
    }
    /**
     * Prints the templates used in the media manager.
     *
     * @since 3.5.0
     */
    function wp_print_media_templates()
    {
    }
    /**
     * Retrieves additional image sizes.
     *
     * @since 4.7.0
     *
     * @global array $_wp_additional_image_sizes
     *
     * @return array Additional images size data.
     */
    function wp_get_additional_image_sizes()
    {
    }
    /**
     * Scales down the default size of an image.
     *
     * This is so that the image is a better fit for the editor and theme.
     *
     * The `$size` parameter accepts either an array or a string. The supported string
     * values are 'thumb' or 'thumbnail' for the given thumbnail size or defaults at
     * 128 width and 96 height in pixels. Also supported for the string value is
     * 'medium', 'medium_large' and 'full'. The 'full' isn't actually supported, but any value other
     * than the supported will result in the content_width size or 500 if that is
     * not set.
     *
     * Finally, there is a filter named {@see 'editor_max_image_size'}, that will be
     * called on the calculated array for width and height, respectively.
     *
     * @since 2.5.0
     *
     * @global int $content_width
     *
     * @param int          $width   Width of the image in pixels.
     * @param int          $height  Height of the image in pixels.
     * @param string|int[] $size    Optional. Image size. Accepts any registered image size name, or an array
     *                              of width and height values in pixels (in that order). Default 'medium'.
     * @param string       $context Optional. Could be 'display' (like in a theme) or 'edit'
     *                              (like inserting into an editor). Default null.
     * @return int[] {
     *     An array of width and height values.
     *
     *     @type int $0 The maximum width in pixels.
     *     @type int $1 The maximum height in pixels.
     * }
     * @phpstan-return array{
     *   0: int,
     *   1: int,
     * }
     */
    function image_constrain_size_for_editor($width, $height, $size = 'medium', $context = \null)
    {
    }
    /**
     * Retrieves width and height attributes using given width and height values.
     *
     * Both attributes are required in the sense that both parameters must have a
     * value, but are optional in that if you set them to false or null, then they
     * will not be added to the returned string.
     *
     * You can set the value using a string, but it will only take numeric values.
     * If you wish to put 'px' after the numbers, then it will be stripped out of
     * the return.
     *
     * @since 2.5.0
     *
     * @param int|string $width  Image width in pixels.
     * @param int|string $height Image height in pixels.
     * @return string HTML attributes for width and, or height.
     */
    function image_hwstring($width, $height)
    {
    }
    /**
     * Scales an image to fit a particular size (such as 'thumb' or 'medium').
     *
     * The URL might be the original image, or it might be a resized version. This
     * function won't create a new resized copy, it will just return an already
     * resized one if it exists.
     *
     * A plugin may use the {@see 'image_downsize'} filter to hook into and offer image
     * resizing services for images. The hook must return an array with the same
     * elements that are normally returned from the function.
     *
     * @since 2.5.0
     *
     * @param int          $id   Attachment ID for image.
     * @param string|int[] $size Optional. Image size. Accepts any registered image size name, or an array
     *                           of width and height values in pixels (in that order). Default 'medium'.
     * @return array|false {
     *     Array of image data, or boolean false if no image is available.
     *
     *     @type string $0 Image source URL.
     *     @type int    $1 Image width in pixels.
     *     @type int    $2 Image height in pixels.
     *     @type bool   $3 Whether the image is a resized image.
     * }
     * @phpstan-return false|array{
     *   0: string,
     *   1: int,
     *   2: int,
     *   3: bool,
     * }
     */
    function image_downsize($id, $size = 'medium')
    {
    }
    /**
     * Registers a new image size.
     *
     * @since 2.9.0
     *
     * @global array $_wp_additional_image_sizes Associative array of additional image sizes.
     *
     * @param string     $name   Image size identifier.
     * @param int        $width  Optional. Image width in pixels. Default 0.
     * @param int        $height Optional. Image height in pixels. Default 0.
     * @param bool|array $crop   {
     *     Optional. Image cropping behavior. If false, the image will be scaled (default).
     *     If true, image will be cropped to the specified dimensions using center positions.
     *     If an array, the image will be cropped using the array to specify the crop location:
     *
     *     @type string $0 The x crop position. Accepts 'left' 'center', or 'right'.
     *     @type string $1 The y crop position. Accepts 'top', 'center', or 'bottom'.
     * }
     * @phpstan-param bool|array{
     *   0: string,
     *   1: string,
     * } $crop
     */
    function add_image_size($name, $width = 0, $height = 0, $crop = \false)
    {
    }
    /**
     * Checks if an image size exists.
     *
     * @since 3.9.0
     *
     * @param string $name The image size to check.
     * @return bool True if the image size exists, false if not.
     */
    function has_image_size($name)
    {
    }
    /**
     * Removes a new image size.
     *
     * @since 3.9.0
     *
     * @global array $_wp_additional_image_sizes
     *
     * @param string $name The image size to remove.
     * @return bool True if the image size was successfully removed, false on failure.
     */
    function remove_image_size($name)
    {
    }
    /**
     * Registers an image size for the post thumbnail.
     *
     * @since 2.9.0
     *
     * @see add_image_size() for details on cropping behavior.
     *
     * @param int        $width  Image width in pixels.
     * @param int        $height Image height in pixels.
     * @param bool|array $crop   {
     *     Optional. Image cropping behavior. If false, the image will be scaled (default).
     *     If true, image will be cropped to the specified dimensions using center positions.
     *     If an array, the image will be cropped using the array to specify the crop location:
     *
     *     @type string $0 The x crop position. Accepts 'left' 'center', or 'right'.
     *     @type string $1 The y crop position. Accepts 'top', 'center', or 'bottom'.
     * }
     * @phpstan-param bool|array{
     *   0: string,
     *   1: string,
     * } $crop
     */
    function set_post_thumbnail_size($width = 0, $height = 0, $crop = \false)
    {
    }
    /**
     * Gets an img tag for an image attachment, scaling it down if requested.
     *
     * The {@see 'get_image_tag_class'} filter allows for changing the class name for the
     * image without having to use regular expressions on the HTML content. The
     * parameters are: what WordPress will use for the class, the Attachment ID,
     * image align value, and the size the image should be.
     *
     * The second filter, {@see 'get_image_tag'}, has the HTML content, which can then be
     * further manipulated by a plugin to change all attribute values and even HTML
     * content.
     *
     * @since 2.5.0
     *
     * @param int          $id    Attachment ID.
     * @param string       $alt   Image description for the alt attribute.
     * @param string       $title Image description for the title attribute.
     * @param string       $align Part of the class name for aligning the image.
     * @param string|int[] $size  Optional. Image size. Accepts any registered image size name, or an array of
     *                            width and height values in pixels (in that order). Default 'medium'.
     * @return string HTML IMG element for given image attachment.
     */
    function get_image_tag($id, $alt, $title, $align, $size = 'medium')
    {
    }
    /**
     * Calculates the new dimensions for a down-sampled image.
     *
     * If either width or height are empty, no constraint is applied on
     * that dimension.
     *
     * @since 2.5.0
     *
     * @param int $current_width  Current width of the image.
     * @param int $current_height Current height of the image.
     * @param int $max_width      Optional. Max width in pixels to constrain to. Default 0.
     * @param int $max_height     Optional. Max height in pixels to constrain to. Default 0.
     * @return int[] {
     *     An array of width and height values.
     *
     *     @type int $0 The width in pixels.
     *     @type int $1 The height in pixels.
     * }
     * @phpstan-return array{
     *   0: int,
     *   1: int,
     * }
     */
    function wp_constrain_dimensions($current_width, $current_height, $max_width = 0, $max_height = 0)
    {
    }
    /**
     * Retrieves calculated resize dimensions for use in WP_Image_Editor.
     *
     * Calculates dimensions and coordinates for a resized image that fits
     * within a specified width and height.
     *
     * @since 2.5.0
     *
     * @param int        $orig_w Original width in pixels.
     * @param int        $orig_h Original height in pixels.
     * @param int        $dest_w New width in pixels.
     * @param int        $dest_h New height in pixels.
     * @param bool|array $crop   {
     *     Optional. Image cropping behavior. If false, the image will be scaled (default).
     *     If true, image will be cropped to the specified dimensions using center positions.
     *     If an array, the image will be cropped using the array to specify the crop location:
     *
     *     @type string $0 The x crop position. Accepts 'left' 'center', or 'right'.
     *     @type string $1 The y crop position. Accepts 'top', 'center', or 'bottom'.
     * }
     * @return array|false Returned array matches parameters for `imagecopyresampled()`. False on failure.
     * @phpstan-param bool|array{
     *   0: string,
     *   1: string,
     * } $crop
     */
    function image_resize_dimensions($orig_w, $orig_h, $dest_w, $dest_h, $crop = \false)
    {
    }
    /**
     * Resizes an image to make a thumbnail or intermediate size.
     *
     * The returned array has the file size, the image width, and image height. The
     * {@see 'image_make_intermediate_size'} filter can be used to hook in and change the
     * values of the returned array. The only parameter is the resized file path.
     *
     * @since 2.5.0
     *
     * @param string     $file   File path.
     * @param int        $width  Image width.
     * @param int        $height Image height.
     * @param bool|array $crop   {
     *     Optional. Image cropping behavior. If false, the image will be scaled (default).
     *     If true, image will be cropped to the specified dimensions using center positions.
     *     If an array, the image will be cropped using the array to specify the crop location:
     *
     *     @type string $0 The x crop position. Accepts 'left' 'center', or 'right'.
     *     @type string $1 The y crop position. Accepts 'top', 'center', or 'bottom'.
     * }
     * @return array|false Metadata array on success. False if no image was created.
     * @phpstan-param bool|array{
     *   0: string,
     *   1: string,
     * } $crop
     */
    function image_make_intermediate_size($file, $width, $height, $crop = \false)
    {
    }
    /**
     * Helper function to test if aspect ratios for two images match.
     *
     * @since 4.6.0
     *
     * @param int $source_width  Width of the first image in pixels.
     * @param int $source_height Height of the first image in pixels.
     * @param int $target_width  Width of the second image in pixels.
     * @param int $target_height Height of the second image in pixels.
     * @return bool True if aspect ratios match within 1px. False if not.
     */
    function wp_image_matches_ratio($source_width, $source_height, $target_width, $target_height)
    {
    }
    /**
     * Retrieves the image's intermediate size (resized) path, width, and height.
     *
     * The $size parameter can be an array with the width and height respectively.
     * If the size matches the 'sizes' metadata array for width and height, then it
     * will be used. If there is no direct match, then the nearest image size larger
     * than the specified size will be used. If nothing is found, then the function
     * will break out and return false.
     *
     * The metadata 'sizes' is used for compatible sizes that can be used for the
     * parameter $size value.
     *
     * The url path will be given, when the $size parameter is a string.
     *
     * If you are passing an array for the $size, you should consider using
     * add_image_size() so that a cropped version is generated. It's much more
     * efficient than having to find the closest-sized image and then having the
     * browser scale down the image.
     *
     * @since 2.5.0
     *
     * @param int          $post_id Attachment ID.
     * @param string|int[] $size    Optional. Image size. Accepts any registered image size name, or an array
     *                              of width and height values in pixels (in that order). Default 'thumbnail'.
     * @return array|false {
     *     Array of file relative path, width, and height on success. Additionally includes absolute
     *     path and URL if registered size is passed to `$size` parameter. False on failure.
     *
     *     @type string $file   Filename of image.
     *     @type int    $width  Width of image in pixels.
     *     @type int    $height Height of image in pixels.
     *     @type string $path   Path of image relative to uploads directory.
     *     @type string $url    URL of image.
     * }
     * @phpstan-return false|array{
     *   file: string,
     *   width: int,
     *   height: int,
     *   path: string,
     *   url: string,
     * }
     */
    function image_get_intermediate_size($post_id, $size = 'thumbnail')
    {
    }
    /**
     * Gets the available intermediate image size names.
     *
     * @since 3.0.0
     *
     * @return string[] An array of image size names.
     */
    function get_intermediate_image_sizes()
    {
    }
    /**
     * Returns a normalized list of all currently registered image sub-sizes.
     *
     * @since 5.3.0
     * @uses wp_get_additional_image_sizes()
     * @uses get_intermediate_image_sizes()
     *
     * @return array[] Associative array of arrays of image sub-size information,
     *                 keyed by image size name.
     */
    function wp_get_registered_image_subsizes()
    {
    }
    /**
     * Retrieves an image to represent an attachment.
     *
     * @since 2.5.0
     *
     * @param int          $attachment_id Image attachment ID.
     * @param string|int[] $size          Optional. Image size. Accepts any registered image size name, or an array of
     *                                    width and height values in pixels (in that order). Default 'thumbnail'.
     * @param bool         $icon          Optional. Whether the image should fall back to a mime type icon. Default false.
     * @return array|false {
     *     Array of image data, or boolean false if no image is available.
     *
     *     @type string $0 Image source URL.
     *     @type int    $1 Image width in pixels.
     *     @type int    $2 Image height in pixels.
     *     @type bool   $3 Whether the image is a resized image.
     * }
     * @phpstan-return false|array{
     *   0: string,
     *   1: int,
     *   2: int,
     *   3: bool,
     * }
     */
    function wp_get_attachment_image_src($attachment_id, $size = 'thumbnail', $icon = \false)
    {
    }
    /**
     * Gets an HTML img element representing an image attachment.
     *
     * While `$size` will accept an array, it is better to register a size with
     * add_image_size() so that a cropped version is generated. It's much more
     * efficient than having to find the closest-sized image and then having the
     * browser scale down the image.
     *
     * @since 2.5.0
     * @since 4.4.0 The `$srcset` and `$sizes` attributes were added.
     * @since 5.5.0 The `$loading` attribute was added.
     * @since 6.1.0 The `$decoding` attribute was added.
     *
     * @param int          $attachment_id Image attachment ID.
     * @param string|int[] $size          Optional. Image size. Accepts any registered image size name, or an array
     *                                    of width and height values in pixels (in that order). Default 'thumbnail'.
     * @param bool         $icon          Optional. Whether the image should be treated as an icon. Default false.
     * @param string|array $attr {
     *     Optional. Attributes for the image markup.
     *
     *     @type string       $src           Image attachment URL.
     *     @type string       $class         CSS class name or space-separated list of classes.
     *                                       Default `attachment-$size_class size-$size_class`,
     *                                       where `$size_class` is the image size being requested.
     *     @type string       $alt           Image description for the alt attribute.
     *     @type string       $srcset        The 'srcset' attribute value.
     *     @type string       $sizes         The 'sizes' attribute value.
     *     @type string|false $loading       The 'loading' attribute value. Passing a value of false
     *                                       will result in the attribute being omitted for the image.
     *                                       Default determined by {@see wp_get_loading_optimization_attributes()}.
     *     @type string       $decoding      The 'decoding' attribute value. Possible values are
     *                                       'async' (default), 'sync', or 'auto'. Passing false or an empty
     *                                       string will result in the attribute being omitted.
     *     @type string       $fetchpriority The 'fetchpriority' attribute value, whether `high`, `low`, or `auto`.
     *                                       Default determined by {@see wp_get_loading_optimization_attributes()}.
     * }
     * @return string HTML img element or empty string on failure.
     * @phpstan-param array{
     *   src?: string,
     *   class?: string,
     *   alt?: string,
     *   srcset?: string,
     *   sizes?: string,
     *   loading?: string|false,
     *   decoding?: string,
     *   fetchpriority?: string,
     * } $attr
     */
    function wp_get_attachment_image($attachment_id, $size = 'thumbnail', $icon = \false, $attr = '')
    {
    }
    /**
     * Gets the URL of an image attachment.
     *
     * @since 4.4.0
     *
     * @param int          $attachment_id Image attachment ID.
     * @param string|int[] $size          Optional. Image size. Accepts any registered image size name, or an array of
     *                                    width and height values in pixels (in that order). Default 'thumbnail'.
     * @param bool         $icon          Optional. Whether the image should be treated as an icon. Default false.
     * @return string|false Attachment URL or false if no image is available. If `$size` does not match
     *                      any registered image size, the original image URL will be returned.
     */
    function wp_get_attachment_image_url($attachment_id, $size = 'thumbnail', $icon = \false)
    {
    }
    /**
     * Gets the attachment path relative to the upload directory.
     *
     * @since 4.4.1
     * @access private
     *
     * @param string $file Attachment file name.
     * @return string Attachment path relative to the upload directory.
     */
    function _wp_get_attachment_relative_path($file)
    {
    }
    /**
     * Gets the image size as array from its meta data.
     *
     * Used for responsive images.
     *
     * @since 4.4.0
     * @access private
     *
     * @param string $size_name  Image size. Accepts any registered image size name.
     * @param array  $image_meta The image meta data.
     * @return array|false {
     *     Array of width and height or false if the size isn't present in the meta data.
     *
     *     @type int $0 Image width.
     *     @type int $1 Image height.
     * }
     * @phpstan-return false|array{
     *   0: int,
     *   1: int,
     * }
     */
    function _wp_get_image_size_from_meta($size_name, $image_meta)
    {
    }
    /**
     * Retrieves the value for an image attachment's 'srcset' attribute.
     *
     * @since 4.4.0
     *
     * @see wp_calculate_image_srcset()
     *
     * @param int          $attachment_id Image attachment ID.
     * @param string|int[] $size          Optional. Image size. Accepts any registered image size name, or an array of
     *                                    width and height values in pixels (in that order). Default 'medium'.
     * @param array|null   $image_meta    Optional. The image meta data as returned by 'wp_get_attachment_metadata()'.
     *                                    Default null.
     * @return string|false A 'srcset' value string or false.
     */
    function wp_get_attachment_image_srcset($attachment_id, $size = 'medium', $image_meta = \null)
    {
    }
    /**
     * A helper function to calculate the image sources to include in a 'srcset' attribute.
     *
     * @since 4.4.0
     *
     * @param int[]  $size_array    {
     *     An array of width and height values.
     *
     *     @type int $0 The width in pixels.
     *     @type int $1 The height in pixels.
     * }
     * @param string $image_src     The 'src' of the image.
     * @param array  $image_meta    The image meta data as returned by 'wp_get_attachment_metadata()'.
     * @param int    $attachment_id Optional. The image attachment ID. Default 0.
     * @return string|false The 'srcset' attribute value. False on error or when only one source exists.
     * @phpstan-param array{
     *   0: int,
     *   1: int,
     * } $size_array
     */
    function wp_calculate_image_srcset($size_array, $image_src, $image_meta, $attachment_id = 0)
    {
    }
    /**
     * Retrieves the value for an image attachment's 'sizes' attribute.
     *
     * @since 4.4.0
     *
     * @see wp_calculate_image_sizes()
     *
     * @param int          $attachment_id Image attachment ID.
     * @param string|int[] $size          Optional. Image size. Accepts any registered image size name, or an array of
     *                                    width and height values in pixels (in that order). Default 'medium'.
     * @param array|null   $image_meta    Optional. The image meta data as returned by 'wp_get_attachment_metadata()'.
     *                                    Default null.
     * @return string|false A valid source size value for use in a 'sizes' attribute or false.
     */
    function wp_get_attachment_image_sizes($attachment_id, $size = 'medium', $image_meta = \null)
    {
    }
    /**
     * Creates a 'sizes' attribute value for an image.
     *
     * @since 4.4.0
     *
     * @param string|int[] $size          Image size. Accepts any registered image size name, or an array of
     *                                    width and height values in pixels (in that order).
     * @param string|null  $image_src     Optional. The URL to the image file. Default null.
     * @param array|null   $image_meta    Optional. The image meta data as returned by 'wp_get_attachment_metadata()'.
     *                                    Default null.
     * @param int          $attachment_id Optional. Image attachment ID. Either `$image_meta` or `$attachment_id`
     *                                    is needed when using the image size name as argument for `$size`. Default 0.
     * @return string|false A valid source size value for use in a 'sizes' attribute or false.
     */
    function wp_calculate_image_sizes($size, $image_src = \null, $image_meta = \null, $attachment_id = 0)
    {
    }
    /**
     * Determines if the image meta data is for the image source file.
     *
     * The image meta data is retrieved by attachment post ID. In some cases the post IDs may change.
     * For example when the website is exported and imported at another website. Then the
     * attachment post IDs that are in post_content for the exported website may not match
     * the same attachments at the new website.
     *
     * @since 5.5.0
     *
     * @param string $image_location The full path or URI to the image file.
     * @param array  $image_meta     The attachment meta data as returned by 'wp_get_attachment_metadata()'.
     * @param int    $attachment_id  Optional. The image attachment ID. Default 0.
     * @return bool Whether the image meta is for this image file.
     */
    function wp_image_file_matches_image_meta($image_location, $image_meta, $attachment_id = 0)
    {
    }
    /**
     * Determines an image's width and height dimensions based on the source file.
     *
     * @since 5.5.0
     *
     * @param string $image_src     The image source file.
     * @param array  $image_meta    The image meta data as returned by 'wp_get_attachment_metadata()'.
     * @param int    $attachment_id Optional. The image attachment ID. Default 0.
     * @return array|false Array with first element being the width and second element being the height,
     *                     or false if dimensions cannot be determined.
     */
    function wp_image_src_get_dimensions($image_src, $image_meta, $attachment_id = 0)
    {
    }
    /**
     * Adds 'srcset' and 'sizes' attributes to an existing 'img' element.
     *
     * @since 4.4.0
     *
     * @see wp_calculate_image_srcset()
     * @see wp_calculate_image_sizes()
     *
     * @param string $image         An HTML 'img' element to be filtered.
     * @param array  $image_meta    The image meta data as returned by 'wp_get_attachment_metadata()'.
     * @param int    $attachment_id Image attachment ID.
     * @return string Converted 'img' element with 'srcset' and 'sizes' attributes added.
     */
    function wp_image_add_srcset_and_sizes($image, $image_meta, $attachment_id)
    {
    }
    /**
     * Determines whether to add the `loading` attribute to the specified tag in the specified context.
     *
     * @since 5.5.0
     * @since 5.7.0 Now returns `true` by default for `iframe` tags.
     *
     * @param string $tag_name The tag name.
     * @param string $context  Additional context, like the current filter name
     *                         or the function name from where this was called.
     * @return bool Whether to add the attribute.
     */
    function wp_lazy_loading_enabled($tag_name, $context)
    {
    }
    /**
     * Filters specific tags in post content and modifies their markup.
     *
     * Modifies HTML tags in post content to include new browser and HTML technologies
     * that may not have existed at the time of post creation. These modifications currently
     * include adding `srcset`, `sizes`, and `loading` attributes to `img` HTML tags, as well
     * as adding `loading` attributes to `iframe` HTML tags.
     * Future similar optimizations should be added/expected here.
     *
     * @since 5.5.0
     * @since 5.7.0 Now supports adding `loading` attributes to `iframe` tags.
     *
     * @see wp_img_tag_add_width_and_height_attr()
     * @see wp_img_tag_add_srcset_and_sizes_attr()
     * @see wp_img_tag_add_loading_optimization_attrs()
     * @see wp_iframe_tag_add_loading_attr()
     *
     * @param string $content The HTML content to be filtered.
     * @param string $context Optional. Additional context to pass to the filters.
     *                        Defaults to `current_filter()` when not set.
     * @return string Converted content with images modified.
     */
    function wp_filter_content_tags($content, $context = \null)
    {
    }
    /**
     * Adds 'auto' to the sizes attribute to the image, if the image is lazy loaded and does not already include it.
     *
     * @since 6.7.0
     *
     * @param string $image The image tag markup being filtered.
     * @return string The filtered image tag markup.
     */
    function wp_img_tag_add_auto_sizes(string $image) : string
    {
    }
    /**
     * Checks whether the given 'sizes' attribute includes the 'auto' keyword as the first item in the list.
     *
     * Per the HTML spec, if present it must be the first entry.
     *
     * @since 6.7.0
     *
     * @param string $sizes_attr The 'sizes' attribute value.
     * @return bool True if the 'auto' keyword is present, false otherwise.
     */
    function wp_sizes_attribute_includes_valid_auto(string $sizes_attr) : bool
    {
    }
    /**
     * Prints a CSS rule to fix potential visual issues with images using `sizes=auto`.
     *
     * This rule overrides the similar rule in the default user agent stylesheet, to avoid images that use e.g.
     * `width: auto` or `width: fit-content` to appear smaller.
     *
     * @since 6.7.1
     * @see https://html.spec.whatwg.org/multipage/rendering.html#img-contain-size
     * @see https://core.trac.wordpress.org/ticket/62413
     * @phpstan-return void
     */
    function wp_print_auto_sizes_contain_css_fix()
    {
    }
    /**
     * Adds optimization attributes to an `img` HTML tag.
     *
     * @since 6.3.0
     *
     * @param string $image   The HTML `img` tag where the attribute should be added.
     * @param string $context Additional context to pass to the filters.
     * @return string Converted `img` tag with optimization attributes added.
     */
    function wp_img_tag_add_loading_optimization_attrs($image, $context)
    {
    }
    /**
     * Adds `width` and `height` attributes to an `img` HTML tag.
     *
     * @since 5.5.0
     *
     * @param string $image         The HTML `img` tag where the attribute should be added.
     * @param string $context       Additional context to pass to the filters.
     * @param int    $attachment_id Image attachment ID.
     * @return string Converted 'img' element with 'width' and 'height' attributes added.
     */
    function wp_img_tag_add_width_and_height_attr($image, $context, $attachment_id)
    {
    }
    /**
     * Adds `srcset` and `sizes` attributes to an existing `img` HTML tag.
     *
     * @since 5.5.0
     *
     * @param string $image         The HTML `img` tag where the attribute should be added.
     * @param string $context       Additional context to pass to the filters.
     * @param int    $attachment_id Image attachment ID.
     * @return string Converted 'img' element with 'loading' attribute added.
     */
    function wp_img_tag_add_srcset_and_sizes_attr($image, $context, $attachment_id)
    {
    }
    /**
     * Adds `loading` attribute to an `iframe` HTML tag.
     *
     * @since 5.7.0
     *
     * @param string $iframe  The HTML `iframe` tag where the attribute should be added.
     * @param string $context Additional context to pass to the filters.
     * @return string Converted `iframe` tag with `loading` attribute added.
     */
    function wp_iframe_tag_add_loading_attr($iframe, $context)
    {
    }
    /**
     * Adds a 'wp-post-image' class to post thumbnails. Internal use only.
     *
     * Uses the {@see 'begin_fetch_post_thumbnail_html'} and {@see 'end_fetch_post_thumbnail_html'}
     * action hooks to dynamically add/remove itself so as to only filter post thumbnails.
     *
     * @ignore
     * @since 2.9.0
     *
     * @param string[] $attr Array of thumbnail attributes including src, class, alt, title, keyed by attribute name.
     * @return string[] Modified array of attributes including the new 'wp-post-image' class.
     */
    function _wp_post_thumbnail_class_filter($attr)
    {
    }
    /**
     * Adds '_wp_post_thumbnail_class_filter' callback to the 'wp_get_attachment_image_attributes'
     * filter hook. Internal use only.
     *
     * @ignore
     * @since 2.9.0
     *
     * @param string[] $attr Array of thumbnail attributes including src, class, alt, title, keyed by attribute name.
     */
    function _wp_post_thumbnail_class_filter_add($attr)
    {
    }
    /**
     * Removes the '_wp_post_thumbnail_class_filter' callback from the 'wp_get_attachment_image_attributes'
     * filter hook. Internal use only.
     *
     * @ignore
     * @since 2.9.0
     *
     * @param string[] $attr Array of thumbnail attributes including src, class, alt, title, keyed by attribute name.
     */
    function _wp_post_thumbnail_class_filter_remove($attr)
    {
    }
    /**
     * Overrides the context used in {@see wp_get_attachment_image()}. Internal use only.
     *
     * Uses the {@see 'begin_fetch_post_thumbnail_html'} and {@see 'end_fetch_post_thumbnail_html'}
     * action hooks to dynamically add/remove itself so as to only filter post thumbnails.
     *
     * @ignore
     * @since 6.3.0
     * @access private
     *
     * @param string $context The context for rendering an attachment image.
     * @return string Modified context set to 'the_post_thumbnail'.
     */
    function _wp_post_thumbnail_context_filter($context)
    {
    }
    /**
     * Adds the '_wp_post_thumbnail_context_filter' callback to the 'wp_get_attachment_image_context'
     * filter hook. Internal use only.
     *
     * @ignore
     * @since 6.3.0
     * @access private
     */
    function _wp_post_thumbnail_context_filter_add()
    {
    }
    /**
     * Removes the '_wp_post_thumbnail_context_filter' callback from the 'wp_get_attachment_image_context'
     * filter hook. Internal use only.
     *
     * @ignore
     * @since 6.3.0
     * @access private
     */
    function _wp_post_thumbnail_context_filter_remove()
    {
    }
    /**
     * Builds the Caption shortcode output.
     *
     * Allows a plugin to replace the content that would otherwise be returned. The
     * filter is {@see 'img_caption_shortcode'} and passes an empty string, the attr
     * parameter and the content parameter values.
     *
     * The supported attributes for the shortcode are 'id', 'caption_id', 'align',
     * 'width', 'caption', and 'class'.
     *
     * @since 2.6.0
     * @since 3.9.0 The `class` attribute was added.
     * @since 5.1.0 The `caption_id` attribute was added.
     * @since 5.9.0 The `$content` parameter default value changed from `null` to `''`.
     *
     * @param array  $attr {
     *     Attributes of the caption shortcode.
     *
     *     @type string $id         ID of the image and caption container element, i.e. `<figure>` or `<div>`.
     *     @type string $caption_id ID of the caption element, i.e. `<figcaption>` or `<p>`.
     *     @type string $align      Class name that aligns the caption. Default 'alignnone'. Accepts 'alignleft',
     *                              'aligncenter', alignright', 'alignnone'.
     *     @type int    $width      The width of the caption, in pixels.
     *     @type string $caption    The caption text.
     *     @type string $class      Additional class name(s) added to the caption container.
     * }
     * @param string $content Optional. Shortcode content. Default empty string.
     * @return string HTML content to display the caption.
     * @phpstan-param array{
     *   id?: string,
     *   caption_id?: string,
     *   align?: string,
     *   width?: int,
     *   caption?: string,
     *   class?: string,
     * } $attr
     */
    function img_caption_shortcode($attr, $content = '')
    {
    }
    /**
     * Builds the Gallery shortcode output.
     *
     * This implements the functionality of the Gallery Shortcode for displaying
     * WordPress images on a post.
     *
     * @since 2.5.0
     * @since 2.8.0 Added the `$attr` parameter to set the shortcode output. New attributes included
     *              such as `size`, `itemtag`, `icontag`, `captiontag`, and columns. Changed markup from
     *              `div` tags to `dl`, `dt` and `dd` tags. Support more than one gallery on the
     *              same page.
     * @since 2.9.0 Added support for `include` and `exclude` to shortcode.
     * @since 3.5.0 Use get_post() instead of global `$post`. Handle mapping of `ids` to `include`
     *              and `orderby`.
     * @since 3.6.0 Added validation for tags used in gallery shortcode. Add orientation information to items.
     * @since 3.7.0 Introduced the `link` attribute.
     * @since 3.9.0 `html5` gallery support, accepting 'itemtag', 'icontag', and 'captiontag' attributes.
     * @since 4.0.0 Removed use of `extract()`.
     * @since 4.1.0 Added attribute to `wp_get_attachment_link()` to output `aria-describedby`.
     * @since 4.2.0 Passed the shortcode instance ID to `post_gallery` and `post_playlist` filters.
     * @since 4.6.0 Standardized filter docs to match documentation standards for PHP.
     * @since 5.1.0 Code cleanup for WPCS 1.0.0 coding standards.
     * @since 5.3.0 Saved progress of intermediate image creation after upload.
     * @since 5.5.0 Ensured that galleries can be output as a list of links in feeds.
     * @since 5.6.0 Replaced order-style PHP type conversion functions with typecasts. Fix logic for
     *              an array of image dimensions.
     *
     * @param array $attr {
     *     Attributes of the gallery shortcode.
     *
     *     @type string       $order      Order of the images in the gallery. Default 'ASC'. Accepts 'ASC', 'DESC'.
     *     @type string       $orderby    The field to use when ordering the images. Default 'menu_order ID'.
     *                                    Accepts any valid SQL ORDERBY statement.
     *     @type int          $id         Post ID.
     *     @type string       $itemtag    HTML tag to use for each image in the gallery.
     *                                    Default 'dl', or 'figure' when the theme registers HTML5 gallery support.
     *     @type string       $icontag    HTML tag to use for each image's icon.
     *                                    Default 'dt', or 'div' when the theme registers HTML5 gallery support.
     *     @type string       $captiontag HTML tag to use for each image's caption.
     *                                    Default 'dd', or 'figcaption' when the theme registers HTML5 gallery support.
     *     @type int          $columns    Number of columns of images to display. Default 3.
     *     @type string|int[] $size       Size of the images to display. Accepts any registered image size name, or an array
     *                                    of width and height values in pixels (in that order). Default 'thumbnail'.
     *     @type string       $ids        A comma-separated list of IDs of attachments to display. Default empty.
     *     @type string       $include    A comma-separated list of IDs of attachments to include. Default empty.
     *     @type string       $exclude    A comma-separated list of IDs of attachments to exclude. Default empty.
     *     @type string       $link       What to link each image to. Default empty (links to the attachment page).
     *                                    Accepts 'file', 'none'.
     * }
     * @return string HTML content to display gallery.
     * @phpstan-param array{
     *   order?: string,
     *   orderby?: string,
     *   id?: int,
     *   itemtag?: string,
     *   icontag?: string,
     *   captiontag?: string,
     *   columns?: int,
     *   size?: string|int[],
     *   ids?: string,
     *   include?: string,
     *   exclude?: string,
     *   link?: string,
     * } $attr
     */
    function gallery_shortcode($attr)
    {
    }
    /**
     * Outputs the templates used by playlists.
     *
     * @since 3.9.0
     */
    function wp_underscore_playlist_templates()
    {
    }
    /**
     * Outputs and enqueues default scripts and styles for playlists.
     *
     * @since 3.9.0
     *
     * @param string $type Type of playlist. Accepts 'audio' or 'video'.
     * @phpstan-param 'audio'|'video' $type
     */
    function wp_playlist_scripts($type)
    {
    }
    /**
     * Builds the Playlist shortcode output.
     *
     * This implements the functionality of the playlist shortcode for displaying
     * a collection of WordPress audio or video files in a post.
     *
     * @since 3.9.0
     *
     * @global int $content_width
     *
     * @param array $attr {
     *     Array of default playlist attributes.
     *
     *     @type string  $type         Type of playlist to display. Accepts 'audio' or 'video'. Default 'audio'.
     *     @type string  $order        Designates ascending or descending order of items in the playlist.
     *                                 Accepts 'ASC', 'DESC'. Default 'ASC'.
     *     @type string  $orderby      Any column, or columns, to sort the playlist. If $ids are
     *                                 passed, this defaults to the order of the $ids array ('post__in').
     *                                 Otherwise default is 'menu_order ID'.
     *     @type int     $id           If an explicit $ids array is not present, this parameter
     *                                 will determine which attachments are used for the playlist.
     *                                 Default is the current post ID.
     *     @type array   $ids          Create a playlist out of these explicit attachment IDs. If empty,
     *                                 a playlist will be created from all $type attachments of $id.
     *                                 Default empty.
     *     @type array   $exclude      List of specific attachment IDs to exclude from the playlist. Default empty.
     *     @type string  $style        Playlist style to use. Accepts 'light' or 'dark'. Default 'light'.
     *     @type bool    $tracklist    Whether to show or hide the playlist. Default true.
     *     @type bool    $tracknumbers Whether to show or hide the numbers next to entries in the playlist. Default true.
     *     @type bool    $images       Show or hide the video or audio thumbnail (Featured Image/post
     *                                 thumbnail). Default true.
     *     @type bool    $artists      Whether to show or hide artist name in the playlist. Default true.
     * }
     *
     * @return string Playlist output. Empty string if the passed type is unsupported.
     * @phpstan-param array{
     *   type?: string,
     *   order?: string,
     *   orderby?: string,
     *   id?: int,
     *   ids?: array,
     *   exclude?: array,
     *   style?: string,
     *   tracklist?: bool,
     *   tracknumbers?: bool,
     *   images?: bool,
     *   artists?: bool,
     * } $attr
     */
    function wp_playlist_shortcode($attr)
    {
    }
    /**
     * Provides a No-JS Flash fallback as a last resort for audio / video.
     *
     * @since 3.6.0
     *
     * @param string $url The media element URL.
     * @return string Fallback HTML.
     */
    function wp_mediaelement_fallback($url)
    {
    }
    /**
     * Returns a filtered list of supported audio formats.
     *
     * @since 3.6.0
     *
     * @return string[] Supported audio formats.
     */
    function wp_get_audio_extensions()
    {
    }
    /**
     * Returns useful keys to use to lookup data from an attachment's stored metadata.
     *
     * @since 3.9.0
     *
     * @param WP_Post $attachment The current attachment, provided for context.
     * @param string  $context    Optional. The context. Accepts 'edit', 'display'. Default 'display'.
     * @return string[] Key/value pairs of field keys to labels.
     */
    function wp_get_attachment_id3_keys($attachment, $context = 'display')
    {
    }
    /**
     * Builds the Audio shortcode output.
     *
     * This implements the functionality of the Audio Shortcode for displaying
     * WordPress mp3s in a post.
     *
     * @since 3.6.0
     *
     * @param array  $attr {
     *     Attributes of the audio shortcode.
     *
     *     @type string $src      URL to the source of the audio file. Default empty.
     *     @type string $loop     The 'loop' attribute for the `<audio>` element. Default empty.
     *     @type string $autoplay The 'autoplay' attribute for the `<audio>` element. Default empty.
     *     @type string $preload  The 'preload' attribute for the `<audio>` element. Default 'none'.
     *     @type string $class    The 'class' attribute for the `<audio>` element. Default 'wp-audio-shortcode'.
     *     @type string $style    The 'style' attribute for the `<audio>` element. Default 'width: 100%;'.
     * }
     * @param string $content Shortcode content.
     * @return string|void HTML content to display audio.
     * @phpstan-param array{
     *   src?: string,
     *   loop?: string,
     *   autoplay?: string,
     *   preload?: string,
     *   class?: string,
     *   style?: string,
     * } $attr
     */
    function wp_audio_shortcode($attr, $content = '')
    {
    }
    /**
     * Returns a filtered list of supported video formats.
     *
     * @since 3.6.0
     *
     * @return string[] List of supported video formats.
     */
    function wp_get_video_extensions()
    {
    }
    /**
     * Builds the Video shortcode output.
     *
     * This implements the functionality of the Video Shortcode for displaying
     * WordPress mp4s in a post.
     *
     * @since 3.6.0
     *
     * @global int $content_width
     *
     * @param array  $attr {
     *     Attributes of the shortcode.
     *
     *     @type string $src      URL to the source of the video file. Default empty.
     *     @type int    $height   Height of the video embed in pixels. Default 360.
     *     @type int    $width    Width of the video embed in pixels. Default $content_width or 640.
     *     @type string $poster   The 'poster' attribute for the `<video>` element. Default empty.
     *     @type string $loop     The 'loop' attribute for the `<video>` element. Default empty.
     *     @type string $autoplay The 'autoplay' attribute for the `<video>` element. Default empty.
     *     @type string $muted    The 'muted' attribute for the `<video>` element. Default false.
     *     @type string $preload  The 'preload' attribute for the `<video>` element.
     *                            Default 'metadata'.
     *     @type string $class    The 'class' attribute for the `<video>` element.
     *                            Default 'wp-video-shortcode'.
     * }
     * @param string $content Shortcode content.
     * @return string|void HTML content to display video.
     * @phpstan-param array{
     *   src?: string,
     *   height?: int,
     *   width?: int,
     *   poster?: string,
     *   loop?: string,
     *   autoplay?: string,
     *   muted?: string,
     *   preload?: string,
     *   class?: string,
     * } $attr
     */
    function wp_video_shortcode($attr, $content = '')
    {
    }
    /**
     * Gets the previous image link that has the same post parent.
     *
     * @since 5.8.0
     *
     * @see get_adjacent_image_link()
     *
     * @param string|int[] $size Optional. Image size. Accepts any registered image size name, or an array
     *                           of width and height values in pixels (in that order). Default 'thumbnail'.
     * @param string|false $text Optional. Link text. Default false.
     * @return string Markup for previous image link.
     */
    function get_previous_image_link($size = 'thumbnail', $text = \false)
    {
    }
    /**
     * Displays previous image link that has the same post parent.
     *
     * @since 2.5.0
     *
     * @param string|int[] $size Optional. Image size. Accepts any registered image size name, or an array
     *                           of width and height values in pixels (in that order). Default 'thumbnail'.
     * @param string|false $text Optional. Link text. Default false.
     */
    function previous_image_link($size = 'thumbnail', $text = \false)
    {
    }
    /**
     * Gets the next image link that has the same post parent.
     *
     * @since 5.8.0
     *
     * @see get_adjacent_image_link()
     *
     * @param string|int[] $size Optional. Image size. Accepts any registered image size name, or an array
     *                           of width and height values in pixels (in that order). Default 'thumbnail'.
     * @param string|false $text Optional. Link text. Default false.
     * @return string Markup for next image link.
     */
    function get_next_image_link($size = 'thumbnail', $text = \false)
    {
    }
    /**
     * Displays next image link that has the same post parent.
     *
     * @since 2.5.0
     *
     * @param string|int[] $size Optional. Image size. Accepts any registered image size name, or an array
     *                           of width and height values in pixels (in that order). Default 'thumbnail'.
     * @param string|false $text Optional. Link text. Default false.
     */
    function next_image_link($size = 'thumbnail', $text = \false)
    {
    }
    /**
     * Gets the next or previous image link that has the same post parent.
     *
     * Retrieves the current attachment object from the $post global.
     *
     * @since 5.8.0
     *
     * @param bool         $prev Optional. Whether to display the next (false) or previous (true) link. Default true.
     * @param string|int[] $size Optional. Image size. Accepts any registered image size name, or an array
     *                           of width and height values in pixels (in that order). Default 'thumbnail'.
     * @param bool         $text Optional. Link text. Default false.
     * @return string Markup for image link.
     */
    function get_adjacent_image_link($prev = \true, $size = 'thumbnail', $text = \false)
    {
    }
    /**
     * Displays next or previous image link that has the same post parent.
     *
     * Retrieves the current attachment object from the $post global.
     *
     * @since 2.5.0
     *
     * @param bool         $prev Optional. Whether to display the next (false) or previous (true) link. Default true.
     * @param string|int[] $size Optional. Image size. Accepts any registered image size name, or an array
     *                           of width and height values in pixels (in that order). Default 'thumbnail'.
     * @param bool         $text Optional. Link text. Default false.
     */
    function adjacent_image_link($prev = \true, $size = 'thumbnail', $text = \false)
    {
    }
    /**
     * Retrieves taxonomies attached to given the attachment.
     *
     * @since 2.5.0
     * @since 4.7.0 Introduced the `$output` parameter.
     *
     * @param int|array|object $attachment Attachment ID, data array, or data object.
     * @param string           $output     Output type. 'names' to return an array of taxonomy names,
     *                                     or 'objects' to return an array of taxonomy objects.
     *                                     Default is 'names'.
     * @return string[]|WP_Taxonomy[] List of taxonomies or taxonomy names. Empty array on failure.
     * @phpstan-return ($output is 'names' ? array<int, string> : array<string, \WP_Taxonomy>)
     */
    function get_attachment_taxonomies($attachment, $output = 'names')
    {
    }
    /**
     * Retrieves all of the taxonomies that are registered for attachments.
     *
     * Handles mime-type-specific taxonomies such as attachment:image and attachment:video.
     *
     * @since 3.5.0
     *
     * @see get_taxonomies()
     *
     * @param string $output Optional. The type of taxonomy output to return. Accepts 'names' or 'objects'.
     *                       Default 'names'.
     * @return string[]|WP_Taxonomy[] Array of names or objects of registered taxonomies for attachments.
     * @phpstan-param 'names'|'objects' $output
     * @phpstan-return ($output is 'names' ? array<int, string> : array<string, \WP_Taxonomy>)
     */
    function get_taxonomies_for_attachments($output = 'names')
    {
    }
    /**
     * Determines whether the value is an acceptable type for GD image functions.
     *
     * In PHP 8.0, the GD extension uses GdImage objects for its data structures.
     * This function checks if the passed value is either a GdImage object instance
     * or a resource of type `gd`. Any other type will return false.
     *
     * @since 5.6.0
     *
     * @param resource|GdImage|false $image A value to check the type for.
     * @return bool True if `$image` is either a GD image resource or a GdImage instance,
     *              false otherwise.
     */
    function is_gd_image($image)
    {
    }
    /**
     * Creates a new GD image resource with transparency support.
     *
     * @todo Deprecate if possible.
     *
     * @since 2.9.0
     *
     * @param int $width  Image width in pixels.
     * @param int $height Image height in pixels.
     * @return resource|GdImage|false The GD image resource or GdImage instance on success.
     *                                False on failure.
     */
    function wp_imagecreatetruecolor($width, $height)
    {
    }
    /**
     * Based on a supplied width/height example, returns the biggest possible dimensions based on the max width/height.
     *
     * @since 2.9.0
     *
     * @see wp_constrain_dimensions()
     *
     * @param int $example_width  The width of an example embed.
     * @param int $example_height The height of an example embed.
     * @param int $max_width      The maximum allowed width.
     * @param int $max_height     The maximum allowed height.
     * @return int[] {
     *     An array of maximum width and height values.
     *
     *     @type int $0 The maximum width in pixels.
     *     @type int $1 The maximum height in pixels.
     * }
     * @phpstan-return array{
     *   0: int,
     *   1: int,
     * }
     */
    function wp_expand_dimensions($example_width, $example_height, $max_width, $max_height)
    {
    }
    /**
     * Determines the maximum upload size allowed in php.ini.
     *
     * @since 2.5.0
     *
     * @return int Allowed upload size.
     */
    function wp_max_upload_size()
    {
    }
    /**
     * Returns a WP_Image_Editor instance and loads file into it.
     *
     * @since 3.5.0
     *
     * @param string $path Path to the file to load.
     * @param array  $args Optional. Additional arguments for retrieving the image editor.
     *                     Default empty array.
     * @return WP_Image_Editor|WP_Error The WP_Image_Editor object on success,
     *                                  a WP_Error object otherwise.
     */
    function wp_get_image_editor($path, $args = array())
    {
    }
    /**
     * Tests whether there is an editor that supports a given mime type or methods.
     *
     * @since 3.5.0
     *
     * @param string|array $args Optional. Array of arguments to retrieve the image editor supports.
     *                           Default empty array.
     * @return bool True if an eligible editor is found; false otherwise.
     */
    function wp_image_editor_supports($args = array())
    {
    }
    /**
     * Tests which editors are capable of supporting the request.
     *
     * @ignore
     * @since 3.5.0
     *
     * @param array $args Optional. Array of arguments for choosing a capable editor. Default empty array.
     * @return string|false Class name for the first editor that claims to support the request.
     *                      False if no editor claims to support the request.
     */
    function _wp_image_editor_choose($args = array())
    {
    }
    /**
     * Prints default Plupload arguments.
     *
     * @since 3.4.0
     * @phpstan-return void
     */
    function wp_plupload_default_settings()
    {
    }
    /**
     * Prepares an attachment post object for JS, where it is expected
     * to be JSON-encoded and fit into an Attachment model.
     *
     * @since 3.5.0
     *
     * @param int|WP_Post $attachment Attachment ID or object.
     * @return array|void {
     *     Array of attachment details, or void if the parameter does not correspond to an attachment.
     *
     *     @type string $alt                   Alt text of the attachment.
     *     @type string $author                ID of the attachment author, as a string.
     *     @type string $authorName            Name of the attachment author.
     *     @type string $caption               Caption for the attachment.
     *     @type array  $compat                Containing item and meta.
     *     @type string $context               Context, whether it's used as the site icon for example.
     *     @type int    $date                  Uploaded date, timestamp in milliseconds.
     *     @type string $dateFormatted         Formatted date (e.g. June 29, 2018).
     *     @type string $description           Description of the attachment.
     *     @type string $editLink              URL to the edit page for the attachment.
     *     @type string $filename              File name of the attachment.
     *     @type string $filesizeHumanReadable Filesize of the attachment in human readable format (e.g. 1 MB).
     *     @type int    $filesizeInBytes       Filesize of the attachment in bytes.
     *     @type int    $height                If the attachment is an image, represents the height of the image in pixels.
     *     @type string $icon                  Icon URL of the attachment (e.g. /wp-includes/images/media/archive.png).
     *     @type int    $id                    ID of the attachment.
     *     @type string $link                  URL to the attachment.
     *     @type int    $menuOrder             Menu order of the attachment post.
     *     @type array  $meta                  Meta data for the attachment.
     *     @type string $mime                  Mime type of the attachment (e.g. image/jpeg or application/zip).
     *     @type int    $modified              Last modified, timestamp in milliseconds.
     *     @type string $name                  Name, same as title of the attachment.
     *     @type array  $nonces                Nonces for update, delete and edit.
     *     @type string $orientation           If the attachment is an image, represents the image orientation
     *                                         (landscape or portrait).
     *     @type array  $sizes                 If the attachment is an image, contains an array of arrays
     *                                         for the images sizes: thumbnail, medium, large, and full.
     *     @type string $status                Post status of the attachment (usually 'inherit').
     *     @type string $subtype               Mime subtype of the attachment (usually the last part, e.g. jpeg or zip).
     *     @type string $title                 Title of the attachment (usually slugified file name without the extension).
     *     @type string $type                  Type of the attachment (usually first part of the mime type, e.g. image).
     *     @type int    $uploadedTo            Parent post to which the attachment was uploaded.
     *     @type string $uploadedToLink        URL to the edit page of the parent post of the attachment.
     *     @type string $uploadedToTitle       Post title of the parent of the attachment.
     *     @type string $url                   Direct URL to the attachment file (from wp-content).
     *     @type int    $width                 If the attachment is an image, represents the width of the image in pixels.
     * }
     *
     * @phpstan-return void|array{
     *   alt: string,
     *   author: string,
     *   authorName: string,
     *   caption: string,
     *   compat: array,
     *   context: string,
     *   date: int,
     *   dateFormatted: string,
     *   description: string,
     *   editLink: string,
     *   filename: string,
     *   filesizeHumanReadable: string,
     *   filesizeInBytes: int,
     *   height: int,
     *   icon: string,
     *   id: int,
     *   link: string,
     *   menuOrder: int,
     *   meta: array,
     *   mime: string,
     *   modified: int,
     *   name: string,
     *   nonces: array,
     *   orientation: string,
     *   sizes: array,
     *   status: string,
     *   subtype: string,
     *   title: string,
     *   type: string,
     *   uploadedTo: int,
     *   uploadedToLink: string,
     *   uploadedToTitle: string,
     *   url: string,
     *   width: int,
     * }
     */
    function wp_prepare_attachment_for_js($attachment)
    {
    }
    /**
     * Enqueues all scripts, styles, settings, and templates necessary to use
     * all media JS APIs.
     *
     * @since 3.5.0
     *
     * @global int       $content_width
     * @global wpdb      $wpdb          WordPress database abstraction object.
     * @global WP_Locale $wp_locale     WordPress date and time locale object.
     *
     * @param array $args {
     *     Arguments for enqueuing media scripts.
     *
     *     @type int|WP_Post $post Post ID or post object.
     * }
     * @phpstan-param array{
     *   post?: int|WP_Post,
     * } $args
     * @phpstan-return void
     */
    function wp_enqueue_media($args = array())
    {
    }
    /**
     * Retrieves media attached to the passed post.
     *
     * @since 3.6.0
     *
     * @param string      $type Mime type.
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return WP_Post[] Array of media attached to the given post.
     */
    function get_attached_media($type, $post = 0)
    {
    }
    /**
     * Checks the HTML content for an audio, video, object, embed, or iframe tags.
     *
     * @since 3.6.0
     *
     * @param string   $content A string of HTML which might contain media elements.
     * @param string[] $types   An array of media types: 'audio', 'video', 'object', 'embed', or 'iframe'.
     * @return string[] Array of found HTML media elements.
     */
    function get_media_embedded_in_content($content, $types = \null)
    {
    }
    /**
     * Retrieves galleries from the passed post's content.
     *
     * @since 3.6.0
     *
     * @param int|WP_Post $post Post ID or object.
     * @param bool        $html Optional. Whether to return HTML or data in the array. Default true.
     * @return array A list of arrays, each containing gallery data and srcs parsed
     *               from the expanded shortcode.
     */
    function get_post_galleries($post, $html = \true)
    {
    }
    /**
     * Checks a specified post's content for gallery and, if present, return the first
     *
     * @since 3.6.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @param bool        $html Optional. Whether to return HTML or data. Default is true.
     * @return string|array Gallery data and srcs parsed from the expanded shortcode.
     */
    function get_post_gallery($post = 0, $html = \true)
    {
    }
    /**
     * Retrieves the image srcs from galleries from a post's content, if present.
     *
     * @since 3.6.0
     *
     * @see get_post_galleries()
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global `$post`.
     * @return array A list of lists, each containing image srcs parsed.
     *               from an expanded shortcode
     */
    function get_post_galleries_images($post = 0)
    {
    }
    /**
     * Checks a post's content for galleries and return the image srcs for the first found gallery.
     *
     * @since 3.6.0
     *
     * @see get_post_gallery()
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global `$post`.
     * @return string[] A list of a gallery's image srcs in order.
     */
    function get_post_gallery_images($post = 0)
    {
    }
    /**
     * Maybe attempts to generate attachment metadata, if missing.
     *
     * @since 3.9.0
     *
     * @param WP_Post $attachment Attachment object.
     * @phpstan-return void
     */
    function wp_maybe_generate_attachment_metadata($attachment)
    {
    }
    /**
     * Tries to convert an attachment URL into a post ID.
     *
     * @since 4.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $url The URL to resolve.
     * @return int The found post ID, or 0 on failure.
     */
    function attachment_url_to_postid($url)
    {
    }
    /**
     * Returns the URLs for CSS files used in an iframe-sandbox'd TinyMCE media view.
     *
     * @since 4.0.0
     *
     * @return string[] The relevant CSS file URLs.
     */
    function wpview_media_sandbox_styles()
    {
    }
    /**
     * Registers the personal data exporter for media.
     *
     * @param array[] $exporters An array of personal data exporters, keyed by their ID.
     * @return array[] Updated array of personal data exporters.
     */
    function wp_register_media_personal_data_exporter($exporters)
    {
    }
    /**
     * Finds and exports attachments associated with an email address.
     *
     * @since 4.9.6
     *
     * @param string $email_address The attachment owner email address.
     * @param int    $page          Attachment page number.
     * @return array {
     *     An array of personal data.
     *
     *     @type array[] $data An array of personal data arrays.
     *     @type bool    $done Whether the exporter is finished.
     * }
     * @phpstan-return array{
     *   data: array[],
     *   done: bool,
     * }
     */
    function wp_media_personal_data_exporter($email_address, $page = 1)
    {
    }
    /**
     * Adds additional default image sub-sizes.
     *
     * These sizes are meant to enhance the way WordPress displays images on the front-end on larger,
     * high-density devices. They make it possible to generate more suitable `srcset` and `sizes` attributes
     * when the users upload large images.
     *
     * The sizes can be changed or removed by themes and plugins but that is not recommended.
     * The size "names" reflect the image dimensions, so changing the sizes would be quite misleading.
     *
     * @since 5.3.0
     * @access private
     */
    function _wp_add_additional_image_sizes()
    {
    }
    /**
     * Callback to enable showing of the user error when uploading .heic images.
     *
     * @since 5.5.0
     * @since 6.7.0 The default behavior is to enable heic uploads as long as the server
     *              supports the format. The uploads are converted to JPEG's by default.
     *
     * @param array[] $plupload_settings The settings for Plupload.js.
     * @return array[] Modified settings for Plupload.js.
     */
    function wp_show_heic_upload_error($plupload_settings)
    {
    }
    /**
     * Allows PHP's getimagesize() to be debuggable when necessary.
     *
     * @since 5.7.0
     * @since 5.8.0 Added support for WebP images.
     * @since 6.5.0 Added support for AVIF images.
     *
     * @param string $filename   The file path.
     * @param array  $image_info Optional. Extended image information (passed by reference).
     * @return array|false Array of image information or false on failure.
     */
    function wp_getimagesize($filename, ?array &$image_info = \null)
    {
    }
    /**
     * Extracts meta information about an AVIF file: width, height, bit depth, and number of channels.
     *
     * @since 6.5.0
     *
     * @param string $filename Path to an AVIF file.
     * @return array {
     *     An array of AVIF image information.
     *
     *     @type int|false $width        Image width on success, false on failure.
     *     @type int|false $height       Image height on success, false on failure.
     *     @type int|false $bit_depth    Image bit depth on success, false on failure.
     *     @type int|false $num_channels Image number of channels on success, false on failure.
     * }
     * @phpstan-return array{
     *   width: int|false,
     *   height: int|false,
     *   bit_depth: int|false,
     *   num_channels: int|false,
     * }
     */
    function wp_get_avif_info($filename)
    {
    }
    /**
     * Extracts meta information about a WebP file: width, height, and type.
     *
     * @since 5.8.0
     *
     * @param string $filename Path to a WebP file.
     * @return array {
     *     An array of WebP image information.
     *
     *     @type int|false    $width  Image width on success, false on failure.
     *     @type int|false    $height Image height on success, false on failure.
     *     @type string|false $type   The WebP type: one of 'lossy', 'lossless' or 'animated-alpha'.
     *                                False on failure.
     * }
     * @phpstan-return array{
     *   width: int|false,
     *   height: int|false,
     *   type: string|false,
     * }
     */
    function wp_get_webp_info($filename)
    {
    }
    /**
     * Gets loading optimization attributes.
     *
     * This function returns an array of attributes that should be merged into the given attributes array to optimize
     * loading performance. Potential attributes returned by this function are:
     * - `loading` attribute with a value of "lazy"
     * - `fetchpriority` attribute with a value of "high"
     * - `decoding` attribute with a value of "async"
     *
     * If any of these attributes are already present in the given attributes, they will not be modified. Note that no
     * element should have both `loading="lazy"` and `fetchpriority="high"`, so the function will trigger a warning in case
     * both attributes are present with those values.
     *
     * @since 6.3.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string $tag_name The tag name.
     * @param array  $attr     Array of the attributes for the tag.
     * @param string $context  Context for the element for which the loading optimization attribute is requested.
     * @return array Loading optimization attributes.
     */
    function wp_get_loading_optimization_attributes($tag_name, $attr, $context)
    {
    }
    /**
     * Gets the threshold for how many of the first content media elements to not lazy-load.
     *
     * This function runs the {@see 'wp_omit_loading_attr_threshold'} filter, which uses a default threshold value of 3.
     * The filter is only run once per page load, unless the `$force` parameter is used.
     *
     * @since 5.9.0
     *
     * @param bool $force Optional. If set to true, the filter will be (re-)applied even if it already has been before.
     *                    Default false.
     * @return int The number of content media elements to not lazy-load.
     */
    function wp_omit_loading_attr_threshold($force = \false)
    {
    }
    /**
     * Increases an internal content media count variable.
     *
     * @since 5.9.0
     * @access private
     *
     * @param int $amount Optional. Amount to increase by. Default 1.
     * @return int The latest content media count, after the increase.
     */
    function wp_increase_content_media_count($amount = 1)
    {
    }
    /**
     * Determines whether to add `fetchpriority='high'` to loading attributes.
     *
     * @since 6.3.0
     * @access private
     *
     * @param array  $loading_attrs Array of the loading optimization attributes for the element.
     * @param string $tag_name      The tag name.
     * @param array  $attr          Array of the attributes for the element.
     * @return array Updated loading optimization attributes for the element.
     */
    function wp_maybe_add_fetchpriority_high_attr($loading_attrs, $tag_name, $attr)
    {
    }
    /**
     * Accesses a flag that indicates if an element is a possible candidate for `fetchpriority='high'`.
     *
     * @since 6.3.0
     * @access private
     *
     * @param bool $value Optional. Used to change the static variable. Default null.
     * @return bool Returns true if high-priority element was marked already, otherwise false.
     */
    function wp_high_priority_element_flag($value = \null)
    {
    }
    /**
     * Determines the output format for the image editor.
     *
     * @since 6.7.0
     * @access private
     *
     * @param string $filename  Path to the image.
     * @param string $mime_type The source image mime type.
     * @return string[] An array of mime type mappings.
     */
    function wp_get_image_editor_output_format($filename, $mime_type)
    {
    }
    /**
     * Adds metadata for the specified object.
     *
     * @since 2.9.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $meta_type  Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                           or any other object type with an associated meta table.
     * @param int    $object_id  ID of the object metadata is for.
     * @param string $meta_key   Metadata key.
     * @param mixed  $meta_value Metadata value. Must be serializable if non-scalar.
     * @param bool   $unique     Optional. Whether the specified metadata key should be unique for the object.
     *                           If true, and the object already has a value for the specified metadata key,
     *                           no change will be made. Default false.
     * @return int|false The meta ID on success, false on failure.
     */
    function add_metadata($meta_type, $object_id, $meta_key, $meta_value, $unique = \false)
    {
    }
    /**
     * Updates metadata for the specified object. If no value already exists for the specified object
     * ID and metadata key, the metadata will be added.
     *
     * @since 2.9.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $meta_type  Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                           or any other object type with an associated meta table.
     * @param int    $object_id  ID of the object metadata is for.
     * @param string $meta_key   Metadata key.
     * @param mixed  $meta_value Metadata value. Must be serializable if non-scalar.
     * @param mixed  $prev_value Optional. Previous value to check before updating.
     *                           If specified, only update existing metadata entries with
     *                           this value. Otherwise, update all entries. Default empty string.
     * @return int|bool The new meta field ID if a field with the given key didn't exist
     *                  and was therefore added, true on successful update,
     *                  false on failure or if the value passed to the function
     *                  is the same as the one that is already in the database.
     */
    function update_metadata($meta_type, $object_id, $meta_key, $meta_value, $prev_value = '')
    {
    }
    /**
     * Deletes metadata for the specified object.
     *
     * @since 2.9.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $meta_type  Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                           or any other object type with an associated meta table.
     * @param int    $object_id  ID of the object metadata is for.
     * @param string $meta_key   Metadata key.
     * @param mixed  $meta_value Optional. Metadata value. Must be serializable if non-scalar.
     *                           If specified, only delete metadata entries with this value.
     *                           Otherwise, delete all entries with the specified meta_key.
     *                           Pass `null`, `false`, or an empty string to skip this check.
     *                           (For backward compatibility, it is not possible to pass an empty string
     *                           to delete those entries with an empty string for a value.)
     *                           Default empty string.
     * @param bool   $delete_all Optional. If true, delete matching metadata entries for all objects,
     *                           ignoring the specified object_id. Otherwise, only delete
     *                           matching metadata entries for the specified object_id. Default false.
     * @return bool True on successful delete, false on failure.
     */
    function delete_metadata($meta_type, $object_id, $meta_key, $meta_value = '', $delete_all = \false)
    {
    }
    /**
     * Retrieves the value of a metadata field for the specified object type and ID.
     *
     * If the meta field exists, a single value is returned if `$single` is true,
     * or an array of values if it's false.
     *
     * If the meta field does not exist, the result depends on get_metadata_default().
     * By default, an empty string is returned if `$single` is true, or an empty array
     * if it's false.
     *
     * @since 2.9.0
     *
     * @see get_metadata_raw()
     * @see get_metadata_default()
     *
     * @param string $meta_type Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                          or any other object type with an associated meta table.
     * @param int    $object_id ID of the object metadata is for.
     * @param string $meta_key  Optional. Metadata key. If not specified, retrieve all metadata for
     *                          the specified object. Default empty string.
     * @param bool   $single    Optional. If true, return only the first value of the specified `$meta_key`.
     *                          This parameter has no effect if `$meta_key` is not specified. Default false.
     * @return mixed An array of values if `$single` is false.
     *               The value of the meta field if `$single` is true.
     *               False for an invalid `$object_id` (non-numeric, zero, or negative value),
     *               or if `$meta_type` is not specified.
     *               An empty array if a valid but non-existing object ID is passed and `$single` is false.
     *               An empty string if a valid but non-existing object ID is passed and `$single` is true.
     */
    function get_metadata($meta_type, $object_id, $meta_key = '', $single = \false)
    {
    }
    /**
     * Retrieves raw metadata value for the specified object.
     *
     * @since 5.5.0
     *
     * @param string $meta_type Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                          or any other object type with an associated meta table.
     * @param int    $object_id ID of the object metadata is for.
     * @param string $meta_key  Optional. Metadata key. If not specified, retrieve all metadata for
     *                          the specified object. Default empty string.
     * @param bool   $single    Optional. If true, return only the first value of the specified `$meta_key`.
     *                          This parameter has no effect if `$meta_key` is not specified. Default false.
     * @return mixed An array of values if `$single` is false.
     *               The value of the meta field if `$single` is true.
     *               False for an invalid `$object_id` (non-numeric, zero, or negative value),
     *               or if `$meta_type` is not specified.
     *               Null if the value does not exist.
     */
    function get_metadata_raw($meta_type, $object_id, $meta_key = '', $single = \false)
    {
    }
    /**
     * Retrieves default metadata value for the specified meta key and object.
     *
     * By default, an empty string is returned if `$single` is true, or an empty array
     * if it's false.
     *
     * @since 5.5.0
     *
     * @param string $meta_type Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                          or any other object type with an associated meta table.
     * @param int    $object_id ID of the object metadata is for.
     * @param string $meta_key  Metadata key.
     * @param bool   $single    Optional. If true, return only the first value of the specified `$meta_key`.
     *                          This parameter has no effect if `$meta_key` is not specified. Default false.
     * @return mixed An array of default values if `$single` is false.
     *               The default value of the meta field if `$single` is true.
     */
    function get_metadata_default($meta_type, $object_id, $meta_key, $single = \false)
    {
    }
    /**
     * Determines if a meta field with the given key exists for the given object ID.
     *
     * @since 3.3.0
     *
     * @param string $meta_type Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                          or any other object type with an associated meta table.
     * @param int    $object_id ID of the object metadata is for.
     * @param string $meta_key  Metadata key.
     * @return bool Whether a meta field with the given key exists.
     */
    function metadata_exists($meta_type, $object_id, $meta_key)
    {
    }
    /**
     * Retrieves metadata by meta ID.
     *
     * @since 3.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $meta_type Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                          or any other object type with an associated meta table.
     * @param int    $meta_id   ID for a specific meta row.
     * @return stdClass|false {
     *     Metadata object, or boolean `false` if the metadata doesn't exist.
     *
     *     @type string $meta_key   The meta key.
     *     @type mixed  $meta_value The unserialized meta value.
     *     @type string $meta_id    Optional. The meta ID when the meta type is any value except 'user'.
     *     @type string $umeta_id   Optional. The meta ID when the meta type is 'user'.
     *     @type string $post_id    Optional. The object ID when the meta type is 'post'.
     *     @type string $comment_id Optional. The object ID when the meta type is 'comment'.
     *     @type string $term_id    Optional. The object ID when the meta type is 'term'.
     *     @type string $user_id    Optional. The object ID when the meta type is 'user'.
     * }
     * @phpstan-return false|object{
     *   meta_key: string,
     *   meta_value: mixed,
     *   meta_id: string,
     *   umeta_id: string,
     *   post_id: string,
     *   comment_id: string,
     *   term_id: string,
     *   user_id: string,
     * }
     */
    function get_metadata_by_mid($meta_type, $meta_id)
    {
    }
    /**
     * Updates metadata by meta ID.
     *
     * @since 3.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string       $meta_type  Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                                 or any other object type with an associated meta table.
     * @param int          $meta_id    ID for a specific meta row.
     * @param string       $meta_value Metadata value. Must be serializable if non-scalar.
     * @param string|false $meta_key   Optional. You can provide a meta key to update it. Default false.
     * @return bool True on successful update, false on failure.
     */
    function update_metadata_by_mid($meta_type, $meta_id, $meta_value, $meta_key = \false)
    {
    }
    /**
     * Deletes metadata by meta ID.
     *
     * @since 3.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $meta_type Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                          or any other object type with an associated meta table.
     * @param int    $meta_id   ID for a specific meta row.
     * @return bool True on successful delete, false on failure.
     */
    function delete_metadata_by_mid($meta_type, $meta_id)
    {
    }
    /**
     * Updates the metadata cache for the specified objects.
     *
     * @since 2.9.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string       $meta_type  Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                                 or any other object type with an associated meta table.
     * @param string|int[] $object_ids Array or comma delimited list of object IDs to update cache for.
     * @return array|false Metadata cache for the specified objects, or false on failure.
     */
    function update_meta_cache($meta_type, $object_ids)
    {
    }
    /**
     * Retrieves the queue for lazy-loading metadata.
     *
     * @since 4.5.0
     *
     * @return WP_Metadata_Lazyloader Metadata lazyloader queue.
     */
    function wp_metadata_lazyloader()
    {
    }
    /**
     * Given a meta query, generates SQL clauses to be appended to a main query.
     *
     * @since 3.2.0
     *
     * @see WP_Meta_Query
     *
     * @param array  $meta_query        A meta query.
     * @param string $type              Type of meta.
     * @param string $primary_table     Primary database table name.
     * @param string $primary_id_column Primary ID column name.
     * @param object $context           Optional. The main query object. Default null.
     * @return string[]|false {
     *     Array containing JOIN and WHERE SQL clauses to append to the main query,
     *     or false if no table exists for the requested meta type.
     *
     *     @type string $join  SQL fragment to append to the main JOIN clause.
     *     @type string $where SQL fragment to append to the main WHERE clause.
     * }
     * @phpstan-return false|array{
     *   join: string,
     *   where: string,
     * }
     */
    function get_meta_sql($meta_query, $type, $primary_table, $primary_id_column, $context = \null)
    {
    }
    /**
     * Retrieves the name of the metadata table for the specified object type.
     *
     * @since 2.9.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $type Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                     or any other object type with an associated meta table.
     * @return string|false Metadata table name, or false if no metadata table exists
     */
    function _get_meta_table($type)
    {
    }
    /**
     * Determines whether a meta key is considered protected.
     *
     * @since 3.1.3
     *
     * @param string $meta_key  Metadata key.
     * @param string $meta_type Optional. Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                          or any other object type with an associated meta table. Default empty string.
     * @return bool Whether the meta key is considered protected.
     */
    function is_protected_meta($meta_key, $meta_type = '')
    {
    }
    /**
     * Sanitizes meta value.
     *
     * @since 3.1.3
     * @since 4.9.8 The `$object_subtype` parameter was added.
     *
     * @param string $meta_key       Metadata key.
     * @param mixed  $meta_value     Metadata value to sanitize.
     * @param string $object_type    Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                               or any other object type with an associated meta table.
     * @param string $object_subtype Optional. The subtype of the object type. Default empty string.
     * @return mixed Sanitized $meta_value.
     */
    function sanitize_meta($meta_key, $meta_value, $object_type, $object_subtype = '')
    {
    }
    /**
     * Registers a meta key.
     *
     * It is recommended to register meta keys for a specific combination of object type and object subtype. If passing
     * an object subtype is omitted, the meta key will be registered for the entire object type, however it can be partly
     * overridden in case a more specific meta key of the same name exists for the same object type and a subtype.
     *
     * If an object type does not support any subtypes, such as users or comments, you should commonly call this function
     * without passing a subtype.
     *
     * @since 3.3.0
     * @since 4.6.0 {@link https://core.trac.wordpress.org/ticket/35658 Modified
     *              to support an array of data to attach to registered meta keys}. Previous arguments for
     *              `$sanitize_callback` and `$auth_callback` have been folded into this array.
     * @since 4.9.8 The `$object_subtype` argument was added to the arguments array.
     * @since 5.3.0 Valid meta types expanded to include "array" and "object".
     * @since 5.5.0 The `$default` argument was added to the arguments array.
     * @since 6.4.0 The `$revisions_enabled` argument was added to the arguments array.
     * @since 6.7.0 The `label` argument was added to the arguments array.
     *
     * @param string       $object_type Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                                  or any other object type with an associated meta table.
     * @param string       $meta_key    Meta key to register.
     * @param array        $args {
     *     Data used to describe the meta key when registered.
     *
     *     @type string     $object_subtype    A subtype; e.g. if the object type is "post", the post type. If left empty,
     *                                         the meta key will be registered on the entire object type. Default empty.
     *     @type string     $type              The type of data associated with this meta key.
     *                                         Valid values are 'string', 'boolean', 'integer', 'number', 'array', and 'object'.
     *     @type string     $label             A human-readable label of the data attached to this meta key.
     *     @type string     $description       A description of the data attached to this meta key.
     *     @type bool       $single            Whether the meta key has one value per object, or an array of values per object.
     *     @type mixed      $default           The default value returned from get_metadata() if no value has been set yet.
     *                                         When using a non-single meta key, the default value is for the first entry.
     *                                         In other words, when calling get_metadata() with `$single` set to `false`,
     *                                         the default value given here will be wrapped in an array.
     *     @type callable   $sanitize_callback A function or method to call when sanitizing `$meta_key` data.
     *     @type callable   $auth_callback     Optional. A function or method to call when performing edit_post_meta,
     *                                         add_post_meta, and delete_post_meta capability checks.
     *     @type bool|array $show_in_rest      Whether data associated with this meta key can be considered public and
     *                                         should be accessible via the REST API. A custom post type must also declare
     *                                         support for custom fields for registered meta to be accessible via REST.
     *                                         When registering complex meta values this argument may optionally be an
     *                                         array with 'schema' or 'prepare_callback' keys instead of a boolean.
     *     @type bool       $revisions_enabled Whether to enable revisions support for this meta_key. Can only be used when the
     *                                         object type is 'post'.
     * }
     * @param string|array $deprecated Deprecated. Use `$args` instead.
     * @return bool True if the meta key was successfully registered in the global array, false if not.
     *              Registering a meta key with distinct sanitize and auth callbacks will fire those callbacks,
     *              but will not add to the global registry.
     * @phpstan-param array{
     *   object_subtype?: string,
     *   type?: string,
     *   label?: string,
     *   description?: string,
     *   single?: bool,
     *   default?: mixed,
     *   sanitize_callback?: callable,
     *   auth_callback?: callable,
     *   show_in_rest?: bool|array,
     *   revisions_enabled?: bool,
     * } $args
     */
    function register_meta($object_type, $meta_key, $args, $deprecated = \null)
    {
    }
    /**
     * Filters into default_{$object_type}_metadata and adds in default value.
     *
     * @since 5.5.0
     *
     * @param mixed  $value     Current value passed to filter.
     * @param int    $object_id ID of the object metadata is for.
     * @param string $meta_key  Metadata key.
     * @param bool   $single    If true, return only the first value of the specified `$meta_key`.
     *                          This parameter has no effect if `$meta_key` is not specified.
     * @param string $meta_type Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                          or any other object type with an associated meta table.
     * @return mixed An array of default values if `$single` is false.
     *               The default value of the meta field if `$single` is true.
     */
    function filter_default_metadata($value, $object_id, $meta_key, $single, $meta_type)
    {
    }
    /**
     * Checks if a meta key is registered.
     *
     * @since 4.6.0
     * @since 4.9.8 The `$object_subtype` parameter was added.
     *
     * @param string $object_type    Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                               or any other object type with an associated meta table.
     * @param string $meta_key       Metadata key.
     * @param string $object_subtype Optional. The subtype of the object type. Default empty string.
     * @return bool True if the meta key is registered to the object type and, if provided,
     *              the object subtype. False if not.
     */
    function registered_meta_key_exists($object_type, $meta_key, $object_subtype = '')
    {
    }
    /**
     * Unregisters a meta key from the list of registered keys.
     *
     * @since 4.6.0
     * @since 4.9.8 The `$object_subtype` parameter was added.
     *
     * @param string $object_type    Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                               or any other object type with an associated meta table.
     * @param string $meta_key       Metadata key.
     * @param string $object_subtype Optional. The subtype of the object type. Default empty string.
     * @return bool True if successful. False if the meta key was not registered.
     */
    function unregister_meta_key($object_type, $meta_key, $object_subtype = '')
    {
    }
    /**
     * Retrieves a list of registered metadata args for an object type, keyed by their meta keys.
     *
     * @since 4.6.0
     * @since 4.9.8 The `$object_subtype` parameter was added.
     *
     * @param string $object_type    Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                               or any other object type with an associated meta table.
     * @param string $object_subtype Optional. The subtype of the object type. Default empty string.
     * @return array[] List of registered metadata args, keyed by their meta keys.
     */
    function get_registered_meta_keys($object_type, $object_subtype = '')
    {
    }
    /**
     * Retrieves registered metadata for a specified object.
     *
     * The results include both meta that is registered specifically for the
     * object's subtype and meta that is registered for the entire object type.
     *
     * @since 4.6.0
     *
     * @param string $object_type Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                            or any other object type with an associated meta table.
     * @param int    $object_id   ID of the object the metadata is for.
     * @param string $meta_key    Optional. Registered metadata key. If not specified, retrieve all registered
     *                            metadata for the specified object.
     * @return mixed A single value or array of values for a key if specified. An array of all registered keys
     *               and values for an object ID if not. False if a given $meta_key is not registered.
     */
    function get_registered_metadata($object_type, $object_id, $meta_key = '')
    {
    }
    /**
     * Filters out `register_meta()` args based on an allowed list.
     *
     * `register_meta()` args may change over time, so requiring the allowed list
     * to be explicitly turned off is a warranty seal of sorts.
     *
     * @access private
     * @since 5.5.0
     *
     * @param array $args         Arguments from `register_meta()`.
     * @param array $default_args Default arguments for `register_meta()`.
     * @return array Filtered arguments.
     */
    function _wp_register_meta_args_allowed_list($args, $default_args)
    {
    }
    /**
     * Returns the object subtype for a given object ID of a specific type.
     *
     * @since 4.9.8
     *
     * @param string $object_type Type of object metadata is for. Accepts 'post', 'comment', 'term', 'user',
     *                            or any other object type with an associated meta table.
     * @param int    $object_id   ID of the object to retrieve its subtype.
     * @return string The object subtype or an empty string if unspecified subtype.
     */
    function get_object_subtype($object_type, $object_id)
    {
    }
    /**
     * Updates the last_updated field for the current site.
     *
     * @since MU (3.0.0)
     */
    function wpmu_update_blogs_date()
    {
    }
    /**
     * Gets a full site URL, given a site ID.
     *
     * @since MU (3.0.0)
     *
     * @param int $blog_id Site ID.
     * @return string Full site URL if found. Empty string if not.
     */
    function get_blogaddress_by_id($blog_id)
    {
    }
    /**
     * Gets a full site URL, given a site name.
     *
     * @since MU (3.0.0)
     *
     * @param string $blogname Name of the subdomain or directory.
     * @return string
     */
    function get_blogaddress_by_name($blogname)
    {
    }
    /**
     * Retrieves a site's ID given its (subdomain or directory) slug.
     *
     * @since MU (3.0.0)
     * @since 4.7.0 Converted to use `get_sites()`.
     *
     * @param string $slug A site's slug.
     * @return int|null The site ID, or null if no site is found for the given slug.
     */
    function get_id_from_blogname($slug)
    {
    }
    /**
     * Retrieves the details for a blog from the blogs table and blog options.
     *
     * @since MU (3.0.0)
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|string|array $fields  Optional. A blog ID, a blog slug, or an array of fields to query against.
     *                                  Defaults to the current blog ID.
     * @param bool             $get_all Whether to retrieve all details or only the details in the blogs table.
     *                                  Default is true.
     * @return WP_Site|false Blog details on success. False on failure.
     */
    function get_blog_details($fields = \null, $get_all = \true)
    {
    }
    /**
     * Clears the blog details cache.
     *
     * @since MU (3.0.0)
     *
     * @param int $blog_id Optional. Blog ID. Defaults to current blog.
     */
    function refresh_blog_details($blog_id = 0)
    {
    }
    /**
     * Updates the details for a blog and the blogs table for a given blog ID.
     *
     * @since MU (3.0.0)
     *
     * @param int   $blog_id Blog ID.
     * @param array $details Array of details keyed by blogs table field names.
     * @return bool True if update succeeds, false otherwise.
     */
    function update_blog_details($blog_id, $details = array())
    {
    }
    /**
     * Cleans the site details cache for a site.
     *
     * @since 4.7.4
     *
     * @param int $site_id Optional. Site ID. Default is the current site ID.
     */
    function clean_site_details_cache($site_id = 0)
    {
    }
    /**
     * Retrieves option value for a given blog id based on name of option.
     *
     * If the option does not exist or does not have a value, then the return value
     * will be false. This is useful to check whether you need to install an option
     * and is commonly used during installation of plugin options and to test
     * whether upgrading is required.
     *
     * If the option was serialized then it will be unserialized when it is returned.
     *
     * @since MU (3.0.0)
     *
     * @param int    $id            A blog ID. Can be null to refer to the current blog.
     * @param string $option        Name of option to retrieve. Expected to not be SQL-escaped.
     * @param mixed  $default_value Optional. Default value to return if the option does not exist.
     * @return mixed Value set for the option.
     */
    function get_blog_option($id, $option, $default_value = \false)
    {
    }
    /**
     * Adds a new option for a given blog ID.
     *
     * You do not need to serialize values. If the value needs to be serialized, then
     * it will be serialized before it is inserted into the database. Remember,
     * resources can not be serialized or added as an option.
     *
     * You can create options without values and then update the values later.
     * Existing options will not be updated and checks are performed to ensure that you
     * aren't adding a protected WordPress option. Care should be taken to not name
     * options the same as the ones which are protected.
     *
     * @since MU (3.0.0)
     *
     * @param int    $id     A blog ID. Can be null to refer to the current blog.
     * @param string $option Name of option to add. Expected to not be SQL-escaped.
     * @param mixed  $value  Option value, can be anything. Expected to not be SQL-escaped.
     * @return bool True if the option was added, false otherwise.
     */
    function add_blog_option($id, $option, $value)
    {
    }
    /**
     * Removes an option by name for a given blog ID. Prevents removal of protected WordPress options.
     *
     * @since MU (3.0.0)
     *
     * @param int    $id     A blog ID. Can be null to refer to the current blog.
     * @param string $option Name of option to remove. Expected to not be SQL-escaped.
     * @return bool True if the option was deleted, false otherwise.
     */
    function delete_blog_option($id, $option)
    {
    }
    /**
     * Updates an option for a particular blog.
     *
     * @since MU (3.0.0)
     *
     * @param int    $id         The blog ID.
     * @param string $option     The option key.
     * @param mixed  $value      The option value.
     * @param mixed  $deprecated Not used.
     * @return bool True if the value was updated, false otherwise.
     */
    function update_blog_option($id, $option, $value, $deprecated = \null)
    {
    }
    /**
     * Switches the current blog.
     *
     * This function is useful if you need to pull posts, or other information,
     * from other blogs. You can switch back afterwards using restore_current_blog().
     *
     * PHP code loaded with the originally requested site, such as code from a plugin or theme, does not switch. See #14941.
     *
     * @see restore_current_blog()
     * @since MU (3.0.0)
     *
     * @global wpdb            $wpdb               WordPress database abstraction object.
     * @global int             $blog_id
     * @global array           $_wp_switched_stack
     * @global bool            $switched
     * @global string          $table_prefix       The database table prefix.
     * @global WP_Object_Cache $wp_object_cache
     *
     * @param int  $new_blog_id The ID of the blog to switch to. Default: current blog.
     * @param bool $deprecated  Not used.
     * @return true Always returns true.
     */
    function switch_to_blog($new_blog_id, $deprecated = \null)
    {
    }
    /**
     * Restores the current blog, after calling switch_to_blog().
     *
     * @see switch_to_blog()
     * @since MU (3.0.0)
     *
     * @global wpdb            $wpdb               WordPress database abstraction object.
     * @global array           $_wp_switched_stack
     * @global int             $blog_id
     * @global bool            $switched
     * @global string          $table_prefix       The database table prefix.
     * @global WP_Object_Cache $wp_object_cache
     *
     * @return bool True on success, false if we're already on the current blog.
     */
    function restore_current_blog()
    {
    }
    /**
     * Switches the initialized roles and current user capabilities to another site.
     *
     * @since 4.9.0
     *
     * @param int $new_site_id New site ID.
     * @param int $old_site_id Old site ID.
     * @phpstan-return void
     */
    function wp_switch_roles_and_user($new_site_id, $old_site_id)
    {
    }
    /**
     * Determines if switch_to_blog() is in effect.
     *
     * @since 3.5.0
     *
     * @global array $_wp_switched_stack
     *
     * @return bool True if switched, false otherwise.
     */
    function ms_is_switched()
    {
    }
    /**
     * Checks if a particular blog is archived.
     *
     * @since MU (3.0.0)
     *
     * @param int $id Blog ID.
     * @return string Whether the blog is archived or not.
     */
    function is_archived($id)
    {
    }
    /**
     * Updates the 'archived' status of a particular blog.
     *
     * @since MU (3.0.0)
     *
     * @param int    $id       Blog ID.
     * @param string $archived The new status.
     * @return string $archived
     */
    function update_archived($id, $archived)
    {
    }
    /**
     * Updates a blog details field.
     *
     * @since MU (3.0.0)
     * @since 5.1.0 Use wp_update_site() internally.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $blog_id    Blog ID.
     * @param string $pref       Field name.
     * @param string $value      Field value.
     * @param null   $deprecated Not used.
     * @return string|false $value
     */
    function update_blog_status($blog_id, $pref, $value, $deprecated = \null)
    {
    }
    /**
     * Gets a blog details field.
     *
     * @since MU (3.0.0)
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $id   Blog ID.
     * @param string $pref Field name.
     * @return bool|string|null $value
     */
    function get_blog_status($id, $pref)
    {
    }
    /**
     * Gets a list of most recently updated blogs.
     *
     * @since MU (3.0.0)
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param mixed $deprecated Not used.
     * @param int   $start      Optional. Number of blogs to offset the query. Used to build LIMIT clause.
     *                          Can be used for pagination. Default 0.
     * @param int   $quantity   Optional. The maximum number of blogs to retrieve. Default 40.
     * @return array The list of blogs.
     */
    function get_last_updated($deprecated = '', $start = 0, $quantity = 40)
    {
    }
    /**
     * Handler for updating the site's last updated date when a post is published or
     * an already published post is changed.
     *
     * @since 3.3.0
     *
     * @param string  $new_status The new post status.
     * @param string  $old_status The old post status.
     * @param WP_Post $post       Post object.
     * @phpstan-return void
     */
    function _update_blog_date_on_post_publish($new_status, $old_status, $post)
    {
    }
    /**
     * Handler for updating the current site's last updated date when a published
     * post is deleted.
     *
     * @since 3.4.0
     *
     * @param int $post_id Post ID
     * @phpstan-return void
     */
    function _update_blog_date_on_post_delete($post_id)
    {
    }
    /**
     * Handler for updating the current site's posts count when a post is deleted.
     *
     * @since 4.0.0
     * @since 6.2.0 Added the `$post` parameter.
     *
     * @param int     $post_id Post ID.
     * @param WP_Post $post    Post object.
     * @phpstan-return void
     */
    function _update_posts_count_on_delete($post_id, $post)
    {
    }
    /**
     * Handler for updating the current site's posts count when a post status changes.
     *
     * @since 4.0.0
     * @since 4.9.0 Added the `$post` parameter.
     *
     * @param string  $new_status The status the post is changing to.
     * @param string  $old_status The status the post is changing from.
     * @param WP_Post $post       Post object
     * @phpstan-return void
     */
    function _update_posts_count_on_transition_post_status($new_status, $old_status, $post = \null)
    {
    }
    /**
     * Counts number of sites grouped by site status.
     *
     * @since 5.3.0
     *
     * @param int $network_id Optional. The network to get counts for. Default is the current network ID.
     * @return int[] {
     *     Numbers of sites grouped by site status.
     *
     *     @type int $all      The total number of sites.
     *     @type int $public   The number of public sites.
     *     @type int $archived The number of archived sites.
     *     @type int $mature   The number of mature sites.
     *     @type int $spam     The number of spam sites.
     *     @type int $deleted  The number of deleted sites.
     * }
     * @phpstan-return array{
     *   all: int,
     *   public: int,
     *   archived: int,
     *   mature: int,
     *   spam: int,
     *   deleted: int,
     * }
     */
    function wp_count_sites($network_id = \null)
    {
    }
    /**
     * Defines Multisite upload constants.
     *
     * Exists for backward compatibility with legacy file-serving through
     * wp-includes/ms-files.php (wp-content/blogs.php in MU).
     *
     * @since 3.0.0
     * @phpstan-return void
     */
    function ms_upload_constants()
    {
    }
    /**
     * Defines Multisite cookie constants.
     *
     * @since 3.0.0
     */
    function ms_cookie_constants()
    {
    }
    /**
     * Defines Multisite file constants.
     *
     * Exists for backward compatibility with legacy file-serving through
     * wp-includes/ms-files.php (wp-content/blogs.php in MU).
     *
     * @since 3.0.0
     */
    function ms_file_constants()
    {
    }
    /**
     * Defines Multisite subdomain constants and handles warnings and notices.
     *
     * VHOST is deprecated in favor of SUBDOMAIN_INSTALL, which is a bool.
     *
     * On first call, the constants are checked and defined. On second call,
     * we will have translations loaded and can trigger warnings easily.
     *
     * @since 3.0.0
     * @phpstan-return void
     */
    function ms_subdomain_constants()
    {
    }
    /**
     * Get the "dashboard blog", the blog where users without a blog edit their profile data.
     * Dashboard blog functionality was removed in WordPress 3.1, replaced by the user admin.
     *
     * @since MU (3.0.0)
     * @deprecated 3.1.0 Use get_site()
     * @see get_site()
     *
     * @return WP_Site Current site object.
     */
    function get_dashboard_blog()
    {
    }
    /**
     * Generates a random password.
     *
     * @since MU (3.0.0)
     * @deprecated 3.0.0 Use wp_generate_password()
     * @see wp_generate_password()
     *
     * @param int $len Optional. The length of password to generate. Default 8.
     */
    function generate_random_password($len = 8)
    {
    }
    /**
     * Determine if user is a site admin.
     *
     * Plugins should use is_multisite() instead of checking if this function exists
     * to determine if multisite is enabled.
     *
     * This function must reside in a file included only if is_multisite() due to
     * legacy function_exists() checks to determine if multisite is enabled.
     *
     * @since MU (3.0.0)
     * @deprecated 3.0.0 Use is_super_admin()
     * @see is_super_admin()
     *
     * @param string $user_login Optional. Username for the user to check. Default empty.
     */
    function is_site_admin($user_login = '')
    {
    }
    /**
     * Deprecated functionality to gracefully fail.
     *
     * @since MU (3.0.0)
     * @deprecated 3.0.0 Use wp_die()
     * @see wp_die()
     * @phpstan-return never
     */
    function graceful_fail($message)
    {
    }
    /**
     * Deprecated functionality to retrieve user information.
     *
     * @since MU (3.0.0)
     * @deprecated 3.0.0 Use get_user_by()
     * @see get_user_by()
     *
     * @param string $username Username.
     */
    function get_user_details($username)
    {
    }
    /**
     * Deprecated functionality to clear the global post cache.
     *
     * @since MU (3.0.0)
     * @deprecated 3.0.0 Use clean_post_cache()
     * @see clean_post_cache()
     *
     * @param int $post_id Post ID.
     */
    function clear_global_post_cache($post_id)
    {
    }
    /**
     * Deprecated functionality to determine if the current site is the main site.
     *
     * @since MU (3.0.0)
     * @deprecated 3.0.0 Use is_main_site()
     * @see is_main_site()
     */
    function is_main_blog()
    {
    }
    /**
     * Deprecated functionality to validate an email address.
     *
     * @since MU (3.0.0)
     * @deprecated 3.0.0 Use is_email()
     * @see is_email()
     *
     * @param string $email        Email address to verify.
     * @param bool   $check_domain Deprecated.
     * @return string|false Valid email address on success, false on failure.
     */
    function validate_email($email, $check_domain = \true)
    {
    }
    /**
     * Deprecated functionality to retrieve a list of all sites.
     *
     * @since MU (3.0.0)
     * @deprecated 3.0.0 Use wp_get_sites()
     * @see wp_get_sites()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $start      Optional. Offset for retrieving the blog list. Default 0.
     * @param int    $num        Optional. Number of blogs to list. Default 10.
     * @param string $deprecated Unused.
     */
    function get_blog_list($start = 0, $num = 10, $deprecated = '')
    {
    }
    /**
     * Deprecated functionality to retrieve a list of the most active sites.
     *
     * @since MU (3.0.0)
     * @deprecated 3.0.0
     *
     * @param int  $num     Optional. Number of activate blogs to retrieve. Default 10.
     * @param bool $display Optional. Whether or not to display the most active blogs list. Default true.
     * @return array List of "most active" sites.
     */
    function get_most_active_blogs($num = 10, $display = \true)
    {
    }
    /**
     * Redirect a user based on $_GET or $_POST arguments.
     *
     * The function looks for redirect arguments in the following order:
     * 1) $_GET['ref']
     * 2) $_POST['ref']
     * 3) $_SERVER['HTTP_REFERER']
     * 4) $_GET['redirect']
     * 5) $_POST['redirect']
     * 6) $url
     *
     * @since MU (3.0.0)
     * @deprecated 3.3.0 Use wp_redirect()
     * @see wp_redirect()
     *
     * @param string $url Optional. Redirect URL. Default empty.
     * @phpstan-return never
     */
    function wpmu_admin_do_redirect($url = '')
    {
    }
    /**
     * Adds an 'updated=true' argument to a URL.
     *
     * @since MU (3.0.0)
     * @deprecated 3.3.0 Use add_query_arg()
     * @see add_query_arg()
     *
     * @param string $url Optional. Redirect URL. Default empty.
     * @return string
     */
    function wpmu_admin_redirect_add_updated_param($url = '')
    {
    }
    /**
     * Get a numeric user ID from either an email address or a login.
     *
     * A numeric string is considered to be an existing user ID
     * and is simply returned as such.
     *
     * @since MU (3.0.0)
     * @deprecated 3.6.0 Use get_user_by()
     * @see get_user_by()
     *
     * @param string $email_or_login Either an email address or a login.
     * @return int
     */
    function get_user_id_from_string($email_or_login)
    {
    }
    /**
     * Get a full site URL, given a domain and a path.
     *
     * @since MU (3.0.0)
     * @deprecated 3.7.0
     *
     * @param string $domain
     * @param string $path
     * @return string
     */
    function get_blogaddress_by_domain($domain, $path)
    {
    }
    /**
     * Create an empty blog.
     *
     * @since MU (3.0.0)
     * @deprecated 4.4.0
     *
     * @param string $domain       The new blog's domain.
     * @param string $path         The new blog's path.
     * @param string $weblog_title The new blog's title.
     * @param int    $site_id      Optional. Defaults to 1.
     * @return string|int The ID of the newly created blog
     */
    function create_empty_blog($domain, $path, $weblog_title, $site_id = 1)
    {
    }
    /**
     * Get the admin for a domain/path combination.
     *
     * @since MU (3.0.0)
     * @deprecated 4.4.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $domain Optional. Network domain.
     * @param string $path   Optional. Network path.
     * @return array|false The network admins.
     */
    function get_admin_users_for_domain($domain = '', $path = '')
    {
    }
    /**
     * Return an array of sites for a network or networks.
     *
     * @since 3.7.0
     * @deprecated 4.6.0 Use get_sites()
     * @see get_sites()
     *
     * @param array $args {
     *     Array of default arguments. Optional.
     *
     *     @type int|int[] $network_id A network ID or array of network IDs. Set to null to retrieve sites
     *                                 from all networks. Defaults to current network ID.
     *     @type int       $public     Retrieve public or non-public sites. Default null, for any.
     *     @type int       $archived   Retrieve archived or non-archived sites. Default null, for any.
     *     @type int       $mature     Retrieve mature or non-mature sites. Default null, for any.
     *     @type int       $spam       Retrieve spam or non-spam sites. Default null, for any.
     *     @type int       $deleted    Retrieve deleted or non-deleted sites. Default null, for any.
     *     @type int       $limit      Number of sites to limit the query to. Default 100.
     *     @type int       $offset     Exclude the first x sites. Used in combination with the $limit parameter. Default 0.
     * }
     * @return array[] An empty array if the installation is considered "large" via wp_is_large_network(). Otherwise,
     *                 an associative array of WP_Site data as arrays.
     * @phpstan-param array{
     *   network_id?: int|int[],
     *   public?: int,
     *   archived?: int,
     *   mature?: int,
     *   spam?: int,
     *   deleted?: int,
     *   limit?: int,
     *   offset?: int,
     * } $args
     */
    function wp_get_sites($args = array())
    {
    }
    /**
     * Check whether a usermeta key has to do with the current blog.
     *
     * @since MU (3.0.0)
     * @deprecated 4.9.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $key
     * @param int    $user_id Optional. Defaults to current user.
     * @param int    $blog_id Optional. Defaults to current blog.
     * @return bool
     */
    function is_user_option_local($key, $user_id = 0, $blog_id = 0)
    {
    }
    /**
     * Store basic site info in the blogs table.
     *
     * This function creates a row in the wp_blogs table and returns
     * the new blog's ID. It is the first step in creating a new blog.
     *
     * @since MU (3.0.0)
     * @deprecated 5.1.0 Use wp_insert_site()
     * @see wp_insert_site()
     *
     * @param string $domain  The domain of the new site.
     * @param string $path    The path of the new site.
     * @param int    $site_id Unless you're running a multi-network install, be sure to set this value to 1.
     * @return int|false The ID of the new row
     */
    function insert_blog($domain, $path, $site_id)
    {
    }
    /**
     * Install an empty blog.
     *
     * Creates the new blog tables and options. If calling this function
     * directly, be sure to use switch_to_blog() first, so that $wpdb
     * points to the new blog.
     *
     * @since MU (3.0.0)
     * @deprecated 5.1.0
     *
     * @global wpdb     $wpdb     WordPress database abstraction object.
     * @global WP_Roles $wp_roles WordPress role management object.
     *
     * @param int    $blog_id    The value returned by wp_insert_site().
     * @param string $blog_title The title of the new site.
     */
    function install_blog($blog_id, $blog_title = '')
    {
    }
    /**
     * Set blog defaults.
     *
     * This function creates a row in the wp_blogs table.
     *
     * @since MU (3.0.0)
     * @deprecated MU
     * @deprecated Use wp_install_defaults()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $blog_id Ignored in this function.
     * @param int $user_id
     */
    function install_blog_defaults($blog_id, $user_id)
    {
    }
    /**
     * Update the status of a user in the database.
     *
     * Previously used in core to mark a user as spam or "ham" (not spam) in Multisite.
     *
     * @since 3.0.0
     * @deprecated 5.3.0 Use wp_update_user()
     * @see wp_update_user()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $id         The user ID.
     * @param string $pref       The column in the wp_users table to update the user's status
     *                           in (presumably user_status, spam, or deleted).
     * @param int    $value      The new status for the user.
     * @param null   $deprecated Deprecated as of 3.0.2 and should not be used.
     * @return int   The initially passed $value.
     */
    function update_user_status($id, $pref, $value, $deprecated = \null)
    {
    }
    /**
     * Maintains a canonical list of terms by syncing terms created for each blog with the global terms table.
     *
     * @since 3.0.0
     * @since 6.1.0 This function no longer does anything.
     * @deprecated 6.1.0
     *
     * @param int    $term_id    An ID for a term on the current blog.
     * @param string $deprecated Not used.
     * @return int An ID from the global terms table mapped from $term_id.
     */
    function global_terms($term_id, $deprecated = '')
    {
    }
    /**
     * Gets the network's site and user counts.
     *
     * @since MU (3.0.0)
     *
     * @return int[] {
     *     Site and user count for the network.
     *
     *     @type int $blogs Number of sites on the network.
     *     @type int $users Number of users on the network.
     * }
     * @phpstan-return array{
     *   blogs: int,
     *   users: int,
     * }
     */
    function get_sitestats()
    {
    }
    /**
     * Gets one of a user's active blogs.
     *
     * Returns the user's primary blog, if they have one and
     * it is active. If it's inactive, function returns another
     * active blog of the user. If none are found, the user
     * is added as a Subscriber to the Dashboard Blog and that blog
     * is returned.
     *
     * @since MU (3.0.0)
     *
     * @param int $user_id The unique ID of the user
     * @return WP_Site|void The blog object
     */
    function get_active_blog_for_user($user_id)
    {
    }
    /**
     * Gets the number of active sites on the installation.
     *
     * The count is cached and updated twice daily. This is not a live count.
     *
     * @since MU (3.0.0)
     * @since 3.7.0 The `$network_id` parameter has been deprecated.
     * @since 4.8.0 The `$network_id` parameter is now being used.
     *
     * @param int|null $network_id ID of the network. Default is the current network.
     * @return int Number of active sites on the network.
     */
    function get_blog_count($network_id = \null)
    {
    }
    /**
     * Gets a blog post from any site on the network.
     *
     * This function is similar to get_post(), except that it can retrieve a post
     * from any site on the network, not just the current site.
     *
     * @since MU (3.0.0)
     *
     * @param int $blog_id ID of the blog.
     * @param int $post_id ID of the post being looked for.
     * @return WP_Post|null WP_Post object on success, null on failure
     */
    function get_blog_post($blog_id, $post_id)
    {
    }
    /**
     * Adds a user to a blog, along with specifying the user's role.
     *
     * Use the {@see 'add_user_to_blog'} action to fire an event when users are added to a blog.
     *
     * @since MU (3.0.0)
     *
     * @param int    $blog_id ID of the blog the user is being added to.
     * @param int    $user_id ID of the user being added.
     * @param string $role    User role.
     * @return true|WP_Error True on success or a WP_Error object if the user doesn't exist
     *                       or could not be added.
     */
    function add_user_to_blog($blog_id, $user_id, $role)
    {
    }
    /**
     * Removes a user from a blog.
     *
     * Use the {@see 'remove_user_from_blog'} action to fire an event when
     * users are removed from a blog.
     *
     * Accepts an optional `$reassign` parameter, if you want to
     * reassign the user's blog posts to another user upon removal.
     *
     * @since MU (3.0.0)
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $user_id  ID of the user being removed.
     * @param int $blog_id  Optional. ID of the blog the user is being removed from. Default 0.
     * @param int $reassign Optional. ID of the user to whom to reassign posts. Default 0.
     * @return true|WP_Error True on success or a WP_Error object if the user doesn't exist.
     */
    function remove_user_from_blog($user_id, $blog_id = 0, $reassign = 0)
    {
    }
    /**
     * Gets the permalink for a post on another blog.
     *
     * @since MU (3.0.0) 1.0
     *
     * @param int $blog_id ID of the source blog.
     * @param int $post_id ID of the desired post.
     * @return string The post's permalink.
     */
    function get_blog_permalink($blog_id, $post_id)
    {
    }
    /**
     * Gets a blog's numeric ID from its URL.
     *
     * On a subdirectory installation like example.com/blog1/,
     * $domain will be the root 'example.com' and $path the
     * subdirectory '/blog1/'. With subdomains like blog1.example.com,
     * $domain is 'blog1.example.com' and $path is '/'.
     *
     * @since MU (3.0.0)
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $domain Website domain.
     * @param string $path   Optional. Not required for subdomain installations. Default '/'.
     * @return int 0 if no blog found, otherwise the ID of the matching blog.
     */
    function get_blog_id_from_url($domain, $path = '/')
    {
    }
    /**
     * Checks an email address against a list of banned domains.
     *
     * This function checks against the Banned Email Domains list
     * at wp-admin/network/settings.php. The check is only run on
     * self-registrations; user creation at wp-admin/network/users.php
     * bypasses this check.
     *
     * @since MU (3.0.0)
     *
     * @param string $user_email The email provided by the user at registration.
     * @return bool True when the email address is banned, false otherwise.
     */
    function is_email_address_unsafe($user_email)
    {
    }
    /**
     * Sanitizes and validates data required for a user sign-up.
     *
     * Verifies the validity and uniqueness of user names and user email addresses,
     * and checks email addresses against allowed and disallowed domains provided by
     * administrators.
     *
     * The {@see 'wpmu_validate_user_signup'} hook provides an easy way to modify the sign-up
     * process. The value $result, which is passed to the hook, contains both the user-provided
     * info and the error messages created by the function. {@see 'wpmu_validate_user_signup'}
     * allows you to process the data in any way you'd like, and unset the relevant errors if
     * necessary.
     *
     * @since MU (3.0.0)
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $user_name  The login name provided by the user.
     * @param string $user_email The email provided by the user.
     * @return array {
     *     The array of user name, email, and the error messages.
     *
     *     @type string   $user_name     Sanitized and unique username.
     *     @type string   $orig_username Original username.
     *     @type string   $user_email    User email address.
     *     @type WP_Error $errors        WP_Error object containing any errors found.
     * }
     * @phpstan-return array{
     *   user_name: string,
     *   orig_username: string,
     *   user_email: string,
     *   errors: WP_Error,
     * }
     */
    function wpmu_validate_user_signup($user_name, $user_email)
    {
    }
    /**
     * Processes new site registrations.
     *
     * Checks the data provided by the user during blog signup. Verifies
     * the validity and uniqueness of blog paths and domains.
     *
     * This function prevents the current user from registering a new site
     * with a blogname equivalent to another user's login name. Passing the
     * $user parameter to the function, where $user is the other user, is
     * effectively an override of this limitation.
     *
     * Filter {@see 'wpmu_validate_blog_signup'} if you want to modify
     * the way that WordPress validates new site signups.
     *
     * @since MU (3.0.0)
     *
     * @global wpdb   $wpdb   WordPress database abstraction object.
     * @global string $domain
     *
     * @param string         $blogname   The site name provided by the user. Must be unique.
     * @param string         $blog_title The site title provided by the user.
     * @param WP_User|string $user       Optional. The user object to check against the new site name.
     *                                   Default empty string.
     * @return array {
     *     Array of domain, path, site name, site title, user and error messages.
     *
     *     @type string         $domain     Domain for the site.
     *     @type string         $path       Path for the site. Used in subdirectory installations.
     *     @type string         $blogname   The unique site name (slug).
     *     @type string         $blog_title Blog title.
     *     @type string|WP_User $user       By default, an empty string. A user object if provided.
     *     @type WP_Error       $errors     WP_Error containing any errors found.
     * }
     * @phpstan-return array{
     *   domain: string,
     *   path: string,
     *   blogname: string,
     *   blog_title: string,
     *   user: string|WP_User,
     *   errors: WP_Error,
     * }
     */
    function wpmu_validate_blog_signup($blogname, $blog_title, $user = '')
    {
    }
    /**
     * Records site signup information for future activation.
     *
     * @since MU (3.0.0)
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $domain     The requested domain.
     * @param string $path       The requested path.
     * @param string $title      The requested site title.
     * @param string $user       The user's requested login name.
     * @param string $user_email The user's email address.
     * @param array  $meta       Optional. Signup meta data. By default, contains the requested privacy setting and lang_id.
     */
    function wpmu_signup_blog($domain, $path, $title, $user, $user_email, $meta = array())
    {
    }
    /**
     * Records user signup information for future activation.
     *
     * This function is used when user registration is open but
     * new site registration is not.
     *
     * @since MU (3.0.0)
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $user       The user's requested login name.
     * @param string $user_email The user's email address.
     * @param array  $meta       Optional. Signup meta data. Default empty array.
     */
    function wpmu_signup_user($user, $user_email, $meta = array())
    {
    }
    /**
     * Sends a confirmation request email to a user when they sign up for a new site. The new site will not become active
     * until the confirmation link is clicked.
     *
     * This is the notification function used when site registration
     * is enabled.
     *
     * Filter {@see 'wpmu_signup_blog_notification'} to bypass this function or
     * replace it with your own notification behavior.
     *
     * Filter {@see 'wpmu_signup_blog_notification_email'} and
     * {@see 'wpmu_signup_blog_notification_subject'} to change the content
     * and subject line of the email sent to newly registered users.
     *
     * @since MU (3.0.0)
     *
     * @param string $domain     The new blog domain.
     * @param string $path       The new blog path.
     * @param string $title      The site title.
     * @param string $user_login The user's login name.
     * @param string $user_email The user's email address.
     * @param string $key        The activation key created in wpmu_signup_blog().
     * @param array  $meta       Optional. Signup meta data. By default, contains the requested privacy setting and lang_id.
     * @return bool
     */
    function wpmu_signup_blog_notification($domain, $path, $title, $user_login, $user_email, $key, $meta = array())
    {
    }
    /**
     * Sends a confirmation request email to a user when they sign up for a new user account (without signing up for a site
     * at the same time). The user account will not become active until the confirmation link is clicked.
     *
     * This is the notification function used when no new site has
     * been requested.
     *
     * Filter {@see 'wpmu_signup_user_notification'} to bypass this function or
     * replace it with your own notification behavior.
     *
     * Filter {@see 'wpmu_signup_user_notification_email'} and
     * {@see 'wpmu_signup_user_notification_subject'} to change the content
     * and subject line of the email sent to newly registered users.
     *
     * @since MU (3.0.0)
     *
     * @param string $user_login The user's login name.
     * @param string $user_email The user's email address.
     * @param string $key        The activation key created in wpmu_signup_user()
     * @param array  $meta       Optional. Signup meta data. Default empty array.
     * @return bool
     */
    function wpmu_signup_user_notification($user_login, $user_email, $key, $meta = array())
    {
    }
    /**
     * Activates a signup.
     *
     * Hook to {@see 'wpmu_activate_user'} or {@see 'wpmu_activate_blog'} for events
     * that should happen only when users or sites are self-created (since
     * those actions are not called when users and sites are created
     * by a Super Admin).
     *
     * @since MU (3.0.0)
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $key The activation key provided to the user.
     * @return array|WP_Error An array containing information about the activated user and/or blog.
     */
    function wpmu_activate_signup($key)
    {
    }
    /**
     * Deletes an associated signup entry when a user is deleted from the database.
     *
     * @since 5.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int      $id       ID of the user to delete.
     * @param int|null $reassign ID of the user to reassign posts and links to.
     * @param WP_User  $user     User object.
     */
    function wp_delete_signup_on_user_delete($id, $reassign, $user)
    {
    }
    /**
     * Creates a user.
     *
     * This function runs when a user self-registers as well as when
     * a Super Admin creates a new user. Hook to {@see 'wpmu_new_user'} for events
     * that should affect all new users, but only on Multisite (otherwise
     * use {@see 'user_register'}).
     *
     * @since MU (3.0.0)
     *
     * @param string $user_name The new user's login name.
     * @param string $password  The new user's password.
     * @param string $email     The new user's email address.
     * @return int|false Returns false on failure, or int $user_id on success.
     */
    function wpmu_create_user($user_name, $password, $email)
    {
    }
    /**
     * Creates a site.
     *
     * This function runs when a user self-registers a new site as well
     * as when a Super Admin creates a new site. Hook to {@see 'wpmu_new_blog'}
     * for events that should affect all new sites.
     *
     * On subdirectory installations, $domain is the same as the main site's
     * domain, and the path is the subdirectory name (eg 'example.com'
     * and '/blog1/'). On subdomain installations, $domain is the new subdomain +
     * root domain (eg 'blog1.example.com'), and $path is '/'.
     *
     * @since MU (3.0.0)
     *
     * @param string $domain     The new site's domain.
     * @param string $path       The new site's path.
     * @param string $title      The new site's title.
     * @param int    $user_id    The user ID of the new site's admin.
     * @param array  $options    Optional. Array of key=>value pairs used to set initial site options.
     *                           If valid status keys are included ('public', 'archived', 'mature',
     *                           'spam', 'deleted', or 'lang_id') the given site status(es) will be
     *                           updated. Otherwise, keys and values will be used to set options for
     *                           the new site. Default empty array.
     * @param int    $network_id Optional. Network ID. Only relevant on multi-network installations.
     *                           Default 1.
     * @return int|WP_Error Returns WP_Error object on failure, the new site ID on success.
     */
    function wpmu_create_blog($domain, $path, $title, $user_id, $options = array(), $network_id = 1)
    {
    }
    /**
     * Notifies the network admin that a new site has been activated.
     *
     * Filter {@see 'newblog_notify_siteadmin'} to change the content of
     * the notification email.
     *
     * @since MU (3.0.0)
     * @since 5.1.0 $blog_id now supports input from the {@see 'wp_initialize_site'} action.
     *
     * @param WP_Site|int $blog_id    The new site's object or ID.
     * @param string      $deprecated Not used.
     * @return bool
     */
    function newblog_notify_siteadmin($blog_id, $deprecated = '')
    {
    }
    /**
     * Notifies the network admin that a new user has been activated.
     *
     * Filter {@see 'newuser_notify_siteadmin'} to change the content of
     * the notification email.
     *
     * @since MU (3.0.0)
     *
     * @param int $user_id The new user's ID.
     * @return bool
     */
    function newuser_notify_siteadmin($user_id)
    {
    }
    /**
     * Checks whether a site name is already taken.
     *
     * The name is the site's subdomain or the site's subdirectory
     * path depending on the network settings.
     *
     * Used during the new site registration process to ensure
     * that each site name is unique.
     *
     * @since MU (3.0.0)
     *
     * @param string $domain     The domain to be checked.
     * @param string $path       The path to be checked.
     * @param int    $network_id Optional. Network ID. Only relevant on multi-network installations.
     *                           Default 1.
     * @return int|null The site ID if the site name exists, null otherwise.
     */
    function domain_exists($domain, $path, $network_id = 1)
    {
    }
    /**
     * Notifies the site administrator that their site activation was successful.
     *
     * Filter {@see 'wpmu_welcome_notification'} to disable or bypass.
     *
     * Filter {@see 'update_welcome_email'} and {@see 'update_welcome_subject'} to
     * modify the content and subject line of the notification email.
     *
     * @since MU (3.0.0)
     *
     * @param int    $blog_id  Site ID.
     * @param int    $user_id  User ID.
     * @param string $password User password, or "N/A" if the user account is not new.
     * @param string $title    Site title.
     * @param array  $meta     Optional. Signup meta data. By default, contains the requested privacy setting and lang_id.
     * @return bool Whether the email notification was sent.
     */
    function wpmu_welcome_notification($blog_id, $user_id, $password, $title, $meta = array())
    {
    }
    /**
     * Notifies the Multisite network administrator that a new site was created.
     *
     * Filter {@see 'send_new_site_email'} to disable or bypass.
     *
     * Filter {@see 'new_site_email'} to filter the contents.
     *
     * @since 5.6.0
     *
     * @param int $site_id Site ID of the new site.
     * @param int $user_id User ID of the administrator of the new site.
     * @return bool Whether the email notification was sent.
     */
    function wpmu_new_site_admin_notification($site_id, $user_id)
    {
    }
    /**
     * Notifies a user that their account activation has been successful.
     *
     * Filter {@see 'wpmu_welcome_user_notification'} to disable or bypass.
     *
     * Filter {@see 'update_welcome_user_email'} and {@see 'update_welcome_user_subject'} to
     * modify the content and subject line of the notification email.
     *
     * @since MU (3.0.0)
     *
     * @param int    $user_id  User ID.
     * @param string $password User password.
     * @param array  $meta     Optional. Signup meta data. Default empty array.
     * @return bool
     */
    function wpmu_welcome_user_notification($user_id, $password, $meta = array())
    {
    }
    /**
     * Gets the current network.
     *
     * Returns an object containing the 'id', 'domain', 'path', and 'site_name'
     * properties of the network being viewed.
     *
     * @see wpmu_current_site()
     *
     * @since MU (3.0.0)
     *
     * @global WP_Network $current_site The current network.
     *
     * @return WP_Network The current network.
     */
    function get_current_site()
    {
    }
    /**
     * Gets a user's most recent post.
     *
     * Walks through each of a user's blogs to find the post with
     * the most recent post_date_gmt.
     *
     * @since MU (3.0.0)
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $user_id User ID.
     * @return array Contains the blog_id, post_id, post_date_gmt, and post_gmt_ts.
     */
    function get_most_recent_post_of_user($user_id)
    {
    }
    /**
     * Checks an array of MIME types against a list of allowed types.
     *
     * WordPress ships with a set of allowed upload filetypes,
     * which is defined in wp-includes/functions.php in
     * get_allowed_mime_types(). This function is used to filter
     * that list against the filetypes allowed provided by Multisite
     * Super Admins at wp-admin/network/settings.php.
     *
     * @since MU (3.0.0)
     *
     * @param array $mimes
     * @return array
     */
    function check_upload_mimes($mimes)
    {
    }
    /**
     * Updates a blog's post count.
     *
     * WordPress MS stores a blog's post count as an option so as
     * to avoid extraneous COUNTs when a blog's details are fetched
     * with get_site(). This function is called when posts are published
     * or unpublished to make sure the count stays current.
     *
     * @since MU (3.0.0)
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $deprecated Not used.
     */
    function update_posts_count($deprecated = '')
    {
    }
    /**
     * Logs the user email, IP, and registration date of a new site.
     *
     * @since MU (3.0.0)
     * @since 5.1.0 Parameters now support input from the {@see 'wp_initialize_site'} action.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param WP_Site|int $blog_id The new site's object or ID.
     * @param int|array   $user_id User ID, or array of arguments including 'user_id'.
     */
    function wpmu_log_new_registrations($blog_id, $user_id)
    {
    }
    /**
     * Ensures that the current site's domain is listed in the allowed redirect host list.
     *
     * @see wp_validate_redirect()
     * @since MU (3.0.0)
     *
     * @param array|string $deprecated Not used.
     * @return string[] {
     *     An array containing the current site's domain.
     *
     *     @type string $0 The current site's domain.
     * }
     * @phpstan-return array{
     *   0: string,
     * }
     */
    function redirect_this_site($deprecated = '')
    {
    }
    /**
     * Checks whether an upload is too big.
     *
     * @since MU (3.0.0)
     *
     * @param array $upload An array of information about the newly-uploaded file.
     * @return string|array If the upload is under the size limit, $upload is returned. Otherwise returns an error message.
     */
    function upload_is_file_too_big($upload)
    {
    }
    /**
     * Adds a nonce field to the signup page.
     *
     * @since MU (3.0.0)
     */
    function signup_nonce_fields()
    {
    }
    /**
     * Processes the signup nonce created in signup_nonce_fields().
     *
     * @since MU (3.0.0)
     *
     * @param array $result
     * @return array
     */
    function signup_nonce_check($result)
    {
    }
    /**
     * Corrects 404 redirects when NOBLOGREDIRECT is defined.
     *
     * @since MU (3.0.0)
     */
    function maybe_redirect_404()
    {
    }
    /**
     * Adds a new user to a blog by visiting /newbloguser/{key}/.
     *
     * This will only work when the user's details are saved as an option
     * keyed as 'new_user_{key}', where '{key}' is a hash generated for the user to be
     * added, as when a user is invited through the regular WP Add User interface.
     *
     * @since MU (3.0.0)
     * @phpstan-return void
     */
    function maybe_add_existing_user_to_blog()
    {
    }
    /**
     * Adds a user to a blog based on details from maybe_add_existing_user_to_blog().
     *
     * @since MU (3.0.0)
     *
     * @param array|false $details {
     *     User details. Must at least contain values for the keys listed below.
     *
     *     @type int    $user_id The ID of the user being added to the current blog.
     *     @type string $role    The role to be assigned to the user.
     * }
     * @return true|WP_Error|void True on success or a WP_Error object if the user doesn't exist
     *                            or could not be added. Void if $details array was not provided.
     * @phpstan-param false|array{
     *   user_id?: int,
     *   role?: string,
     * } $details
     */
    function add_existing_user_to_blog($details = \false)
    {
    }
    /**
     * Adds a newly created user to the appropriate blog
     *
     * To add a user in general, use add_user_to_blog(). This function
     * is specifically hooked into the {@see 'wpmu_activate_user'} action.
     *
     * @since MU (3.0.0)
     *
     * @see add_user_to_blog()
     *
     * @param int    $user_id  User ID.
     * @param string $password User password. Ignored.
     * @param array  $meta     Signup meta data.
     */
    function add_new_user_to_blog($user_id, $password, $meta)
    {
    }
    /**
     * Corrects From host on outgoing mail to match the site domain.
     *
     * @since MU (3.0.0)
     *
     * @param PHPMailer $phpmailer The PHPMailer instance (passed by reference).
     */
    function fix_phpmailer_messageid($phpmailer)
    {
    }
    /**
     * Determines whether a user is marked as a spammer, based on user login.
     *
     * @since MU (3.0.0)
     *
     * @param string|WP_User $user Optional. Defaults to current user. WP_User object,
     *                             or user login name as a string.
     * @return bool
     */
    function is_user_spammy($user = \null)
    {
    }
    /**
     * Updates this blog's 'public' setting in the global blogs table.
     *
     * Public blogs have a setting of 1, private blogs are 0.
     *
     * @since MU (3.0.0)
     *
     * @param int $old_value The old public value.
     * @param int $value     The new public value.
     */
    function update_blog_public($old_value, $value)
    {
    }
    /**
     * Determines whether users can self-register, based on Network settings.
     *
     * @since MU (3.0.0)
     *
     * @return bool
     */
    function users_can_register_signup_filter()
    {
    }
    /**
     * Ensures that the welcome message is not empty. Currently unused.
     *
     * @since MU (3.0.0)
     *
     * @param string $text
     * @return string
     */
    function welcome_user_msg_filter($text)
    {
    }
    /**
     * Determines whether to force SSL on content.
     *
     * @since 2.8.5
     *
     * @param bool $force
     * @return bool True if forced, false if not forced.
     */
    function force_ssl_content($force = '')
    {
    }
    /**
     * Formats a URL to use https.
     *
     * Useful as a filter.
     *
     * @since 2.8.5
     *
     * @param string $url URL.
     * @return string URL with https as the scheme.
     */
    function filter_SSL($url)
    {
    }
    /**
     * Schedules update of the network-wide counts for the current network.
     *
     * @since 3.1.0
     * @phpstan-return void
     */
    function wp_schedule_update_network_counts()
    {
    }
    /**
     * Updates the network-wide counts for the current network.
     *
     * @since 3.1.0
     * @since 4.8.0 The `$network_id` parameter has been added.
     *
     * @param int|null $network_id ID of the network. Default is the current network.
     */
    function wp_update_network_counts($network_id = \null)
    {
    }
    /**
     * Updates the count of sites for the current network.
     *
     * If enabled through the {@see 'enable_live_network_counts'} filter, update the sites count
     * on a network when a site is created or its status is updated.
     *
     * @since 3.7.0
     * @since 4.8.0 The `$network_id` parameter has been added.
     *
     * @param int|null $network_id ID of the network. Default is the current network.
     * @phpstan-return void
     */
    function wp_maybe_update_network_site_counts($network_id = \null)
    {
    }
    /**
     * Updates the network-wide users count.
     *
     * If enabled through the {@see 'enable_live_network_counts'} filter, update the users count
     * on a network when a user is created or its status is updated.
     *
     * @since 3.7.0
     * @since 4.8.0 The `$network_id` parameter has been added.
     *
     * @param int|null $network_id ID of the network. Default is the current network.
     * @phpstan-return void
     */
    function wp_maybe_update_network_user_counts($network_id = \null)
    {
    }
    /**
     * Updates the network-wide site count.
     *
     * @since 3.7.0
     * @since 4.8.0 The `$network_id` parameter has been added.
     *
     * @param int|null $network_id ID of the network. Default is the current network.
     */
    function wp_update_network_site_counts($network_id = \null)
    {
    }
    /**
     * Updates the network-wide user count.
     *
     * @since 3.7.0
     * @since 4.8.0 The `$network_id` parameter has been added.
     * @since 6.0.0 This function is now a wrapper for wp_update_user_counts().
     *
     * @param int|null $network_id ID of the network. Default is the current network.
     */
    function wp_update_network_user_counts($network_id = \null)
    {
    }
    /**
     * Returns the space used by the current site.
     *
     * @since 3.5.0
     *
     * @return int Used space in megabytes.
     */
    function get_space_used()
    {
    }
    /**
     * Returns the upload quota for the current blog.
     *
     * @since MU (3.0.0)
     *
     * @return int Quota in megabytes.
     */
    function get_space_allowed()
    {
    }
    /**
     * Determines if there is any upload space left in the current blog's quota.
     *
     * @since 3.0.0
     *
     * @return int of upload space available in bytes.
     */
    function get_upload_space_available()
    {
    }
    /**
     * Determines if there is any upload space left in the current blog's quota.
     *
     * @since 3.0.0
     * @return bool True if space is available, false otherwise.
     */
    function is_upload_space_available()
    {
    }
    /**
     * Filters the maximum upload file size allowed, in bytes.
     *
     * @since 3.0.0
     *
     * @param int $size Upload size limit in bytes.
     * @return int Upload size limit in bytes.
     */
    function upload_size_limit_filter($size)
    {
    }
    /**
     * Determines whether or not we have a large network.
     *
     * The default criteria for a large network is either more than 10,000 users or more than 10,000 sites.
     * Plugins can alter this criteria using the {@see 'wp_is_large_network'} filter.
     *
     * @since 3.3.0
     * @since 4.8.0 The `$network_id` parameter has been added.
     *
     * @param string   $using      'sites' or 'users'. Default is 'sites'.
     * @param int|null $network_id ID of the network. Default is the current network.
     * @return bool True if the network meets the criteria for large. False otherwise.
     */
    function wp_is_large_network($using = 'sites', $network_id = \null)
    {
    }
    /**
     * Retrieves a list of reserved site on a sub-directory Multisite installation.
     *
     * @since 4.4.0
     *
     * @return string[] Array of reserved names.
     */
    function get_subdirectory_reserved_names()
    {
    }
    /**
     * Sends a confirmation request email when a change of network admin email address is attempted.
     *
     * The new network admin address will not become active until confirmed.
     *
     * @since 4.9.0
     *
     * @param string $old_value The old network admin email address.
     * @param string $value     The proposed new network admin email address.
     * @phpstan-return void
     */
    function update_network_option_new_admin_email($old_value, $value)
    {
    }
    /**
     * Sends an email to the old network admin email address when the network admin email address changes.
     *
     * @since 4.9.0
     *
     * @param string $option_name The relevant database option name.
     * @param string $new_email   The new network admin email address.
     * @param string $old_email   The old network admin email address.
     * @param int    $network_id  ID of the network.
     * @phpstan-return void
     */
    function wp_network_admin_email_change_notification($option_name, $new_email, $old_email, $network_id)
    {
    }
    /**
     * Whether a subdomain configuration is enabled.
     *
     * @since 3.0.0
     *
     * @return bool True if subdomain configuration is enabled, false otherwise.
     */
    function is_subdomain_install()
    {
    }
    /**
     * Returns array of network plugin files to be included in global scope.
     *
     * The default directory is wp-content/plugins. To change the default directory
     * manually, define `WP_PLUGIN_DIR` and `WP_PLUGIN_URL` in `wp-config.php`.
     *
     * @access private
     * @since 3.1.0
     *
     * @return string[] Array of absolute paths to files to include.
     */
    function wp_get_active_network_plugins()
    {
    }
    /**
     * Checks status of current blog.
     *
     * Checks if the blog is deleted, inactive, archived, or spammed.
     *
     * Dies with a default message if the blog does not pass the check.
     *
     * To change the default message when a blog does not pass the check,
     * use the wp-content/blog-deleted.php, blog-inactive.php and
     * blog-suspended.php drop-ins.
     *
     * @since 3.0.0
     *
     * @return true|string Returns true on success, or drop-in file to include.
     */
    function ms_site_check()
    {
    }
    /**
     * Retrieves the closest matching network for a domain and path.
     *
     * @since 3.9.0
     *
     * @internal In 4.4.0, converted to a wrapper for WP_Network::get_by_path()
     *
     * @param string   $domain   Domain to check.
     * @param string   $path     Path to check.
     * @param int|null $segments Path segments to use. Defaults to null, or the full path.
     * @return WP_Network|false Network object if successful. False when no network is found.
     */
    function get_network_by_path($domain, $path, $segments = \null)
    {
    }
    /**
     * Retrieves the closest matching site object by its domain and path.
     *
     * This will not necessarily return an exact match for a domain and path. Instead, it
     * breaks the domain and path into pieces that are then used to match the closest
     * possibility from a query.
     *
     * The intent of this method is to match a site object during bootstrap for a
     * requested site address
     *
     * @since 3.9.0
     * @since 4.7.0 Updated to always return a `WP_Site` object.
     *
     * @param string   $domain   Domain to check.
     * @param string   $path     Path to check.
     * @param int|null $segments Path segments to use. Defaults to null, or the full path.
     * @return WP_Site|false Site object if successful. False when no site is found.
     */
    function get_site_by_path($domain, $path, $segments = \null)
    {
    }
    /**
     * Identifies the network and site of a requested domain and path and populates the
     * corresponding network and site global objects as part of the multisite bootstrap process.
     *
     * Prior to 4.6.0, this was a procedural block in `ms-settings.php`. It was wrapped into
     * a function to facilitate unit tests. It should not be used outside of core.
     *
     * Usually, it's easier to query the site first, which then declares its network.
     * In limited situations, we either can or must find the network first.
     *
     * If a network and site are found, a `true` response will be returned so that the
     * request can continue.
     *
     * If neither a network or site is found, `false` or a URL string will be returned
     * so that either an error can be shown or a redirect can occur.
     *
     * @since 4.6.0
     * @access private
     *
     * @global WP_Network $current_site The current network.
     * @global WP_Site    $current_blog The current site.
     *
     * @param string $domain    The requested domain.
     * @param string $path      The requested path.
     * @param bool   $subdomain Optional. Whether a subdomain (true) or subdirectory (false) configuration.
     *                          Default false.
     * @return bool|string True if bootstrap successfully populated `$current_blog` and `$current_site`.
     *                     False if bootstrap could not be properly completed.
     *                     Redirect URL if parts exist, but the request as a whole can not be fulfilled.
     */
    function ms_load_current_site_and_network($domain, $path, $subdomain = \false)
    {
    }
    /**
     * Displays a failure message.
     *
     * Used when a blog's tables do not exist. Checks for a missing $wpdb->site table as well.
     *
     * @access private
     * @since 3.0.0
     * @since 4.4.0 The `$domain` and `$path` parameters were added.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $domain The requested domain for the error to reference.
     * @param string $path   The requested path for the error to reference.
     * @phpstan-return never
     */
    function ms_not_installed($domain, $path)
    {
    }
    /**
     * This deprecated function formerly set the site_name property of the $current_site object.
     *
     * This function simply returns the object, as before.
     * The bootstrap takes care of setting site_name.
     *
     * @access private
     * @since 3.0.0
     * @deprecated 3.9.0 Use get_current_site() instead.
     *
     * @param WP_Network $current_site
     * @return WP_Network
     */
    function get_current_site_name($current_site)
    {
    }
    /**
     * This deprecated function managed much of the site and network loading in multisite.
     *
     * The current bootstrap code is now responsible for parsing the site and network load as
     * well as setting the global $current_site object.
     *
     * @access private
     * @since 3.0.0
     * @deprecated 3.9.0
     *
     * @global WP_Network $current_site
     *
     * @return WP_Network
     */
    function wpmu_current_site()
    {
    }
    /**
     * Retrieves an object containing information about the requested network.
     *
     * @since 3.9.0
     * @deprecated 4.7.0 Use get_network()
     * @see get_network()
     *
     * @internal In 4.6.0, converted to use get_network()
     *
     * @param object|int $network The network's database row or ID.
     * @return WP_Network|false Object containing network information if found, false if not.
     */
    function wp_get_network($network)
    {
    }
    /**
     * Retrieves network data given a network ID or network object.
     *
     * Network data will be cached and returned after being passed through a filter.
     * If the provided network is empty, the current network global will be used.
     *
     * @since 4.6.0
     *
     * @global WP_Network $current_site
     *
     * @param WP_Network|int|null $network Optional. Network to retrieve. Default is the current network.
     * @return WP_Network|null The network object or null if not found.
     */
    function get_network($network = \null)
    {
    }
    /**
     * Retrieves a list of networks.
     *
     * @since 4.6.0
     *
     * @param string|array $args Optional. Array or string of arguments. See WP_Network_Query::parse_query()
     *                           for information on accepted arguments. Default empty array.
     * @return array|int List of WP_Network objects, a list of network IDs when 'fields' is set to 'ids',
     *                   or the number of networks when 'count' is passed as a query var.
     */
    function get_networks($args = array())
    {
    }
    /**
     * Removes a network from the object cache.
     *
     * @since 4.6.0
     *
     * @global bool $_wp_suspend_cache_invalidation
     *
     * @param int|array $ids Network ID or an array of network IDs to remove from cache.
     * @phpstan-return void
     */
    function clean_network_cache($ids)
    {
    }
    /**
     * Updates the network cache of given networks.
     *
     * Will add the networks in $networks to the cache. If network ID already exists
     * in the network cache then it will not be updated. The network is added to the
     * cache using the network group with the key using the ID of the networks.
     *
     * @since 4.6.0
     *
     * @param array $networks Array of network row objects.
     */
    function update_network_cache($networks)
    {
    }
    /**
     * Adds any networks from the given IDs to the cache that do not already exist in cache.
     *
     * @since 4.6.0
     * @since 6.1.0 This function is no longer marked as "private".
     *
     * @see update_network_cache()
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array $network_ids Array of network IDs.
     */
    function _prime_network_caches($network_ids)
    {
    }
    /**
     * Inserts a new site into the database.
     *
     * @since 5.1.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array $data {
     *     Data for the new site that should be inserted.
     *
     *     @type string $domain       Site domain. Default empty string.
     *     @type string $path         Site path. Default '/'.
     *     @type int    $network_id   The site's network ID. Default is the current network ID.
     *     @type string $registered   When the site was registered, in SQL datetime format. Default is
     *                                the current time.
     *     @type string $last_updated When the site was last updated, in SQL datetime format. Default is
     *                                the value of $registered.
     *     @type int    $public       Whether the site is public. Default 1.
     *     @type int    $archived     Whether the site is archived. Default 0.
     *     @type int    $mature       Whether the site is mature. Default 0.
     *     @type int    $spam         Whether the site is spam. Default 0.
     *     @type int    $deleted      Whether the site is deleted. Default 0.
     *     @type int    $lang_id      The site's language ID. Currently unused. Default 0.
     *     @type int    $user_id      User ID for the site administrator. Passed to the
     *                                `wp_initialize_site` hook.
     *     @type string $title        Site title. Default is 'Site %d' where %d is the site ID. Passed
     *                                to the `wp_initialize_site` hook.
     *     @type array  $options      Custom option $key => $value pairs to use. Default empty array. Passed
     *                                to the `wp_initialize_site` hook.
     *     @type array  $meta         Custom site metadata $key => $value pairs to use. Default empty array.
     *                                Passed to the `wp_initialize_site` hook.
     * }
     * @return int|WP_Error The new site's ID on success, or error object on failure.
     * @phpstan-param array{
     *   domain?: string,
     *   path?: string,
     *   network_id?: int,
     *   registered?: string,
     *   last_updated?: string,
     *   public?: int,
     *   archived?: int,
     *   mature?: int,
     *   spam?: int,
     *   deleted?: int,
     *   lang_id?: int,
     *   user_id?: int,
     *   title?: string,
     *   options?: array,
     *   meta?: array,
     * } $data
     */
    function wp_insert_site(array $data)
    {
    }
    /**
     * Updates a site in the database.
     *
     * @since 5.1.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int   $site_id ID of the site that should be updated.
     * @param array $data    Site data to update. See {@see wp_insert_site()} for the list of supported keys.
     * @return int|WP_Error The updated site's ID on success, or error object on failure.
     * @phpstan-param array{
     *   domain?: string,
     *   path?: string,
     *   network_id?: int,
     *   registered?: string,
     *   last_updated?: string,
     *   public?: int,
     *   archived?: int,
     *   mature?: int,
     *   spam?: int,
     *   deleted?: int,
     *   lang_id?: int,
     *   user_id?: int,
     *   title?: string,
     *   options?: array,
     *   meta?: array,
     * } $data See wp_insert_site()
     */
    function wp_update_site($site_id, array $data)
    {
    }
    /**
     * Deletes a site from the database.
     *
     * @since 5.1.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $site_id ID of the site that should be deleted.
     * @return WP_Site|WP_Error The deleted site object on success, or error object on failure.
     */
    function wp_delete_site($site_id)
    {
    }
    /**
     * Retrieves site data given a site ID or site object.
     *
     * Site data will be cached and returned after being passed through a filter.
     * If the provided site is empty, the current site global will be used.
     *
     * @since 4.6.0
     *
     * @param WP_Site|int|null $site Optional. Site to retrieve. Default is the current site.
     * @return WP_Site|null The site object or null if not found.
     */
    function get_site($site = \null)
    {
    }
    /**
     * Adds any sites from the given IDs to the cache that do not already exist in cache.
     *
     * @since 4.6.0
     * @since 5.1.0 Introduced the `$update_meta_cache` parameter.
     * @since 6.1.0 This function is no longer marked as "private".
     * @since 6.3.0 Use wp_lazyload_site_meta() for lazy-loading of site meta.
     *
     * @see update_site_cache()
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array $ids               ID list.
     * @param bool  $update_meta_cache Optional. Whether to update the meta cache. Default true.
     */
    function _prime_site_caches($ids, $update_meta_cache = \true)
    {
    }
    /**
     * Queue site meta for lazy-loading.
     *
     * @since 6.3.0
     *
     * @param array $site_ids List of site IDs.
     * @phpstan-return void
     */
    function wp_lazyload_site_meta(array $site_ids)
    {
    }
    /**
     * Updates sites in cache.
     *
     * @since 4.6.0
     * @since 5.1.0 Introduced the `$update_meta_cache` parameter.
     *
     * @param array $sites             Array of site objects.
     * @param bool  $update_meta_cache Whether to update site meta cache. Default true.
     * @phpstan-return void
     */
    function update_site_cache($sites, $update_meta_cache = \true)
    {
    }
    /**
     * Updates metadata cache for list of site IDs.
     *
     * Performs SQL query to retrieve all metadata for the sites matching `$site_ids` and stores them in the cache.
     * Subsequent calls to `get_site_meta()` will not need to query the database.
     *
     * @since 5.1.0
     *
     * @param array $site_ids List of site IDs.
     * @return array|false An array of metadata on success, false if there is nothing to update.
     */
    function update_sitemeta_cache($site_ids)
    {
    }
    /**
     * Retrieves a list of sites matching requested arguments.
     *
     * @since 4.6.0
     * @since 4.8.0 Introduced the 'lang_id', 'lang__in', and 'lang__not_in' parameters.
     *
     * @see WP_Site_Query::parse_query()
     *
     * @param string|array $args Optional. Array or string of arguments. See WP_Site_Query::__construct()
     *                           for information on accepted arguments. Default empty array.
     * @return WP_Site[]|int[]|int List of WP_Site objects, a list of site IDs when 'fields' is set to 'ids',
     *                             or the number of sites when 'count' is passed as a query var.
     * @phpstan-param array{
     *   site__in?: int[],
     *   site__not_in?: int[],
     *   count?: bool,
     *   date_query?: array,
     *   fields?: string,
     *   ID?: int,
     *   number?: int,
     *   offset?: int,
     *   no_found_rows?: bool,
     *   orderby?: string|array,
     *   order?: string,
     *   network_id?: int,
     *   network__in?: int[],
     *   network__not_in?: int[],
     *   domain?: string,
     *   domain__in?: string[],
     *   domain__not_in?: string[],
     *   path?: string,
     *   path__in?: string[],
     *   path__not_in?: string[],
     *   public?: int,
     *   archived?: int,
     *   mature?: int,
     *   spam?: int,
     *   deleted?: int,
     *   lang_id?: int,
     *   lang__in?: string[],
     *   lang__not_in?: string[],
     *   search?: string,
     *   search_columns?: string[],
     *   update_site_cache?: bool,
     *   update_site_meta_cache?: bool,
     *   meta_key?: string|string[],
     *   meta_value?: string|string[],
     *   meta_compare?: string,
     *   meta_compare_key?: string,
     *   meta_type?: string,
     *   meta_type_key?: string,
     *   meta_query?: array,
     * } $args See WP_Site_Query::__construct()
     * @phpstan-return ($args is array{count: true}&array ? int : ($args is array{fields: 'ids'}&array ?  array<int, int> : array<int, \WP_Site>))
     */
    function get_sites($args = array())
    {
    }
    /**
     * Prepares site data for insertion or update in the database.
     *
     * @since 5.1.0
     *
     * @param array        $data     Associative array of site data passed to the respective function.
     *                               See {@see wp_insert_site()} for the possibly included data.
     * @param array        $defaults Site data defaults to parse $data against.
     * @param WP_Site|null $old_site Optional. Old site object if an update, or null if an insertion.
     *                               Default null.
     * @return array|WP_Error Site data ready for a database transaction, or WP_Error in case a validation
     *                        error occurred.
     * @phpstan-param array{
     *   domain?: string,
     *   path?: string,
     *   network_id?: int,
     *   registered?: string,
     *   last_updated?: string,
     *   public?: int,
     *   archived?: int,
     *   mature?: int,
     *   spam?: int,
     *   deleted?: int,
     *   lang_id?: int,
     *   user_id?: int,
     *   title?: string,
     *   options?: array,
     *   meta?: array,
     * } $data See wp_insert_site()
     */
    function wp_prepare_site_data($data, $defaults, $old_site = \null)
    {
    }
    /**
     * Normalizes data for a site prior to inserting or updating in the database.
     *
     * @since 5.1.0
     *
     * @param array $data Associative array of site data passed to the respective function.
     *                    See {@see wp_insert_site()} for the possibly included data.
     * @return array Normalized site data.
     * @phpstan-param array{
     *   domain?: string,
     *   path?: string,
     *   network_id?: int,
     *   registered?: string,
     *   last_updated?: string,
     *   public?: int,
     *   archived?: int,
     *   mature?: int,
     *   spam?: int,
     *   deleted?: int,
     *   lang_id?: int,
     *   user_id?: int,
     *   title?: string,
     *   options?: array,
     *   meta?: array,
     * } $data See wp_insert_site()
     */
    function wp_normalize_site_data($data)
    {
    }
    /**
     * Validates data for a site prior to inserting or updating in the database.
     *
     * @since 5.1.0
     *
     * @param WP_Error     $errors   Error object, passed by reference. Will contain validation errors if
     *                               any occurred.
     * @param array        $data     Associative array of complete site data. See {@see wp_insert_site()}
     *                               for the included data.
     * @param WP_Site|null $old_site The old site object if the data belongs to a site being updated,
     *                               or null if it is a new site being inserted.
     * @phpstan-param array{
     *   domain?: string,
     *   path?: string,
     *   network_id?: int,
     *   registered?: string,
     *   last_updated?: string,
     *   public?: int,
     *   archived?: int,
     *   mature?: int,
     *   spam?: int,
     *   deleted?: int,
     *   lang_id?: int,
     *   user_id?: int,
     *   title?: string,
     *   options?: array,
     *   meta?: array,
     * } $data See wp_insert_site()
     * @phpstan-return void
     */
    function wp_validate_site_data($errors, $data, $old_site = \null)
    {
    }
    /**
     * Runs the initialization routine for a given site.
     *
     * This process includes creating the site's database tables and
     * populating them with defaults.
     *
     * @since 5.1.0
     *
     * @global wpdb     $wpdb     WordPress database abstraction object.
     * @global WP_Roles $wp_roles WordPress role management object.
     *
     * @param int|WP_Site $site_id Site ID or object.
     * @param array       $args    {
     *     Optional. Arguments to modify the initialization behavior.
     *
     *     @type int    $user_id Required. User ID for the site administrator.
     *     @type string $title   Site title. Default is 'Site %d' where %d is the
     *                           site ID.
     *     @type array  $options Custom option $key => $value pairs to use. Default
     *                           empty array.
     *     @type array  $meta    Custom site metadata $key => $value pairs to use.
     *                           Default empty array.
     * }
     * @return true|WP_Error True on success, or error object on failure.
     * @phpstan-param array{
     *   user_id?: int,
     *   title?: string,
     *   options?: array,
     *   meta?: array,
     * } $args
     */
    function wp_initialize_site($site_id, array $args = array())
    {
    }
    /**
     * Runs the uninitialization routine for a given site.
     *
     * This process includes dropping the site's database tables and deleting its uploads directory.
     *
     * @since 5.1.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|WP_Site $site_id Site ID or object.
     * @return true|WP_Error True on success, or error object on failure.
     */
    function wp_uninitialize_site($site_id)
    {
    }
    /**
     * Checks whether a site is initialized.
     *
     * A site is considered initialized when its database tables are present.
     *
     * @since 5.1.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|WP_Site $site_id Site ID or object.
     * @return bool True if the site is initialized, false otherwise.
     */
    function wp_is_site_initialized($site_id)
    {
    }
    /**
     * Clean the blog cache
     *
     * @since 3.5.0
     *
     * @global bool $_wp_suspend_cache_invalidation
     *
     * @param WP_Site|int $blog The site object or ID to be cleared from cache.
     * @phpstan-return void
     */
    function clean_blog_cache($blog)
    {
    }
    /**
     * Adds metadata to a site.
     *
     * @since 5.1.0
     *
     * @param int    $site_id    Site ID.
     * @param string $meta_key   Metadata name.
     * @param mixed  $meta_value Metadata value. Must be serializable if non-scalar.
     * @param bool   $unique     Optional. Whether the same key should not be added.
     *                           Default false.
     * @return int|false Meta ID on success, false on failure.
     */
    function add_site_meta($site_id, $meta_key, $meta_value, $unique = \false)
    {
    }
    /**
     * Removes metadata matching criteria from a site.
     *
     * You can match based on the key, or key and value. Removing based on key and
     * value, will keep from removing duplicate metadata with the same key. It also
     * allows removing all metadata matching key, if needed.
     *
     * @since 5.1.0
     *
     * @param int    $site_id    Site ID.
     * @param string $meta_key   Metadata name.
     * @param mixed  $meta_value Optional. Metadata value. If provided,
     *                           rows will only be removed that match the value.
     *                           Must be serializable if non-scalar. Default empty.
     * @return bool True on success, false on failure.
     */
    function delete_site_meta($site_id, $meta_key, $meta_value = '')
    {
    }
    /**
     * Retrieves metadata for a site.
     *
     * @since 5.1.0
     *
     * @param int    $site_id Site ID.
     * @param string $key     Optional. The meta key to retrieve. By default,
     *                        returns data for all keys. Default empty.
     * @param bool   $single  Optional. Whether to return a single value.
     *                        This parameter has no effect if `$key` is not specified.
     *                        Default false.
     * @return mixed An array of values if `$single` is false.
     *               The value of meta data field if `$single` is true.
     *               False for an invalid `$site_id` (non-numeric, zero, or negative value).
     *               An empty array if a valid but non-existing site ID is passed and `$single` is false.
     *               An empty string if a valid but non-existing site ID is passed and `$single` is true.
     */
    function get_site_meta($site_id, $key = '', $single = \false)
    {
    }
    /**
     * Updates metadata for a site.
     *
     * Use the $prev_value parameter to differentiate between meta fields with the
     * same key and site ID.
     *
     * If the meta field for the site does not exist, it will be added.
     *
     * @since 5.1.0
     *
     * @param int    $site_id    Site ID.
     * @param string $meta_key   Metadata key.
     * @param mixed  $meta_value Metadata value. Must be serializable if non-scalar.
     * @param mixed  $prev_value Optional. Previous value to check before updating.
     *                           If specified, only update existing metadata entries with
     *                           this value. Otherwise, update all entries. Default empty.
     * @return int|bool Meta ID if the key didn't exist, true on successful update,
     *                  false on failure or if the value passed to the function
     *                  is the same as the one that is already in the database.
     */
    function update_site_meta($site_id, $meta_key, $meta_value, $prev_value = '')
    {
    }
    /**
     * Deletes everything from site meta matching meta key.
     *
     * @since 5.1.0
     *
     * @param string $meta_key Metadata key to search for when deleting.
     * @return bool Whether the site meta key was deleted from the database.
     */
    function delete_site_meta_by_key($meta_key)
    {
    }
    /**
     * Updates the count of sites for a network based on a changed site.
     *
     * @since 5.1.0
     *
     * @param WP_Site      $new_site The site object that has been inserted, updated or deleted.
     * @param WP_Site|null $old_site Optional. If $new_site has been updated, this must be the previous
     *                               state of that site. Default null.
     * @phpstan-return void
     */
    function wp_maybe_update_network_site_counts_on_update($new_site, $old_site = \null)
    {
    }
    /**
     * Triggers actions on site status updates.
     *
     * @since 5.1.0
     *
     * @param WP_Site      $new_site The site object after the update.
     * @param WP_Site|null $old_site Optional. If $new_site has been updated, this must be the previous
     *                               state of that site. Default null.
     */
    function wp_maybe_transition_site_statuses_on_update($new_site, $old_site = \null)
    {
    }
    /**
     * Cleans the necessary caches after specific site data has been updated.
     *
     * @since 5.1.0
     *
     * @param WP_Site $new_site The site object after the update.
     * @param WP_Site $old_site The site object prior to the update.
     */
    function wp_maybe_clean_new_site_cache_on_update($new_site, $old_site)
    {
    }
    /**
     * Updates the `blog_public` option for a given site ID.
     *
     * @since 5.1.0
     *
     * @param int    $site_id   Site ID.
     * @param string $is_public Whether the site is public. A numeric string,
     *                          for compatibility reasons. Accepts '1' or '0'.
     * @phpstan-param '1'|'0' $is_public
     * @phpstan-return void
     */
    function wp_update_blog_public_option_on_site_update($site_id, $is_public)
    {
    }
    /**
     * Sets the last changed time for the 'sites' cache group.
     *
     * @since 5.1.0
     */
    function wp_cache_set_sites_last_changed()
    {
    }
    /**
     * Aborts calls to site meta if it is not supported.
     *
     * @since 5.1.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param mixed $check Skip-value for whether to proceed site meta function execution.
     * @return mixed Original value of $check, or false if site meta is not supported.
     */
    function wp_check_site_meta_support_prefilter($check)
    {
    }
    /**
     * Displays a navigation menu.
     *
     * @since 3.0.0
     * @since 4.7.0 Added the `item_spacing` argument.
     * @since 5.5.0 Added the `container_aria_label` argument.
     *
     * @param array $args {
     *     Optional. Array of nav menu arguments.
     *
     *     @type int|string|WP_Term $menu                 Desired menu. Accepts a menu ID, slug, name, or object.
     *                                                    Default empty.
     *     @type string             $menu_class           CSS class to use for the ul element which forms the menu.
     *                                                    Default 'menu'.
     *     @type string             $menu_id              The ID that is applied to the ul element which forms the menu.
     *                                                    Default is the menu slug, incremented.
     *     @type string             $container            Whether to wrap the ul, and what to wrap it with.
     *                                                    Default 'div'.
     *     @type string             $container_class      Class that is applied to the container.
     *                                                    Default 'menu-{menu slug}-container'.
     *     @type string             $container_id         The ID that is applied to the container. Default empty.
     *     @type string             $container_aria_label The aria-label attribute that is applied to the container
     *                                                    when it's a nav element. Default empty.
     *     @type callable|false     $fallback_cb          If the menu doesn't exist, a callback function will fire.
     *                                                    Default is 'wp_page_menu'. Set to false for no fallback.
     *     @type string             $before               Text before the link markup. Default empty.
     *     @type string             $after                Text after the link markup. Default empty.
     *     @type string             $link_before          Text before the link text. Default empty.
     *     @type string             $link_after           Text after the link text. Default empty.
     *     @type bool               $echo                 Whether to echo the menu or return it. Default true.
     *     @type int                $depth                How many levels of the hierarchy are to be included.
     *                                                    0 means all. Default 0.
     *                                                    Default 0.
     *     @type object             $walker               Instance of a custom walker class. Default empty.
     *     @type string             $theme_location       Theme location to be used. Must be registered with
     *                                                    register_nav_menu() in order to be selectable by the user.
     *     @type string             $items_wrap           How the list items should be wrapped. Uses printf() format with
     *                                                    numbered placeholders. Default is a ul with an id and class.
     *     @type string             $item_spacing         Whether to preserve whitespace within the menu's HTML.
     *                                                    Accepts 'preserve' or 'discard'. Default 'preserve'.
     * }
     * @return void|string|false Void if 'echo' argument is true, menu output if 'echo' is false.
     *                           False if there are no items or no menu was found.
     * @phpstan-param array{
     *   menu?: int|string|WP_Term,
     *   menu_class?: string,
     *   menu_id?: string,
     *   container?: string,
     *   container_class?: string,
     *   container_id?: string,
     *   container_aria_label?: string,
     *   fallback_cb?: callable|false,
     *   before?: string,
     *   after?: string,
     *   link_before?: string,
     *   link_after?: string,
     *   echo?: bool,
     *   depth?: int,
     *   walker?: object,
     *   theme_location?: string,
     *   items_wrap?: string,
     *   item_spacing?: string,
     * } $args
     */
    function wp_nav_menu($args = array())
    {
    }
    /**
     * Adds the class property classes for the current context, if applicable.
     *
     * @access private
     * @since 3.0.0
     *
     * @global WP_Query   $wp_query   WordPress Query object.
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param array $menu_items The current menu item objects to which to add the class property information.
     */
    function _wp_menu_item_classes_by_context(&$menu_items)
    {
    }
    /**
     * Retrieves the HTML list content for nav menu items.
     *
     * @uses Walker_Nav_Menu to create HTML list content.
     * @since 3.0.0
     *
     * @param array    $items The menu items, sorted by each menu item's menu order.
     * @param int      $depth Depth of the item in reference to parents.
     * @param stdClass $args  An object containing wp_nav_menu() arguments.
     * @return string The HTML list content for the menu items.
     */
    function walk_nav_menu_tree($items, $depth, $args)
    {
    }
    /**
     * Prevents a menu item ID from being used more than once.
     *
     * @since 3.0.1
     * @access private
     *
     * @param string $id
     * @param object $item
     * @return string
     */
    function _nav_menu_item_id_use_once($id, $item)
    {
    }
    /**
     * Remove the `menu-item-has-children` class from bottom level menu items.
     *
     * This runs on the {@see 'nav_menu_css_class'} filter. The $args and $depth
     * parameters were added after the filter was originally introduced in
     * WordPress 3.0.0 so this needs to allow for cases in which the filter is
     * called without them.
     *
     * @see https://core.trac.wordpress.org/ticket/56926
     *
     * @since 6.2.0
     *
     * @param string[]       $classes   Array of the CSS classes that are applied to the menu item's `<li>` element.
     * @param WP_Post        $menu_item The current menu item object.
     * @param stdClass|false $args      An object of wp_nav_menu() arguments. Default false ($args unspecified when filter is called).
     * @param int|false      $depth     Depth of menu item. Default false ($depth unspecified when filter is called).
     * @return string[] Modified nav menu classes.
     */
    function wp_nav_menu_remove_menu_item_has_children_class($classes, $menu_item, $args = \false, $depth = \false)
    {
    }
    /**
     * Returns a navigation menu object.
     *
     * @since 3.0.0
     *
     * @param int|string|WP_Term $menu Menu ID, slug, name, or object.
     * @return WP_Term|false Menu object on success, false if $menu param isn't supplied or term does not exist.
     */
    function wp_get_nav_menu_object($menu)
    {
    }
    /**
     * Determines whether the given ID is a navigation menu.
     *
     * Returns true if it is; false otherwise.
     *
     * @since 3.0.0
     *
     * @param int|string|WP_Term $menu Menu ID, slug, name, or object of menu to check.
     * @return bool Whether the menu exists.
     */
    function is_nav_menu($menu)
    {
    }
    /**
     * Registers navigation menu locations for a theme.
     *
     * @since 3.0.0
     *
     * @global array $_wp_registered_nav_menus
     *
     * @param string[] $locations Associative array of menu location identifiers (like a slug) and descriptive text.
     */
    function register_nav_menus($locations = array())
    {
    }
    /**
     * Unregisters a navigation menu location for a theme.
     *
     * @since 3.1.0
     *
     * @global array $_wp_registered_nav_menus
     *
     * @param string $location The menu location identifier.
     * @return bool True on success, false on failure.
     */
    function unregister_nav_menu($location)
    {
    }
    /**
     * Registers a navigation menu location for a theme.
     *
     * @since 3.0.0
     *
     * @param string $location    Menu location identifier, like a slug.
     * @param string $description Menu location descriptive text.
     */
    function register_nav_menu($location, $description)
    {
    }
    /**
     * Retrieves all registered navigation menu locations in a theme.
     *
     * @since 3.0.0
     *
     * @global array $_wp_registered_nav_menus
     *
     * @return string[] Associative array of registered navigation menu descriptions keyed
     *                  by their location. If none are registered, an empty array.
     */
    function get_registered_nav_menus()
    {
    }
    /**
     * Retrieves all registered navigation menu locations and the menus assigned to them.
     *
     * @since 3.0.0
     *
     * @return int[] Associative array of registered navigation menu IDs keyed by their
     *               location name. If none are registered, an empty array.
     */
    function get_nav_menu_locations()
    {
    }
    /**
     * Determines whether a registered nav menu location has a menu assigned to it.
     *
     * @since 3.0.0
     *
     * @param string $location Menu location identifier.
     * @return bool Whether location has a menu.
     */
    function has_nav_menu($location)
    {
    }
    /**
     * Returns the name of a navigation menu.
     *
     * @since 4.9.0
     *
     * @param string $location Menu location identifier.
     * @return string Menu name.
     */
    function wp_get_nav_menu_name($location)
    {
    }
    /**
     * Determines whether the given ID is a nav menu item.
     *
     * @since 3.0.0
     *
     * @param int $menu_item_id The ID of the potential nav menu item.
     * @return bool Whether the given ID is that of a nav menu item.
     */
    function is_nav_menu_item($menu_item_id = 0)
    {
    }
    /**
     * Creates a navigation menu.
     *
     * Note that `$menu_name` is expected to be pre-slashed.
     *
     * @since 3.0.0
     *
     * @param string $menu_name Menu name.
     * @return int|WP_Error Menu ID on success, WP_Error object on failure.
     */
    function wp_create_nav_menu($menu_name)
    {
    }
    /**
     * Deletes a navigation menu.
     *
     * @since 3.0.0
     *
     * @param int|string|WP_Term $menu Menu ID, slug, name, or object.
     * @return bool|WP_Error True on success, false or WP_Error object on failure.
     */
    function wp_delete_nav_menu($menu)
    {
    }
    /**
     * Saves the properties of a menu or create a new menu with those properties.
     *
     * Note that `$menu_data` is expected to be pre-slashed.
     *
     * @since 3.0.0
     *
     * @param int   $menu_id   The ID of the menu or "0" to create a new menu.
     * @param array $menu_data The array of menu data.
     * @return int|WP_Error Menu ID on success, WP_Error object on failure.
     */
    function wp_update_nav_menu_object($menu_id = 0, $menu_data = array())
    {
    }
    /**
     * Saves the properties of a menu item or create a new one.
     *
     * The menu-item-title, menu-item-description and menu-item-attr-title are expected
     * to be pre-slashed since they are passed directly to APIs that expect slashed data.
     *
     * @since 3.0.0
     * @since 5.9.0 Added the `$fire_after_hooks` parameter.
     *
     * @param int   $menu_id          The ID of the menu. If 0, makes the menu item a draft orphan.
     * @param int   $menu_item_db_id  The ID of the menu item. If 0, creates a new menu item.
     * @param array $menu_item_data   The menu item's data.
     * @param bool  $fire_after_hooks Whether to fire the after insert hooks. Default true.
     * @return int|WP_Error The menu item's database ID or WP_Error object on failure.
     */
    function wp_update_nav_menu_item($menu_id = 0, $menu_item_db_id = 0, $menu_item_data = array(), $fire_after_hooks = \true)
    {
    }
    /**
     * Returns all navigation menu objects.
     *
     * @since 3.0.0
     * @since 4.1.0 Default value of the 'orderby' argument was changed from 'none'
     *              to 'name'.
     *
     * @param array $args Optional. Array of arguments passed on to get_terms().
     *                    Default empty array.
     * @return WP_Term[] An array of menu objects.
     */
    function wp_get_nav_menus($args = array())
    {
    }
    /**
     * Determines whether a menu item is valid.
     *
     * @link https://core.trac.wordpress.org/ticket/13958
     *
     * @since 3.2.0
     * @access private
     *
     * @param object $item The menu item to check.
     * @return bool False if invalid, otherwise true.
     */
    function _is_valid_nav_menu_item($item)
    {
    }
    /**
     * Retrieves all menu items of a navigation menu.
     *
     * Note: Most arguments passed to the `$args` parameter – save for 'output_key' – are
     * specifically for retrieving nav_menu_item posts from get_posts() and may only
     * indirectly affect the ultimate ordering and content of the resulting nav menu
     * items that get returned from this function.
     *
     * @since 3.0.0
     *
     * @param int|string|WP_Term $menu Menu ID, slug, name, or object.
     * @param array              $args {
     *     Optional. Arguments to pass to get_posts().
     *
     *     @type string $order                  How to order nav menu items as queried with get_posts().
     *                                          Will be ignored if 'output' is ARRAY_A. Default 'ASC'.
     *     @type string $orderby                Field to order menu items by as retrieved from get_posts().
     *                                          Supply an orderby field via 'output_key' to affect the
     *                                          output order of nav menu items. Default 'menu_order'.
     *     @type string $post_type              Menu items post type. Default 'nav_menu_item'.
     *     @type string $post_status            Menu items post status. Default 'publish'.
     *     @type string $output                 How to order outputted menu items. Default ARRAY_A.
     *     @type string $output_key             Key to use for ordering the actual menu items that get
     *                                          returned. Note that that is not a get_posts() argument
     *                                          and will only affect output of menu items processed in
     *                                          this function. Default 'menu_order'.
     *     @type bool   $nopaging               Whether to retrieve all menu items (true) or paginate
     *                                          (false). Default true.
     *     @type bool   $update_menu_item_cache Whether to update the menu item cache. Default true.
     * }
     * @return array|false Array of menu items, otherwise false.
     * @phpstan-param array{
     *   order?: string,
     *   orderby?: string,
     *   post_type?: string,
     *   post_status?: string,
     *   output?: string,
     *   output_key?: string,
     *   nopaging?: bool,
     *   update_menu_item_cache?: bool,
     * } $args
     */
    function wp_get_nav_menu_items($menu, $args = array())
    {
    }
    /**
     * Updates post and term caches for all linked objects for a list of menu items.
     *
     * @since 6.1.0
     *
     * @param WP_Post[] $menu_items Array of menu item post objects.
     */
    function update_menu_item_cache($menu_items)
    {
    }
    /**
     * Decorates a menu item object with the shared navigation menu item properties.
     *
     * Properties:
     * - ID:               The term_id if the menu item represents a taxonomy term.
     * - attr_title:       The title attribute of the link element for this menu item.
     * - classes:          The array of class attribute values for the link element of this menu item.
     * - db_id:            The DB ID of this item as a nav_menu_item object, if it exists (0 if it doesn't exist).
     * - description:      The description of this menu item.
     * - menu_item_parent: The DB ID of the nav_menu_item that is this item's menu parent, if any. 0 otherwise.
     * - object:           The type of object originally represented, such as 'category', 'post', or 'attachment'.
     * - object_id:        The DB ID of the original object this menu item represents, e.g. ID for posts and term_id for categories.
     * - post_parent:      The DB ID of the original object's parent object, if any (0 otherwise).
     * - post_title:       A "no title" label if menu item represents a post that lacks a title.
     * - target:           The target attribute of the link element for this menu item.
     * - title:            The title of this menu item.
     * - type:             The family of objects originally represented, such as 'post_type' or 'taxonomy'.
     * - type_label:       The singular label used to describe this type of menu item.
     * - url:              The URL to which this menu item points.
     * - xfn:              The XFN relationship expressed in the link of this menu item.
     * - _invalid:         Whether the menu item represents an object that no longer exists.
     *
     * @since 3.0.0
     *
     * @param object $menu_item The menu item to modify.
     * @return object The menu item with standard menu item properties.
     */
    function wp_setup_nav_menu_item($menu_item)
    {
    }
    /**
     * Returns the menu items associated with a particular object.
     *
     * @since 3.0.0
     *
     * @param int    $object_id   Optional. The ID of the original object. Default 0.
     * @param string $object_type Optional. The type of object, such as 'post_type' or 'taxonomy'.
     *                            Default 'post_type'.
     * @param string $taxonomy    Optional. If $object_type is 'taxonomy', $taxonomy is the name
     *                            of the tax that $object_id belongs to. Default empty.
     * @return int[] The array of menu item IDs; empty array if none.
     */
    function wp_get_associated_nav_menu_items($object_id = 0, $object_type = 'post_type', $taxonomy = '')
    {
    }
    /**
     * Callback for handling a menu item when its original object is deleted.
     *
     * @since 3.0.0
     * @access private
     *
     * @param int $object_id The ID of the original object being trashed.
     */
    function _wp_delete_post_menu_item($object_id)
    {
    }
    /**
     * Serves as a callback for handling a menu item when its original object is deleted.
     *
     * @since 3.0.0
     * @access private
     *
     * @param int    $object_id The ID of the original object being trashed.
     * @param int    $tt_id     Term taxonomy ID. Unused.
     * @param string $taxonomy  Taxonomy slug.
     */
    function _wp_delete_tax_menu_item($object_id, $tt_id, $taxonomy)
    {
    }
    /**
     * Automatically add newly published page objects to menus with that as an option.
     *
     * @since 3.0.0
     * @access private
     *
     * @param string  $new_status The new status of the post object.
     * @param string  $old_status The old status of the post object.
     * @param WP_Post $post       The post object being transitioned from one status to another.
     * @phpstan-return void
     */
    function _wp_auto_add_pages_to_menu($new_status, $old_status, $post)
    {
    }
    /**
     * Deletes auto-draft posts associated with the supplied changeset.
     *
     * @since 4.8.0
     * @access private
     *
     * @param int $post_id Post ID for the customize_changeset.
     * @phpstan-return void
     */
    function _wp_delete_customize_changeset_dependent_auto_drafts($post_id)
    {
    }
    /**
     * Handles menu config after theme change.
     *
     * @access private
     * @since 4.9.0
     */
    function _wp_menus_changed()
    {
    }
    /**
     * Maps nav menu locations according to assignments in previously active theme.
     *
     * @since 4.9.0
     *
     * @param array $new_nav_menu_locations New nav menu locations assignments.
     * @param array $old_nav_menu_locations Old nav menu locations assignments.
     * @return array Nav menus mapped to new nav menu locations.
     */
    function wp_map_nav_menu_locations($new_nav_menu_locations, $old_nav_menu_locations)
    {
    }
    /**
     * Prevents menu items from being their own parent.
     *
     * Resets menu_item_parent to 0 when the parent is set to the item itself.
     * For use before saving `_menu_item_menu_item_parent` in nav-menus.php.
     *
     * @since 6.2.0
     * @access private
     *
     * @param array $menu_item_data The menu item data array.
     * @return array The menu item data with reset menu_item_parent.
     */
    function _wp_reset_invalid_menu_item_parent($menu_item_data)
    {
    }
    /**
     * Retrieves an option value based on an option name.
     *
     * If the option does not exist, and a default value is not provided,
     * boolean false is returned. This could be used to check whether you need
     * to initialize an option during installation of a plugin, however that
     * can be done better by using add_option() which will not overwrite
     * existing options.
     *
     * Not initializing an option and using boolean `false` as a return value
     * is a bad practice as it triggers an additional database query.
     *
     * The type of the returned value can be different from the type that was passed
     * when saving or updating the option. If the option value was serialized,
     * then it will be unserialized when it is returned. In this case the type will
     * be the same. For example, storing a non-scalar value like an array will
     * return the same array.
     *
     * In most cases non-string scalar and null values will be converted and returned
     * as string equivalents.
     *
     * Exceptions:
     *
     * 1. When the option has not been saved in the database, the `$default_value` value
     *    is returned if provided. If not, boolean `false` is returned.
     * 2. When one of the Options API filters is used: {@see 'pre_option_$option'},
     *    {@see 'default_option_$option'}, or {@see 'option_$option'}, the returned
     *    value may not match the expected type.
     * 3. When the option has just been saved in the database, and get_option()
     *    is used right after, non-string scalar and null values are not converted to
     *    string equivalents and the original type is returned.
     *
     * Examples:
     *
     * When adding options like this: `add_option( 'my_option_name', 'value' )`
     * and then retrieving them with `get_option( 'my_option_name' )`, the returned
     * values will be:
     *
     *   - `false` returns `string(0) ""`
     *   - `true`  returns `string(1) "1"`
     *   - `0`     returns `string(1) "0"`
     *   - `1`     returns `string(1) "1"`
     *   - `'0'`   returns `string(1) "0"`
     *   - `'1'`   returns `string(1) "1"`
     *   - `null`  returns `string(0) ""`
     *
     * When adding options with non-scalar values like
     * `add_option( 'my_array', array( false, 'str', null ) )`, the returned value
     * will be identical to the original as it is serialized before saving
     * it in the database:
     *
     *     array(3) {
     *         [0] => bool(false)
     *         [1] => string(3) "str"
     *         [2] => NULL
     *     }
     *
     * @since 1.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $option        Name of the option to retrieve. Expected to not be SQL-escaped.
     * @param mixed  $default_value Optional. Default value to return if the option does not exist.
     * @return mixed Value of the option. A value of any type may be returned, including
     *               scalar (string, boolean, float, integer), null, array, object.
     *               Scalar and null values will be returned as strings as long as they originate
     *               from a database stored option value. If there is no option in the database,
     *               boolean `false` is returned.
     */
    function get_option($option, $default_value = \false)
    {
    }
    /**
     * Primes specific options into the cache with a single database query.
     *
     * Only options that do not already exist in cache will be loaded.
     *
     * @since 6.4.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string[] $options An array of option names to be loaded.
     * @phpstan-return void
     */
    function wp_prime_option_caches($options)
    {
    }
    /**
     * Primes the cache of all options registered with a specific option group.
     *
     * @since 6.4.0
     *
     * @global array $new_allowed_options
     *
     * @param string $option_group The option group to load options for.
     */
    function wp_prime_option_caches_by_group($option_group)
    {
    }
    /**
     * Retrieves multiple options.
     *
     * Options are loaded as necessary first in order to use a single database query at most.
     *
     * @since 6.4.0
     *
     * @param string[] $options An array of option names to retrieve.
     * @return array An array of key-value pairs for the requested options.
     */
    function get_options($options)
    {
    }
    /**
     * Sets the autoload values for multiple options in the database.
     *
     * Autoloading too many options can lead to performance problems, especially if the options are not frequently used.
     * This function allows modifying the autoload value for multiple options without changing the actual option value.
     * This is for example recommended for plugin activation and deactivation hooks, to ensure any options exclusively used
     * by the plugin which are generally autoloaded can be set to not autoload when the plugin is inactive.
     *
     * @since 6.4.0
     * @since 6.7.0 The autoload values 'yes' and 'no' are deprecated.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array $options Associative array of option names and their autoload values to set. The option names are
     *                       expected to not be SQL-escaped. The autoload values should be boolean values. For backward
     *                       compatibility 'yes' and 'no' are also accepted, though using these values is deprecated.
     * @return array Associative array of all provided $options as keys and boolean values for whether their autoload value
     *               was updated.
     */
    function wp_set_option_autoload_values(array $options)
    {
    }
    /**
     * Sets the autoload value for multiple options in the database.
     *
     * This is a wrapper for {@see wp_set_option_autoload_values()}, which can be used to set different autoload values for
     * each option at once.
     *
     * @since 6.4.0
     * @since 6.7.0 The autoload values 'yes' and 'no' are deprecated.
     *
     * @see wp_set_option_autoload_values()
     *
     * @param string[] $options  List of option names. Expected to not be SQL-escaped.
     * @param bool     $autoload Autoload value to control whether to load the options when WordPress starts up.
     *                           For backward compatibility 'yes' and 'no' are also accepted, though using these values is
     *                           deprecated.
     * @return array Associative array of all provided $options as keys and boolean values for whether their autoload value
     *               was updated.
     */
    function wp_set_options_autoload(array $options, $autoload)
    {
    }
    /**
     * Sets the autoload value for an option in the database.
     *
     * This is a wrapper for {@see wp_set_option_autoload_values()}, which can be used to set the autoload value for
     * multiple options at once.
     *
     * @since 6.4.0
     * @since 6.7.0 The autoload values 'yes' and 'no' are deprecated.
     *
     * @see wp_set_option_autoload_values()
     *
     * @param string $option   Name of the option. Expected to not be SQL-escaped.
     * @param bool   $autoload Autoload value to control whether to load the option when WordPress starts up.
     *                         For backward compatibility 'yes' and 'no' are also accepted, though using these values is
     *                         deprecated.
     * @return bool True if the autoload value was modified, false otherwise.
     */
    function wp_set_option_autoload($option, $autoload)
    {
    }
    /**
     * Protects WordPress special option from being modified.
     *
     * Will die if $option is in protected list. Protected options are 'alloptions'
     * and 'notoptions' options.
     *
     * @since 2.2.0
     *
     * @param string $option Option name.
     */
    function wp_protect_special_option($option)
    {
    }
    /**
     * Prints option value after sanitizing for forms.
     *
     * @since 1.5.0
     *
     * @param string $option Option name.
     */
    function form_option($option)
    {
    }
    /**
     * Loads and caches all autoloaded options, if available or all options.
     *
     * @since 2.2.0
     * @since 5.3.1 The `$force_cache` parameter was added.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param bool $force_cache Optional. Whether to force an update of the local cache
     *                          from the persistent cache. Default false.
     * @return array List of all options.
     */
    function wp_load_alloptions($force_cache = \false)
    {
    }
    /**
     * Primes specific network options for the current network into the cache with a single database query.
     *
     * Only network options that do not already exist in cache will be loaded.
     *
     * If site is not multisite, then call wp_prime_option_caches().
     *
     * @since 6.6.0
     *
     * @see wp_prime_network_option_caches()
     *
     * @param string[] $options An array of option names to be loaded.
     */
    function wp_prime_site_option_caches(array $options)
    {
    }
    /**
     * Primes specific network options into the cache with a single database query.
     *
     * Only network options that do not already exist in cache will be loaded.
     *
     * If site is not multisite, then call wp_prime_option_caches().
     *
     * @since 6.6.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int      $network_id ID of the network. Can be null to default to the current network ID.
     * @param string[] $options    An array of option names to be loaded.
     * @phpstan-return void
     */
    function wp_prime_network_option_caches($network_id, array $options)
    {
    }
    /**
     * Loads and primes caches of certain often requested network options if is_multisite().
     *
     * @since 3.0.0
     * @since 6.3.0 Also prime caches for network options when persistent object cache is enabled.
     * @since 6.6.0 Uses wp_prime_network_option_caches().
     *
     * @param int $network_id Optional. Network ID of network for which to prime network options cache. Defaults to current network.
     * @phpstan-return void
     */
    function wp_load_core_site_options($network_id = \null)
    {
    }
    /**
     * Updates the value of an option that was already added.
     *
     * You do not need to serialize values. If the value needs to be serialized,
     * then it will be serialized before it is inserted into the database.
     * Remember, resources cannot be serialized or added as an option.
     *
     * If the option does not exist, it will be created.
     * This function is designed to work with or without a logged-in user. In terms of security,
     * plugin developers should check the current user's capabilities before updating any options.
     *
     * @since 1.0.0
     * @since 4.2.0 The `$autoload` parameter was added.
     * @since 6.7.0 The autoload values 'yes' and 'no' are deprecated.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string    $option   Name of the option to update. Expected to not be SQL-escaped.
     * @param mixed     $value    Option value. Must be serializable if non-scalar. Expected to not be SQL-escaped.
     * @param bool|null $autoload Optional. Whether to load the option when WordPress starts up.
     *                            Accepts a boolean, or `null` to stick with the initial value or, if no initial value is
     *                            set, to leave the decision up to default heuristics in WordPress.
     *                            For existing options, `$autoload` can only be updated using `update_option()` if `$value`
     *                            is also changed.
     *                            For backward compatibility 'yes' and 'no' are also accepted, though using these values is
     *                            deprecated.
     *                            Autoloading too many options can lead to performance problems, especially if the
     *                            options are not frequently used. For options which are accessed across several places
     *                            in the frontend, it is recommended to autoload them, by using true.
     *                            For options which are accessed only on few specific URLs, it is recommended
     *                            to not autoload them, by using false.
     *                            For non-existent options, the default is null, which means WordPress will determine
     *                            the autoload value.
     * @return bool True if the value was updated, false otherwise.
     */
    function update_option($option, $value, $autoload = \null)
    {
    }
    /**
     * Adds a new option.
     *
     * You do not need to serialize values. If the value needs to be serialized,
     * then it will be serialized before it is inserted into the database.
     * Remember, resources cannot be serialized or added as an option.
     *
     * You can create options without values and then update the values later.
     * Existing options will not be updated and checks are performed to ensure that you
     * aren't adding a protected WordPress option. Care should be taken to not name
     * options the same as the ones which are protected.
     *
     * @since 1.0.0
     * @since 6.6.0 The $autoload parameter's default value was changed to null.
     * @since 6.7.0 The autoload values 'yes' and 'no' are deprecated.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string    $option     Name of the option to add. Expected to not be SQL-escaped.
     * @param mixed     $value      Optional. Option value. Must be serializable if non-scalar.
     *                              Expected to not be SQL-escaped.
     * @param string    $deprecated Optional. Description. Not used anymore.
     * @param bool|null $autoload   Optional. Whether to load the option when WordPress starts up.
     *                              Accepts a boolean, or `null` to leave the decision up to default heuristics in
     *                              WordPress. For backward compatibility 'yes' and 'no' are also accepted, though using
     *                              these values is deprecated.
     *                              Autoloading too many options can lead to performance problems, especially if the
     *                              options are not frequently used. For options which are accessed across several places
     *                              in the frontend, it is recommended to autoload them, by using true.
     *                              For options which are accessed only on few specific URLs, it is recommended
     *                              to not autoload them, by using false.
     *                              Default is null, which means WordPress will determine the autoload value.
     * @return bool True if the option was added, false otherwise.
     */
    function add_option($option, $value = '', $deprecated = '', $autoload = \null)
    {
    }
    /**
     * Removes an option by name. Prevents removal of protected WordPress options.
     *
     * @since 1.2.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $option Name of the option to delete. Expected to not be SQL-escaped.
     * @return bool True if the option was deleted, false otherwise.
     */
    function delete_option($option)
    {
    }
    /**
     *  Determines the appropriate autoload value for an option based on input.
     *
     *  This function checks the provided autoload value and returns a standardized value
     *  ('on', 'off', 'auto-on', 'auto-off', or 'auto') based on specific conditions.
     *
     * If no explicit autoload value is provided, the function will check for certain heuristics around the given option.
     * It will return `auto-on` to indicate autoloading, `auto-off` to indicate not autoloading, or `auto` if no clear
     * decision could be made.
     *
     * @since 6.6.0
     * @access private
     *
     * @param string $option          The name of the option.
     * @param mixed $value            The value of the option to check its autoload value.
     * @param mixed $serialized_value The serialized value of the option to check its autoload value.
     * @param bool|null $autoload     The autoload value to check.
     *                                Accepts 'on'|true to enable or 'off'|false to disable, or
     *                                'auto-on', 'auto-off', or 'auto' for internal purposes.
     *                                Any other autoload value will be forced to either 'auto-on',
     *                                'auto-off', or 'auto'.
     *                                'yes' and 'no' are supported for backward compatibility.
     * @return string Returns the original $autoload value if explicit, or 'auto-on', 'auto-off',
     *                or 'auto' depending on default heuristics.
     */
    function wp_determine_option_autoload_value($option, $value, $serialized_value, $autoload)
    {
    }
    /**
     * Filters the default autoload value to disable autoloading if the option value is too large.
     *
     * @since 6.6.0
     * @access private
     *
     * @param bool|null $autoload         The default autoload value to set.
     * @param string    $option           The passed option name.
     * @param mixed     $value            The passed option value to be saved.
     * @param mixed     $serialized_value The passed option value to be saved, in serialized form.
     * @return bool|null Potentially modified $default.
     */
    function wp_filter_default_autoload_value_via_option_size($autoload, $option, $value, $serialized_value)
    {
    }
    /**
     * Deletes a transient.
     *
     * @since 2.8.0
     *
     * @param string $transient Transient name. Expected to not be SQL-escaped.
     * @return bool True if the transient was deleted, false otherwise.
     */
    function delete_transient($transient)
    {
    }
    /**
     * Retrieves the value of a transient.
     *
     * If the transient does not exist, does not have a value, or has expired,
     * then the return value will be false.
     *
     * @since 2.8.0
     *
     * @param string $transient Transient name. Expected to not be SQL-escaped.
     * @return mixed Value of transient.
     */
    function get_transient($transient)
    {
    }
    /**
     * Sets/updates the value of a transient.
     *
     * You do not need to serialize values. If the value needs to be serialized,
     * then it will be serialized before it is set.
     *
     * @since 2.8.0
     *
     * @param string $transient  Transient name. Expected to not be SQL-escaped.
     *                           Must be 172 characters or fewer in length.
     * @param mixed  $value      Transient value. Must be serializable if non-scalar.
     *                           Expected to not be SQL-escaped.
     * @param int    $expiration Optional. Time until expiration in seconds. Default 0 (no expiration).
     * @return bool True if the value was set, false otherwise.
     */
    function set_transient($transient, $value, $expiration = 0)
    {
    }
    /**
     * Deletes all expired transients.
     *
     * Note that this function won't do anything if an external object cache is in use.
     *
     * The multi-table delete syntax is used to delete the transient record
     * from table a, and the corresponding transient_timeout record from table b.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @since 4.9.0
     *
     * @param bool $force_db Optional. Force cleanup to run against the database even when an external object cache is used.
     * @phpstan-return void
     */
    function delete_expired_transients($force_db = \false)
    {
    }
    /**
     * Saves and restores user interface settings stored in a cookie.
     *
     * Checks if the current user-settings cookie is updated and stores it. When no
     * cookie exists (different browser used), adds the last saved cookie restoring
     * the settings.
     *
     * @since 2.7.0
     * @phpstan-return void
     */
    function wp_user_settings()
    {
    }
    /**
     * Retrieves user interface setting value based on setting name.
     *
     * @since 2.7.0
     *
     * @param string       $name          The name of the setting.
     * @param string|false $default_value Optional. Default value to return when $name is not set. Default false.
     * @return mixed The last saved user setting or the default value/false if it doesn't exist.
     */
    function get_user_setting($name, $default_value = \false)
    {
    }
    /**
     * Adds or updates user interface setting.
     *
     * Both `$name` and `$value` can contain only ASCII letters, numbers, hyphens, and underscores.
     *
     * This function has to be used before any output has started as it calls `setcookie()`.
     *
     * @since 2.8.0
     *
     * @param string $name  The name of the setting.
     * @param string $value The value for the setting.
     * @return bool|null True if set successfully, false otherwise.
     *                   Null if the current user is not a member of the site.
     */
    function set_user_setting($name, $value)
    {
    }
    /**
     * Deletes user interface settings.
     *
     * Deleting settings would reset them to the defaults.
     *
     * This function has to be used before any output has started as it calls `setcookie()`.
     *
     * @since 2.7.0
     *
     * @param string $names The name or array of names of the setting to be deleted.
     * @return bool|null True if deleted successfully, false otherwise.
     *                   Null if the current user is not a member of the site.
     */
    function delete_user_setting($names)
    {
    }
    /**
     * Retrieves all user interface settings.
     *
     * @since 2.7.0
     *
     * @global array $_updated_user_settings
     *
     * @return array The last saved user settings or empty array.
     */
    function get_all_user_settings()
    {
    }
    /**
     * Private. Sets all user interface settings.
     *
     * @since 2.8.0
     * @access private
     *
     * @global array $_updated_user_settings
     *
     * @param array $user_settings User settings.
     * @return bool|null True if set successfully, false if the current user could not be found.
     *                   Null if the current user is not a member of the site.
     */
    function wp_set_all_user_settings($user_settings)
    {
    }
    /**
     * Deletes the user settings of the current user.
     *
     * @since 2.7.0
     * @phpstan-return void
     */
    function delete_all_user_settings()
    {
    }
    /**
     * Retrieve an option value for the current network based on name of option.
     *
     * @since 2.8.0
     * @since 4.4.0 The `$use_cache` parameter was deprecated.
     * @since 4.4.0 Modified into wrapper for get_network_option()
     *
     * @see get_network_option()
     *
     * @param string $option        Name of the option to retrieve. Expected to not be SQL-escaped.
     * @param mixed  $default_value Optional. Value to return if the option doesn't exist. Default false.
     * @param bool   $deprecated    Whether to use cache. Multisite only. Always set to true.
     * @return mixed Value set for the option.
     */
    function get_site_option($option, $default_value = \false, $deprecated = \true)
    {
    }
    /**
     * Adds a new option for the current network.
     *
     * Existing options will not be updated. Note that prior to 3.3 this wasn't the case.
     *
     * @since 2.8.0
     * @since 4.4.0 Modified into wrapper for add_network_option()
     *
     * @see add_network_option()
     *
     * @param string $option Name of the option to add. Expected to not be SQL-escaped.
     * @param mixed  $value  Option value, can be anything. Expected to not be SQL-escaped.
     * @return bool True if the option was added, false otherwise.
     */
    function add_site_option($option, $value)
    {
    }
    /**
     * Removes an option by name for the current network.
     *
     * @since 2.8.0
     * @since 4.4.0 Modified into wrapper for delete_network_option()
     *
     * @see delete_network_option()
     *
     * @param string $option Name of the option to delete. Expected to not be SQL-escaped.
     * @return bool True if the option was deleted, false otherwise.
     */
    function delete_site_option($option)
    {
    }
    /**
     * Updates the value of an option that was already added for the current network.
     *
     * @since 2.8.0
     * @since 4.4.0 Modified into wrapper for update_network_option()
     *
     * @see update_network_option()
     *
     * @param string $option Name of the option. Expected to not be SQL-escaped.
     * @param mixed  $value  Option value. Expected to not be SQL-escaped.
     * @return bool True if the value was updated, false otherwise.
     */
    function update_site_option($option, $value)
    {
    }
    /**
     * Retrieves a network's option value based on the option name.
     *
     * @since 4.4.0
     *
     * @see get_option()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $network_id    ID of the network. Can be null to default to the current network ID.
     * @param string $option        Name of the option to retrieve. Expected to not be SQL-escaped.
     * @param mixed  $default_value Optional. Value to return if the option doesn't exist. Default false.
     * @return mixed Value set for the option.
     */
    function get_network_option($network_id, $option, $default_value = \false)
    {
    }
    /**
     * Adds a new network option.
     *
     * Existing options will not be updated.
     *
     * @since 4.4.0
     *
     * @see add_option()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $network_id ID of the network. Can be null to default to the current network ID.
     * @param string $option     Name of the option to add. Expected to not be SQL-escaped.
     * @param mixed  $value      Option value, can be anything. Expected to not be SQL-escaped.
     * @return bool True if the option was added, false otherwise.
     */
    function add_network_option($network_id, $option, $value)
    {
    }
    /**
     * Removes a network option by name.
     *
     * @since 4.4.0
     *
     * @see delete_option()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $network_id ID of the network. Can be null to default to the current network ID.
     * @param string $option     Name of the option to delete. Expected to not be SQL-escaped.
     * @return bool True if the option was deleted, false otherwise.
     */
    function delete_network_option($network_id, $option)
    {
    }
    /**
     * Updates the value of a network option that was already added.
     *
     * @since 4.4.0
     *
     * @see update_option()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $network_id ID of the network. Can be null to default to the current network ID.
     * @param string $option     Name of the option. Expected to not be SQL-escaped.
     * @param mixed  $value      Option value. Expected to not be SQL-escaped.
     * @return bool True if the value was updated, false otherwise.
     */
    function update_network_option($network_id, $option, $value)
    {
    }
    /**
     * Deletes a site transient.
     *
     * @since 2.9.0
     *
     * @param string $transient Transient name. Expected to not be SQL-escaped.
     * @return bool True if the transient was deleted, false otherwise.
     */
    function delete_site_transient($transient)
    {
    }
    /**
     * Retrieves the value of a site transient.
     *
     * If the transient does not exist, does not have a value, or has expired,
     * then the return value will be false.
     *
     * @since 2.9.0
     *
     * @see get_transient()
     *
     * @param string $transient Transient name. Expected to not be SQL-escaped.
     * @return mixed Value of transient.
     */
    function get_site_transient($transient)
    {
    }
    /**
     * Sets/updates the value of a site transient.
     *
     * You do not need to serialize values. If the value needs to be serialized,
     * then it will be serialized before it is set.
     *
     * @since 2.9.0
     *
     * @see set_transient()
     *
     * @param string $transient  Transient name. Expected to not be SQL-escaped. Must be
     *                           167 characters or fewer in length.
     * @param mixed  $value      Transient value. Expected to not be SQL-escaped.
     * @param int    $expiration Optional. Time until expiration in seconds. Default 0 (no expiration).
     * @return bool True if the value was set, false otherwise.
     */
    function set_site_transient($transient, $value, $expiration = 0)
    {
    }
    /**
     * Registers default settings available in WordPress.
     *
     * The settings registered here are primarily useful for the REST API, so this
     * does not encompass all settings available in WordPress.
     *
     * @since 4.7.0
     * @since 6.0.1 The `show_on_front`, `page_on_front`, and `page_for_posts` options were added.
     */
    function register_initial_settings()
    {
    }
    /**
     * Registers a setting and its data.
     *
     * @since 2.7.0
     * @since 3.0.0 The `misc` option group was deprecated.
     * @since 3.5.0 The `privacy` option group was deprecated.
     * @since 4.7.0 `$args` can be passed to set flags on the setting, similar to `register_meta()`.
     * @since 5.5.0 `$new_whitelist_options` was renamed to `$new_allowed_options`.
     *              Please consider writing more inclusive code.
     * @since 6.6.0 Added the `label` argument.
     *
     * @global array $new_allowed_options
     * @global array $wp_registered_settings
     *
     * @param string $option_group A settings group name. Should correspond to an allowed option key name.
     *                             Default allowed option key names include 'general', 'discussion', 'media',
     *                             'reading', 'writing', and 'options'.
     * @param string $option_name The name of an option to sanitize and save.
     * @param array  $args {
     *     Data used to describe the setting when registered.
     *
     *     @type string     $type              The type of data associated with this setting.
     *                                         Valid values are 'string', 'boolean', 'integer', 'number', 'array', and 'object'.
     *     @type string     $label             A label of the data attached to this setting.
     *     @type string     $description       A description of the data attached to this setting.
     *     @type callable   $sanitize_callback A callback function that sanitizes the option's value.
     *     @type bool|array $show_in_rest      Whether data associated with this setting should be included in the REST API.
     *                                         When registering complex settings, this argument may optionally be an
     *                                         array with a 'schema' key.
     *     @type mixed      $default           Default value when calling `get_option()`.
     * }
     * @phpstan-param array{
     *   type?: string,
     *   label?: string,
     *   description?: string,
     *   sanitize_callback?: callable,
     *   show_in_rest?: bool|array,
     *   default?: mixed,
     * } $args
     */
    function register_setting($option_group, $option_name, $args = array())
    {
    }
    /**
     * Unregisters a setting.
     *
     * @since 2.7.0
     * @since 4.7.0 `$sanitize_callback` was deprecated. The callback from `register_setting()` is now used instead.
     * @since 5.5.0 `$new_whitelist_options` was renamed to `$new_allowed_options`.
     *              Please consider writing more inclusive code.
     *
     * @global array $new_allowed_options
     * @global array $wp_registered_settings
     *
     * @param string   $option_group The settings group name used during registration.
     * @param string   $option_name  The name of the option to unregister.
     * @param callable $deprecated   Optional. Deprecated.
     */
    function unregister_setting($option_group, $option_name, $deprecated = '')
    {
    }
    /**
     * Retrieves an array of registered settings.
     *
     * @since 4.7.0
     *
     * @global array $wp_registered_settings
     *
     * @return array List of registered settings, keyed by option name.
     */
    function get_registered_settings()
    {
    }
    /**
     * Filters the default value for the option.
     *
     * For settings which register a default setting in `register_setting()`, this
     * function is added as a filter to `default_option_{$option}`.
     *
     * @since 4.7.0
     *
     * @param mixed  $default_value  Existing default value to return.
     * @param string $option         Option name.
     * @param bool   $passed_default Was `get_option()` passed a default value?
     * @return mixed Filtered default value.
     */
    function filter_default_option($default_value, $option, $passed_default)
    {
    }
    /**
     * Returns the values that trigger autoloading from the options table.
     *
     * @since 6.6.0
     *
     * @return string[] The values that trigger autoloading.
     */
    function wp_autoload_values_to_autoload()
    {
    }
    /**
     * Changes the current user by ID or name.
     *
     * Set $id to null and specify a name if you do not know a user's ID.
     *
     * @since 2.0.1
     * @deprecated 3.0.0 Use wp_set_current_user()
     * @see wp_set_current_user()
     *
     * @param int|null $id User ID.
     * @param string $name Optional. The user's username
     * @return WP_User returns wp_set_current_user()
     */
    function set_current_user($id, $name = '')
    {
    }
    /**
     * Populate global variables with information about the currently logged in user.
     *
     * @since 0.71
     * @deprecated 4.5.0 Use wp_get_current_user()
     * @see wp_get_current_user()
     *
     * @return bool|WP_User False on XMLRPC Request and invalid auth cookie, WP_User instance otherwise.
     */
    function get_currentuserinfo()
    {
    }
    /**
     * Retrieve user info by login name.
     *
     * @since 0.71
     * @deprecated 3.3.0 Use get_user_by()
     * @see get_user_by()
     *
     * @param string $user_login User's username
     * @return bool|object False on failure, User DB row object
     */
    function get_userdatabylogin($user_login)
    {
    }
    /**
     * Retrieve user info by email.
     *
     * @since 2.5.0
     * @deprecated 3.3.0 Use get_user_by()
     * @see get_user_by()
     *
     * @param string $email User's email address
     * @return bool|object False on failure, User DB row object
     */
    function get_user_by_email($email)
    {
    }
    /**
     * Sets a cookie for a user who just logged in. This function is deprecated.
     *
     * @since 1.5.0
     * @deprecated 2.5.0 Use wp_set_auth_cookie()
     * @see wp_set_auth_cookie()
     *
     * @param string $username The user's username
     * @param string $password Optional. The user's password
     * @param bool $already_md5 Optional. Whether the password has already been through MD5
     * @param string $home Optional. Will be used instead of COOKIEPATH if set
     * @param string $siteurl Optional. Will be used instead of SITECOOKIEPATH if set
     * @param bool $remember Optional. Remember that the user is logged in
     */
    function wp_setcookie($username, $password = '', $already_md5 = \false, $home = '', $siteurl = '', $remember = \false)
    {
    }
    /**
     * Clears the authentication cookie, logging the user out. This function is deprecated.
     *
     * @since 1.5.0
     * @deprecated 2.5.0 Use wp_clear_auth_cookie()
     * @see wp_clear_auth_cookie()
     */
    function wp_clearcookie()
    {
    }
    /**
     * Gets the user cookie login. This function is deprecated.
     *
     * This function is deprecated and should no longer be extended as it won't be
     * used anywhere in WordPress. Also, plugins shouldn't use it either.
     *
     * @since 2.0.3
     * @deprecated 2.5.0
     *
     * @return bool Always returns false
     */
    function wp_get_cookie_login()
    {
    }
    /**
     * Checks a users login information and logs them in if it checks out. This function is deprecated.
     *
     * Use the global $error to get the reason why the login failed. If the username
     * is blank, no error will be set, so assume blank username on that case.
     *
     * Plugins extending this function should also provide the global $error and set
     * what the error is, so that those checking the global for why there was a
     * failure can utilize it later.
     *
     * @since 1.2.2
     * @deprecated 2.5.0 Use wp_signon()
     * @see wp_signon()
     *
     * @global string $error Error when false is returned
     *
     * @param string $username   User's username
     * @param string $password   User's password
     * @param string $deprecated Not used
     * @return bool True on successful check, false on login failure.
     */
    function wp_login($username, $password, $deprecated = '')
    {
    }
    /**
     * Changes the current user by ID or name.
     *
     * Set $id to null and specify a name if you do not know a user's ID.
     *
     * Some WordPress functionality is based on the current user and not based on
     * the signed in user. Therefore, it opens the ability to edit and perform
     * actions on users who aren't signed in.
     *
     * @since 2.0.3
     *
     * @global WP_User $current_user The current user object which holds the user data.
     *
     * @param int|null $id   User ID.
     * @param string   $name User's username.
     * @return WP_User Current user User object.
     */
    function wp_set_current_user($id, $name = '')
    {
    }
    /**
     * Retrieves the current user object.
     *
     * Will set the current user, if the current user is not set. The current user
     * will be set to the logged-in person. If no user is logged-in, then it will
     * set the current user to 0, which is invalid and won't have any permissions.
     *
     * @since 2.0.3
     *
     * @see _wp_get_current_user()
     * @global WP_User $current_user Checks if the current user is set.
     *
     * @return WP_User Current WP_User instance.
     */
    function wp_get_current_user()
    {
    }
    /**
     * Retrieves user info by user ID.
     *
     * @since 0.71
     *
     * @param int $user_id User ID
     * @return WP_User|false WP_User object on success, false on failure.
     */
    function get_userdata($user_id)
    {
    }
    /**
     * Retrieves user info by a given field.
     *
     * @since 2.8.0
     * @since 4.4.0 Added 'ID' as an alias of 'id' for the `$field` parameter.
     *
     * @global WP_User $current_user The current user object which holds the user data.
     *
     * @param string     $field The field to retrieve the user with. id | ID | slug | email | login.
     * @param int|string $value A value for $field. A user ID, slug, email address, or login name.
     * @return WP_User|false WP_User object on success, false on failure.
     * @phpstan-return ($field is 'id'|'ID' ? ($value is int<min, 0> ? false : \WP_User|false) : \WP_User|false)
     */
    function get_user_by($field, $value)
    {
    }
    /**
     * Retrieves info for user lists to prevent multiple queries by get_userdata().
     *
     * @since 3.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int[] $user_ids User ID numbers list
     * @phpstan-return void
     */
    function cache_users($user_ids)
    {
    }
    /**
     * Sends an email, similar to PHP's mail function.
     *
     * A true return value does not automatically mean that the user received the
     * email successfully. It just only means that the method used was able to
     * process the request without any errors.
     *
     * The default content type is `text/plain` which does not allow using HTML.
     * However, you can set the content type of the email by using the
     * {@see 'wp_mail_content_type'} filter.
     *
     * The default charset is based on the charset used on the blog. The charset can
     * be set using the {@see 'wp_mail_charset'} filter.
     *
     * @since 1.2.1
     * @since 5.5.0 is_email() is used for email validation,
     *              instead of PHPMailer's default validator.
     *
     * @global PHPMailer\PHPMailer\PHPMailer $phpmailer
     *
     * @param string|string[] $to          Array or comma-separated list of email addresses to send message.
     * @param string          $subject     Email subject.
     * @param string          $message     Message contents.
     * @param string|string[] $headers     Optional. Additional headers.
     * @param string|string[] $attachments Optional. Paths to files to attach.
     * @return bool Whether the email was sent successfully.
     */
    function wp_mail($to, $subject, $message, $headers = '', $attachments = array())
    {
    }
    /**
     * Authenticates a user, confirming the login credentials are valid.
     *
     * @since 2.5.0
     * @since 4.5.0 `$username` now accepts an email address.
     *
     * @param string $username User's username or email address.
     * @param string $password User's password.
     * @return WP_User|WP_Error WP_User object if the credentials are valid,
     *                          otherwise WP_Error.
     */
    function wp_authenticate($username, $password)
    {
    }
    /**
     * Logs the current user out.
     *
     * @since 2.5.0
     */
    function wp_logout()
    {
    }
    /**
     * Validates authentication cookie.
     *
     * The checks include making sure that the authentication cookie is set and
     * pulling in the contents (if $cookie is not used).
     *
     * Makes sure the cookie is not expired. Verifies the hash in cookie is what is
     * should be and compares the two.
     *
     * @since 2.5.0
     *
     * @global int $login_grace_period
     *
     * @param string $cookie Optional. If used, will validate contents instead of cookie's.
     * @param string $scheme Optional. The cookie scheme to use: 'auth', 'secure_auth', or 'logged_in'.
     * @return int|false User ID if valid cookie, false if invalid.
     * @phpstan-param 'auth'|'secure_auth'|'logged_in' $scheme
     */
    function wp_validate_auth_cookie($cookie = '', $scheme = '')
    {
    }
    /**
     * Generates authentication cookie contents.
     *
     * @since 2.5.0
     * @since 4.0.0 The `$token` parameter was added.
     *
     * @param int    $user_id    User ID.
     * @param int    $expiration The time the cookie expires as a UNIX timestamp.
     * @param string $scheme     Optional. The cookie scheme to use: 'auth', 'secure_auth', or 'logged_in'.
     *                           Default 'auth'.
     * @param string $token      User's session token to use for this cookie.
     * @return string Authentication cookie contents. Empty string if user does not exist.
     * @phpstan-param 'auth'|'secure_auth'|'logged_in' $scheme
     */
    function wp_generate_auth_cookie($user_id, $expiration, $scheme = 'auth', $token = '')
    {
    }
    /**
     * Parses a cookie into its components.
     *
     * @since 2.7.0
     * @since 4.0.0 The `$token` element was added to the return value.
     *
     * @param string $cookie Authentication cookie.
     * @param string $scheme Optional. The cookie scheme to use: 'auth', 'secure_auth', or 'logged_in'.
     * @return string[]|false {
     *     Authentication cookie components. None of the components should be assumed
     *     to be valid as they come directly from a client-provided cookie value. If
     *     the cookie value is malformed, false is returned.
     *
     *     @type string $username   User's username.
     *     @type string $expiration The time the cookie expires as a UNIX timestamp.
     *     @type string $token      User's session token used.
     *     @type string $hmac       The security hash for the cookie.
     *     @type string $scheme     The cookie scheme to use.
     * }
     * @phpstan-param 'auth'|'secure_auth'|'logged_in' $scheme
     * @phpstan-return false|array{
     *   username: string,
     *   expiration: string,
     *   token: string,
     *   hmac: string,
     *   scheme: string,
     * }
     */
    function wp_parse_auth_cookie($cookie = '', $scheme = '')
    {
    }
    /**
     * Sets the authentication cookies based on user ID.
     *
     * The $remember parameter increases the time that the cookie will be kept. The
     * default the cookie is kept without remembering is two days. When $remember is
     * set, the cookies will be kept for 14 days or two weeks.
     *
     * @since 2.5.0
     * @since 4.3.0 Added the `$token` parameter.
     *
     * @param int         $user_id  User ID.
     * @param bool        $remember Whether to remember the user.
     * @param bool|string $secure   Whether the auth cookie should only be sent over HTTPS. Default is an empty
     *                              string which means the value of `is_ssl()` will be used.
     * @param string      $token    Optional. User's session token to use for this cookie.
     * @phpstan-return void
     */
    function wp_set_auth_cookie($user_id, $remember = \false, $secure = '', $token = '')
    {
    }
    /**
     * Removes all of the cookies associated with authentication.
     *
     * @since 2.5.0
     * @phpstan-return void
     */
    function wp_clear_auth_cookie()
    {
    }
    /**
     * Determines whether the current visitor is a logged in user.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.0.0
     *
     * @return bool True if user is logged in, false if not logged in.
     */
    function is_user_logged_in()
    {
    }
    /**
     * Checks if a user is logged in, if not it redirects them to the login page.
     *
     * When this code is called from a page, it checks to see if the user viewing the page is logged in.
     * If the user is not logged in, they are redirected to the login page. The user is redirected
     * in such a way that, upon logging in, they will be sent directly to the page they were originally
     * trying to access.
     *
     * @since 1.5.0
     * @phpstan-return void
     */
    function auth_redirect()
    {
    }
    /**
     * Ensures intent by verifying that a user was referred from another admin page with the correct security nonce.
     *
     * This function ensures the user intends to perform a given action, which helps protect against clickjacking style
     * attacks. It verifies intent, not authorization, therefore it does not verify the user's capabilities. This should
     * be performed with `current_user_can()` or similar.
     *
     * If the nonce value is invalid, the function will exit with an "Are You Sure?" style message.
     *
     * @since 1.2.0
     * @since 2.5.0 The `$query_arg` parameter was added.
     *
     * @param int|string $action    The nonce action.
     * @param string     $query_arg Optional. Key to check for nonce in `$_REQUEST`. Default '_wpnonce'.
     * @return int|false 1 if the nonce is valid and generated between 0-12 hours ago,
     *                   2 if the nonce is valid and generated between 12-24 hours ago.
     *                   False if the nonce is invalid.
     * @phpstan-param -1|string $action
     * @phpstan-return 1|2|false
     */
    function check_admin_referer($action = -1, $query_arg = '_wpnonce')
    {
    }
    /**
     * Verifies the Ajax request to prevent processing requests external of the blog.
     *
     * @since 2.0.3
     *
     * @param int|string   $action    Action nonce.
     * @param false|string $query_arg Optional. Key to check for the nonce in `$_REQUEST` (since 2.5). If false,
     *                                `$_REQUEST` values will be evaluated for '_ajax_nonce', and '_wpnonce'
     *                                (in that order). Default false.
     * @param bool         $stop      Optional. Whether to stop early when the nonce cannot be verified.
     *                                Default true.
     * @return int|false 1 if the nonce is valid and generated between 0-12 hours ago,
     *                   2 if the nonce is valid and generated between 12-24 hours ago.
     *                   False if the nonce is invalid.
     * @phpstan-param -1|string $action
     * @phpstan-return 1|2|false
     */
    function check_ajax_referer($action = -1, $query_arg = \false, $stop = \true)
    {
    }
    /**
     * Redirects to another page.
     *
     * Note: wp_redirect() does not exit automatically, and should almost always be
     * followed by a call to `exit;`:
     *
     *     wp_redirect( $url );
     *     exit;
     *
     * Exiting can also be selectively manipulated by using wp_redirect() as a conditional
     * in conjunction with the {@see 'wp_redirect'} and {@see 'wp_redirect_status'} filters:
     *
     *     if ( wp_redirect( $url ) ) {
     *         exit;
     *     }
     *
     * @since 1.5.1
     * @since 5.1.0 The `$x_redirect_by` parameter was added.
     * @since 5.4.0 On invalid status codes, wp_die() is called.
     *
     * @global bool $is_IIS
     *
     * @param string       $location      The path or URL to redirect to.
     * @param int          $status        Optional. HTTP response status code to use. Default '302' (Moved Temporarily).
     * @param string|false $x_redirect_by Optional. The application doing the redirect or false to omit. Default 'WordPress'.
     * @return bool False if the redirect was canceled, true otherwise.
     */
    function wp_redirect($location, $status = 302, $x_redirect_by = 'WordPress')
    {
    }
    /**
     * Sanitizes a URL for use in a redirect.
     *
     * @since 2.3.0
     *
     * @param string $location The path to redirect to.
     * @return string Redirect-sanitized URL.
     */
    function wp_sanitize_redirect($location)
    {
    }
    /**
     * URL encodes UTF-8 characters in a URL.
     *
     * @ignore
     * @since 4.2.0
     * @access private
     *
     * @see wp_sanitize_redirect()
     *
     * @param array $matches RegEx matches against the redirect location.
     * @return string URL-encoded version of the first RegEx match.
     */
    function _wp_sanitize_utf8_in_redirect($matches)
    {
    }
    /**
     * Performs a safe (local) redirect, using wp_redirect().
     *
     * Checks whether the $location is using an allowed host, if it has an absolute
     * path. A plugin can therefore set or remove allowed host(s) to or from the
     * list.
     *
     * If the host is not allowed, then the redirect defaults to wp-admin on the siteurl
     * instead. This prevents malicious redirects which redirect to another host,
     * but only used in a few places.
     *
     * Note: wp_safe_redirect() does not exit automatically, and should almost always be
     * followed by a call to `exit;`:
     *
     *     wp_safe_redirect( $url );
     *     exit;
     *
     * Exiting can also be selectively manipulated by using wp_safe_redirect() as a conditional
     * in conjunction with the {@see 'wp_redirect'} and {@see 'wp_redirect_status'} filters:
     *
     *     if ( wp_safe_redirect( $url ) ) {
     *         exit;
     *     }
     *
     * @since 2.3.0
     * @since 5.1.0 The return value from wp_redirect() is now passed on, and the `$x_redirect_by` parameter was added.
     *
     * @param string       $location      The path or URL to redirect to.
     * @param int          $status        Optional. HTTP response status code to use. Default '302' (Moved Temporarily).
     * @param string|false $x_redirect_by Optional. The application doing the redirect or false to omit. Default 'WordPress'.
     * @return bool False if the redirect was canceled, true otherwise.
     */
    function wp_safe_redirect($location, $status = 302, $x_redirect_by = 'WordPress')
    {
    }
    /**
     * Validates a URL for use in a redirect.
     *
     * Checks whether the $location is using an allowed host, if it has an absolute
     * path. A plugin can therefore set or remove allowed host(s) to or from the
     * list.
     *
     * If the host is not allowed, then the redirect is to $fallback_url supplied.
     *
     * @since 2.8.1
     *
     * @param string $location     The redirect to validate.
     * @param string $fallback_url The value to return if $location is not allowed.
     * @return string Redirect-sanitized URL.
     */
    function wp_validate_redirect($location, $fallback_url = '')
    {
    }
    /**
     * Notifies an author (and/or others) of a comment/trackback/pingback on a post.
     *
     * @since 1.0.0
     *
     * @param int|WP_Comment $comment_id Comment ID or WP_Comment object.
     * @param string         $deprecated Not used.
     * @return bool True on completion. False if no email addresses were specified.
     */
    function wp_notify_postauthor($comment_id, $deprecated = \null)
    {
    }
    /**
     * Notifies the moderator of the site about a new comment that is awaiting approval.
     *
     * @since 1.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * Uses the {@see 'notify_moderator'} filter to determine whether the site moderator
     * should be notified, overriding the site setting.
     *
     * @param int $comment_id Comment ID.
     * @return true Always returns true.
     */
    function wp_notify_moderator($comment_id)
    {
    }
    /**
     * Notifies the blog admin of a user changing password, normally via email.
     *
     * @since 2.7.0
     *
     * @param WP_User $user User object.
     */
    function wp_password_change_notification($user)
    {
    }
    /**
     * Emails login credentials to a newly-registered user.
     *
     * A new user registration notification is also sent to admin email.
     *
     * @since 2.0.0
     * @since 4.3.0 The `$plaintext_pass` parameter was changed to `$notify`.
     * @since 4.3.1 The `$plaintext_pass` parameter was deprecated. `$notify` added as a third parameter.
     * @since 4.6.0 The `$notify` parameter accepts 'user' for sending notification only to the user created.
     *
     * @param int    $user_id    User ID.
     * @param null   $deprecated Not used (argument deprecated).
     * @param string $notify     Optional. Type of notification that should happen. Accepts 'admin' or an empty
     *                           string (admin only), 'user', or 'both' (admin and user). Default empty.
     * @phpstan-param 'admin'|'user'|'both' $notify
     * @phpstan-return void
     */
    function wp_new_user_notification($user_id, $deprecated = \null, $notify = '')
    {
    }
    /**
     * Returns the time-dependent variable for nonce creation.
     *
     * A nonce has a lifespan of two ticks. Nonces in their second tick may be
     * updated, e.g. by autosave.
     *
     * @since 2.5.0
     * @since 6.1.0 Added `$action` argument.
     *
     * @param string|int $action Optional. The nonce action. Default -1.
     * @return float Float value rounded up to the next highest integer.
     */
    function wp_nonce_tick($action = -1)
    {
    }
    /**
     * Verifies that a correct security nonce was used with time limit.
     *
     * A nonce is valid for 24 hours (by default).
     *
     * @since 2.0.3
     *
     * @param string     $nonce  Nonce value that was used for verification, usually via a form field.
     * @param string|int $action Should give context to what is taking place and be the same when nonce was created.
     * @return int|false 1 if the nonce is valid and generated between 0-12 hours ago,
     *                   2 if the nonce is valid and generated between 12-24 hours ago.
     *                   False if the nonce is invalid.
     * @phpstan-param -1|string $action
     * @phpstan-return 1|2|false
     */
    function wp_verify_nonce($nonce, $action = -1)
    {
    }
    /**
     * Creates a cryptographic token tied to a specific action, user, user session,
     * and window of time.
     *
     * @since 2.0.3
     * @since 4.0.0 Session tokens were integrated with nonce creation.
     *
     * @param string|int $action Scalar value to add context to the nonce.
     * @return string The token.
     * @phpstan-param -1|string $action
     */
    function wp_create_nonce($action = -1)
    {
    }
    /**
     * Returns a salt to add to hashes.
     *
     * Salts are created using secret keys. Secret keys are located in two places:
     * in the database and in the wp-config.php file. The secret key in the database
     * is randomly generated and will be appended to the secret keys in wp-config.php.
     *
     * The secret keys in wp-config.php should be updated to strong, random keys to maximize
     * security. Below is an example of how the secret key constants are defined.
     * Do not paste this example directly into wp-config.php. Instead, have a
     * {@link https://api.wordpress.org/secret-key/1.1/salt/ secret key created} just
     * for you.
     *
     *     define('AUTH_KEY',         ' Xakm<o xQy rw4EMsLKM-?!T+,PFF})H4lzcW57AF0U@N@< >M%G4Yt>f`z]MON');
     *     define('SECURE_AUTH_KEY',  'LzJ}op]mr|6+![P}Ak:uNdJCJZd>(Hx.-Mh#Tz)pCIU#uGEnfFz|f ;;eU%/U^O~');
     *     define('LOGGED_IN_KEY',    '|i|Ux`9<p-h$aFf(qnT:sDO:D1P^wZ$$/Ra@miTJi9G;ddp_<q}6H1)o|a +&JCM');
     *     define('NONCE_KEY',        '%:R{[P|,s.KuMltH5}cI;/k<Gx~j!f0I)m_sIyu+&NJZ)-iO>z7X>QYR0Z_XnZ@|');
     *     define('AUTH_SALT',        'eZyT)-Naw]F8CwA*VaW#q*|.)g@o}||wf~@C-YSt}(dh_r6EbI#A,y|nU2{B#JBW');
     *     define('SECURE_AUTH_SALT', '!=oLUTXh,QW=H `}`L|9/^4-3 STz},T(w}W<I`.JjPi)<Bmf1v,HpGe}T1:Xt7n');
     *     define('LOGGED_IN_SALT',   '+XSqHc;@Q*K_b|Z?NC[3H!!EONbh.n<+=uKR:>*c(u`g~EJBf#8u#R{mUEZrozmm');
     *     define('NONCE_SALT',       'h`GXHhD>SLWVfg1(1(N{;.V!MoE(SfbA_ksP@&`+AycHcAV$+?@3q+rxV{%^VyKT');
     *
     * Salting passwords helps against tools which has stored hashed values of
     * common dictionary strings. The added values makes it harder to crack.
     *
     * @since 2.5.0
     *
     * @link https://api.wordpress.org/secret-key/1.1/salt/ Create secrets for wp-config.php
     *
     * @param string $scheme Authentication scheme (auth, secure_auth, logged_in, nonce).
     * @return string Salt value
     */
    function wp_salt($scheme = 'auth')
    {
    }
    /**
     * Gets hash of given string.
     *
     * @since 2.0.3
     *
     * @param string $data   Plain text to hash.
     * @param string $scheme Authentication scheme (auth, secure_auth, logged_in, nonce).
     * @return string Hash of $data.
     */
    function wp_hash($data, $scheme = 'auth')
    {
    }
    /**
     * Creates a hash of a plain text password.
     *
     * For integration with other applications, this function can be overwritten to
     * instead use the other package password hashing algorithm.
     *
     * @since 2.5.0
     *
     * @global PasswordHash $wp_hasher PHPass object.
     *
     * @param string $password Plain text user password to hash.
     * @return string The hash string of the password.
     */
    function wp_hash_password($password)
    {
    }
    /**
     * Checks a plaintext password against a hashed password.
     *
     * Maintains compatibility between old version and the new cookie authentication
     * protocol using PHPass library. The $hash parameter is the encrypted password
     * and the function compares the plain text password when encrypted similarly
     * against the already encrypted password to see if they match.
     *
     * For integration with other applications, this function can be overwritten to
     * instead use the other package password hashing algorithm.
     *
     * @since 2.5.0
     *
     * @global PasswordHash $wp_hasher PHPass object used for checking the password
     *                                 against the $hash + $password.
     * @uses PasswordHash::CheckPassword
     *
     * @param string     $password Plaintext user's password.
     * @param string     $hash     Hash of the user's password to check against.
     * @param string|int $user_id  Optional. User ID.
     * @return bool False, if the $password does not match the hashed password.
     */
    function wp_check_password($password, $hash, $user_id = '')
    {
    }
    /**
     * Generates a random password drawn from the defined set of characters.
     *
     * Uses wp_rand() to create passwords with far less predictability
     * than similar native PHP functions like `rand()` or `mt_rand()`.
     *
     * @since 2.5.0
     *
     * @param int  $length              Optional. The length of password to generate. Default 12.
     * @param bool $special_chars       Optional. Whether to include standard special characters.
     *                                  Default true.
     * @param bool $extra_special_chars Optional. Whether to include other special characters.
     *                                  Used when generating secret keys and salts. Default false.
     * @return string The random password.
     */
    function wp_generate_password($length = 12, $special_chars = \true, $extra_special_chars = \false)
    {
    }
    /**
     * Generates a random non-negative number.
     *
     * @since 2.6.2
     * @since 4.4.0 Uses PHP7 random_int() or the random_compat library if available.
     * @since 6.1.0 Returns zero instead of a random number if both `$min` and `$max` are zero.
     *
     * @global string $rnd_value
     *
     * @param int $min Optional. Lower limit for the generated number.
     *                 Accepts positive integers or zero. Defaults to 0.
     * @param int $max Optional. Upper limit for the generated number.
     *                 Accepts positive integers. Defaults to 4294967295.
     * @return int A random non-negative number between min and max.
     */
    function wp_rand($min = \null, $max = \null)
    {
    }
    /**
     * Updates the user's password with a new hashed one.
     *
     * For integration with other applications, this function can be overwritten to
     * instead use the other package password checking algorithm.
     *
     * Please note: This function should be used sparingly and is really only meant for single-time
     * application. Leveraging this improperly in a plugin or theme could result in an endless loop
     * of password resets if precautions are not taken to ensure it does not execute on every page load.
     *
     * @since 2.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $password The plaintext new user password.
     * @param int    $user_id  User ID.
     */
    function wp_set_password($password, $user_id)
    {
    }
    /**
     * Retrieves the avatar `<img>` tag for a user, email address, MD5 hash, comment, or post.
     *
     * @since 2.5.0
     * @since 4.2.0 Added the optional `$args` parameter.
     * @since 5.5.0 Added the `loading` argument.
     * @since 6.1.0 Added the `decoding` argument.
     * @since 6.3.0 Added the `fetchpriority` argument.
     *
     * @param mixed  $id_or_email   The avatar to retrieve. Accepts a user ID, Gravatar MD5 hash,
     *                              user email, WP_User object, WP_Post object, or WP_Comment object.
     * @param int    $size          Optional. Height and width of the avatar in pixels. Default 96.
     * @param string $default_value URL for the default image or a default type. Accepts:
     *                              - '404' (return a 404 instead of a default image)
     *                              - 'retro' (a 8-bit arcade-style pixelated face)
     *                              - 'robohash' (a robot)
     *                              - 'monsterid' (a monster)
     *                              - 'wavatar' (a cartoon face)
     *                              - 'identicon' (the "quilt", a geometric pattern)
     *                              - 'mystery', 'mm', or 'mysteryman' (The Oyster Man)
     *                              - 'blank' (transparent GIF)
     *                              - 'gravatar_default' (the Gravatar logo)
     *                              Default is the value of the 'avatar_default' option,
     *                              with a fallback of 'mystery'.
     * @param string $alt           Optional. Alternative text to use in the avatar image tag.
     *                              Default empty.
     * @param array  $args {
     *     Optional. Extra arguments to retrieve the avatar.
     *
     *     @type int          $height        Display height of the avatar in pixels. Defaults to $size.
     *     @type int          $width         Display width of the avatar in pixels. Defaults to $size.
     *     @type bool         $force_default Whether to always show the default image, never the Gravatar.
     *                                       Default false.
     *     @type string       $rating        What rating to display avatars up to. Accepts:
     *                                       - 'G' (suitable for all audiences)
     *                                       - 'PG' (possibly offensive, usually for audiences 13 and above)
     *                                       - 'R' (intended for adult audiences above 17)
     *                                       - 'X' (even more mature than above)
     *                                       Default is the value of the 'avatar_rating' option.
     *     @type string       $scheme        URL scheme to use. See set_url_scheme() for accepted values.
     *                                       Default null.
     *     @type array|string $class         Array or string of additional classes to add to the img element.
     *                                       Default null.
     *     @type bool         $force_display Whether to always show the avatar - ignores the show_avatars option.
     *                                       Default false.
     *     @type string       $loading       Value for the `loading` attribute.
     *                                       Default null.
     *     @type string       $fetchpriority Value for the `fetchpriority` attribute.
     *                                       Default null.
     *     @type string       $decoding      Value for the `decoding` attribute.
     *                                       Default null.
     *     @type string       $extra_attr    HTML attributes to insert in the IMG element. Is not sanitized.
     *                                       Default empty.
     * }
     * @return string|false `<img>` tag for the user's avatar. False on failure.
     * @phpstan-param array{
     *   height?: int,
     *   width?: int,
     *   force_default?: bool,
     *   rating?: string,
     *   scheme?: string,
     *   class?: array|string,
     *   force_display?: bool,
     *   loading?: string,
     *   fetchpriority?: string,
     *   decoding?: string,
     *   extra_attr?: string,
     * } $args
     */
    function get_avatar($id_or_email, $size = 96, $default_value = '', $alt = '', $args = \null)
    {
    }
    /**
     * Displays a human readable HTML representation of the difference between two strings.
     *
     * The Diff is available for getting the changes between versions. The output is
     * HTML, so the primary use is for displaying the changes. If the two strings
     * are equivalent, then an empty string will be returned.
     *
     * @since 2.6.0
     *
     * @see wp_parse_args() Used to change defaults to user defined settings.
     * @uses Text_Diff
     * @uses WP_Text_Diff_Renderer_Table
     *
     * @param string       $left_string  "old" (left) version of string.
     * @param string       $right_string "new" (right) version of string.
     * @param string|array $args {
     *     Associative array of options to pass to WP_Text_Diff_Renderer_Table().
     *
     *     @type string $title           Titles the diff in a manner compatible
     *                                   with the output. Default empty.
     *     @type string $title_left      Change the HTML to the left of the title.
     *                                   Default empty.
     *     @type string $title_right     Change the HTML to the right of the title.
     *                                   Default empty.
     *     @type bool   $show_split_view True for split view (two columns), false for
     *                                   un-split view (single column). Default true.
     * }
     * @return string Empty string if strings are equivalent or HTML with differences.
     * @phpstan-param array{
     *   title?: string,
     *   title_left?: string,
     *   title_right?: string,
     *   show_split_view?: bool,
     * } $args
     */
    function wp_text_diff($left_string, $right_string, $args = \null)
    {
    }
    /**
     * Adds a callback function to a filter hook.
     *
     * WordPress offers filter hooks to allow plugins to modify
     * various types of internal data at runtime.
     *
     * A plugin can modify data by binding a callback to a filter hook. When the filter
     * is later applied, each bound callback is run in order of priority, and given
     * the opportunity to modify a value by returning a new value.
     *
     * The following example shows how a callback function is bound to a filter hook.
     *
     * Note that `$example` is passed to the callback, (maybe) modified, then returned:
     *
     *     function example_callback( $example ) {
     *         // Maybe modify $example in some way.
     *         return $example;
     *     }
     *     add_filter( 'example_filter', 'example_callback' );
     *
     * Bound callbacks can accept from none to the total number of arguments passed as parameters
     * in the corresponding apply_filters() call.
     *
     * In other words, if an apply_filters() call passes four total arguments, callbacks bound to
     * it can accept none (the same as 1) of the arguments or up to four. The important part is that
     * the `$accepted_args` value must reflect the number of arguments the bound callback *actually*
     * opted to accept. If no arguments were accepted by the callback that is considered to be the
     * same as accepting 1 argument. For example:
     *
     *     // Filter call.
     *     $value = apply_filters( 'hook', $value, $arg2, $arg3 );
     *
     *     // Accepting zero/one arguments.
     *     function example_callback() {
     *         ...
     *         return 'some value';
     *     }
     *     add_filter( 'hook', 'example_callback' ); // Where $priority is default 10, $accepted_args is default 1.
     *
     *     // Accepting two arguments (three possible).
     *     function example_callback( $value, $arg2 ) {
     *         ...
     *         return $maybe_modified_value;
     *     }
     *     add_filter( 'hook', 'example_callback', 10, 2 ); // Where $priority is 10, $accepted_args is 2.
     *
     * *Note:* The function will return true whether or not the callback is valid.
     * It is up to you to take care. This is done for optimization purposes, so
     * everything is as quick as possible.
     *
     * @since 0.71
     *
     * @global WP_Hook[] $wp_filter A multidimensional array of all hooks and the callbacks hooked to them.
     *
     * @param string   $hook_name     The name of the filter to add the callback to.
     * @param callable $callback      The callback to be run when the filter is applied.
     * @param int      $priority      Optional. Used to specify the order in which the functions
     *                                associated with a particular filter are executed.
     *                                Lower numbers correspond with earlier execution,
     *                                and functions with the same priority are executed
     *                                in the order in which they were added to the filter. Default 10.
     * @param int      $accepted_args Optional. The number of arguments the function accepts. Default 1.
     * @return true Always returns true.
     */
    function add_filter($hook_name, $callback, $priority = 10, $accepted_args = 1)
    {
    }
    /**
     * Calls the callback functions that have been added to a filter hook.
     *
     * This function invokes all functions attached to filter hook `$hook_name`.
     * It is possible to create new filter hooks by simply calling this function,
     * specifying the name of the new hook using the `$hook_name` parameter.
     *
     * The function also allows for multiple additional arguments to be passed to hooks.
     *
     * Example usage:
     *
     *     // The filter callback function.
     *     function example_callback( $string, $arg1, $arg2 ) {
     *         // (maybe) modify $string.
     *         return $string;
     *     }
     *     add_filter( 'example_filter', 'example_callback', 10, 3 );
     *
     *     /*
     *      * Apply the filters by calling the 'example_callback()' function
     *      * that's hooked onto `example_filter` above.
     *      *
     *      * - 'example_filter' is the filter hook.
     *      * - 'filter me' is the value being filtered.
     *      * - $arg1 and $arg2 are the additional arguments passed to the callback.
     *     $value = apply_filters( 'example_filter', 'filter me', $arg1, $arg2 );
     *
     * @since 0.71
     * @since 6.0.0 Formalized the existing and already documented `...$args` parameter
     *              by adding it to the function signature.
     *
     * @global WP_Hook[] $wp_filter         Stores all of the filters and actions.
     * @global int[]     $wp_filters        Stores the number of times each filter was triggered.
     * @global string[]  $wp_current_filter Stores the list of current filters with the current one last.
     *
     * @param string $hook_name The name of the filter hook.
     * @param mixed  $value     The value to filter.
     * @param mixed  ...$args   Optional. Additional parameters to pass to the callback functions.
     * @return mixed The filtered value after all hooked functions are applied to it.
     */
    function apply_filters($hook_name, $value, ...$args)
    {
    }
    /**
     * Calls the callback functions that have been added to a filter hook, specifying arguments in an array.
     *
     * @since 3.0.0
     *
     * @see apply_filters() This function is identical, but the arguments passed to the
     *                      functions hooked to `$hook_name` are supplied using an array.
     *
     * @global WP_Hook[] $wp_filter         Stores all of the filters and actions.
     * @global int[]     $wp_filters        Stores the number of times each filter was triggered.
     * @global string[]  $wp_current_filter Stores the list of current filters with the current one last.
     *
     * @param string $hook_name The name of the filter hook.
     * @param array  $args      The arguments supplied to the functions hooked to `$hook_name`.
     * @return mixed The filtered value after all hooked functions are applied to it.
     */
    function apply_filters_ref_array($hook_name, $args)
    {
    }
    /**
     * Checks if any filter has been registered for a hook.
     *
     * When using the `$callback` argument, this function may return a non-boolean value
     * that evaluates to false (e.g. 0), so use the `===` operator for testing the return value.
     *
     * @since 2.5.0
     *
     * @global WP_Hook[] $wp_filter Stores all of the filters and actions.
     *
     * @param string                      $hook_name The name of the filter hook.
     * @param callable|string|array|false $callback  Optional. The callback to check for.
     *                                               This function can be called unconditionally to speculatively check
     *                                               a callback that may or may not exist. Default false.
     * @return bool|int If `$callback` is omitted, returns boolean for whether the hook has
     *                  anything registered. When checking a specific function, the priority
     *                  of that hook is returned, or false if the function is not attached.
     * @phpstan-return ($callback is false ? bool : false|int)
     */
    function has_filter($hook_name, $callback = \false)
    {
    }
    /**
     * Removes a callback function from a filter hook.
     *
     * This can be used to remove default functions attached to a specific filter
     * hook and possibly replace them with a substitute.
     *
     * To remove a hook, the `$callback` and `$priority` arguments must match
     * when the hook was added. This goes for both filters and actions. No warning
     * will be given on removal failure.
     *
     * @since 1.2.0
     *
     * @global WP_Hook[] $wp_filter Stores all of the filters and actions.
     *
     * @param string                $hook_name The filter hook to which the function to be removed is hooked.
     * @param callable|string|array $callback  The callback to be removed from running when the filter is applied.
     *                                         This function can be called unconditionally to speculatively remove
     *                                         a callback that may or may not exist.
     * @param int                   $priority  Optional. The exact priority used when adding the original
     *                                         filter callback. Default 10.
     * @return bool Whether the function existed before it was removed.
     */
    function remove_filter($hook_name, $callback, $priority = 10)
    {
    }
    /**
     * Removes all of the callback functions from a filter hook.
     *
     * @since 2.7.0
     *
     * @global WP_Hook[] $wp_filter Stores all of the filters and actions.
     *
     * @param string    $hook_name The filter to remove callbacks from.
     * @param int|false $priority  Optional. The priority number to remove them from.
     *                             Default false.
     * @return true Always returns true.
     */
    function remove_all_filters($hook_name, $priority = \false)
    {
    }
    /**
     * Retrieves the name of the current filter hook.
     *
     * @since 2.5.0
     *
     * @global string[] $wp_current_filter Stores the list of current filters with the current one last
     *
     * @return string Hook name of the current filter.
     */
    function current_filter()
    {
    }
    /**
     * Returns whether or not a filter hook is currently being processed.
     *
     * The function current_filter() only returns the most recent filter being executed.
     * did_filter() returns the number of times a filter has been applied during
     * the current request.
     *
     * This function allows detection for any filter currently being executed
     * (regardless of whether it's the most recent filter to fire, in the case of
     * hooks called from hook callbacks) to be verified.
     *
     * @since 3.9.0
     *
     * @see current_filter()
     * @see did_filter()
     * @global string[] $wp_current_filter Current filter.
     *
     * @param string|null $hook_name Optional. Filter hook to check. Defaults to null,
     *                               which checks if any filter is currently being run.
     * @return bool Whether the filter is currently in the stack.
     */
    function doing_filter($hook_name = \null)
    {
    }
    /**
     * Retrieves the number of times a filter has been applied during the current request.
     *
     * @since 6.1.0
     *
     * @global int[] $wp_filters Stores the number of times each filter was triggered.
     *
     * @param string $hook_name The name of the filter hook.
     * @return int The number of times the filter hook has been applied.
     */
    function did_filter($hook_name)
    {
    }
    /**
     * Adds a callback function to an action hook.
     *
     * Actions are the hooks that the WordPress core launches at specific points
     * during execution, or when specific events occur. Plugins can specify that
     * one or more of its PHP functions are executed at these points, using the
     * Action API.
     *
     * @since 1.2.0
     *
     * @param string   $hook_name       The name of the action to add the callback to.
     * @param callable $callback        The callback to be run when the action is called.
     * @param int      $priority        Optional. Used to specify the order in which the functions
     *                                  associated with a particular action are executed.
     *                                  Lower numbers correspond with earlier execution,
     *                                  and functions with the same priority are executed
     *                                  in the order in which they were added to the action. Default 10.
     * @param int      $accepted_args   Optional. The number of arguments the function accepts. Default 1.
     * @return true Always returns true.
     */
    function add_action($hook_name, $callback, $priority = 10, $accepted_args = 1)
    {
    }
    /**
     * Calls the callback functions that have been added to an action hook.
     *
     * This function invokes all functions attached to action hook `$hook_name`.
     * It is possible to create new action hooks by simply calling this function,
     * specifying the name of the new hook using the `$hook_name` parameter.
     *
     * You can pass extra arguments to the hooks, much like you can with `apply_filters()`.
     *
     * Example usage:
     *
     *     // The action callback function.
     *     function example_callback( $arg1, $arg2 ) {
     *         // (maybe) do something with the args.
     *     }
     *     add_action( 'example_action', 'example_callback', 10, 2 );
     *
     *     /*
     *      * Trigger the actions by calling the 'example_callback()' function
     *      * that's hooked onto `example_action` above.
     *      *
     *      * - 'example_action' is the action hook.
     *      * - $arg1 and $arg2 are the additional arguments passed to the callback.
     *     do_action( 'example_action', $arg1, $arg2 );
     *
     * @since 1.2.0
     * @since 5.3.0 Formalized the existing and already documented `...$arg` parameter
     *              by adding it to the function signature.
     *
     * @global WP_Hook[] $wp_filter         Stores all of the filters and actions.
     * @global int[]     $wp_actions        Stores the number of times each action was triggered.
     * @global string[]  $wp_current_filter Stores the list of current filters with the current one last.
     *
     * @param string $hook_name The name of the action to be executed.
     * @param mixed  ...$arg    Optional. Additional arguments which are passed on to the
     *                          functions hooked to the action. Default empty.
     * @phpstan-return void
     */
    function do_action($hook_name, ...$arg)
    {
    }
    /**
     * Calls the callback functions that have been added to an action hook, specifying arguments in an array.
     *
     * @since 2.1.0
     *
     * @see do_action() This function is identical, but the arguments passed to the
     *                  functions hooked to `$hook_name` are supplied using an array.
     *
     * @global WP_Hook[] $wp_filter         Stores all of the filters and actions.
     * @global int[]     $wp_actions        Stores the number of times each action was triggered.
     * @global string[]  $wp_current_filter Stores the list of current filters with the current one last.
     *
     * @param string $hook_name The name of the action to be executed.
     * @param array  $args      The arguments supplied to the functions hooked to `$hook_name`.
     * @phpstan-return void
     */
    function do_action_ref_array($hook_name, $args)
    {
    }
    /**
     * Checks if any action has been registered for a hook.
     *
     * When using the `$callback` argument, this function may return a non-boolean value
     * that evaluates to false (e.g. 0), so use the `===` operator for testing the return value.
     *
     * @since 2.5.0
     *
     * @see has_filter() This function is an alias of has_filter().
     *
     * @param string                      $hook_name The name of the action hook.
     * @param callable|string|array|false $callback  Optional. The callback to check for.
     *                                               This function can be called unconditionally to speculatively check
     *                                               a callback that may or may not exist. Default false.
     * @return bool|int If `$callback` is omitted, returns boolean for whether the hook has
     *                  anything registered. When checking a specific function, the priority
     *                  of that hook is returned, or false if the function is not attached.
     * @phpstan-return ($callback is false ? bool : false|int)
     */
    function has_action($hook_name, $callback = \false)
    {
    }
    /**
     * Removes a callback function from an action hook.
     *
     * This can be used to remove default functions attached to a specific action
     * hook and possibly replace them with a substitute.
     *
     * To remove a hook, the `$callback` and `$priority` arguments must match
     * when the hook was added. This goes for both filters and actions. No warning
     * will be given on removal failure.
     *
     * @since 1.2.0
     *
     * @param string                $hook_name The action hook to which the function to be removed is hooked.
     * @param callable|string|array $callback  The name of the function which should be removed.
     *                                         This function can be called unconditionally to speculatively remove
     *                                         a callback that may or may not exist.
     * @param int                   $priority  Optional. The exact priority used when adding the original
     *                                         action callback. Default 10.
     * @return bool Whether the function is removed.
     */
    function remove_action($hook_name, $callback, $priority = 10)
    {
    }
    /**
     * Removes all of the callback functions from an action hook.
     *
     * @since 2.7.0
     *
     * @param string    $hook_name The action to remove callbacks from.
     * @param int|false $priority  Optional. The priority number to remove them from.
     *                             Default false.
     * @return true Always returns true.
     */
    function remove_all_actions($hook_name, $priority = \false)
    {
    }
    /**
     * Retrieves the name of the current action hook.
     *
     * @since 3.9.0
     *
     * @return string Hook name of the current action.
     */
    function current_action()
    {
    }
    /**
     * Returns whether or not an action hook is currently being processed.
     *
     * The function current_action() only returns the most recent action being executed.
     * did_action() returns the number of times an action has been fired during
     * the current request.
     *
     * This function allows detection for any action currently being executed
     * (regardless of whether it's the most recent action to fire, in the case of
     * hooks called from hook callbacks) to be verified.
     *
     * @since 3.9.0
     *
     * @see current_action()
     * @see did_action()
     *
     * @param string|null $hook_name Optional. Action hook to check. Defaults to null,
     *                               which checks if any action is currently being run.
     * @return bool Whether the action is currently in the stack.
     */
    function doing_action($hook_name = \null)
    {
    }
    /**
     * Retrieves the number of times an action has been fired during the current request.
     *
     * @since 2.1.0
     *
     * @global int[] $wp_actions Stores the number of times each action was triggered.
     *
     * @param string $hook_name The name of the action hook.
     * @return int The number of times the action hook has been fired.
     * @phpstan-return int<0, max>
     */
    function did_action($hook_name)
    {
    }
    /**
     * Fires functions attached to a deprecated filter hook.
     *
     * When a filter hook is deprecated, the apply_filters() call is replaced with
     * apply_filters_deprecated(), which triggers a deprecation notice and then fires
     * the original filter hook.
     *
     * Note: the value and extra arguments passed to the original apply_filters() call
     * must be passed here to `$args` as an array. For example:
     *
     *     // Old filter.
     *     return apply_filters( 'wpdocs_filter', $value, $extra_arg );
     *
     *     // Deprecated.
     *     return apply_filters_deprecated( 'wpdocs_filter', array( $value, $extra_arg ), '4.9.0', 'wpdocs_new_filter' );
     *
     * @since 4.6.0
     *
     * @see _deprecated_hook()
     *
     * @param string $hook_name   The name of the filter hook.
     * @param array  $args        Array of additional function arguments to be passed to apply_filters().
     * @param string $version     The version of WordPress that deprecated the hook.
     * @param string $replacement Optional. The hook that should have been used. Default empty.
     * @param string $message     Optional. A message regarding the change. Default empty.
     * @return mixed The filtered value after all hooked functions are applied to it.
     */
    function apply_filters_deprecated($hook_name, $args, $version, $replacement = '', $message = '')
    {
    }
    /**
     * Fires functions attached to a deprecated action hook.
     *
     * When an action hook is deprecated, the do_action() call is replaced with
     * do_action_deprecated(), which triggers a deprecation notice and then fires
     * the original hook.
     *
     * @since 4.6.0
     *
     * @see _deprecated_hook()
     *
     * @param string $hook_name   The name of the action hook.
     * @param array  $args        Array of additional function arguments to be passed to do_action().
     * @param string $version     The version of WordPress that deprecated the hook.
     * @param string $replacement Optional. The hook that should have been used. Default empty.
     * @param string $message     Optional. A message regarding the change. Default empty.
     * @phpstan-return void
     */
    function do_action_deprecated($hook_name, $args, $version, $replacement = '', $message = '')
    {
    }
    /**
     * Gets the basename of a plugin.
     *
     * This method extracts the name of a plugin from its filename.
     *
     * @since 1.5.0
     *
     * @global array $wp_plugin_paths
     *
     * @param string $file The filename of plugin.
     * @return string The name of a plugin.
     */
    function plugin_basename($file)
    {
    }
    /**
     * Register a plugin's real path.
     *
     * This is used in plugin_basename() to resolve symlinked paths.
     *
     * @since 3.9.0
     *
     * @see wp_normalize_path()
     *
     * @global array $wp_plugin_paths
     *
     * @param string $file Known path to the file.
     * @return bool Whether the path was able to be registered.
     */
    function wp_register_plugin_realpath($file)
    {
    }
    /**
     * Get the filesystem directory path (with trailing slash) for the plugin __FILE__ passed in.
     *
     * @since 2.8.0
     *
     * @param string $file The filename of the plugin (__FILE__).
     * @return string the filesystem path of the directory that contains the plugin.
     */
    function plugin_dir_path($file)
    {
    }
    /**
     * Get the URL directory path (with trailing slash) for the plugin __FILE__ passed in.
     *
     * @since 2.8.0
     *
     * @param string $file The filename of the plugin (__FILE__).
     * @return string the URL path of the directory that contains the plugin.
     */
    function plugin_dir_url($file)
    {
    }
    /**
     * Set the activation hook for a plugin.
     *
     * When a plugin is activated, the action 'activate_PLUGINNAME' hook is
     * called. In the name of this hook, PLUGINNAME is replaced with the name
     * of the plugin, including the optional subdirectory. For example, when the
     * plugin is located in wp-content/plugins/sampleplugin/sample.php, then
     * the name of this hook will become 'activate_sampleplugin/sample.php'.
     *
     * When the plugin consists of only one file and is (as by default) located at
     * wp-content/plugins/sample.php the name of this hook will be
     * 'activate_sample.php'.
     *
     * @since 2.0.0
     *
     * @param string   $file     The filename of the plugin including the path.
     * @param callable $callback The function hooked to the 'activate_PLUGIN' action.
     */
    function register_activation_hook($file, $callback)
    {
    }
    /**
     * Sets the deactivation hook for a plugin.
     *
     * When a plugin is deactivated, the action 'deactivate_PLUGINNAME' hook is
     * called. In the name of this hook, PLUGINNAME is replaced with the name
     * of the plugin, including the optional subdirectory. For example, when the
     * plugin is located in wp-content/plugins/sampleplugin/sample.php, then
     * the name of this hook will become 'deactivate_sampleplugin/sample.php'.
     *
     * When the plugin consists of only one file and is (as by default) located at
     * wp-content/plugins/sample.php the name of this hook will be
     * 'deactivate_sample.php'.
     *
     * @since 2.0.0
     *
     * @param string   $file     The filename of the plugin including the path.
     * @param callable $callback The function hooked to the 'deactivate_PLUGIN' action.
     */
    function register_deactivation_hook($file, $callback)
    {
    }
    /**
     * Sets the uninstallation hook for a plugin.
     *
     * Registers the uninstall hook that will be called when the user clicks on the
     * uninstall link that calls for the plugin to uninstall itself. The link won't
     * be active unless the plugin hooks into the action.
     *
     * The plugin should not run arbitrary code outside of functions, when
     * registering the uninstall hook. In order to run using the hook, the plugin
     * will have to be included, which means that any code laying outside of a
     * function will be run during the uninstallation process. The plugin should not
     * hinder the uninstallation process.
     *
     * If the plugin can not be written without running code within the plugin, then
     * the plugin should create a file named 'uninstall.php' in the base plugin
     * folder. This file will be called, if it exists, during the uninstallation process
     * bypassing the uninstall hook. The plugin, when using the 'uninstall.php'
     * should always check for the 'WP_UNINSTALL_PLUGIN' constant, before
     * executing.
     *
     * @since 2.7.0
     *
     * @param string   $file     Plugin file.
     * @param callable $callback The callback to run when the hook is called. Must be
     *                           a static method or function.
     * @phpstan-return void
     */
    function register_uninstall_hook($file, $callback)
    {
    }
    /**
     * Calls the 'all' hook, which will process the functions hooked into it.
     *
     * The 'all' hook passes all of the arguments or parameters that were used for
     * the hook, which this function was called for.
     *
     * This function is used internally for apply_filters(), do_action(), and
     * do_action_ref_array() and is not meant to be used from outside those
     * functions. This function does not check for the existence of the all hook, so
     * it will fail unless the all hook exists prior to this function call.
     *
     * @since 2.5.0
     * @access private
     *
     * @global WP_Hook[] $wp_filter Stores all of the filters and actions.
     *
     * @param array $args The collected parameters from the hook that was called.
     */
    function _wp_call_all_hook($args)
    {
    }
    /**
     * Builds a unique string ID for a hook callback function.
     *
     * Functions and static method callbacks are just returned as strings and
     * shouldn't have any speed penalty.
     *
     * @link https://core.trac.wordpress.org/ticket/3875
     *
     * @since 2.2.3
     * @since 5.3.0 Removed workarounds for spl_object_hash().
     *              `$hook_name` and `$priority` are no longer used,
     *              and the function always returns a string.
     *
     * @access private
     *
     * @param string                $hook_name Unused. The name of the filter to build ID for.
     * @param callable|string|array $callback  The callback to generate ID for. The callback may
     *                                         or may not exist.
     * @param int                   $priority  Unused. The order in which the functions
     *                                         associated with a particular action are executed.
     * @return string Unique function ID for usage as array key.
     */
    function _wp_filter_build_unique_id($hook_name, $callback, $priority)
    {
    }
    /**
     * Retrieve the format slug for a post
     *
     * @since 3.1.0
     *
     * @param int|WP_Post|null $post Optional. Post ID or post object. Defaults to the current post in the loop.
     * @return string|false The format if successful. False otherwise.
     */
    function get_post_format($post = \null)
    {
    }
    /**
     * Check if a post has any of the given formats, or any format.
     *
     * @since 3.1.0
     *
     * @param string|string[]  $format Optional. The format or formats to check. Default empty array.
     * @param WP_Post|int|null $post   Optional. The post to check. Defaults to the current post in the loop.
     * @return bool True if the post has any of the given formats (or any format, if no format specified),
     *              false otherwise.
     */
    function has_post_format($format = array(), $post = \null)
    {
    }
    /**
     * Assign a format to a post
     *
     * @since 3.1.0
     *
     * @param int|WP_Post $post   The post for which to assign a format.
     * @param string      $format A format to assign. Use an empty string or array to remove all formats from the post.
     * @return array|WP_Error|false Array of affected term IDs on success. WP_Error on error.
     */
    function set_post_format($post, $format)
    {
    }
    /**
     * Returns an array of post format slugs to their translated and pretty display versions
     *
     * @since 3.1.0
     *
     * @return string[] Array of post format labels keyed by format slug.
     */
    function get_post_format_strings()
    {
    }
    /**
     * Retrieves the array of post format slugs.
     *
     * @since 3.1.0
     *
     * @return string[] The array of post format slugs as both keys and values.
     */
    function get_post_format_slugs()
    {
    }
    /**
     * Returns a pretty, translated version of a post format slug
     *
     * @since 3.1.0
     *
     * @param string $slug A post format slug.
     * @return string The translated post format name.
     */
    function get_post_format_string($slug)
    {
    }
    /**
     * Returns a link to a post format index.
     *
     * @since 3.1.0
     *
     * @param string $format The post format slug.
     * @return string|WP_Error|false The post format term link.
     */
    function get_post_format_link($format)
    {
    }
    /**
     * Filters the request to allow for the format prefix.
     *
     * @access private
     * @since 3.1.0
     *
     * @param array $qvs
     * @return array
     */
    function _post_format_request($qvs)
    {
    }
    /**
     * Filters the post format term link to remove the format prefix.
     *
     * @access private
     * @since 3.1.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string  $link
     * @param WP_Term $term
     * @param string  $taxonomy
     * @return string
     */
    function _post_format_link($link, $term, $taxonomy)
    {
    }
    /**
     * Remove the post format prefix from the name property of the term object created by get_term().
     *
     * @access private
     * @since 3.1.0
     *
     * @param object $term
     * @return object
     */
    function _post_format_get_term($term)
    {
    }
    /**
     * Remove the post format prefix from the name property of the term objects created by get_terms().
     *
     * @access private
     * @since 3.1.0
     *
     * @param array        $terms
     * @param string|array $taxonomies
     * @param array        $args
     * @return array
     */
    function _post_format_get_terms($terms, $taxonomies, $args)
    {
    }
    /**
     * Remove the post format prefix from the name property of the term objects created by wp_get_object_terms().
     *
     * @access private
     * @since 3.1.0
     *
     * @param array $terms
     * @return array
     */
    function _post_format_wp_get_object_terms($terms)
    {
    }
    /**
     * Displays the ID of the current item in the WordPress Loop.
     *
     * @since 0.71
     */
    function the_ID()
    {
    }
    /**
     * Retrieves the ID of the current item in the WordPress Loop.
     *
     * @since 2.1.0
     *
     * @return int|false The ID of the current item in the WordPress Loop. False if $post is not set.
     */
    function get_the_ID()
    {
    }
    /**
     * Displays or retrieves the current post title with optional markup.
     *
     * @since 0.71
     *
     * @param string $before  Optional. Markup to prepend to the title. Default empty.
     * @param string $after   Optional. Markup to append to the title. Default empty.
     * @param bool   $display Optional. Whether to echo or return the title. Default true for echo.
     * @return void|string Void if `$display` argument is true or the title is empty,
     *                     current post title if `$display` is false.
     * @phpstan-return ($display is true ? void : string|void)
     */
    function the_title($before = '', $after = '', $display = \true)
    {
    }
    /**
     * Sanitizes the current title when retrieving or displaying.
     *
     * Works like the_title(), except the parameters can be in a string or
     * an array. See the function for what can be override in the $args parameter.
     *
     * The title before it is displayed will have the tags stripped and esc_attr()
     * before it is passed to the user or displayed. The default as with the_title(),
     * is to display the title.
     *
     * @since 2.3.0
     *
     * @param string|array $args {
     *     Title attribute arguments. Optional.
     *
     *     @type string  $before Markup to prepend to the title. Default empty.
     *     @type string  $after  Markup to append to the title. Default empty.
     *     @type bool    $echo   Whether to echo or return the title. Default true for echo.
     *     @type WP_Post $post   Current post object to retrieve the title for.
     * }
     * @return void|string Void if 'echo' argument is true, the title attribute if 'echo' is false.
     * @phpstan-param array{
     *   before?: string,
     *   after?: string,
     *   echo?: bool,
     *   post?: WP_Post,
     * } $args
     */
    function the_title_attribute($args = '')
    {
    }
    /**
     * Retrieves the post title.
     *
     * If the post is protected and the visitor is not an admin, then "Protected"
     * will be inserted before the post title. If the post is private, then
     * "Private" will be inserted before the post title.
     *
     * @since 0.71
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return string
     */
    function get_the_title($post = 0)
    {
    }
    /**
     * Displays the Post Global Unique Identifier (guid).
     *
     * The guid will appear to be a link, but should not be used as a link to the
     * post. The reason you should not use it as a link, is because of moving the
     * blog across domains.
     *
     * URL is escaped to make it XML-safe.
     *
     * @since 1.5.0
     *
     * @param int|WP_Post $post Optional. Post ID or post object. Default is global $post.
     */
    function the_guid($post = 0)
    {
    }
    /**
     * Retrieves the Post Global Unique Identifier (guid).
     *
     * The guid will appear to be a link, but should not be used as an link to the
     * post. The reason you should not use it as a link, is because of moving the
     * blog across domains.
     *
     * @since 1.5.0
     *
     * @param int|WP_Post $post Optional. Post ID or post object. Default is global $post.
     * @return string
     */
    function get_the_guid($post = 0)
    {
    }
    /**
     * Displays the post content.
     *
     * @since 0.71
     *
     * @param string $more_link_text Optional. Content for when there is more text.
     * @param bool   $strip_teaser   Optional. Strip teaser content before the more text. Default false.
     */
    function the_content($more_link_text = \null, $strip_teaser = \false)
    {
    }
    /**
     * Retrieves the post content.
     *
     * @since 0.71
     * @since 5.2.0 Added the `$post` parameter.
     *
     * @global int   $page      Page number of a single post/page.
     * @global int   $more      Boolean indicator for whether single post/page is being viewed.
     * @global bool  $preview   Whether post/page is in preview mode.
     * @global array $pages     Array of all pages in post/page. Each array element contains
     *                          part of the content separated by the `<!--nextpage-->` tag.
     * @global int   $multipage Boolean indicator for whether multiple pages are in play.
     *
     * @param string             $more_link_text Optional. Content for when there is more text.
     * @param bool               $strip_teaser   Optional. Strip teaser content before the more text. Default false.
     * @param WP_Post|object|int $post           Optional. WP_Post instance or Post ID/object. Default null.
     * @return string
     */
    function get_the_content($more_link_text = \null, $strip_teaser = \false, $post = \null)
    {
    }
    /**
     * Displays the post excerpt.
     *
     * @since 0.71
     */
    function the_excerpt()
    {
    }
    /**
     * Retrieves the post excerpt.
     *
     * @since 0.71
     * @since 4.5.0 Introduced the `$post` parameter.
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return string Post excerpt.
     */
    function get_the_excerpt($post = \null)
    {
    }
    /**
     * Determines whether the post has a custom excerpt.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.3.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return bool True if the post has a custom excerpt, false otherwise.
     */
    function has_excerpt($post = 0)
    {
    }
    /**
     * Displays the classes for the post container element.
     *
     * @since 2.7.0
     *
     * @param string|string[] $css_class Optional. One or more classes to add to the class list.
     *                                   Default empty.
     * @param int|WP_Post     $post      Optional. Post ID or post object. Defaults to the global `$post`.
     */
    function post_class($css_class = '', $post = \null)
    {
    }
    /**
     * Retrieves an array of the class names for the post container element.
     *
     * The class names are many:
     *
     *  - If the post has a post thumbnail, `has-post-thumbnail` is added as a class.
     *  - If the post is sticky, then the `sticky` class name is added.
     *  - The class `hentry` is always added to each post.
     *  - For each taxonomy that the post belongs to, a class will be added of the format
     *    `{$taxonomy}-{$slug}`, e.g. `category-foo` or `my_custom_taxonomy-bar`.
     *    The `post_tag` taxonomy is a special case; the class has the `tag-` prefix
     *    instead of `post_tag-`.
     *
     * All class names are passed through the filter, {@see 'post_class'}, followed by
     * `$css_class` parameter value, with the post ID as the last parameter.
     *
     * @since 2.7.0
     * @since 4.2.0 Custom taxonomy class names were added.
     *
     * @param string|string[] $css_class Optional. Space-separated string or array of class names
     *                                   to add to the class list. Default empty.
     * @param int|WP_Post     $post      Optional. Post ID or post object.
     * @return string[] Array of class names.
     */
    function get_post_class($css_class = '', $post = \null)
    {
    }
    /**
     * Displays the class names for the body element.
     *
     * @since 2.8.0
     *
     * @param string|string[] $css_class Optional. Space-separated string or array of class names
     *                                   to add to the class list. Default empty.
     */
    function body_class($css_class = '')
    {
    }
    /**
     * Retrieves an array of the class names for the body element.
     *
     * @since 2.8.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string|string[] $css_class Optional. Space-separated string or array of class names
     *                                   to add to the class list. Default empty.
     * @return string[] Array of class names.
     */
    function get_body_class($css_class = '')
    {
    }
    /**
     * Determines whether the post requires password and whether a correct password has been provided.
     *
     * @since 2.7.0
     *
     * @param int|WP_Post|null $post An optional post. Global $post used if not provided.
     * @return bool false if a password is not required or the correct password cookie is present, true otherwise.
     */
    function post_password_required($post = \null)
    {
    }
    /**
     * The formatted output of a list of pages.
     *
     * Displays page links for paginated posts (i.e. including the `<!--nextpage-->`
     * Quicktag one or more times). This tag must be within The Loop.
     *
     * @since 1.2.0
     * @since 5.1.0 Added the `aria_current` argument.
     *
     * @global int $page
     * @global int $numpages
     * @global int $multipage
     * @global int $more
     *
     * @param string|array $args {
     *     Optional. Array or string of default arguments.
     *
     *     @type string       $before           HTML or text to prepend to each link. Default is `<p> Pages:`.
     *     @type string       $after            HTML or text to append to each link. Default is `</p>`.
     *     @type string       $link_before      HTML or text to prepend to each link, inside the `<a>` tag.
     *                                          Also prepended to the current item, which is not linked. Default empty.
     *     @type string       $link_after       HTML or text to append to each Pages link inside the `<a>` tag.
     *                                          Also appended to the current item, which is not linked. Default empty.
     *     @type string       $aria_current     The value for the aria-current attribute. Possible values are 'page',
     *                                          'step', 'location', 'date', 'time', 'true', 'false'. Default is 'page'.
     *     @type string       $next_or_number   Indicates whether page numbers should be used. Valid values are number
     *                                          and next. Default is 'number'.
     *     @type string       $separator        Text between pagination links. Default is ' '.
     *     @type string       $nextpagelink     Link text for the next page link, if available. Default is 'Next Page'.
     *     @type string       $previouspagelink Link text for the previous page link, if available. Default is 'Previous Page'.
     *     @type string       $pagelink         Format string for page numbers. The % in the parameter string will be
     *                                          replaced with the page number, so 'Page %' generates "Page 1", "Page 2", etc.
     *                                          Defaults to '%', just the page number.
     *     @type int|bool     $echo             Whether to echo or not. Accepts 1|true or 0|false. Default 1|true.
     * }
     * @return string Formatted output in HTML.
     * @phpstan-param array{
     *   before?: string,
     *   after?: string,
     *   link_before?: string,
     *   link_after?: string,
     *   aria_current?: string,
     *   next_or_number?: string,
     *   separator?: string,
     *   nextpagelink?: string,
     *   previouspagelink?: string,
     *   pagelink?: string,
     *   echo?: int|bool,
     * } $args
     */
    function wp_link_pages($args = '')
    {
    }
    /**
     * Helper function for wp_link_pages().
     *
     * @since 3.1.0
     * @access private
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param int $i Page number.
     * @return string Link.
     */
    function _wp_link_page($i)
    {
    }
    /**
     * Retrieves post custom meta data field.
     *
     * @since 1.5.0
     *
     * @param string $key Meta data key name.
     * @return array|string|false Array of values, or single value if only one element exists.
     *                            False if the key does not exist.
     */
    function post_custom($key = '')
    {
    }
    /**
     * Displays a list of post custom fields.
     *
     * @since 1.2.0
     *
     * @deprecated 6.0.2 Use get_post_meta() to retrieve post meta and render manually.
     */
    function the_meta()
    {
    }
    /**
     * Retrieves or displays a list of pages as a dropdown (select list).
     *
     * @since 2.1.0
     * @since 4.2.0 The `$value_field` argument was added.
     * @since 4.3.0 The `$class` argument was added.
     *
     * @see get_pages()
     *
     * @param array|string $args {
     *     Optional. Array or string of arguments to generate a page dropdown. See get_pages() for additional arguments.
     *
     *     @type int          $depth                 Maximum depth. Default 0.
     *     @type int          $child_of              Page ID to retrieve child pages of. Default 0.
     *     @type int|string   $selected              Value of the option that should be selected. Default 0.
     *     @type bool|int     $echo                  Whether to echo or return the generated markup. Accepts 0, 1,
     *                                               or their bool equivalents. Default 1.
     *     @type string       $name                  Value for the 'name' attribute of the select element.
     *                                               Default 'page_id'.
     *     @type string       $id                    Value for the 'id' attribute of the select element.
     *     @type string       $class                 Value for the 'class' attribute of the select element. Default: none.
     *                                               Defaults to the value of `$name`.
     *     @type string       $show_option_none      Text to display for showing no pages. Default empty (does not display).
     *     @type string       $show_option_no_change Text to display for "no change" option. Default empty (does not display).
     *     @type string       $option_none_value     Value to use when no page is selected. Default empty.
     *     @type string       $value_field           Post field used to populate the 'value' attribute of the option
     *                                               elements. Accepts any valid post field. Default 'ID'.
     * }
     * @return string HTML dropdown list of pages.
     * @phpstan-param array{
     *   depth?: int,
     *   child_of?: int,
     *   selected?: int|string,
     *   echo?: bool|int,
     *   name?: string,
     *   id?: string,
     *   class?: string,
     *   show_option_none?: string,
     *   show_option_no_change?: string,
     *   option_none_value?: string,
     *   value_field?: string,
     *   child_of?: int,
     *   sort_order?: string,
     *   sort_column?: string,
     *   hierarchical?: bool,
     *   exclude?: int[],
     *   include?: int[],
     *   meta_key?: string,
     *   meta_value?: string,
     *   authors?: string,
     *   parent?: int,
     *   exclude_tree?: string|int[],
     *   number?: int,
     *   offset?: int,
     *   post_type?: string,
     *   post_status?: string|array,
     * } $args
     */
    function wp_dropdown_pages($args = '')
    {
    }
    /**
     * Retrieves or displays a list of pages (or hierarchical post type items) in list (li) format.
     *
     * @since 1.5.0
     * @since 4.7.0 Added the `item_spacing` argument.
     *
     * @see get_pages()
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param array|string $args {
     *     Optional. Array or string of arguments to generate a list of pages. See get_pages() for additional arguments.
     *
     *     @type int          $child_of     Display only the sub-pages of a single page by ID. Default 0 (all pages).
     *     @type string       $authors      Comma-separated list of author IDs. Default empty (all authors).
     *     @type string       $date_format  PHP date format to use for the listed pages. Relies on the 'show_date' parameter.
     *                                      Default is the value of 'date_format' option.
     *     @type int          $depth        Number of levels in the hierarchy of pages to include in the generated list.
     *                                      Accepts -1 (any depth), 0 (all pages), 1 (top-level pages only), and n (pages to
     *                                      the given n depth). Default 0.
     *     @type bool         $echo         Whether or not to echo the list of pages. Default true.
     *     @type string       $exclude      Comma-separated list of page IDs to exclude. Default empty.
     *     @type array        $include      Comma-separated list of page IDs to include. Default empty.
     *     @type string       $link_after   Text or HTML to follow the page link label. Default null.
     *     @type string       $link_before  Text or HTML to precede the page link label. Default null.
     *     @type string       $post_type    Post type to query for. Default 'page'.
     *     @type string|array $post_status  Comma-separated list or array of post statuses to include. Default 'publish'.
     *     @type string       $show_date    Whether to display the page publish or modified date for each page. Accepts
     *                                      'modified' or any other value. An empty value hides the date. Default empty.
     *     @type string       $sort_column  Comma-separated list of column names to sort the pages by. Accepts 'post_author',
     *                                      'post_date', 'post_title', 'post_name', 'post_modified', 'post_modified_gmt',
     *                                      'menu_order', 'post_parent', 'ID', 'rand', or 'comment_count'. Default 'post_title'.
     *     @type string       $title_li     List heading. Passing a null or empty value will result in no heading, and the list
     *                                      will not be wrapped with unordered list `<ul>` tags. Default 'Pages'.
     *     @type string       $item_spacing Whether to preserve whitespace within the menu's HTML. Accepts 'preserve' or 'discard'.
     *                                      Default 'preserve'.
     *     @type Walker       $walker       Walker instance to use for listing pages. Default empty which results in a
     *                                      Walker_Page instance being used.
     * }
     * @return void|string Void if 'echo' argument is true, HTML list of pages if 'echo' is false.
     * @phpstan-param array{
     *   child_of?: int,
     *   authors?: string,
     *   date_format?: string,
     *   depth?: int,
     *   echo?: bool,
     *   exclude?: string,
     *   include?: array,
     *   link_after?: string,
     *   link_before?: string,
     *   post_type?: string,
     *   post_status?: string|array,
     *   show_date?: string,
     *   sort_column?: string,
     *   title_li?: string,
     *   item_spacing?: string,
     *   walker?: Walker,
     *   child_of?: int,
     *   sort_order?: string,
     *   sort_column?: string,
     *   hierarchical?: bool,
     *   exclude?: int[],
     *   include?: int[],
     *   meta_key?: string,
     *   meta_value?: string,
     *   authors?: string,
     *   parent?: int,
     *   exclude_tree?: string|int[],
     *   number?: int,
     *   offset?: int,
     *   post_type?: string,
     *   post_status?: string|array,
     * } $args
     * @phpstan-return ($args is array{echo: false}&array ? string : void)
     */
    function wp_list_pages($args = '')
    {
    }
    /**
     * Displays or retrieves a list of pages with an optional home link.
     *
     * The arguments are listed below and part of the arguments are for wp_list_pages() function.
     * Check that function for more info on those arguments.
     *
     * @since 2.7.0
     * @since 4.4.0 Added `menu_id`, `container`, `before`, `after`, and `walker` arguments.
     * @since 4.7.0 Added the `item_spacing` argument.
     *
     * @param array|string $args {
     *     Optional. Array or string of arguments to generate a page menu. See wp_list_pages() for additional arguments.
     *
     *     @type string          $sort_column  How to sort the list of pages. Accepts post column names.
     *                                         Default 'menu_order, post_title'.
     *     @type string          $menu_id      ID for the div containing the page list. Default is empty string.
     *     @type string          $menu_class   Class to use for the element containing the page list. Default 'menu'.
     *     @type string          $container    Element to use for the element containing the page list. Default 'div'.
     *     @type bool            $echo         Whether to echo the list or return it. Accepts true (echo) or false (return).
     *                                         Default true.
     *     @type int|bool|string $show_home    Whether to display the link to the home page. Can just enter the text
     *                                         you'd like shown for the home link. 1|true defaults to 'Home'.
     *     @type string          $link_before  The HTML or text to prepend to $show_home text. Default empty.
     *     @type string          $link_after   The HTML or text to append to $show_home text. Default empty.
     *     @type string          $before       The HTML or text to prepend to the menu. Default is '<ul>'.
     *     @type string          $after        The HTML or text to append to the menu. Default is '</ul>'.
     *     @type string          $item_spacing Whether to preserve whitespace within the menu's HTML. Accepts 'preserve'
     *                                         or 'discard'. Default 'discard'.
     *     @type Walker          $walker       Walker instance to use for listing pages. Default empty which results in a
     *                                         Walker_Page instance being used.
     * }
     * @return void|string Void if 'echo' argument is true, HTML menu if 'echo' is false.
     * @phpstan-param array{
     *   sort_column?: string,
     *   menu_id?: string,
     *   menu_class?: string,
     *   container?: string,
     *   echo?: bool,
     *   show_home?: int|bool|string,
     *   link_before?: string,
     *   link_after?: string,
     *   before?: string,
     *   after?: string,
     *   item_spacing?: string,
     *   walker?: Walker,
     *   child_of?: int,
     *   authors?: string,
     *   date_format?: string,
     *   depth?: int,
     *   echo?: bool,
     *   exclude?: string,
     *   include?: array,
     *   link_after?: string,
     *   link_before?: string,
     *   post_type?: string,
     *   post_status?: string|array,
     *   show_date?: string,
     *   sort_column?: string,
     *   title_li?: string,
     *   item_spacing?: string,
     *   walker?: Walker,
     *   child_of?: int,
     *   sort_order?: string,
     *   sort_column?: string,
     *   hierarchical?: bool,
     *   exclude?: int[],
     *   include?: int[],
     *   meta_key?: string,
     *   meta_value?: string,
     *   authors?: string,
     *   parent?: int,
     *   exclude_tree?: string|int[],
     *   number?: int,
     *   offset?: int,
     *   post_type?: string,
     *   post_status?: string|array,
     * } $args
     */
    function wp_page_menu($args = array())
    {
    }
    /**
     * Retrieves HTML list content for page list.
     *
     * @uses Walker_Page to create HTML list content.
     * @since 2.1.0
     *
     * @param array $pages
     * @param int   $depth
     * @param int   $current_page
     * @param array $args
     * @return string
     */
    function walk_page_tree($pages, $depth, $current_page, $args)
    {
    }
    /**
     * Retrieves HTML dropdown (select) content for page list.
     *
     * @since 2.1.0
     * @since 5.3.0 Formalized the existing `...$args` parameter by adding it
     *              to the function signature.
     *
     * @uses Walker_PageDropdown to create HTML dropdown content.
     * @see Walker_PageDropdown::walk() for parameters and return description.
     *
     * @param mixed ...$args Elements array, maximum hierarchical depth and optional additional arguments.
     * @return string
     */
    function walk_page_dropdown_tree(...$args)
    {
    }
    /**
     * Displays an attachment page link using an image or icon.
     *
     * @since 2.0.0
     *
     * @param int|WP_Post $post       Optional. Post ID or post object.
     * @param bool        $fullsize   Optional. Whether to use full size. Default false.
     * @param bool        $deprecated Deprecated. Not used.
     * @param bool        $permalink Optional. Whether to include permalink. Default false.
     */
    function the_attachment_link($post = 0, $fullsize = \false, $deprecated = \false, $permalink = \false)
    {
    }
    /**
     * Retrieves an attachment page link using an image or icon, if possible.
     *
     * @since 2.5.0
     * @since 4.4.0 The `$post` parameter can now accept either a post ID or `WP_Post` object.
     *
     * @param int|WP_Post  $post      Optional. Post ID or post object.
     * @param string|int[] $size      Optional. Image size. Accepts any registered image size name, or an array
     *                                of width and height values in pixels (in that order). Default 'thumbnail'.
     * @param bool         $permalink Optional. Whether to add permalink to image. Default false.
     * @param bool         $icon      Optional. Whether the attachment is an icon. Default false.
     * @param string|false $text      Optional. Link text to use. Activated by passing a string, false otherwise.
     *                                Default false.
     * @param array|string $attr      Optional. Array or string of attributes. Default empty.
     * @return string HTML content.
     */
    function wp_get_attachment_link($post = 0, $size = 'thumbnail', $permalink = \false, $icon = \false, $text = \false, $attr = '')
    {
    }
    /**
     * Wraps attachment in paragraph tag before content.
     *
     * @since 2.0.0
     *
     * @param string $content
     * @return string
     */
    function prepend_attachment($content)
    {
    }
    /**
     * Retrieves protected post password form content.
     *
     * @since 1.0.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return string HTML content for password form for password protected post.
     */
    function get_the_password_form($post = 0)
    {
    }
    /**
     * Determines whether the current post uses a page template.
     *
     * This template tag allows you to determine if you are in a page template.
     * You can optionally provide a template filename or array of template filenames
     * and then the check will be specific to that template.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.5.0
     * @since 4.2.0 The `$template` parameter was changed to also accept an array of page templates.
     * @since 4.7.0 Now works with any post type, not just pages.
     *
     * @param string|string[] $template The specific template filename or array of templates to match.
     * @return bool True on success, false on failure.
     */
    function is_page_template($template = '')
    {
    }
    /**
     * Gets the specific template filename for a given post.
     *
     * @since 3.4.0
     * @since 4.7.0 Now works with any post type, not just pages.
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return string|false Page template filename. Returns an empty string when the default page template
     *                      is in use. Returns false if the post does not exist.
     */
    function get_page_template_slug($post = \null)
    {
    }
    /**
     * Retrieves formatted date timestamp of a revision (linked to that revisions's page).
     *
     * @since 2.6.0
     *
     * @param int|WP_Post $revision Revision ID or revision object.
     * @param bool        $link     Optional. Whether to link to revision's page. Default true.
     * @return string|false i18n formatted datetimestamp or localized 'Current Revision'.
     */
    function wp_post_revision_title($revision, $link = \true)
    {
    }
    /**
     * Retrieves formatted date timestamp of a revision (linked to that revisions's page).
     *
     * @since 3.6.0
     *
     * @param int|WP_Post $revision Revision ID or revision object.
     * @param bool        $link     Optional. Whether to link to revision's page. Default true.
     * @return string|false gravatar, user, i18n formatted datetimestamp or localized 'Current Revision'.
     */
    function wp_post_revision_title_expanded($revision, $link = \true)
    {
    }
    /**
     * Displays a list of a post's revisions.
     *
     * Can output either a UL with edit links or a TABLE with diff interface, and
     * restore action links.
     *
     * @since 2.6.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @param string      $type 'all' (default), 'revision' or 'autosave'
     * @phpstan-return void
     */
    function wp_list_post_revisions($post = 0, $type = 'all')
    {
    }
    /**
     * Retrieves the parent post object for the given post.
     *
     * @since 5.7.0
     *
     * @param int|WP_Post|null $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return WP_Post|null Parent post object, or null if there isn't one.
     */
    function get_post_parent($post = \null)
    {
    }
    /**
     * Returns whether the given post has a parent post.
     *
     * @since 5.7.0
     *
     * @param int|WP_Post|null $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return bool Whether the post has a parent post.
     */
    function has_post_parent($post = \null)
    {
    }
    /**
     * Determines whether a post has an image attached.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.9.0
     * @since 4.4.0 `$post` can be a post ID or WP_Post object.
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global `$post`.
     * @return bool Whether the post has an image attached.
     */
    function has_post_thumbnail($post = \null)
    {
    }
    /**
     * Retrieves the post thumbnail ID.
     *
     * @since 2.9.0
     * @since 4.4.0 `$post` can be a post ID or WP_Post object.
     * @since 5.5.0 The return value for a non-existing post
     *              was changed to false instead of an empty string.
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global `$post`.
     * @return int|false Post thumbnail ID (which can be 0 if the thumbnail is not set),
     *                   or false if the post does not exist.
     */
    function get_post_thumbnail_id($post = \null)
    {
    }
    /**
     * Displays the post thumbnail.
     *
     * When a theme adds 'post-thumbnail' support, a special 'post-thumbnail' image size
     * is registered, which differs from the 'thumbnail' image size managed via the
     * Settings > Media screen.
     *
     * When using the_post_thumbnail() or related functions, the 'post-thumbnail' image
     * size is used by default, though a different size can be specified instead as needed.
     *
     * @since 2.9.0
     *
     * @see get_the_post_thumbnail()
     *
     * @param string|int[] $size Optional. Image size. Accepts any registered image size name, or an array of
     *                           width and height values in pixels (in that order). Default 'post-thumbnail'.
     * @param string|array $attr Optional. Query string or array of attributes. Default empty.
     */
    function the_post_thumbnail($size = 'post-thumbnail', $attr = '')
    {
    }
    /**
     * Updates cache for thumbnails in the current loop.
     *
     * @since 3.2.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param WP_Query $wp_query Optional. A WP_Query instance. Defaults to the $wp_query global.
     * @phpstan-return void
     */
    function update_post_thumbnail_cache($wp_query = \null)
    {
    }
    /**
     * Retrieves the post thumbnail.
     *
     * When a theme adds 'post-thumbnail' support, a special 'post-thumbnail' image size
     * is registered, which differs from the 'thumbnail' image size managed via the
     * Settings > Media screen.
     *
     * When using the_post_thumbnail() or related functions, the 'post-thumbnail' image
     * size is used by default, though a different size can be specified instead as needed.
     *
     * @since 2.9.0
     * @since 4.4.0 `$post` can be a post ID or WP_Post object.
     *
     * @param int|WP_Post  $post Optional. Post ID or WP_Post object.  Default is global `$post`.
     * @param string|int[] $size Optional. Image size. Accepts any registered image size name, or an array of
     *                           width and height values in pixels (in that order). Default 'post-thumbnail'.
     * @param string|array $attr Optional. Query string or array of attributes. Default empty.
     * @return string The post thumbnail image tag.
     */
    function get_the_post_thumbnail($post = \null, $size = 'post-thumbnail', $attr = '')
    {
    }
    /**
     * Returns the post thumbnail URL.
     *
     * @since 4.4.0
     *
     * @param int|WP_Post  $post Optional. Post ID or WP_Post object.  Default is global `$post`.
     * @param string|int[] $size Optional. Registered image size to retrieve the source for or a flat array
     *                           of height and width dimensions. Default 'post-thumbnail'.
     * @return string|false Post thumbnail URL or false if no image is available. If `$size` does not match
     *                      any registered image size, the original image URL will be returned.
     */
    function get_the_post_thumbnail_url($post = \null, $size = 'post-thumbnail')
    {
    }
    /**
     * Displays the post thumbnail URL.
     *
     * @since 4.4.0
     *
     * @param string|int[] $size Optional. Image size to use. Accepts any valid image size,
     *                           or an array of width and height values in pixels (in that order).
     *                           Default 'post-thumbnail'.
     */
    function the_post_thumbnail_url($size = 'post-thumbnail')
    {
    }
    /**
     * Returns the post thumbnail caption.
     *
     * @since 4.6.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global `$post`.
     * @return string Post thumbnail caption.
     */
    function get_the_post_thumbnail_caption($post = \null)
    {
    }
    /**
     * Displays the post thumbnail caption.
     *
     * @since 4.6.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global `$post`.
     */
    function the_post_thumbnail_caption($post = \null)
    {
    }
    /**
     * Creates the initial post types when 'init' action is fired.
     *
     * See {@see 'init'}.
     *
     * @since 2.9.0
     */
    function create_initial_post_types()
    {
    }
    /**
     * Retrieves attached file path based on attachment ID.
     *
     * By default the path will go through the {@see 'get_attached_file'} filter, but
     * passing `true` to the `$unfiltered` argument will return the file path unfiltered.
     *
     * The function works by retrieving the `_wp_attached_file` post meta value.
     * This is a convenience function to prevent looking up the meta name and provide
     * a mechanism for sending the attached filename through a filter.
     *
     * @since 2.0.0
     *
     * @param int  $attachment_id Attachment ID.
     * @param bool $unfiltered    Optional. Whether to skip the {@see 'get_attached_file'} filter.
     *                            Default false.
     * @return string|false The file path to where the attached file should be, false otherwise.
     */
    function get_attached_file($attachment_id, $unfiltered = \false)
    {
    }
    /**
     * Updates attachment file path based on attachment ID.
     *
     * Used to update the file path of the attachment, which uses post meta name
     * '_wp_attached_file' to store the path of the attachment.
     *
     * @since 2.1.0
     *
     * @param int    $attachment_id Attachment ID.
     * @param string $file          File path for the attachment.
     * @return bool True on success, false on failure.
     */
    function update_attached_file($attachment_id, $file)
    {
    }
    /**
     * Returns relative path to an uploaded file.
     *
     * The path is relative to the current upload dir.
     *
     * @since 2.9.0
     * @access private
     *
     * @param string $path Full path to the file.
     * @return string Relative path on success, unchanged path on failure.
     */
    function _wp_relative_upload_path($path)
    {
    }
    /**
     * Retrieves all children of the post parent ID.
     *
     * Normally, without any enhancements, the children would apply to pages. In the
     * context of the inner workings of WordPress, pages, posts, and attachments
     * share the same table, so therefore the functionality could apply to any one
     * of them. It is then noted that while this function does not work on posts, it
     * does not mean that it won't work on posts. It is recommended that you know
     * what context you wish to retrieve the children of.
     *
     * Attachments may also be made the child of a post, so if that is an accurate
     * statement (which needs to be verified), it would then be possible to get
     * all of the attachments for a post. Attachments have since changed since
     * version 2.5, so this is most likely inaccurate, but serves generally as an
     * example of what is possible.
     *
     * The arguments listed as defaults are for this function and also of the
     * get_posts() function. The arguments are combined with the get_children defaults
     * and are then passed to the get_posts() function, which accepts additional arguments.
     * You can replace the defaults in this function, listed below and the additional
     * arguments listed in the get_posts() function.
     *
     * The 'post_parent' is the most important argument and important attention
     * needs to be paid to the $args parameter. If you pass either an object or an
     * integer (number), then just the 'post_parent' is grabbed and everything else
     * is lost. If you don't specify any arguments, then it is assumed that you are
     * in The Loop and the post parent will be grabbed for from the current post.
     *
     * The 'post_parent' argument is the ID to get the children. The 'numberposts'
     * is the amount of posts to retrieve that has a default of '-1', which is
     * used to get all of the posts. Giving a number higher than 0 will only
     * retrieve that amount of posts.
     *
     * The 'post_type' and 'post_status' arguments can be used to choose what
     * criteria of posts to retrieve. The 'post_type' can be anything, but WordPress
     * post types are 'post', 'pages', and 'attachments'. The 'post_status'
     * argument will accept any post status within the write administration panels.
     *
     * @since 2.0.0
     *
     * @see get_posts()
     * @todo Check validity of description.
     *
     * @global WP_Post $post Global post object.
     *
     * @param mixed  $args   Optional. User defined arguments for replacing the defaults. Default empty.
     * @param string $output Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
     *                       correspond to a WP_Post object, an associative array, or a numeric array,
     *                       respectively. Default OBJECT.
     * @return WP_Post[]|array[]|int[] Array of post objects, arrays, or IDs, depending on `$output`.
     */
    function get_children($args = '', $output = \OBJECT)
    {
    }
    /**
     * Gets extended entry info (<!--more-->).
     *
     * There should not be any space after the second dash and before the word
     * 'more'. There can be text or space(s) after the word 'more', but won't be
     * referenced.
     *
     * The returned array has 'main', 'extended', and 'more_text' keys. Main has the text before
     * the `<!--more-->`. The 'extended' key has the content after the
     * `<!--more-->` comment. The 'more_text' key has the custom "Read More" text.
     *
     * @since 1.0.0
     *
     * @param string $post Post content.
     * @return string[] {
     *     Extended entry info.
     *
     *     @type string $main      Content before the more tag.
     *     @type string $extended  Content after the more tag.
     *     @type string $more_text Custom read more text, or empty string.
     * }
     * @phpstan-return array{
     *   main: string,
     *   extended: string,
     *   more_text: string,
     * }
     */
    function get_extended($post)
    {
    }
    /**
     * Retrieves post data given a post ID or post object.
     *
     * See sanitize_post() for optional $filter values. Also, the parameter
     * `$post`, must be given as a variable, since it is passed by reference.
     *
     * @since 1.5.1
     *
     * @global WP_Post $post Global post object.
     *
     * @param int|WP_Post|null $post   Optional. Post ID or post object. `null`, `false`, `0` and other PHP falsey values
     *                                 return the current global post inside the loop. A numerically valid post ID that
     *                                 points to a non-existent post returns `null`. Defaults to global $post.
     * @param string           $output Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
     *                                 correspond to a WP_Post object, an associative array, or a numeric array,
     *                                 respectively. Default OBJECT.
     * @param string           $filter Optional. Type of filter to apply. Accepts 'raw', 'edit', 'db',
     *                                 or 'display'. Default 'raw'.
     * @return WP_Post|array|null Type corresponding to $output on success or null on failure.
     *                            When $output is OBJECT, a `WP_Post` instance is returned.
     * @phpstan-param 'raw'|'edit'|'db'|'display' $filter
     * @phpstan-param 'OBJECT'|'ARRAY_A'|'ARRAY_N' $output
     * @phpstan-return ($post is \WP_Post ? array<array-key, mixed>|\WP_Post : array<array-key, mixed>|\WP_Post|null) & ($output is 'ARRAY_A' ? array<string, mixed>|null : ($output is 'ARRAY_N' ? array<int, mixed>|null : \WP_Post|null))
     */
    function get_post($post = \null, $output = \OBJECT, $filter = 'raw')
    {
    }
    /**
     * Retrieves the IDs of the ancestors of a post.
     *
     * @since 2.5.0
     *
     * @param int|WP_Post $post Post ID or post object.
     * @return int[] Array of ancestor IDs or empty array if there are none.
     */
    function get_post_ancestors($post)
    {
    }
    /**
     * Retrieves data from a post field based on Post ID.
     *
     * Examples of the post field will be, 'post_type', 'post_status', 'post_content',
     * etc and based off of the post object property or key names.
     *
     * The context values are based off of the taxonomy filter functions and
     * supported values are found within those functions.
     *
     * @since 2.3.0
     * @since 4.5.0 The `$post` parameter was made optional.
     *
     * @see sanitize_post_field()
     *
     * @param string      $field   Post field name.
     * @param int|WP_Post $post    Optional. Post ID or post object. Defaults to global $post.
     * @param string      $context Optional. How to filter the field. Accepts 'raw', 'edit', 'db',
     *                             or 'display'. Default 'display'.
     * @return string The value of the post field on success, empty string on failure.
     * @phpstan-param 'raw'|'edit'|'db'|'display' $context
     */
    function get_post_field($field, $post = \null, $context = 'display')
    {
    }
    /**
     * Retrieves the mime type of an attachment based on the ID.
     *
     * This function can be used with any post type, but it makes more sense with
     * attachments.
     *
     * @since 2.0.0
     *
     * @param int|WP_Post $post Optional. Post ID or post object. Defaults to global $post.
     * @return string|false The mime type on success, false on failure.
     */
    function get_post_mime_type($post = \null)
    {
    }
    /**
     * Retrieves the post status based on the post ID.
     *
     * If the post ID is of an attachment, then the parent post status will be given
     * instead.
     *
     * @since 2.0.0
     *
     * @param int|WP_Post $post Optional. Post ID or post object. Defaults to global $post.
     * @return string|false Post status on success, false on failure.
     */
    function get_post_status($post = \null)
    {
    }
    /**
     * Retrieves all of the WordPress supported post statuses.
     *
     * Posts have a limited set of valid status values, this provides the
     * post_status values and descriptions.
     *
     * @since 2.5.0
     *
     * @return string[] Array of post status labels keyed by their status.
     */
    function get_post_statuses()
    {
    }
    /**
     * Retrieves all of the WordPress support page statuses.
     *
     * Pages have a limited set of valid status values, this provides the
     * post_status values and descriptions.
     *
     * @since 2.5.0
     *
     * @return string[] Array of page status labels keyed by their status.
     */
    function get_page_statuses()
    {
    }
    /**
     * Returns statuses for privacy requests.
     *
     * @since 4.9.6
     * @access private
     *
     * @return string[] Array of privacy request status labels keyed by their status.
     */
    function _wp_privacy_statuses()
    {
    }
    /**
     * Registers a post status. Do not use before init.
     *
     * A simple function for creating or modifying a post status based on the
     * parameters given. The function will accept an array (second optional
     * parameter), along with a string for the post status name.
     *
     * Arguments prefixed with an _underscore shouldn't be used by plugins and themes.
     *
     * @since 3.0.0
     *
     * @global stdClass[] $wp_post_statuses Inserts new post status object into the list
     *
     * @param string       $post_status Name of the post status.
     * @param array|string $args {
     *     Optional. Array or string of post status arguments.
     *
     *     @type bool|string $label                     A descriptive name for the post status marked
     *                                                  for translation. Defaults to value of $post_status.
     *     @type array|false $label_count               Nooped plural text from _n_noop() to provide the singular
     *                                                  and plural forms of the label for counts. Default false
     *                                                  which means the `$label` argument will be used for both
     *                                                  the singular and plural forms of this label.
     *     @type bool        $exclude_from_search       Whether to exclude posts with this post status
     *                                                  from search results. Default is value of $internal.
     *     @type bool        $_builtin                  Whether the status is built-in. Core-use only.
     *                                                  Default false.
     *     @type bool        $public                    Whether posts of this status should be shown
     *                                                  in the front end of the site. Default false.
     *     @type bool        $internal                  Whether the status is for internal use only.
     *                                                  Default false.
     *     @type bool        $protected                 Whether posts with this status should be protected.
     *                                                  Default false.
     *     @type bool        $private                   Whether posts with this status should be private.
     *                                                  Default false.
     *     @type bool        $publicly_queryable        Whether posts with this status should be publicly-
     *                                                  queryable. Default is value of $public.
     *     @type bool        $show_in_admin_all_list    Whether to include posts in the edit listing for
     *                                                  their post type. Default is the opposite value
     *                                                  of $internal.
     *     @type bool        $show_in_admin_status_list Show in the list of statuses with post counts at
     *                                                  the top of the edit listings,
     *                                                  e.g. All (12) | Published (9) | My Custom Status (2)
     *                                                  Default is the opposite value of $internal.
     *     @type bool        $date_floating             Whether the post has a floating creation date.
     *                                                  Default to false.
     * }
     * @return object
     * @phpstan-param array{
     *   label?: bool|string,
     *   label_count?: array|false,
     *   exclude_from_search?: bool,
     *   _builtin?: bool,
     *   public?: bool,
     *   internal?: bool,
     *   protected?: bool,
     *   private?: bool,
     *   publicly_queryable?: bool,
     *   show_in_admin_all_list?: bool,
     *   show_in_admin_status_list?: bool,
     *   date_floating?: bool,
     * } $args
     */
    function register_post_status($post_status, $args = array())
    {
    }
    /**
     * Retrieves a post status object by name.
     *
     * @since 3.0.0
     *
     * @global stdClass[] $wp_post_statuses List of post statuses.
     *
     * @see register_post_status()
     *
     * @param string $post_status The name of a registered post status.
     * @return stdClass|null A post status object.
     */
    function get_post_status_object($post_status)
    {
    }
    /**
     * Gets a list of post statuses.
     *
     * @since 3.0.0
     *
     * @global stdClass[] $wp_post_statuses List of post statuses.
     *
     * @see register_post_status()
     *
     * @param array|string $args     Optional. Array or string of post status arguments to compare against
     *                               properties of the global `$wp_post_statuses objects`. Default empty array.
     * @param string       $output   Optional. The type of output to return, either 'names' or 'objects'. Default 'names'.
     * @param string       $operator Optional. The logical operation to perform. 'or' means only one element
     *                               from the array needs to match; 'and' means all elements must match.
     *                               Default 'and'.
     * @return string[]|stdClass[] A list of post status names or objects.
     * @phpstan-param 'names'|'objects' $output
     * @phpstan-return ($output is 'names' ? array<string, string> : array<string, \stdClass>)
     */
    function get_post_stati($args = array(), $output = 'names', $operator = 'and')
    {
    }
    /**
     * Determines whether the post type is hierarchical.
     *
     * A false return value might also mean that the post type does not exist.
     *
     * @since 3.0.0
     *
     * @see get_post_type_object()
     *
     * @param string $post_type Post type name
     * @return bool Whether post type is hierarchical.
     */
    function is_post_type_hierarchical($post_type)
    {
    }
    /**
     * Determines whether a post type is registered.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 3.0.0
     *
     * @see get_post_type_object()
     *
     * @param string $post_type Post type name.
     * @return bool Whether post type is registered.
     */
    function post_type_exists($post_type)
    {
    }
    /**
     * Retrieves the post type of the current post or of a given post.
     *
     * @since 2.1.0
     *
     * @param int|WP_Post|null $post Optional. Post ID or post object. Default is global $post.
     * @return string|false          Post type on success, false on failure.
     */
    function get_post_type($post = \null)
    {
    }
    /**
     * Retrieves a post type object by name.
     *
     * @since 3.0.0
     * @since 4.6.0 Object returned is now an instance of `WP_Post_Type`.
     *
     * @global array $wp_post_types List of post types.
     *
     * @see register_post_type()
     *
     * @param string $post_type The name of a registered post type.
     * @return WP_Post_Type|null WP_Post_Type object if it exists, null otherwise.
     */
    function get_post_type_object($post_type)
    {
    }
    /**
     * Gets a list of all registered post type objects.
     *
     * @since 2.9.0
     *
     * @global array $wp_post_types List of post types.
     *
     * @see register_post_type() for accepted arguments.
     *
     * @param array|string $args     Optional. An array of key => value arguments to match against
     *                               the post type objects. Default empty array.
     * @param string       $output   Optional. The type of output to return. Either 'names'
     *                               or 'objects'. Default 'names'.
     * @param string       $operator Optional. The logical operation to perform. 'or' means only one
     *                               element from the array needs to match; 'and' means all elements
     *                               must match; 'not' means no elements may match. Default 'and'.
     * @return string[]|WP_Post_Type[] An array of post type names or objects.
     * @phpstan-param 'names'|'objects' $output
     * @phpstan-return ($output is 'names' ? array<string, string> : array<string, \WP_Post_Type>)
     */
    function get_post_types($args = array(), $output = 'names', $operator = 'and')
    {
    }
    /**
     * Registers a post type.
     *
     * Note: Post type registrations should not be hooked before the
     * {@see 'init'} action. Also, any taxonomy connections should be
     * registered via the `$taxonomies` argument to ensure consistency
     * when hooks such as {@see 'parse_query'} or {@see 'pre_get_posts'}
     * are used.
     *
     * Post types can support any number of built-in core features such
     * as meta boxes, custom fields, post thumbnails, post statuses,
     * comments, and more. See the `$supports` argument for a complete
     * list of supported features.
     *
     * @since 2.9.0
     * @since 3.0.0 The `show_ui` argument is now enforced on the new post screen.
     * @since 4.4.0 The `show_ui` argument is now enforced on the post type listing
     *              screen and post editing screen.
     * @since 4.6.0 Post type object returned is now an instance of `WP_Post_Type`.
     * @since 4.7.0 Introduced `show_in_rest`, `rest_base` and `rest_controller_class`
     *              arguments to register the post type in REST API.
     * @since 5.0.0 The `template` and `template_lock` arguments were added.
     * @since 5.3.0 The `supports` argument will now accept an array of arguments for a feature.
     * @since 5.9.0 The `rest_namespace` argument was added.
     *
     * @global array $wp_post_types List of post types.
     *
     * @param string       $post_type Post type key. Must not exceed 20 characters and may only contain
     *                                lowercase alphanumeric characters, dashes, and underscores. See sanitize_key().
     * @param array|string $args {
     *     Array or string of arguments for registering a post type.
     *
     *     @type string       $label                           Name of the post type shown in the menu. Usually plural.
     *                                                         Default is value of $labels['name'].
     *     @type string[]     $labels                          An array of labels for this post type. If not set, post
     *                                                         labels are inherited for non-hierarchical types and page
     *                                                         labels for hierarchical ones. See get_post_type_labels() for a full
     *                                                         list of supported labels.
     *     @type string       $description                     A short descriptive summary of what the post type is.
     *                                                         Default empty.
     *     @type bool         $public                          Whether a post type is intended for use publicly either via
     *                                                         the admin interface or by front-end users. While the default
     *                                                         settings of $exclude_from_search, $publicly_queryable, $show_ui,
     *                                                         and $show_in_nav_menus are inherited from $public, each does not
     *                                                         rely on this relationship and controls a very specific intention.
     *                                                         Default false.
     *     @type bool         $hierarchical                    Whether the post type is hierarchical (e.g. page). Default false.
     *     @type bool         $exclude_from_search             Whether to exclude posts with this post type from front end search
     *                                                         results. Default is the opposite value of $public.
     *     @type bool         $publicly_queryable              Whether queries can be performed on the front end for the post type
     *                                                         as part of parse_request(). Endpoints would include:
     *                                                          * ?post_type={post_type_key}
     *                                                          * ?{post_type_key}={single_post_slug}
     *                                                          * ?{post_type_query_var}={single_post_slug}
     *                                                         If not set, the default is inherited from $public.
     *     @type bool         $show_ui                         Whether to generate and allow a UI for managing this post type in the
     *                                                         admin. Default is value of $public.
     *     @type bool|string  $show_in_menu                    Where to show the post type in the admin menu. To work, $show_ui
     *                                                         must be true. If true, the post type is shown in its own top level
     *                                                         menu. If false, no menu is shown. If a string of an existing top
     *                                                         level menu ('tools.php' or 'edit.php?post_type=page', for example), the
     *                                                         post type will be placed as a sub-menu of that.
     *                                                         Default is value of $show_ui.
     *     @type bool         $show_in_nav_menus               Makes this post type available for selection in navigation menus.
     *                                                         Default is value of $public.
     *     @type bool         $show_in_admin_bar               Makes this post type available via the admin bar. Default is value
     *                                                         of $show_in_menu.
     *     @type bool         $show_in_rest                    Whether to include the post type in the REST API. Set this to true
     *                                                         for the post type to be available in the block editor.
     *     @type string       $rest_base                       To change the base URL of REST API route. Default is $post_type.
     *     @type string       $rest_namespace                  To change the namespace URL of REST API route. Default is wp/v2.
     *     @type string       $rest_controller_class           REST API controller class name. Default is 'WP_REST_Posts_Controller'.
     *     @type string|bool  $autosave_rest_controller_class  REST API controller class name. Default is 'WP_REST_Autosaves_Controller'.
     *     @type string|bool  $revisions_rest_controller_class REST API controller class name. Default is 'WP_REST_Revisions_Controller'.
     *     @type bool         $late_route_registration         A flag to direct the REST API controllers for autosave / revisions
     *                                                         should be registered before/after the post type controller.
     *     @type int          $menu_position                   The position in the menu order the post type should appear. To work,
     *                                                         $show_in_menu must be true. Default null (at the bottom).
     *     @type string       $menu_icon                       The URL to the icon to be used for this menu. Pass a base64-encoded
     *                                                         SVG using a data URI, which will be colored to match the color scheme
     *                                                         -- this should begin with 'data:image/svg+xml;base64,'. Pass the name
     *                                                         of a Dashicons helper class to use a font icon, e.g.
     *                                                        'dashicons-chart-pie'. Pass 'none' to leave div.wp-menu-image empty
     *                                                         so an icon can be added via CSS. Defaults to use the posts icon.
     *     @type string|array $capability_type                 The string to use to build the read, edit, and delete capabilities.
     *                                                         May be passed as an array to allow for alternative plurals when using
     *                                                         this argument as a base to construct the capabilities, e.g.
     *                                                         array('story', 'stories'). Default 'post'.
     *     @type string[]     $capabilities                    Array of capabilities for this post type. $capability_type is used
     *                                                         as a base to construct capabilities by default.
     *                                                         See get_post_type_capabilities().
     *     @type bool         $map_meta_cap                    Whether to use the internal default meta capability handling.
     *                                                         Default false.
     *     @type array|false  $supports                        Core feature(s) the post type supports. Serves as an alias for calling
     *                                                         add_post_type_support() directly. Core features include 'title',
     *                                                         'editor', 'comments', 'revisions', 'trackbacks', 'author', 'excerpt',
     *                                                         'page-attributes', 'thumbnail', 'custom-fields', and 'post-formats'.
     *                                                         Additionally, the 'revisions' feature dictates whether the post type
     *                                                         will store revisions, the 'autosave' feature dictates whether the post type
     *                                                         will be autosaved, and the 'comments' feature dictates whether the
     *                                                         comments count will show on the edit screen. For backward compatibility reasons,
     *                                                         adding 'editor' support implies 'autosave' support too. A feature can also be
     *                                                         specified as an array of arguments to provide additional information
     *                                                         about supporting that feature.
     *                                                         Example: `array( 'my_feature', array( 'field' => 'value' ) )`.
     *                                                         If false, no features will be added.
     *                                                         Default is an array containing 'title' and 'editor'.
     *     @type callable     $register_meta_box_cb            Provide a callback function that sets up the meta boxes for the
     *                                                         edit form. Do remove_meta_box() and add_meta_box() calls in the
     *                                                         callback. Default null.
     *     @type string[]     $taxonomies                      An array of taxonomy identifiers that will be registered for the
     *                                                         post type. Taxonomies can be registered later with register_taxonomy()
     *                                                         or register_taxonomy_for_object_type().
     *                                                         Default empty array.
     *     @type bool|string  $has_archive                     Whether there should be post type archives, or if a string, the
     *                                                         archive slug to use. Will generate the proper rewrite rules if
     *                                                         $rewrite is enabled. Default false.
     *     @type bool|array   $rewrite                         {
     *         Triggers the handling of rewrites for this post type. To prevent rewrite, set to false.
     *         Defaults to true, using $post_type as slug. To specify rewrite rules, an array can be
     *         passed with any of these keys:
     *
     *         @type string $slug       Customize the permastruct slug. Defaults to $post_type key.
     *         @type bool   $with_front Whether the permastruct should be prepended with WP_Rewrite::$front.
     *                                  Default true.
     *         @type bool   $feeds      Whether the feed permastruct should be built for this post type.
     *                                  Default is value of $has_archive.
     *         @type bool   $pages      Whether the permastruct should provide for pagination. Default true.
     *         @type int    $ep_mask    Endpoint mask to assign. If not specified and permalink_epmask is set,
     *                                  inherits from $permalink_epmask. If not specified and permalink_epmask
     *                                  is not set, defaults to EP_PERMALINK.
     *     }
     *     @type string|bool  $query_var                      Sets the query_var key for this post type. Defaults to $post_type
     *                                                        key. If false, a post type cannot be loaded at
     *                                                        ?{query_var}={post_slug}. If specified as a string, the query
     *                                                        ?{query_var_string}={post_slug} will be valid.
     *     @type bool         $can_export                     Whether to allow this post type to be exported. Default true.
     *     @type bool         $delete_with_user               Whether to delete posts of this type when deleting a user.
     *                                                          * If true, posts of this type belonging to the user will be moved
     *                                                            to Trash when the user is deleted.
     *                                                          * If false, posts of this type belonging to the user will *not*
     *                                                            be trashed or deleted.
     *                                                          * If not set (the default), posts are trashed if post type supports
     *                                                            the 'author' feature. Otherwise posts are not trashed or deleted.
     *                                                        Default null.
     *     @type array        $template                       Array of blocks to use as the default initial state for an editor
     *                                                        session. Each item should be an array containing block name and
     *                                                        optional attributes. Default empty array.
     *     @type string|false $template_lock                  Whether the block template should be locked if $template is set.
     *                                                        * If set to 'all', the user is unable to insert new blocks,
     *                                                          move existing blocks and delete blocks.
     *                                                       * If set to 'insert', the user is able to move existing blocks
     *                                                         but is unable to insert new blocks and delete blocks.
     *                                                         Default false.
     *     @type bool         $_builtin                     FOR INTERNAL USE ONLY! True if this post type is a native or
     *                                                      "built-in" post_type. Default false.
     *     @type string       $_edit_link                   FOR INTERNAL USE ONLY! URL segment to use for edit link of
     *                                                      this post type. Default 'post.php?post=%d'.
     * }
     * @return WP_Post_Type|WP_Error The registered post type object on success,
     *                               WP_Error object on failure.
     * @phpstan-param array{
     *   label?: string,
     *   labels?: string[],
     *   description?: string,
     *   public?: bool,
     *   hierarchical?: bool,
     *   exclude_from_search?: bool,
     *   publicly_queryable?: bool,
     *   show_ui?: bool,
     *   show_in_menu?: bool|string,
     *   show_in_nav_menus?: bool,
     *   show_in_admin_bar?: bool,
     *   show_in_rest?: bool,
     *   rest_base?: string,
     *   rest_namespace?: string,
     *   rest_controller_class?: string,
     *   autosave_rest_controller_class?: string|bool,
     *   revisions_rest_controller_class?: string|bool,
     *   late_route_registration?: bool,
     *   menu_position?: int,
     *   menu_icon?: string,
     *   capability_type?: string|array,
     *   capabilities?: string[],
     *   map_meta_cap?: bool,
     *   supports?: array|false,
     *   register_meta_box_cb?: callable,
     *   taxonomies?: string[],
     *   has_archive?: bool|string,
     *   rewrite?: bool|array{
     *     slug?: string,
     *     with_front?: bool,
     *     feeds?: bool,
     *     pages?: bool,
     *     ep_mask?: int,
     *   },
     *   query_var?: string|bool,
     *   can_export?: bool,
     *   delete_with_user?: bool,
     *   template?: array,
     *   template_lock?: string|false,
     *   _builtin?: bool,
     *   _edit_link?: string,
     * } $args
     */
    function register_post_type($post_type, $args = array())
    {
    }
    /**
     * Unregisters a post type.
     *
     * Cannot be used to unregister built-in post types.
     *
     * @since 4.5.0
     *
     * @global array $wp_post_types List of post types.
     *
     * @param string $post_type Post type to unregister.
     * @return true|WP_Error True on success, WP_Error on failure or if the post type doesn't exist.
     */
    function unregister_post_type($post_type)
    {
    }
    /**
     * Builds an object with all post type capabilities out of a post type object
     *
     * Post type capabilities use the 'capability_type' argument as a base, if the
     * capability is not set in the 'capabilities' argument array or if the
     * 'capabilities' argument is not supplied.
     *
     * The capability_type argument can optionally be registered as an array, with
     * the first value being singular and the second plural, e.g. array('story, 'stories')
     * Otherwise, an 's' will be added to the value for the plural form. After
     * registration, capability_type will always be a string of the singular value.
     *
     * By default, eight keys are accepted as part of the capabilities array:
     *
     * - edit_post, read_post, and delete_post are meta capabilities, which are then
     *   generally mapped to corresponding primitive capabilities depending on the
     *   context, which would be the post being edited/read/deleted and the user or
     *   role being checked. Thus these capabilities would generally not be granted
     *   directly to users or roles.
     *
     * - edit_posts - Controls whether objects of this post type can be edited.
     * - edit_others_posts - Controls whether objects of this type owned by other users
     *   can be edited. If the post type does not support an author, then this will
     *   behave like edit_posts.
     * - delete_posts - Controls whether objects of this post type can be deleted.
     * - publish_posts - Controls publishing objects of this post type.
     * - read_private_posts - Controls whether private objects can be read.
     *
     * These five primitive capabilities are checked in core in various locations.
     * There are also six other primitive capabilities which are not referenced
     * directly in core, except in map_meta_cap(), which takes the three aforementioned
     * meta capabilities and translates them into one or more primitive capabilities
     * that must then be checked against the user or role, depending on the context.
     *
     * - read - Controls whether objects of this post type can be read.
     * - delete_private_posts - Controls whether private objects can be deleted.
     * - delete_published_posts - Controls whether published objects can be deleted.
     * - delete_others_posts - Controls whether objects owned by other users can be
     *   can be deleted. If the post type does not support an author, then this will
     *   behave like delete_posts.
     * - edit_private_posts - Controls whether private objects can be edited.
     * - edit_published_posts - Controls whether published objects can be edited.
     *
     * These additional capabilities are only used in map_meta_cap(). Thus, they are
     * only assigned by default if the post type is registered with the 'map_meta_cap'
     * argument set to true (default is false).
     *
     * @since 3.0.0
     * @since 5.4.0 'delete_posts' is included in default capabilities.
     *
     * @see register_post_type()
     * @see map_meta_cap()
     *
     * @param object $args Post type registration arguments.
     * @return object Object with all the capabilities as member variables.
     */
    function get_post_type_capabilities($args)
    {
    }
    /**
     * Stores or returns a list of post type meta caps for map_meta_cap().
     *
     * @since 3.1.0
     * @access private
     *
     * @global array $post_type_meta_caps Used to store meta capabilities.
     *
     * @param string[] $capabilities Post type meta capabilities.
     */
    function _post_type_meta_capabilities($capabilities = \null)
    {
    }
    /**
     * Builds an object with all post type labels out of a post type object.
     *
     * Accepted keys of the label array in the post type object:
     *
     * - `name` - General name for the post type, usually plural. The same and overridden
     *          by `$post_type_object->label`. Default is 'Posts' / 'Pages'.
     * - `singular_name` - Name for one object of this post type. Default is 'Post' / 'Page'.
     * - `add_new` - Label for adding a new item. Default is 'Add New' / 'Add New'.
     * - `add_new_item` - Label for adding a new singular item. Default is 'Add New Post' / 'Add New Page'.
     * - `edit_item` - Label for editing a singular item. Default is 'Edit Post' / 'Edit Page'.
     * - `new_item` - Label for the new item page title. Default is 'New Post' / 'New Page'.
     * - `view_item` - Label for viewing a singular item. Default is 'View Post' / 'View Page'.
     * - `view_items` - Label for viewing post type archives. Default is 'View Posts' / 'View Pages'.
     * - `search_items` - Label for searching plural items. Default is 'Search Posts' / 'Search Pages'.
     * - `not_found` - Label used when no items are found. Default is 'No posts found' / 'No pages found'.
     * - `not_found_in_trash` - Label used when no items are in the Trash. Default is 'No posts found in Trash' /
     *                        'No pages found in Trash'.
     * - `parent_item_colon` - Label used to prefix parents of hierarchical items. Not used on non-hierarchical
     *                       post types. Default is 'Parent Page:'.
     * - `all_items` - Label to signify all items in a submenu link. Default is 'All Posts' / 'All Pages'.
     * - `archives` - Label for archives in nav menus. Default is 'Post Archives' / 'Page Archives'.
     * - `attributes` - Label for the attributes meta box. Default is 'Post Attributes' / 'Page Attributes'.
     * - `insert_into_item` - Label for the media frame button. Default is 'Insert into post' / 'Insert into page'.
     * - `uploaded_to_this_item` - Label for the media frame filter. Default is 'Uploaded to this post' /
     *                           'Uploaded to this page'.
     * - `featured_image` - Label for the featured image meta box title. Default is 'Featured image'.
     * - `set_featured_image` - Label for setting the featured image. Default is 'Set featured image'.
     * - `remove_featured_image` - Label for removing the featured image. Default is 'Remove featured image'.
     * - `use_featured_image` - Label in the media frame for using a featured image. Default is 'Use as featured image'.
     * - `menu_name` - Label for the menu name. Default is the same as `name`.
     * - `filter_items_list` - Label for the table views hidden heading. Default is 'Filter posts list' /
     *                       'Filter pages list'.
     * - `filter_by_date` - Label for the date filter in list tables. Default is 'Filter by date'.
     * - `items_list_navigation` - Label for the table pagination hidden heading. Default is 'Posts list navigation' /
     *                           'Pages list navigation'.
     * - `items_list` - Label for the table hidden heading. Default is 'Posts list' / 'Pages list'.
     * - `item_published` - Label used when an item is published. Default is 'Post published.' / 'Page published.'
     * - `item_published_privately` - Label used when an item is published with private visibility.
     *                              Default is 'Post published privately.' / 'Page published privately.'
     * - `item_reverted_to_draft` - Label used when an item is switched to a draft.
     *                            Default is 'Post reverted to draft.' / 'Page reverted to draft.'
     * - `item_trashed` - Label used when an item is moved to Trash. Default is 'Post trashed.' / 'Page trashed.'
     * - `item_scheduled` - Label used when an item is scheduled for publishing. Default is 'Post scheduled.' /
     *                    'Page scheduled.'
     * - `item_updated` - Label used when an item is updated. Default is 'Post updated.' / 'Page updated.'
     * - `item_link` - Title for a navigation link block variation. Default is 'Post Link' / 'Page Link'.
     * - `item_link_description` - Description for a navigation link block variation. Default is 'A link to a post.' /
     *                             'A link to a page.'
     *
     * Above, the first default value is for non-hierarchical post types (like posts)
     * and the second one is for hierarchical post types (like pages).
     *
     * Note: To set labels used in post type admin notices, see the {@see 'post_updated_messages'} filter.
     *
     * @since 3.0.0
     * @since 4.3.0 Added the `featured_image`, `set_featured_image`, `remove_featured_image`,
     *              and `use_featured_image` labels.
     * @since 4.4.0 Added the `archives`, `insert_into_item`, `uploaded_to_this_item`, `filter_items_list`,
     *              `items_list_navigation`, and `items_list` labels.
     * @since 4.6.0 Converted the `$post_type` parameter to accept a `WP_Post_Type` object.
     * @since 4.7.0 Added the `view_items` and `attributes` labels.
     * @since 5.0.0 Added the `item_published`, `item_published_privately`, `item_reverted_to_draft`,
     *              `item_scheduled`, and `item_updated` labels.
     * @since 5.7.0 Added the `filter_by_date` label.
     * @since 5.8.0 Added the `item_link` and `item_link_description` labels.
     * @since 6.3.0 Added the `item_trashed` label.
     * @since 6.4.0 Changed default values for the `add_new` label to include the type of content.
     *              This matches `add_new_item` and provides more context for better accessibility.
     * @since 6.6.0 Added the `template_name` label.
     * @since 6.7.0 Restored pre-6.4.0 defaults for the `add_new` label and updated documentation.
     *              Updated core usage to reference `add_new_item`.
     *
     * @access private
     *
     * @param object|WP_Post_Type $post_type_object Post type object.
     * @return object Object with all the labels as member variables.
     */
    function get_post_type_labels($post_type_object)
    {
    }
    /**
     * Builds an object with custom-something object (post type, taxonomy) labels
     * out of a custom-something object
     *
     * @since 3.0.0
     * @access private
     *
     * @param object $data_object             A custom-something object.
     * @param array  $nohier_vs_hier_defaults Hierarchical vs non-hierarchical default labels.
     * @return object Object containing labels for the given custom-something object.
     */
    function _get_custom_object_labels($data_object, $nohier_vs_hier_defaults)
    {
    }
    /**
     * Adds submenus for post types.
     *
     * @access private
     * @since 3.1.0
     */
    function _add_post_type_submenus()
    {
    }
    /**
     * Registers support of certain features for a post type.
     *
     * All core features are directly associated with a functional area of the edit
     * screen, such as the editor or a meta box. Features include: 'title', 'editor',
     * 'comments', 'revisions', 'trackbacks', 'author', 'excerpt', 'page-attributes',
     * 'thumbnail', 'custom-fields', and 'post-formats'.
     *
     * Additionally, the 'revisions' feature dictates whether the post type will
     * store revisions, the 'autosave' feature dictates whether the post type
     * will be autosaved, and the 'comments' feature dictates whether the comments
     * count will show on the edit screen.
     *
     * A third, optional parameter can also be passed along with a feature to provide
     * additional information about supporting that feature.
     *
     * Example usage:
     *
     *     add_post_type_support( 'my_post_type', 'comments' );
     *     add_post_type_support( 'my_post_type', array(
     *         'author', 'excerpt',
     *     ) );
     *     add_post_type_support( 'my_post_type', 'my_feature', array(
     *         'field' => 'value',
     *     ) );
     *
     * @since 3.0.0
     * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
     *              by adding it to the function signature.
     *
     * @global array $_wp_post_type_features
     *
     * @param string       $post_type The post type for which to add the feature.
     * @param string|array $feature   The feature being added, accepts an array of
     *                                feature strings or a single string.
     * @param mixed        ...$args   Optional extra arguments to pass along with certain features.
     */
    function add_post_type_support($post_type, $feature, ...$args)
    {
    }
    /**
     * Removes support for a feature from a post type.
     *
     * @since 3.0.0
     *
     * @global array $_wp_post_type_features
     *
     * @param string $post_type The post type for which to remove the feature.
     * @param string $feature   The feature being removed.
     */
    function remove_post_type_support($post_type, $feature)
    {
    }
    /**
     * Gets all the post type features
     *
     * @since 3.4.0
     *
     * @global array $_wp_post_type_features
     *
     * @param string $post_type The post type.
     * @return array Post type supports list.
     */
    function get_all_post_type_supports($post_type)
    {
    }
    /**
     * Checks a post type's support for a given feature.
     *
     * @since 3.0.0
     *
     * @global array $_wp_post_type_features
     *
     * @param string $post_type The post type being checked.
     * @param string $feature   The feature being checked.
     * @return bool Whether the post type supports the given feature.
     */
    function post_type_supports($post_type, $feature)
    {
    }
    /**
     * Retrieves a list of post type names that support a specific feature.
     *
     * @since 4.5.0
     *
     * @global array $_wp_post_type_features Post type features
     *
     * @param array|string $feature  Single feature or an array of features the post types should support.
     * @param string       $operator Optional. The logical operation to perform. 'or' means
     *                               only one element from the array needs to match; 'and'
     *                               means all elements must match; 'not' means no elements may
     *                               match. Default 'and'.
     * @return string[] A list of post type names.
     */
    function get_post_types_by_support($feature, $operator = 'and')
    {
    }
    /**
     * Updates the post type for the post ID.
     *
     * The page or post cache will be cleaned for the post ID.
     *
     * @since 2.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $post_id   Optional. Post ID to change post type. Default 0.
     * @param string $post_type Optional. Post type. Accepts 'post' or 'page' to
     *                          name a few. Default 'post'.
     * @return int|false Amount of rows changed. Should be 1 for success and 0 for failure.
     * @phpstan-param 'post'|'page' $post_type
     */
    function set_post_type($post_id = 0, $post_type = 'post')
    {
    }
    /**
     * Determines whether a post type is considered "viewable".
     *
     * For built-in post types such as posts and pages, the 'public' value will be evaluated.
     * For all others, the 'publicly_queryable' value will be used.
     *
     * @since 4.4.0
     * @since 4.5.0 Added the ability to pass a post type name in addition to object.
     * @since 4.6.0 Converted the `$post_type` parameter to accept a `WP_Post_Type` object.
     * @since 5.9.0 Added `is_post_type_viewable` hook to filter the result.
     *
     * @param string|WP_Post_Type $post_type Post type name or object.
     * @return bool Whether the post type should be considered viewable.
     */
    function is_post_type_viewable($post_type)
    {
    }
    /**
     * Determines whether a post status is considered "viewable".
     *
     * For built-in post statuses such as publish and private, the 'public' value will be evaluated.
     * For all others, the 'publicly_queryable' value will be used.
     *
     * @since 5.7.0
     * @since 5.9.0 Added `is_post_status_viewable` hook to filter the result.
     *
     * @param string|stdClass $post_status Post status name or object.
     * @return bool Whether the post status should be considered viewable.
     */
    function is_post_status_viewable($post_status)
    {
    }
    /**
     * Determines whether a post is publicly viewable.
     *
     * Posts are considered publicly viewable if both the post status and post type
     * are viewable.
     *
     * @since 5.7.0
     *
     * @param int|WP_Post|null $post Optional. Post ID or post object. Defaults to global $post.
     * @return bool Whether the post is publicly viewable.
     */
    function is_post_publicly_viewable($post = \null)
    {
    }
    /**
     * Retrieves an array of the latest posts, or posts matching the given criteria.
     *
     * For more information on the accepted arguments, see the
     * {@link https://developer.wordpress.org/reference/classes/wp_query/
     * WP_Query} documentation in the Developer Handbook.
     *
     * The `$ignore_sticky_posts` and `$no_found_rows` arguments are ignored by
     * this function and both are set to `true`.
     *
     * The defaults are as follows:
     *
     * @since 1.2.0
     *
     * @see WP_Query
     * @see WP_Query::parse_query()
     *
     * @param array $args {
     *     Optional. Arguments to retrieve posts. See WP_Query::parse_query() for all available arguments.
     *
     *     @type int        $numberposts      Total number of posts to retrieve. Is an alias of `$posts_per_page`
     *                                        in WP_Query. Accepts -1 for all. Default 5.
     *     @type int|string $category         Category ID or comma-separated list of IDs (this or any children).
     *                                        Is an alias of `$cat` in WP_Query. Default 0.
     *     @type int[]      $include          An array of post IDs to retrieve, sticky posts will be included.
     *                                        Is an alias of `$post__in` in WP_Query. Default empty array.
     *     @type int[]      $exclude          An array of post IDs not to retrieve. Default empty array.
     *     @type bool       $suppress_filters Whether to suppress filters. Default true.
     * }
     * @return WP_Post[]|int[] Array of post objects or post IDs.
     * @phpstan-param array{
     *   numberposts?: int,
     *   category?: int|string,
     *   include?: int[],
     *   exclude?: int[],
     *   suppress_filters?: bool,
     *   attachment_id?: int,
     *   author?: int|string,
     *   author_name?: string,
     *   author__in?: int[],
     *   author__not_in?: int[],
     *   cache_results?: bool,
     *   cat?: int|string,
     *   category__and?: int[],
     *   category__in?: int[],
     *   category__not_in?: int[],
     *   category_name?: string,
     *   comment_count?: array|int,
     *   comment_status?: string,
     *   comments_per_page?: int,
     *   date_query?: array,
     *   day?: int,
     *   exact?: bool,
     *   fields?: string,
     *   hour?: int,
     *   ignore_sticky_posts?: int|bool,
     *   m?: int,
     *   meta_key?: string|string[],
     *   meta_value?: string|string[],
     *   meta_compare?: string,
     *   meta_compare_key?: string,
     *   meta_type?: string,
     *   meta_type_key?: string,
     *   meta_query?: array,
     *   menu_order?: int,
     *   minute?: int,
     *   monthnum?: int,
     *   name?: string,
     *   nopaging?: bool,
     *   no_found_rows?: bool,
     *   offset?: int,
     *   order?: string,
     *   orderby?: string|array,
     *   p?: int,
     *   page?: int,
     *   paged?: int,
     *   page_id?: int,
     *   pagename?: string,
     *   perm?: string,
     *   ping_status?: string,
     *   post__in?: int[],
     *   post__not_in?: int[],
     *   post_mime_type?: string,
     *   post_name__in?: string[],
     *   post_parent?: int,
     *   post_parent__in?: int[],
     *   post_parent__not_in?: int[],
     *   post_type?: string|string[],
     *   post_status?: string|string[],
     *   posts_per_page?: int,
     *   posts_per_archive_page?: int,
     *   s?: string,
     *   search_columns?: string[],
     *   second?: int,
     *   sentence?: bool,
     *   suppress_filters?: bool,
     *   tag?: string,
     *   tag__and?: int[],
     *   tag__in?: int[],
     *   tag__not_in?: int[],
     *   tag_id?: int,
     *   tag_slug__and?: string[],
     *   tag_slug__in?: string[],
     *   tax_query?: array,
     *   title?: string,
     *   update_post_meta_cache?: bool,
     *   update_post_term_cache?: bool,
     *   update_menu_item_cache?: bool,
     *   lazy_load_term_meta?: bool,
     *   w?: int,
     *   year?: int,
     * } $args
     * @phpstan-return ($args is array{fields: 'id=>parent'|'ids'}&array ? array<int, int> : array<int, \WP_Post>)
     */
    function get_posts($args = \null)
    {
    }
    /**
     * Adds a meta field to the given post.
     *
     * Post meta data is called "Custom Fields" on the Administration Screen.
     *
     * @since 1.5.0
     *
     * @param int    $post_id    Post ID.
     * @param string $meta_key   Metadata name.
     * @param mixed  $meta_value Metadata value. Must be serializable if non-scalar.
     * @param bool   $unique     Optional. Whether the same key should not be added.
     *                           Default false.
     * @return int|false Meta ID on success, false on failure.
     */
    function add_post_meta($post_id, $meta_key, $meta_value, $unique = \false)
    {
    }
    /**
     * Deletes a post meta field for the given post ID.
     *
     * You can match based on the key, or key and value. Removing based on key and
     * value, will keep from removing duplicate metadata with the same key. It also
     * allows removing all metadata matching the key, if needed.
     *
     * @since 1.5.0
     *
     * @param int    $post_id    Post ID.
     * @param string $meta_key   Metadata name.
     * @param mixed  $meta_value Optional. Metadata value. If provided,
     *                           rows will only be removed that match the value.
     *                           Must be serializable if non-scalar. Default empty.
     * @return bool True on success, false on failure.
     */
    function delete_post_meta($post_id, $meta_key, $meta_value = '')
    {
    }
    /**
     * Retrieves a post meta field for the given post ID.
     *
     * @since 1.5.0
     *
     * @param int    $post_id Post ID.
     * @param string $key     Optional. The meta key to retrieve. By default,
     *                        returns data for all keys. Default empty.
     * @param bool   $single  Optional. Whether to return a single value.
     *                        This parameter has no effect if `$key` is not specified.
     *                        Default false.
     * @return mixed An array of values if `$single` is false.
     *               The value of the meta field if `$single` is true.
     *               False for an invalid `$post_id` (non-numeric, zero, or negative value).
     *               An empty array if a valid but non-existing post ID is passed and `$single` is false.
     *               An empty string if a valid but non-existing post ID is passed and `$single` is true.
     */
    function get_post_meta($post_id, $key = '', $single = \false)
    {
    }
    /**
     * Updates a post meta field based on the given post ID.
     *
     * Use the `$prev_value` parameter to differentiate between meta fields with the
     * same key and post ID.
     *
     * If the meta field for the post does not exist, it will be added and its ID returned.
     *
     * Can be used in place of add_post_meta().
     *
     * @since 1.5.0
     *
     * @param int    $post_id    Post ID.
     * @param string $meta_key   Metadata key.
     * @param mixed  $meta_value Metadata value. Must be serializable if non-scalar.
     * @param mixed  $prev_value Optional. Previous value to check before updating.
     *                           If specified, only update existing metadata entries with
     *                           this value. Otherwise, update all entries. Default empty.
     * @return int|bool Meta ID if the key didn't exist, true on successful update,
     *                  false on failure or if the value passed to the function
     *                  is the same as the one that is already in the database.
     */
    function update_post_meta($post_id, $meta_key, $meta_value, $prev_value = '')
    {
    }
    /**
     * Deletes everything from post meta matching the given meta key.
     *
     * @since 2.3.0
     *
     * @param string $post_meta_key Key to search for when deleting.
     * @return bool Whether the post meta key was deleted from the database.
     */
    function delete_post_meta_by_key($post_meta_key)
    {
    }
    /**
     * Registers a meta key for posts.
     *
     * @since 4.9.8
     *
     * @param string $post_type Post type to register a meta key for. Pass an empty string
     *                          to register the meta key across all existing post types.
     * @param string $meta_key  The meta key to register.
     * @param array  $args      Data used to describe the meta key when registered. See
     *                          {@see register_meta()} for a list of supported arguments.
     * @return bool True if the meta key was successfully registered, false if not.
     * @phpstan-param array{
     *   object_subtype?: string,
     *   type?: string,
     *   label?: string,
     *   description?: string,
     *   single?: bool,
     *   default?: mixed,
     *   sanitize_callback?: callable,
     *   auth_callback?: callable,
     *   show_in_rest?: bool|array,
     *   revisions_enabled?: bool,
     * } $args See register_meta()
     */
    function register_post_meta($post_type, $meta_key, array $args)
    {
    }
    /**
     * Unregisters a meta key for posts.
     *
     * @since 4.9.8
     *
     * @param string $post_type Post type the meta key is currently registered for. Pass
     *                          an empty string if the meta key is registered across all
     *                          existing post types.
     * @param string $meta_key  The meta key to unregister.
     * @return bool True on success, false if the meta key was not previously registered.
     */
    function unregister_post_meta($post_type, $meta_key)
    {
    }
    /**
     * Retrieves post meta fields, based on post ID.
     *
     * The post meta fields are retrieved from the cache where possible,
     * so the function is optimized to be called more than once.
     *
     * @since 1.2.0
     *
     * @param int $post_id Optional. Post ID. Default is the ID of the global `$post`.
     * @return mixed An array of values.
     *               False for an invalid `$post_id` (non-numeric, zero, or negative value).
     *               An empty string if a valid but non-existing post ID is passed.
     */
    function get_post_custom($post_id = 0)
    {
    }
    /**
     * Retrieves meta field names for a post.
     *
     * If there are no meta fields, then nothing (null) will be returned.
     *
     * @since 1.2.0
     *
     * @param int $post_id Optional. Post ID. Default is the ID of the global `$post`.
     * @return array|void Array of the keys, if retrieved.
     */
    function get_post_custom_keys($post_id = 0)
    {
    }
    /**
     * Retrieves values for a custom post field.
     *
     * The parameters must not be considered optional. All of the post meta fields
     * will be retrieved and only the meta field key values returned.
     *
     * @since 1.2.0
     *
     * @param string $key     Optional. Meta field key. Default empty.
     * @param int    $post_id Optional. Post ID. Default is the ID of the global `$post`.
     * @return array|null Meta field values.
     */
    function get_post_custom_values($key = '', $post_id = 0)
    {
    }
    /**
     * Determines whether a post is sticky.
     *
     * Sticky posts should remain at the top of The Loop. If the post ID is not
     * given, then The Loop ID for the current post will be used.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.7.0
     *
     * @param int $post_id Optional. Post ID. Default is the ID of the global `$post`.
     * @return bool Whether post is sticky.
     */
    function is_sticky($post_id = 0)
    {
    }
    /**
     * Sanitizes every post field.
     *
     * If the context is 'raw', then the post object or array will get minimal
     * sanitization of the integer fields.
     *
     * @since 2.3.0
     *
     * @see sanitize_post_field()
     *
     * @param object|WP_Post|array $post    The post object or array
     * @param string               $context Optional. How to sanitize post fields.
     *                                      Accepts 'raw', 'edit', 'db', 'display',
     *                                      'attribute', or 'js'. Default 'display'.
     * @return object|WP_Post|array The now sanitized post object or array (will be the
     *                              same type as `$post`).
     * @phpstan-param 'raw'|'edit'|'db'|'display'|'attribute'|'js' $context
     * @phpstan-template T of array|object
     * @phpstan-param T $post
     * @phpstan-return T
     */
    function sanitize_post($post, $context = 'display')
    {
    }
    /**
     * Sanitizes a post field based on context.
     *
     * Possible context values are:  'raw', 'edit', 'db', 'display', 'attribute' and
     * 'js'. The 'display' context is used by default. 'attribute' and 'js' contexts
     * are treated like 'display' when calling filters.
     *
     * @since 2.3.0
     * @since 4.4.0 Like `sanitize_post()`, `$context` defaults to 'display'.
     *
     * @param string $field   The Post Object field name.
     * @param mixed  $value   The Post Object value.
     * @param int    $post_id Post ID.
     * @param string $context Optional. How to sanitize the field. Possible values are 'raw', 'edit',
     *                        'db', 'display', 'attribute' and 'js'. Default 'display'.
     * @return mixed Sanitized value.
     * @phpstan-param 'raw'|'edit'|'db'|'display'|'attribute'|'js' $context
     */
    function sanitize_post_field($field, $value, $post_id, $context = 'display')
    {
    }
    /**
     * Makes a post sticky.
     *
     * Sticky posts should be displayed at the top of the front page.
     *
     * @since 2.7.0
     *
     * @param int $post_id Post ID.
     */
    function stick_post($post_id)
    {
    }
    /**
     * Un-sticks a post.
     *
     * Sticky posts should be displayed at the top of the front page.
     *
     * @since 2.7.0
     *
     * @param int $post_id Post ID.
     * @phpstan-return void
     */
    function unstick_post($post_id)
    {
    }
    /**
     * Returns the cache key for wp_count_posts() based on the passed arguments.
     *
     * @since 3.9.0
     * @access private
     *
     * @param string $type Optional. Post type to retrieve count Default 'post'.
     * @param string $perm Optional. 'readable' or empty. Default empty.
     * @return string The cache key.
     */
    function _count_posts_cache_key($type = 'post', $perm = '')
    {
    }
    /**
     * Counts number of posts of a post type and if user has permissions to view.
     *
     * This function provides an efficient method of finding the amount of post's
     * type a blog has. Another method is to count the amount of items in
     * get_posts(), but that method has a lot of overhead with doing so. Therefore,
     * when developing for 2.5+, use this function instead.
     *
     * The $perm parameter checks for 'readable' value and if the user can read
     * private posts, it will display that for the user that is signed in.
     *
     * @since 2.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $type Optional. Post type to retrieve count. Default 'post'.
     * @param string $perm Optional. 'readable' or empty. Default empty.
     * @return stdClass An object containing the number of posts for each status,
     *                  or an empty object if the post type does not exist.
     */
    function wp_count_posts($type = 'post', $perm = '')
    {
    }
    /**
     * Counts number of attachments for the mime type(s).
     *
     * If you set the optional mime_type parameter, then an array will still be
     * returned, but will only have the item you are looking for. It does not give
     * you the number of attachments that are children of a post. You can get that
     * by counting the number of children that post has.
     *
     * @since 2.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string|string[] $mime_type Optional. Array or comma-separated list of
     *                                   MIME patterns. Default empty.
     * @return stdClass An object containing the attachment counts by mime type.
     */
    function wp_count_attachments($mime_type = '')
    {
    }
    /**
     * Gets default post mime types.
     *
     * @since 2.9.0
     * @since 5.3.0 Added the 'Documents', 'Spreadsheets', and 'Archives' mime type groups.
     *
     * @return array List of post mime types.
     */
    function get_post_mime_types()
    {
    }
    /**
     * Checks a MIME-Type against a list.
     *
     * If the `$wildcard_mime_types` parameter is a string, it must be comma separated
     * list. If the `$real_mime_types` is a string, it is also comma separated to
     * create the list.
     *
     * @since 2.5.0
     *
     * @param string|string[] $wildcard_mime_types Mime types, e.g. `audio/mpeg`, `image` (same as `image/*`),
     *                                             or `flash` (same as `*flash*`).
     * @param string|string[] $real_mime_types     Real post mime type values.
     * @return array array(wildcard=>array(real types)).
     */
    function wp_match_mime_types($wildcard_mime_types, $real_mime_types)
    {
    }
    /**
     * Converts MIME types into SQL.
     *
     * @since 2.5.0
     *
     * @param string|string[] $post_mime_types List of mime types or comma separated string
     *                                         of mime types.
     * @param string          $table_alias     Optional. Specify a table alias, if needed.
     *                                         Default empty.
     * @return string The SQL AND clause for mime searching.
     */
    function wp_post_mime_type_where($post_mime_types, $table_alias = '')
    {
    }
    /**
     * Trashes or deletes a post or page.
     *
     * When the post and page is permanently deleted, everything that is tied to
     * it is deleted also. This includes comments, post meta fields, and terms
     * associated with the post.
     *
     * The post or page is moved to Trash instead of permanently deleted unless
     * Trash is disabled, item is already in the Trash, or $force_delete is true.
     *
     * @since 1.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     * @see wp_delete_attachment()
     * @see wp_trash_post()
     *
     * @param int  $post_id      Optional. Post ID. Default 0.
     * @param bool $force_delete Optional. Whether to bypass Trash and force deletion.
     *                           Default false.
     * @return WP_Post|false|null Post data on success, false or null on failure.
     */
    function wp_delete_post($post_id = 0, $force_delete = \false)
    {
    }
    /**
     * Resets the page_on_front, show_on_front, and page_for_post settings when
     * a linked page is deleted or trashed.
     *
     * Also ensures the post is no longer sticky.
     *
     * @since 3.7.0
     * @access private
     *
     * @param int $post_id Post ID.
     */
    function _reset_front_page_settings_for_post($post_id)
    {
    }
    /**
     * Moves a post or page to the Trash
     *
     * If Trash is disabled, the post or page is permanently deleted.
     *
     * @since 2.9.0
     *
     * @see wp_delete_post()
     *
     * @param int $post_id Optional. Post ID. Default is the ID of the global `$post`
     *                     if `EMPTY_TRASH_DAYS` equals true.
     * @return WP_Post|false|null Post data on success, false or null on failure.
     */
    function wp_trash_post($post_id = 0)
    {
    }
    /**
     * Restores a post from the Trash.
     *
     * @since 2.9.0
     * @since 5.6.0 An untrashed post is now returned to 'draft' status by default, except for
     *              attachments which are returned to their original 'inherit' status.
     *
     * @param int $post_id Optional. Post ID. Default is the ID of the global `$post`.
     * @return WP_Post|false|null Post data on success, false or null on failure.
     */
    function wp_untrash_post($post_id = 0)
    {
    }
    /**
     * Moves comments for a post to the Trash.
     *
     * @since 2.9.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|WP_Post|null $post Optional. Post ID or post object. Defaults to global $post.
     * @return mixed|void False on failure.
     */
    function wp_trash_post_comments($post = \null)
    {
    }
    /**
     * Restores comments for a post from the Trash.
     *
     * @since 2.9.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|WP_Post|null $post Optional. Post ID or post object. Defaults to global $post.
     * @return true|void
     */
    function wp_untrash_post_comments($post = \null)
    {
    }
    /**
     * Retrieves the list of categories for a post.
     *
     * Compatibility layer for themes and plugins. Also an easy layer of abstraction
     * away from the complexity of the taxonomy layer.
     *
     * @since 2.1.0
     *
     * @see wp_get_object_terms()
     *
     * @param int   $post_id Optional. The Post ID. Does not default to the ID of the
     *                       global $post. Default 0.
     * @param array $args    Optional. Category query parameters. Default empty array.
     *                       See WP_Term_Query::__construct() for supported arguments.
     * @return array|WP_Error List of categories. If the `$fields` argument passed via `$args` is 'all' or
     *                        'all_with_object_id', an array of WP_Term objects will be returned. If `$fields`
     *                        is 'ids', an array of category IDs. If `$fields` is 'names', an array of category names.
     *                        WP_Error object if 'category' taxonomy doesn't exist.
     * @phpstan-param array{
     *   taxonomy?: string|string[],
     *   object_ids?: int|int[],
     *   orderby?: string,
     *   order?: string,
     *   hide_empty?: bool|int,
     *   include?: int[]|string,
     *   exclude?: int[]|string,
     *   exclude_tree?: int[]|string,
     *   number?: int|string,
     *   offset?: int,
     *   fields?: string,
     *   name?: string|string[],
     *   slug?: string|string[],
     *   term_taxonomy_id?: int|int[],
     *   hierarchical?: bool,
     *   search?: string,
     *   name__like?: string,
     *   description__like?: string,
     *   pad_counts?: bool,
     *   get?: string,
     *   child_of?: int,
     *   parent?: int,
     *   childless?: bool,
     *   cache_domain?: string,
     *   cache_results?: bool,
     *   update_term_meta_cache?: bool,
     *   meta_key?: string|string[],
     *   meta_value?: string|string[],
     *   meta_compare?: string,
     *   meta_compare_key?: string,
     *   meta_type?: string,
     *   meta_type_key?: string,
     *   meta_query?: array,
     * } $args See WP_Term_Query::__construct()
     * @phpstan-return ($post_id is 0 ? array{} : (($args is array{fields: 'names'|'slugs'}&array ? list<string> : ($args is array{fields: 'id=>name'|'id=>slug'}&array ? array<int, string> : ($args is array{fields: 'id=>parent'}&array ? array<int, int> : ($args is array{fields: 'all'|'all_with_object_id'}&array ? array<int, \WP_Term> : ($args is array{fields: 'count'}&array ? numeric-string : list<int>)))))|\WP_Error))
     */
    function wp_get_post_categories($post_id = 0, $args = array())
    {
    }
    /**
     * Retrieves the tags for a post.
     *
     * There is only one default for this function, called 'fields' and by default
     * is set to 'all'. There are other defaults that can be overridden in
     * wp_get_object_terms().
     *
     * @since 2.3.0
     *
     * @param int   $post_id Optional. The Post ID. Does not default to the ID of the
     *                       global $post. Default 0.
     * @param array $args    Optional. Tag query parameters. Default empty array.
     *                       See WP_Term_Query::__construct() for supported arguments.
     * @return array|WP_Error Array of WP_Term objects on success or empty array if no tags were found.
     *                        WP_Error object if 'post_tag' taxonomy doesn't exist.
     * @phpstan-param array{
     *   taxonomy?: string|string[],
     *   object_ids?: int|int[],
     *   orderby?: string,
     *   order?: string,
     *   hide_empty?: bool|int,
     *   include?: int[]|string,
     *   exclude?: int[]|string,
     *   exclude_tree?: int[]|string,
     *   number?: int|string,
     *   offset?: int,
     *   fields?: string,
     *   name?: string|string[],
     *   slug?: string|string[],
     *   term_taxonomy_id?: int|int[],
     *   hierarchical?: bool,
     *   search?: string,
     *   name__like?: string,
     *   description__like?: string,
     *   pad_counts?: bool,
     *   get?: string,
     *   child_of?: int,
     *   parent?: int,
     *   childless?: bool,
     *   cache_domain?: string,
     *   cache_results?: bool,
     *   update_term_meta_cache?: bool,
     *   meta_key?: string|string[],
     *   meta_value?: string|string[],
     *   meta_compare?: string,
     *   meta_compare_key?: string,
     *   meta_type?: string,
     *   meta_type_key?: string,
     *   meta_query?: array,
     * } $args See WP_Term_Query::__construct()
     * @phpstan-return ($post_id is 0 ? array{} : (($args is array{fields: 'names'|'slugs'}&array ? list<string> : ($args is array{fields: 'id=>name'|'id=>slug'}&array ? array<int, string> : ($args is array{fields: 'id=>parent'}&array ? array<int, int> : ($args is array{fields: 'ids'|'tt_ids'}&array ? list<int> : ($args is array{fields: 'count'}&array ? numeric-string : array<int, \WP_Term>)))))|\WP_Error))
     */
    function wp_get_post_tags($post_id = 0, $args = array())
    {
    }
    /**
     * Retrieves the terms for a post.
     *
     * @since 2.8.0
     *
     * @param int             $post_id  Optional. The Post ID. Does not default to the ID of the
     *                                  global $post. Default 0.
     * @param string|string[] $taxonomy Optional. The taxonomy slug or array of slugs for which
     *                                  to retrieve terms. Default 'post_tag'.
     * @param array           $args     {
     *     Optional. Term query parameters. See WP_Term_Query::__construct() for supported arguments.
     *
     *     @type string $fields Term fields to retrieve. Default 'all'.
     * }
     * @return array|WP_Error Array of WP_Term objects on success or empty array if no terms were found.
     *                        WP_Error object if `$taxonomy` doesn't exist.
     * @phpstan-param array{
     *   fields?: string,
     *   taxonomy?: string|string[],
     *   object_ids?: int|int[],
     *   orderby?: string,
     *   order?: string,
     *   hide_empty?: bool|int,
     *   include?: int[]|string,
     *   exclude?: int[]|string,
     *   exclude_tree?: int[]|string,
     *   number?: int|string,
     *   offset?: int,
     *   fields?: string,
     *   name?: string|string[],
     *   slug?: string|string[],
     *   term_taxonomy_id?: int|int[],
     *   hierarchical?: bool,
     *   search?: string,
     *   name__like?: string,
     *   description__like?: string,
     *   pad_counts?: bool,
     *   get?: string,
     *   child_of?: int,
     *   parent?: int,
     *   childless?: bool,
     *   cache_domain?: string,
     *   cache_results?: bool,
     *   update_term_meta_cache?: bool,
     *   meta_key?: string|string[],
     *   meta_value?: string|string[],
     *   meta_compare?: string,
     *   meta_compare_key?: string,
     *   meta_type?: string,
     *   meta_type_key?: string,
     *   meta_query?: array,
     * } $args
     * @phpstan-return ($post_id is 0 ? array{} : ($taxonomy is empty ? array{} : (($args is array{fields: 'names'|'slugs'}&array ? list<string> : ($args is array{fields: 'id=>name'|'id=>slug'}&array ? array<int, string> : ($args is array{fields: 'id=>parent'}&array ? array<int, int> : ($args is array{fields: 'ids'|'tt_ids'}&array ? list<int> : ($args is array{fields: 'count'}&array ? numeric-string : array<int, \WP_Term>)))))|\WP_Error)))
     */
    function wp_get_post_terms($post_id = 0, $taxonomy = 'post_tag', $args = array())
    {
    }
    /**
     * Retrieves a number of recent posts.
     *
     * @since 1.0.0
     *
     * @see get_posts()
     *
     * @param array  $args   Optional. Arguments to retrieve posts. Default empty array.
     * @param string $output Optional. The required return type. One of OBJECT or ARRAY_A, which
     *                       correspond to a WP_Post object or an associative array, respectively.
     *                       Default ARRAY_A.
     * @return array|false Array of recent posts, where the type of each element is determined
     *                     by the `$output` parameter. Empty array on failure.
     */
    function wp_get_recent_posts($args = array(), $output = \ARRAY_A)
    {
    }
    /**
     * Inserts or update a post.
     *
     * If the $postarr parameter has 'ID' set to a value, then post will be updated.
     *
     * You can set the post date manually, by setting the values for 'post_date'
     * and 'post_date_gmt' keys. You can close the comments or open the comments by
     * setting the value for 'comment_status' key.
     *
     * @since 1.0.0
     * @since 2.6.0 Added the `$wp_error` parameter to allow a WP_Error to be returned on failure.
     * @since 4.2.0 Support was added for encoding emoji in the post title, content, and excerpt.
     * @since 4.4.0 A 'meta_input' array can now be passed to `$postarr` to add post meta data.
     * @since 5.6.0 Added the `$fire_after_hooks` parameter.
     *
     * @see sanitize_post()
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array $postarr {
     *     An array of elements that make up a post to update or insert.
     *
     *     @type int    $ID                    The post ID. If equal to something other than 0,
     *                                         the post with that ID will be updated. Default 0.
     *     @type int    $post_author           The ID of the user who added the post. Default is
     *                                         the current user ID.
     *     @type string $post_date             The date of the post. Default is the current time.
     *     @type string $post_date_gmt         The date of the post in the GMT timezone. Default is
     *                                         the value of `$post_date`.
     *     @type string $post_content          The post content. Default empty.
     *     @type string $post_content_filtered The filtered post content. Default empty.
     *     @type string $post_title            The post title. Default empty.
     *     @type string $post_excerpt          The post excerpt. Default empty.
     *     @type string $post_status           The post status. Default 'draft'.
     *     @type string $post_type             The post type. Default 'post'.
     *     @type string $comment_status        Whether the post can accept comments. Accepts 'open' or 'closed'.
     *                                         Default is the value of 'default_comment_status' option.
     *     @type string $ping_status           Whether the post can accept pings. Accepts 'open' or 'closed'.
     *                                         Default is the value of 'default_ping_status' option.
     *     @type string $post_password         The password to access the post. Default empty.
     *     @type string $post_name             The post name. Default is the sanitized post title
     *                                         when creating a new post.
     *     @type string $to_ping               Space or carriage return-separated list of URLs to ping.
     *                                         Default empty.
     *     @type string $pinged                Space or carriage return-separated list of URLs that have
     *                                         been pinged. Default empty.
     *     @type int    $post_parent           Set this for the post it belongs to, if any. Default 0.
     *     @type int    $menu_order            The order the post should be displayed in. Default 0.
     *     @type string $post_mime_type        The mime type of the post. Default empty.
     *     @type string $guid                  Global Unique ID for referencing the post. Default empty.
     *     @type int    $import_id             The post ID to be used when inserting a new post.
     *                                         If specified, must not match any existing post ID. Default 0.
     *     @type int[]  $post_category         Array of category IDs.
     *                                         Defaults to value of the 'default_category' option.
     *     @type array  $tags_input            Array of tag names, slugs, or IDs. Default empty.
     *     @type array  $tax_input             An array of taxonomy terms keyed by their taxonomy name.
     *                                         If the taxonomy is hierarchical, the term list needs to be
     *                                         either an array of term IDs or a comma-separated string of IDs.
     *                                         If the taxonomy is non-hierarchical, the term list can be an array
     *                                         that contains term names or slugs, or a comma-separated string
     *                                         of names or slugs. This is because, in hierarchical taxonomy,
     *                                         child terms can have the same names with different parent terms,
     *                                         so the only way to connect them is using ID. Default empty.
     *     @type array  $meta_input            Array of post meta values keyed by their post meta key. Default empty.
     *     @type string $page_template         Page template to use.
     * }
     * @param bool  $wp_error         Optional. Whether to return a WP_Error on failure. Default false.
     * @param bool  $fire_after_hooks Optional. Whether to fire the after insert hooks. Default true.
     * @return int|WP_Error The post ID on success. The value 0 or WP_Error on failure.
     * @phpstan-param array{
     *   ID?: int,
     *   post_author?: int,
     *   post_date?: string,
     *   post_date_gmt?: string,
     *   post_content?: string,
     *   post_content_filtered?: string,
     *   post_title?: string,
     *   post_excerpt?: string,
     *   post_status?: string,
     *   post_type?: string,
     *   comment_status?: string,
     *   ping_status?: string,
     *   post_password?: string,
     *   post_name?: string,
     *   to_ping?: string,
     *   pinged?: string,
     *   post_parent?: int,
     *   menu_order?: int,
     *   post_mime_type?: string,
     *   guid?: string,
     *   import_id?: int,
     *   post_category?: int[],
     *   tags_input?: array,
     *   tax_input?: array,
     *   meta_input?: array,
     *   page_template?: string,
     * } $postarr
     * @phpstan-return ($wp_error is false ? int<0, max> : int<1, max>|\WP_Error)
     */
    function wp_insert_post($postarr, $wp_error = \false, $fire_after_hooks = \true)
    {
    }
    /**
     * Updates a post with new post data.
     *
     * The date does not have to be set for drafts. You can set the date and it will
     * not be overridden.
     *
     * @since 1.0.0
     * @since 3.5.0 Added the `$wp_error` parameter to allow a WP_Error to be returned on failure.
     * @since 5.6.0 Added the `$fire_after_hooks` parameter.
     *
     * @param array|object $postarr          Optional. Post data. Arrays are expected to be escaped,
     *                                       objects are not. See wp_insert_post() for accepted arguments.
     *                                       Default array.
     * @param bool         $wp_error         Optional. Whether to return a WP_Error on failure. Default false.
     * @param bool         $fire_after_hooks Optional. Whether to fire the after insert hooks. Default true.
     * @return int|WP_Error The post ID on success. The value 0 or WP_Error on failure.
     * @phpstan-param array{
     *   ID?: int,
     *   post_author?: int,
     *   post_date?: string,
     *   post_date_gmt?: string,
     *   post_content?: string,
     *   post_content_filtered?: string,
     *   post_title?: string,
     *   post_excerpt?: string,
     *   post_status?: string,
     *   post_type?: string,
     *   comment_status?: string,
     *   ping_status?: string,
     *   post_password?: string,
     *   post_name?: string,
     *   to_ping?: string,
     *   pinged?: string,
     *   post_parent?: int,
     *   menu_order?: int,
     *   post_mime_type?: string,
     *   guid?: string,
     *   import_id?: int,
     *   post_category?: int[],
     *   tags_input?: array,
     *   tax_input?: array,
     *   meta_input?: array,
     *   page_template?: string,
     * } $postarr See wp_insert_post()
     * @phpstan-return ($wp_error is false ? int<0, max> : int<1, max>|\WP_Error)
     */
    function wp_update_post($postarr = array(), $wp_error = \false, $fire_after_hooks = \true)
    {
    }
    /**
     * Publishes a post by transitioning the post status.
     *
     * @since 2.1.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|WP_Post $post Post ID or post object.
     * @phpstan-return void
     */
    function wp_publish_post($post)
    {
    }
    /**
     * Publishes future post and make sure post ID has future post status.
     *
     * Invoked by cron 'publish_future_post' event. This safeguard prevents cron
     * from publishing drafts, etc.
     *
     * @since 2.5.0
     *
     * @param int|WP_Post $post Post ID or post object.
     * @phpstan-return void
     */
    function check_and_publish_future_post($post)
    {
    }
    /**
     * Uses wp_checkdate to return a valid Gregorian-calendar value for post_date.
     * If post_date is not provided, this first checks post_date_gmt if provided,
     * then falls back to use the current time.
     *
     * For back-compat purposes in wp_insert_post, an empty post_date and an invalid
     * post_date_gmt will continue to return '1970-01-01 00:00:00' rather than false.
     *
     * @since 5.7.0
     *
     * @param string $post_date     The date in mysql format (`Y-m-d H:i:s`).
     * @param string $post_date_gmt The GMT date in mysql format (`Y-m-d H:i:s`).
     * @return string|false A valid Gregorian-calendar date string, or false on failure.
     */
    function wp_resolve_post_date($post_date = '', $post_date_gmt = '')
    {
    }
    /**
     * Computes a unique slug for the post, when given the desired slug and some post details.
     *
     * @since 2.8.0
     *
     * @global wpdb       $wpdb       WordPress database abstraction object.
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string $slug        The desired slug (post_name).
     * @param int    $post_id     Post ID.
     * @param string $post_status No uniqueness checks are made if the post is still draft or pending.
     * @param string $post_type   Post type.
     * @param int    $post_parent Post parent ID.
     * @return string Unique slug for the post, based on $post_name (with a -1, -2, etc. suffix)
     */
    function wp_unique_post_slug($slug, $post_id, $post_status, $post_type, $post_parent)
    {
    }
    /**
     * Truncates a post slug.
     *
     * @since 3.6.0
     * @access private
     *
     * @see utf8_uri_encode()
     *
     * @param string $slug   The slug to truncate.
     * @param int    $length Optional. Max length of the slug. Default 200 (characters).
     * @return string The truncated slug.
     */
    function _truncate_post_slug($slug, $length = 200)
    {
    }
    /**
     * Adds tags to a post.
     *
     * @see wp_set_post_tags()
     *
     * @since 2.3.0
     *
     * @param int          $post_id Optional. The Post ID. Does not default to the ID of the global $post.
     * @param string|array $tags    Optional. An array of tags to set for the post, or a string of tags
     *                              separated by commas. Default empty.
     * @return array|false|WP_Error Array of affected term IDs. WP_Error or false on failure.
     */
    function wp_add_post_tags($post_id = 0, $tags = '')
    {
    }
    /**
     * Sets the tags for a post.
     *
     * @since 2.3.0
     *
     * @see wp_set_object_terms()
     *
     * @param int          $post_id Optional. The Post ID. Does not default to the ID of the global $post.
     * @param string|array $tags    Optional. An array of tags to set for the post, or a string of tags
     *                              separated by commas. Default empty.
     * @param bool         $append  Optional. If true, don't delete existing tags, just add on. If false,
     *                              replace the tags with the new tags. Default false.
     * @return array|false|WP_Error Array of term taxonomy IDs of affected terms. WP_Error or false on failure.
     */
    function wp_set_post_tags($post_id = 0, $tags = '', $append = \false)
    {
    }
    /**
     * Sets the terms for a post.
     *
     * @since 2.8.0
     *
     * @see wp_set_object_terms()
     *
     * @param int          $post_id  Optional. The Post ID. Does not default to the ID of the global $post.
     * @param string|array $terms    Optional. An array of terms to set for the post, or a string of terms
     *                               separated by commas. Hierarchical taxonomies must always pass IDs rather
     *                               than names so that children with the same names but different parents
     *                               aren't confused. Default empty.
     * @param string       $taxonomy Optional. Taxonomy name. Default 'post_tag'.
     * @param bool         $append   Optional. If true, don't delete existing terms, just add on. If false,
     *                               replace the terms with the new terms. Default false.
     * @return array|false|WP_Error Array of term taxonomy IDs of affected terms. WP_Error or false on failure.
     */
    function wp_set_post_terms($post_id = 0, $terms = '', $taxonomy = 'post_tag', $append = \false)
    {
    }
    /**
     * Sets categories for a post.
     *
     * If no categories are provided, the default category is used.
     *
     * @since 2.1.0
     *
     * @param int       $post_id         Optional. The Post ID. Does not default to the ID
     *                                   of the global $post. Default 0.
     * @param int[]|int $post_categories Optional. List of category IDs, or the ID of a single category.
     *                                   Default empty array.
     * @param bool      $append          If true, don't delete existing categories, just add on.
     *                                   If false, replace the categories with the new categories.
     * @return array|false|WP_Error Array of term taxonomy IDs of affected categories. WP_Error or false on failure.
     */
    function wp_set_post_categories($post_id = 0, $post_categories = array(), $append = \false)
    {
    }
    /**
     * Fires actions related to the transitioning of a post's status.
     *
     * When a post is saved, the post status is "transitioned" from one status to another,
     * though this does not always mean the status has actually changed before and after
     * the save. This function fires a number of action hooks related to that transition:
     * the generic {@see 'transition_post_status'} action, as well as the dynamic hooks
     * {@see '$old_status_to_$new_status'} and {@see '$new_status_$post->post_type'}. Note
     * that the function does not transition the post object in the database.
     *
     * For instance: When publishing a post for the first time, the post status may transition
     * from 'draft' – or some other status – to 'publish'. However, if a post is already
     * published and is simply being updated, the "old" and "new" statuses may both be 'publish'
     * before and after the transition.
     *
     * @since 2.3.0
     *
     * @param string  $new_status Transition to this post status.
     * @param string  $old_status Previous post status.
     * @param WP_Post $post Post data.
     */
    function wp_transition_post_status($new_status, $old_status, $post)
    {
    }
    /**
     * Fires actions after a post, its terms and meta data has been saved.
     *
     * @since 5.6.0
     *
     * @param int|WP_Post  $post        The post ID or object that has been saved.
     * @param bool         $update      Whether this is an existing post being updated.
     * @param null|WP_Post $post_before Null for new posts, the WP_Post object prior
     *                                  to the update for updated posts.
     * @phpstan-return void
     */
    function wp_after_insert_post($post, $update, $post_before)
    {
    }
    /**
     * Adds a URL to those already pinged.
     *
     * @since 1.5.0
     * @since 4.7.0 `$post` can be a WP_Post object.
     * @since 4.7.0 `$uri` can be an array of URIs.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|WP_Post  $post Post ID or post object.
     * @param string|array $uri  Ping URI or array of URIs.
     * @return int|false How many rows were updated.
     */
    function add_ping($post, $uri)
    {
    }
    /**
     * Retrieves enclosures already enclosed for a post.
     *
     * @since 1.5.0
     *
     * @param int $post_id Post ID.
     * @return string[] Array of enclosures for the given post.
     */
    function get_enclosed($post_id)
    {
    }
    /**
     * Retrieves URLs already pinged for a post.
     *
     * @since 1.5.0
     *
     * @since 4.7.0 `$post` can be a WP_Post object.
     *
     * @param int|WP_Post $post Post ID or object.
     * @return string[]|false Array of URLs already pinged for the given post, false if the post is not found.
     */
    function get_pung($post)
    {
    }
    /**
     * Retrieves URLs that need to be pinged.
     *
     * @since 1.5.0
     * @since 4.7.0 `$post` can be a WP_Post object.
     *
     * @param int|WP_Post $post Post ID or post object.
     * @return string[]|false List of URLs yet to ping.
     */
    function get_to_ping($post)
    {
    }
    /**
     * Does trackbacks for a list of URLs.
     *
     * @since 1.0.0
     *
     * @param string $tb_list Comma separated list of URLs.
     * @param int    $post_id Post ID.
     */
    function trackback_url_list($tb_list, $post_id)
    {
    }
    /**
     * Gets a list of page IDs.
     *
     * @since 2.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @return string[] List of page IDs as strings.
     */
    function get_all_page_ids()
    {
    }
    /**
     * Retrieves page data given a page ID or page object.
     *
     * Use get_post() instead of get_page().
     *
     * @since 1.5.1
     * @deprecated 3.5.0 Use get_post()
     *
     * @param int|WP_Post $page   Page object or page ID. Passed by reference.
     * @param string      $output Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
     *                            correspond to a WP_Post object, an associative array, or a numeric array,
     *                            respectively. Default OBJECT.
     * @param string      $filter Optional. How the return value should be filtered. Accepts 'raw',
     *                            'edit', 'db', 'display'. Default 'raw'.
     * @return WP_Post|array|null WP_Post or array on success, null on failure.
     */
    function get_page($page, $output = \OBJECT, $filter = 'raw')
    {
    }
    /**
     * Retrieves a page given its path.
     *
     * @since 2.1.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string       $page_path Page path.
     * @param string       $output    Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
     *                                correspond to a WP_Post object, an associative array, or a numeric array,
     *                                respectively. Default OBJECT.
     * @param string|array $post_type Optional. Post type or array of post types. Default 'page'.
     * @return WP_Post|array|null WP_Post (or array) on success, or null on failure.
     * @phpstan-return ($output is 'ARRAY_A' ? array<string, mixed>|null : ($output is 'ARRAY_N' ? array<int, mixed>|null : \WP_Post|null))
     */
    function get_page_by_path($page_path, $output = \OBJECT, $post_type = 'page')
    {
    }
    /**
     * Identifies descendants of a given page ID in a list of page objects.
     *
     * Descendants are identified from the `$pages` array passed to the function. No database queries are performed.
     *
     * @since 1.5.1
     *
     * @param int       $page_id Page ID.
     * @param WP_Post[] $pages   List of page objects from which descendants should be identified.
     * @return WP_Post[] List of page children.
     */
    function get_page_children($page_id, $pages)
    {
    }
    /**
     * Orders the pages with children under parents in a flat list.
     *
     * It uses auxiliary structure to hold parent-children relationships and
     * runs in O(N) complexity
     *
     * @since 2.0.0
     *
     * @param WP_Post[] $pages   Posts array (passed by reference).
     * @param int       $page_id Optional. Parent page ID. Default 0.
     * @return string[] Array of post names keyed by ID and arranged by hierarchy. Children immediately follow their parents.
     */
    function get_page_hierarchy(&$pages, $page_id = 0)
    {
    }
    /**
     * Traverses and return all the nested children post names of a root page.
     *
     * $children contains parent-children relations
     *
     * @since 2.9.0
     * @access private
     *
     * @see _page_traverse_name()
     *
     * @param int      $page_id  Page ID.
     * @param array    $children Parent-children relations (passed by reference).
     * @param string[] $result   Array of page names keyed by ID (passed by reference).
     */
    function _page_traverse_name($page_id, &$children, &$result)
    {
    }
    /**
     * Builds the URI path for a page.
     *
     * Sub pages will be in the "directory" under the parent page post name.
     *
     * @since 1.5.0
     * @since 4.6.0 The `$page` parameter was made optional.
     *
     * @param WP_Post|object|int $page Optional. Page ID or WP_Post object. Default is global $post.
     * @return string|false Page URI, false on error.
     */
    function get_page_uri($page = 0)
    {
    }
    /**
     * Retrieves an array of pages (or hierarchical post type items).
     *
     * @since 1.5.0
     * @since 6.3.0 Use WP_Query internally.
     *
     * @param array|string $args {
     *     Optional. Array or string of arguments to retrieve pages.
     *
     *     @type int          $child_of     Page ID to return child and grandchild pages of. Note: The value
     *                                      of `$hierarchical` has no bearing on whether `$child_of` returns
     *                                      hierarchical results. Default 0, or no restriction.
     *     @type string       $sort_order   How to sort retrieved pages. Accepts 'ASC', 'DESC'. Default 'ASC'.
     *     @type string       $sort_column  What columns to sort pages by, comma-separated. Accepts 'post_author',
     *                                      'post_date', 'post_title', 'post_name', 'post_modified', 'menu_order',
     *                                      'post_modified_gmt', 'post_parent', 'ID', 'rand', 'comment_count'.
     *                                      'post_' can be omitted for any values that start with it.
     *                                      Default 'post_title'.
     *     @type bool         $hierarchical Whether to return pages hierarchically. If false in conjunction with
     *                                      `$child_of` also being false, both arguments will be disregarded.
     *                                      Default true.
     *     @type int[]        $exclude      Array of page IDs to exclude. Default empty array.
     *     @type int[]        $include      Array of page IDs to include. Cannot be used with `$child_of`,
     *                                      `$parent`, `$exclude`, `$meta_key`, `$meta_value`, or `$hierarchical`.
     *                                      Default empty array.
     *     @type string       $meta_key     Only include pages with this meta key. Default empty.
     *     @type string       $meta_value   Only include pages with this meta value. Requires `$meta_key`.
     *                                      Default empty.
     *     @type string       $authors      A comma-separated list of author IDs. Default empty.
     *     @type int          $parent       Page ID to return direct children of. Default -1, or no restriction.
     *     @type string|int[] $exclude_tree Comma-separated string or array of page IDs to exclude.
     *                                      Default empty array.
     *     @type int          $number       The number of pages to return. Default 0, or all pages.
     *     @type int          $offset       The number of pages to skip before returning. Requires `$number`.
     *                                      Default 0.
     *     @type string       $post_type    The post type to query. Default 'page'.
     *     @type string|array $post_status  A comma-separated list or array of post statuses to include.
     *                                      Default 'publish'.
     * }
     * @return WP_Post[]|false Array of pages (or hierarchical post type items). Boolean false if the
     *                         specified post type is not hierarchical or the specified status is not
     *                         supported by the post type.
     * @phpstan-param array{
     *   child_of?: int,
     *   sort_order?: string,
     *   sort_column?: string,
     *   hierarchical?: bool,
     *   exclude?: int[],
     *   include?: int[],
     *   meta_key?: string,
     *   meta_value?: string,
     *   authors?: string,
     *   parent?: int,
     *   exclude_tree?: string|int[],
     *   number?: int,
     *   offset?: int,
     *   post_type?: string,
     *   post_status?: string|array,
     * } $args
     */
    function get_pages($args = array())
    {
    }
    /**
     * Determines whether an attachment URI is local and really an attachment.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.0.0
     *
     * @param string $url URL to check
     * @return bool True on success, false on failure.
     */
    function is_local_attachment($url)
    {
    }
    /**
     * Inserts an attachment.
     *
     * If you set the 'ID' in the $args parameter, it will mean that you are
     * updating and attempt to update the attachment. You can also set the
     * attachment name or title by setting the key 'post_name' or 'post_title'.
     *
     * You can set the dates for the attachment manually by setting the 'post_date'
     * and 'post_date_gmt' keys' values.
     *
     * By default, the comments will use the default settings for whether the
     * comments are allowed. You can close them manually or keep them open by
     * setting the value for the 'comment_status' key.
     *
     * @since 2.0.0
     * @since 4.7.0 Added the `$wp_error` parameter to allow a WP_Error to be returned on failure.
     * @since 5.6.0 Added the `$fire_after_hooks` parameter.
     *
     * @see wp_insert_post()
     *
     * @param string|array $args             Arguments for inserting an attachment.
     * @param string|false $file             Optional. Filename. Default false.
     * @param int          $parent_post_id   Optional. Parent post ID or 0 for no parent. Default 0.
     * @param bool         $wp_error         Optional. Whether to return a WP_Error on failure. Default false.
     * @param bool         $fire_after_hooks Optional. Whether to fire the after insert hooks. Default true.
     * @return int|WP_Error The attachment ID on success. The value 0 or WP_Error on failure.
     * @phpstan-return ($wp_error is false ? int<0, max> : int<1, max>|\WP_Error)
     */
    function wp_insert_attachment($args, $file = \false, $parent_post_id = 0, $wp_error = \false, $fire_after_hooks = \true)
    {
    }
    /**
     * Trashes or deletes an attachment.
     *
     * When an attachment is permanently deleted, the file will also be removed.
     * Deletion removes all post meta fields, taxonomy, comments, etc. associated
     * with the attachment (except the main post).
     *
     * The attachment is moved to the Trash instead of permanently deleted unless Trash
     * for media is disabled, item is already in the Trash, or $force_delete is true.
     *
     * @since 2.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int  $post_id      Attachment ID.
     * @param bool $force_delete Optional. Whether to bypass Trash and force deletion.
     *                           Default false.
     * @return WP_Post|false|null Post data on success, false or null on failure.
     */
    function wp_delete_attachment($post_id, $force_delete = \false)
    {
    }
    /**
     * Deletes all files that belong to the given attachment.
     *
     * @since 4.9.7
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $post_id      Attachment ID.
     * @param array  $meta         The attachment's meta data.
     * @param array  $backup_sizes The meta data for the attachment's backup images.
     * @param string $file         Absolute path to the attachment's file.
     * @return bool True on success, false on failure.
     */
    function wp_delete_attachment_files($post_id, $meta, $backup_sizes, $file)
    {
    }
    /**
     * Retrieves attachment metadata for attachment ID.
     *
     * @since 2.1.0
     * @since 6.0.0 The `$filesize` value was added to the returned array.
     *
     * @param int  $attachment_id Attachment post ID. Defaults to global $post.
     * @param bool $unfiltered    Optional. If true, filters are not run. Default false.
     * @return array|false {
     *     Attachment metadata. False on failure.
     *
     *     @type int    $width      The width of the attachment.
     *     @type int    $height     The height of the attachment.
     *     @type string $file       The file path relative to `wp-content/uploads`.
     *     @type array  $sizes      Keys are size slugs, each value is an array containing
     *                              'file', 'width', 'height', and 'mime-type'.
     *     @type array  $image_meta Image metadata.
     *     @type int    $filesize   File size of the attachment.
     * }
     * @phpstan-return false|array{
     *   width: int,
     *   height: int,
     *   file: string,
     *   sizes: array,
     *   image_meta: array,
     *   filesize: int,
     * }
     */
    function wp_get_attachment_metadata($attachment_id = 0, $unfiltered = \false)
    {
    }
    /**
     * Updates metadata for an attachment.
     *
     * @since 2.1.0
     *
     * @param int   $attachment_id Attachment post ID.
     * @param array $data          Attachment meta data.
     * @return int|false False if $post is invalid.
     */
    function wp_update_attachment_metadata($attachment_id, $data)
    {
    }
    /**
     * Retrieves the URL for an attachment.
     *
     * @since 2.1.0
     *
     * @global string $pagenow The filename of the current screen.
     *
     * @param int $attachment_id Optional. Attachment post ID. Defaults to global $post.
     * @return string|false Attachment URL, otherwise false.
     */
    function wp_get_attachment_url($attachment_id = 0)
    {
    }
    /**
     * Retrieves the caption for an attachment.
     *
     * @since 4.6.0
     *
     * @param int $post_id Optional. Attachment ID. Default is the ID of the global `$post`.
     * @return string|false Attachment caption on success, false on failure.
     */
    function wp_get_attachment_caption($post_id = 0)
    {
    }
    /**
     * Retrieves URL for an attachment thumbnail.
     *
     * @since 2.1.0
     * @since 6.1.0 Changed to use wp_get_attachment_image_url().
     *
     * @param int $post_id Optional. Attachment ID. Default is the ID of the global `$post`.
     * @return string|false Thumbnail URL on success, false on failure.
     */
    function wp_get_attachment_thumb_url($post_id = 0)
    {
    }
    /**
     * Verifies an attachment is of a given type.
     *
     * @since 4.2.0
     *
     * @param string      $type Attachment type. Accepts `image`, `audio`, `video`, or a file extension.
     * @param int|WP_Post $post Optional. Attachment ID or object. Default is global $post.
     * @return bool True if an accepted type or a matching file extension, false otherwise.
     */
    function wp_attachment_is($type, $post = \null)
    {
    }
    /**
     * Determines whether an attachment is an image.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.1.0
     * @since 4.2.0 Modified into wrapper for wp_attachment_is() and
     *              allowed WP_Post object to be passed.
     *
     * @param int|WP_Post $post Optional. Attachment ID or object. Default is global $post.
     * @return bool Whether the attachment is an image.
     */
    function wp_attachment_is_image($post = \null)
    {
    }
    /**
     * Retrieves the icon for a MIME type or attachment.
     *
     * @since 2.1.0
     * @since 6.5.0 Added the `$preferred_ext` parameter.
     *
     * @param string|int $mime          MIME type or attachment ID.
     * @param string     $preferred_ext File format to prefer in return. Default '.png'.
     * @return string|false Icon, false otherwise.
     */
    function wp_mime_type_icon($mime = 0, $preferred_ext = '.png')
    {
    }
    /**
     * Checks for changed slugs for published post objects and save the old slug.
     *
     * The function is used when a post object of any type is updated,
     * by comparing the current and previous post objects.
     *
     * If the slug was changed and not already part of the old slugs then it will be
     * added to the post meta field ('_wp_old_slug') for storing old slugs for that
     * post.
     *
     * The most logically usage of this function is redirecting changed post objects, so
     * that those that linked to an changed post will be redirected to the new post.
     *
     * @since 2.1.0
     *
     * @param int     $post_id     Post ID.
     * @param WP_Post $post        The post object.
     * @param WP_Post $post_before The previous post object.
     * @phpstan-return void
     */
    function wp_check_for_changed_slugs($post_id, $post, $post_before)
    {
    }
    /**
     * Checks for changed dates for published post objects and save the old date.
     *
     * The function is used when a post object of any type is updated,
     * by comparing the current and previous post objects.
     *
     * If the date was changed and not already part of the old dates then it will be
     * added to the post meta field ('_wp_old_date') for storing old dates for that
     * post.
     *
     * The most logically usage of this function is redirecting changed post objects, so
     * that those that linked to an changed post will be redirected to the new post.
     *
     * @since 4.9.3
     *
     * @param int     $post_id     Post ID.
     * @param WP_Post $post        The post object.
     * @param WP_Post $post_before The previous post object.
     * @phpstan-return void
     */
    function wp_check_for_changed_dates($post_id, $post, $post_before)
    {
    }
    /**
     * Retrieves the private post SQL based on capability.
     *
     * This function provides a standardized way to appropriately select on the
     * post_status of a post type. The function will return a piece of SQL code
     * that can be added to a WHERE clause; this SQL is constructed to allow all
     * published posts, and all private posts to which the user has access.
     *
     * @since 2.2.0
     * @since 4.3.0 Added the ability to pass an array to `$post_type`.
     *
     * @param string|array $post_type Single post type or an array of post types. Currently only supports 'post' or 'page'.
     * @return string SQL code that can be added to a where clause.
     */
    function get_private_posts_cap_sql($post_type)
    {
    }
    /**
     * Retrieves the post SQL based on capability, author, and type.
     *
     * @since 3.0.0
     * @since 4.3.0 Introduced the ability to pass an array of post types to `$post_type`.
     *
     * @see get_private_posts_cap_sql()
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string|string[] $post_type   Single post type or an array of post types.
     * @param bool            $full        Optional. Returns a full WHERE statement instead of just
     *                                     an 'andalso' term. Default true.
     * @param int             $post_author Optional. Query posts having a single author ID. Default null.
     * @param bool            $public_only Optional. Only return public posts. Skips cap checks for
     *                                     $current_user.  Default false.
     * @return string SQL WHERE code that can be added to a query.
     */
    function get_posts_by_author_sql($post_type, $full = \true, $post_author = \null, $public_only = \false)
    {
    }
    /**
     * Retrieves the most recent time that a post on the site was published.
     *
     * The server timezone is the default and is the difference between GMT and
     * server time. The 'blog' value is the date when the last post was posted.
     * The 'gmt' is when the last post was posted in GMT formatted date.
     *
     * @since 0.71
     * @since 4.4.0 The `$post_type` argument was added.
     *
     * @param string $timezone  Optional. The timezone for the timestamp. Accepts 'server', 'blog', or 'gmt'.
     *                          'server' uses the server's internal timezone.
     *                          'blog' uses the `post_date` field, which proxies to the timezone set for the site.
     *                          'gmt' uses the `post_date_gmt` field.
     *                          Default 'server'.
     * @param string $post_type Optional. The post type to check. Default 'any'.
     * @return string The date of the last post, or false on failure.
     * @phpstan-param 'server'|'blog'|'gmt' $timezone
     */
    function get_lastpostdate($timezone = 'server', $post_type = 'any')
    {
    }
    /**
     * Gets the most recent time that a post on the site was modified.
     *
     * The server timezone is the default and is the difference between GMT and
     * server time. The 'blog' value is just when the last post was modified.
     * The 'gmt' is when the last post was modified in GMT time.
     *
     * @since 1.2.0
     * @since 4.4.0 The `$post_type` argument was added.
     *
     * @param string $timezone  Optional. The timezone for the timestamp. See get_lastpostdate()
     *                          for information on accepted values.
     *                          Default 'server'.
     * @param string $post_type Optional. The post type to check. Default 'any'.
     * @return string The timestamp in 'Y-m-d H:i:s' format, or false on failure.
     * @phpstan-param 'server'|'blog'|'gmt' $timezone
     */
    function get_lastpostmodified($timezone = 'server', $post_type = 'any')
    {
    }
    /**
     * Gets the timestamp of the last time any post was modified or published.
     *
     * @since 3.1.0
     * @since 4.4.0 The `$post_type` argument was added.
     * @access private
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $timezone  The timezone for the timestamp. See get_lastpostdate().
     *                          for information on accepted values.
     * @param string $field     Post field to check. Accepts 'date' or 'modified'.
     * @param string $post_type Optional. The post type to check. Default 'any'.
     * @return string|false The timestamp in 'Y-m-d H:i:s' format, or false on failure.
     * @phpstan-param 'date'|'modified' $field
     * @phpstan-param 'server'|'blog'|'gmt' $timezone
     */
    function _get_last_post_time($timezone, $field, $post_type = 'any')
    {
    }
    /**
     * Updates posts in cache.
     *
     * @since 1.5.1
     *
     * @param WP_Post[] $posts Array of post objects (passed by reference).
     * @phpstan-return void
     */
    function update_post_cache(&$posts)
    {
    }
    /**
     * Will clean the post in the cache.
     *
     * Cleaning means delete from the cache of the post. Will call to clean the term
     * object cache associated with the post ID.
     *
     * This function not run if $_wp_suspend_cache_invalidation is not empty. See
     * wp_suspend_cache_invalidation().
     *
     * @since 2.0.0
     *
     * @global bool $_wp_suspend_cache_invalidation
     *
     * @param int|WP_Post $post Post ID or post object to remove from the cache.
     * @phpstan-return void
     */
    function clean_post_cache($post)
    {
    }
    /**
     * Updates post, term, and metadata caches for a list of post objects.
     *
     * @since 1.5.0
     *
     * @param WP_Post[] $posts             Array of post objects (passed by reference).
     * @param string    $post_type         Optional. Post type. Default 'post'.
     * @param bool      $update_term_cache Optional. Whether to update the term cache. Default true.
     * @param bool      $update_meta_cache Optional. Whether to update the meta cache. Default true.
     * @phpstan-return void
     */
    function update_post_caches(&$posts, $post_type = 'post', $update_term_cache = \true, $update_meta_cache = \true)
    {
    }
    /**
     * Updates post author user caches for a list of post objects.
     *
     * @since 6.1.0
     *
     * @param WP_Post[] $posts Array of post objects.
     * @phpstan-return void
     */
    function update_post_author_caches($posts)
    {
    }
    /**
     * Updates parent post caches for a list of post objects.
     *
     * @since 6.1.0
     *
     * @param WP_Post[] $posts Array of post objects.
     */
    function update_post_parent_caches($posts)
    {
    }
    /**
     * Updates metadata cache for a list of post IDs.
     *
     * Performs SQL query to retrieve the metadata for the post IDs and updates the
     * metadata cache for the posts. Therefore, the functions, which call this
     * function, do not need to perform SQL queries on their own.
     *
     * @since 2.1.0
     *
     * @param int[] $post_ids Array of post IDs.
     * @return array|false An array of metadata on success, false if there is nothing to update.
     */
    function update_postmeta_cache($post_ids)
    {
    }
    /**
     * Will clean the attachment in the cache.
     *
     * Cleaning means delete from the cache. Optionally will clean the term
     * object cache associated with the attachment ID.
     *
     * This function will not run if $_wp_suspend_cache_invalidation is not empty.
     *
     * @since 3.0.0
     *
     * @global bool $_wp_suspend_cache_invalidation
     *
     * @param int  $id          The attachment ID in the cache to clean.
     * @param bool $clean_terms Optional. Whether to clean terms cache. Default false.
     * @phpstan-return void
     */
    function clean_attachment_cache($id, $clean_terms = \false)
    {
    }
    /**
     * Hook for managing future post transitions to published.
     *
     * @since 2.3.0
     * @access private
     *
     * @see wp_clear_scheduled_hook()
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string  $new_status New post status.
     * @param string  $old_status Previous post status.
     * @param WP_Post $post       Post object.
     */
    function _transition_post_status($new_status, $old_status, $post)
    {
    }
    /**
     * Hook used to schedule publication for a post marked for the future.
     *
     * The $post properties used and must exist are 'ID' and 'post_date_gmt'.
     *
     * @since 2.3.0
     * @access private
     *
     * @param int     $deprecated Not used. Can be set to null. Never implemented. Not marked
     *                            as deprecated with _deprecated_argument() as it conflicts with
     *                            wp_transition_post_status() and the default filter for _future_post_hook().
     * @param WP_Post $post       Post object.
     */
    function _future_post_hook($deprecated, $post)
    {
    }
    /**
     * Hook to schedule pings and enclosures when a post is published.
     *
     * Uses XMLRPC_REQUEST and WP_IMPORTING constants.
     *
     * @since 2.3.0
     * @access private
     *
     * @param int $post_id The ID of the post being published.
     * @phpstan-return void
     */
    function _publish_post_hook($post_id)
    {
    }
    /**
     * Returns the ID of the post's parent.
     *
     * @since 3.1.0
     * @since 5.9.0 The `$post` parameter was made optional.
     *
     * @param int|WP_Post|null $post Optional. Post ID or post object. Defaults to global $post.
     * @return int|false Post parent ID (which can be 0 if there is no parent),
     *                   or false if the post does not exist.
     */
    function wp_get_post_parent_id($post = \null)
    {
    }
    /**
     * Checks the given subset of the post hierarchy for hierarchy loops.
     *
     * Prevents loops from forming and breaks those that it finds. Attached
     * to the {@see 'wp_insert_post_parent'} filter.
     *
     * @since 3.1.0
     *
     * @see wp_find_hierarchy_loop()
     *
     * @param int $post_parent ID of the parent for the post we're checking.
     * @param int $post_id     ID of the post we're checking.
     * @return int The new post_parent for the post, 0 otherwise.
     */
    function wp_check_post_hierarchy_for_loops($post_parent, $post_id)
    {
    }
    /**
     * Sets the post thumbnail (featured image) for the given post.
     *
     * @since 3.1.0
     *
     * @param int|WP_Post $post         Post ID or post object where thumbnail should be attached.
     * @param int         $thumbnail_id Thumbnail to attach.
     * @return int|bool Post meta ID if the key didn't exist (ie. this is the first time that
     *                  a thumbnail has been saved for the post), true on successful update,
     *                  false on failure or if the value passed is the same as the one that
     *                  is already in the database.
     */
    function set_post_thumbnail($post, $thumbnail_id)
    {
    }
    /**
     * Removes the thumbnail (featured image) from the given post.
     *
     * @since 3.3.0
     *
     * @param int|WP_Post $post Post ID or post object from which the thumbnail should be removed.
     * @return bool True on success, false on failure.
     */
    function delete_post_thumbnail($post)
    {
    }
    /**
     * Deletes auto-drafts for new posts that are > 7 days old.
     *
     * @since 3.4.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function wp_delete_auto_drafts()
    {
    }
    /**
     * Queues posts for lazy-loading of term meta.
     *
     * @since 4.5.0
     *
     * @param WP_Post[] $posts Array of WP_Post objects.
     */
    function wp_queue_posts_for_term_meta_lazyload($posts)
    {
    }
    /**
     * Updates the custom taxonomies' term counts when a post's status is changed.
     *
     * For example, default posts term counts (for custom taxonomies) don't include
     * private / draft posts.
     *
     * @since 3.3.0
     * @access private
     *
     * @param string  $new_status New post status.
     * @param string  $old_status Old post status.
     * @param WP_Post $post       Post object.
     */
    function _update_term_count_on_transition_post_status($new_status, $old_status, $post)
    {
    }
    /**
     * Adds any posts from the given IDs to the cache that do not already exist in cache.
     *
     * @since 3.4.0
     * @since 6.1.0 This function is no longer marked as "private".
     *
     * @see update_post_cache()
     * @see update_postmeta_cache()
     * @see update_object_term_cache()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int[] $ids               ID list.
     * @param bool  $update_term_cache Optional. Whether to update the term cache. Default true.
     * @param bool  $update_meta_cache Optional. Whether to update the meta cache. Default true.
     */
    function _prime_post_caches($ids, $update_term_cache = \true, $update_meta_cache = \true)
    {
    }
    /**
     * Prime the cache containing the parent ID of various post objects.
     *
     * @since 6.4.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int[] $ids ID list.
     * @phpstan-return void
     */
    function _prime_post_parent_id_caches(array $ids)
    {
    }
    /**
     * Adds a suffix if any trashed posts have a given slug.
     *
     * Store its desired (i.e. current) slug so it can try to reclaim it
     * if the post is untrashed.
     *
     * For internal use.
     *
     * @since 4.5.0
     * @access private
     *
     * @param string $post_name Post slug.
     * @param int    $post_id   Optional. Post ID that should be ignored. Default 0.
     */
    function wp_add_trashed_suffix_to_post_name_for_trashed_posts($post_name, $post_id = 0)
    {
    }
    /**
     * Adds a trashed suffix for a given post.
     *
     * Store its desired (i.e. current) slug so it can try to reclaim it
     * if the post is untrashed.
     *
     * For internal use.
     *
     * @since 4.5.0
     * @access private
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param WP_Post $post The post.
     * @return string New slug for the post.
     */
    function wp_add_trashed_suffix_to_post_name_for_post($post)
    {
    }
    /**
     * Sets the last changed time for the 'posts' cache group.
     *
     * @since 5.0.0
     */
    function wp_cache_set_posts_last_changed()
    {
    }
    /**
     * Gets all available post MIME types for a given post type.
     *
     * @since 2.5.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $type
     * @return string[] An array of MIME types.
     */
    function get_available_post_mime_types($type = 'attachment')
    {
    }
    /**
     * Retrieves the path to an uploaded image file.
     *
     * Similar to `get_attached_file()` however some images may have been processed after uploading
     * to make them suitable for web use. In this case the attached "full" size file is usually replaced
     * with a scaled down version of the original image. This function always returns the path
     * to the originally uploaded image file.
     *
     * @since 5.3.0
     * @since 5.4.0 Added the `$unfiltered` parameter.
     *
     * @param int  $attachment_id Attachment ID.
     * @param bool $unfiltered Optional. Passed through to `get_attached_file()`. Default false.
     * @return string|false Path to the original image file or false if the attachment is not an image.
     */
    function wp_get_original_image_path($attachment_id, $unfiltered = \false)
    {
    }
    /**
     * Retrieves the URL to an original attachment image.
     *
     * Similar to `wp_get_attachment_url()` however some images may have been
     * processed after uploading. In this case this function returns the URL
     * to the originally uploaded image file.
     *
     * @since 5.3.0
     *
     * @param int $attachment_id Attachment post ID.
     * @return string|false Attachment image URL, false on error or if the attachment is not an image.
     */
    function wp_get_original_image_url($attachment_id)
    {
    }
    /**
     * Filters callback which sets the status of an untrashed post to its previous status.
     *
     * This can be used as a callback on the `wp_untrash_post_status` filter.
     *
     * @since 5.6.0
     *
     * @param string $new_status      The new status of the post being restored.
     * @param int    $post_id         The ID of the post being restored.
     * @param string $previous_status The status of the post at the point where it was trashed.
     * @return string The new status of the post.
     */
    function wp_untrash_post_set_previous_status($new_status, $post_id, $previous_status)
    {
    }
    /**
     * Returns whether the post can be edited in the block editor.
     *
     * @since 5.0.0
     * @since 6.1.0 Moved to wp-includes from wp-admin.
     *
     * @param int|WP_Post $post Post ID or WP_Post object.
     * @return bool Whether the post can be edited in the block editor.
     */
    function use_block_editor_for_post($post)
    {
    }
    /**
     * Returns whether a post type is compatible with the block editor.
     *
     * The block editor depends on the REST API, and if the post type is not shown in the
     * REST API, then it won't work with the block editor.
     *
     * @since 5.0.0
     * @since 6.1.0 Moved to wp-includes from wp-admin.
     *
     * @param string $post_type The post type.
     * @return bool Whether the post type can be edited with the block editor.
     */
    function use_block_editor_for_post_type($post_type)
    {
    }
    /**
     * Registers any additional post meta fields.
     *
     * @since 6.3.0 Adds `wp_pattern_sync_status` meta field to the wp_block post type so an unsynced option can be added.
     *
     * @link https://github.com/WordPress/gutenberg/pull/51144
     */
    function wp_create_initial_post_meta()
    {
    }
    /**
     * Retrieves the value of a query variable in the WP_Query class.
     *
     * @since 1.5.0
     * @since 3.9.0 The `$default_value` argument was introduced.
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string $query_var     The variable key to retrieve.
     * @param mixed  $default_value Optional. Value to return if the query variable is not set.
     *                              Default empty string.
     * @return mixed Contents of the query variable.
     */
    function get_query_var($query_var, $default_value = '')
    {
    }
    /**
     * Retrieves the currently queried object.
     *
     * Wrapper for WP_Query::get_queried_object().
     *
     * @since 3.1.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return WP_Term|WP_Post_Type|WP_Post|WP_User|null The queried object.
     */
    function get_queried_object()
    {
    }
    /**
     * Retrieves the ID of the currently queried object.
     *
     * Wrapper for WP_Query::get_queried_object_id().
     *
     * @since 3.1.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return int ID of the queried object.
     */
    function get_queried_object_id()
    {
    }
    /**
     * Sets the value of a query variable in the WP_Query class.
     *
     * @since 2.2.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string $query_var Query variable key.
     * @param mixed  $value     Query variable value.
     */
    function set_query_var($query_var, $value)
    {
    }
    /**
     * Sets up The Loop with query parameters.
     *
     * Note: This function will completely override the main query and isn't intended for use
     * by plugins or themes. Its overly-simplistic approach to modifying the main query can be
     * problematic and should be avoided wherever possible. In most cases, there are better,
     * more performant options for modifying the main query such as via the {@see 'pre_get_posts'}
     * action within WP_Query.
     *
     * This must not be used within the WordPress Loop.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param array|string $query Array or string of WP_Query arguments.
     * @return WP_Post[]|int[] Array of post objects or post IDs.
     */
    function query_posts($query)
    {
    }
    /**
     * Destroys the previous query and sets up a new query.
     *
     * This should be used after query_posts() and before another query_posts().
     * This will remove obscure bugs that occur when the previous WP_Query object
     * is not destroyed properly before another is set up.
     *
     * @since 2.3.0
     *
     * @global WP_Query $wp_query     WordPress Query object.
     * @global WP_Query $wp_the_query Copy of the global WP_Query instance created during wp_reset_query().
     */
    function wp_reset_query()
    {
    }
    /**
     * After looping through a separate query, this function restores
     * the $post global to the current post in the main query.
     *
     * @since 3.0.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     */
    function wp_reset_postdata()
    {
    }
    /**
     * Determines whether the query is for an existing archive page.
     *
     * Archive pages include category, tag, author, date, custom post type,
     * and custom taxonomy based archives.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @see is_category()
     * @see is_tag()
     * @see is_author()
     * @see is_date()
     * @see is_post_type_archive()
     * @see is_tax()
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for an existing archive page.
     */
    function is_archive()
    {
    }
    /**
     * Determines whether the query is for an existing post type archive page.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 3.1.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string|string[] $post_types Optional. Post type or array of posts types
     *                                    to check against. Default empty.
     * @return bool Whether the query is for an existing post type archive page.
     */
    function is_post_type_archive($post_types = '')
    {
    }
    /**
     * Determines whether the query is for an existing attachment page.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.0.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param int|string|int[]|string[] $attachment Optional. Attachment ID, title, slug, or array of such
     *                                              to check against. Default empty.
     * @return bool Whether the query is for an existing attachment page.
     */
    function is_attachment($attachment = '')
    {
    }
    /**
     * Determines whether the query is for an existing author archive page.
     *
     * If the $author parameter is specified, this function will additionally
     * check if the query is for one of the authors specified.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param int|string|int[]|string[] $author Optional. User ID, nickname, nicename, or array of such
     *                                          to check against. Default empty.
     * @return bool Whether the query is for an existing author archive page.
     */
    function is_author($author = '')
    {
    }
    /**
     * Determines whether the query is for an existing category archive page.
     *
     * If the $category parameter is specified, this function will additionally
     * check if the query is for one of the categories specified.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param int|string|int[]|string[] $category Optional. Category ID, name, slug, or array of such
     *                                            to check against. Default empty.
     * @return bool Whether the query is for an existing category archive page.
     */
    function is_category($category = '')
    {
    }
    /**
     * Determines whether the query is for an existing tag archive page.
     *
     * If the $tag parameter is specified, this function will additionally
     * check if the query is for one of the tags specified.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.3.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param int|string|int[]|string[] $tag Optional. Tag ID, name, slug, or array of such
     *                                       to check against. Default empty.
     * @return bool Whether the query is for an existing tag archive page.
     */
    function is_tag($tag = '')
    {
    }
    /**
     * Determines whether the query is for an existing custom taxonomy archive page.
     *
     * If the $taxonomy parameter is specified, this function will additionally
     * check if the query is for that specific $taxonomy.
     *
     * If the $term parameter is specified in addition to the $taxonomy parameter,
     * this function will additionally check if the query is for one of the terms
     * specified.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string|string[]           $taxonomy Optional. Taxonomy slug or slugs to check against.
     *                                            Default empty.
     * @param int|string|int[]|string[] $term     Optional. Term ID, name, slug, or array of such
     *                                            to check against. Default empty.
     * @return bool Whether the query is for an existing custom taxonomy archive page.
     *              True for custom taxonomy archive pages, false for built-in taxonomies
     *              (category and tag archives).
     */
    function is_tax($taxonomy = '', $term = '')
    {
    }
    /**
     * Determines whether the query is for an existing date archive.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for an existing date archive.
     */
    function is_date()
    {
    }
    /**
     * Determines whether the query is for an existing day archive.
     *
     * A conditional check to test whether the page is a date-based archive page displaying posts for the current day.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for an existing day archive.
     */
    function is_day()
    {
    }
    /**
     * Determines whether the query is for a feed.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string|string[] $feeds Optional. Feed type or array of feed types
     *                                         to check against. Default empty.
     * @return bool Whether the query is for a feed.
     */
    function is_feed($feeds = '')
    {
    }
    /**
     * Is the query for a comments feed?
     *
     * @since 3.0.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for a comments feed.
     */
    function is_comment_feed()
    {
    }
    /**
     * Determines whether the query is for the front page of the site.
     *
     * This is for what is displayed at your site's main URL.
     *
     * Depends on the site's "Front page displays" Reading Settings 'show_on_front' and 'page_on_front'.
     *
     * If you set a static page for the front page of your site, this function will return
     * true when viewing that page.
     *
     * Otherwise the same as {@see is_home()}.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for the front page of the site.
     */
    function is_front_page()
    {
    }
    /**
     * Determines whether the query is for the blog homepage.
     *
     * The blog homepage is the page that shows the time-based blog content of the site.
     *
     * is_home() is dependent on the site's "Front page displays" Reading Settings 'show_on_front'
     * and 'page_for_posts'.
     *
     * If a static page is set for the front page of the site, this function will return true only
     * on the page you set as the "Posts page".
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @see is_front_page()
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for the blog homepage.
     */
    function is_home()
    {
    }
    /**
     * Determines whether the query is for the Privacy Policy page.
     *
     * The Privacy Policy page is the page that shows the Privacy Policy content of the site.
     *
     * is_privacy_policy() is dependent on the site's "Change your Privacy Policy page" Privacy Settings 'wp_page_for_privacy_policy'.
     *
     * This function will return true only on the page you set as the "Privacy Policy page".
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 5.2.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for the Privacy Policy page.
     */
    function is_privacy_policy()
    {
    }
    /**
     * Determines whether the query is for an existing month archive.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for an existing month archive.
     */
    function is_month()
    {
    }
    /**
     * Determines whether the query is for an existing single page.
     *
     * If the $page parameter is specified, this function will additionally
     * check if the query is for one of the pages specified.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @see is_single()
     * @see is_singular()
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param int|string|int[]|string[] $page Optional. Page ID, title, slug, or array of such
     *                                        to check against. Default empty.
     * @return bool Whether the query is for an existing single page.
     */
    function is_page($page = '')
    {
    }
    /**
     * Determines whether the query is for a paged result and not for the first page.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for a paged result.
     */
    function is_paged()
    {
    }
    /**
     * Determines whether the query is for a post or page preview.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.0.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for a post or page preview.
     */
    function is_preview()
    {
    }
    /**
     * Is the query for the robots.txt file?
     *
     * @since 2.1.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for the robots.txt file.
     */
    function is_robots()
    {
    }
    /**
     * Is the query for the favicon.ico file?
     *
     * @since 5.4.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for the favicon.ico file.
     */
    function is_favicon()
    {
    }
    /**
     * Determines whether the query is for a search.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for a search.
     */
    function is_search()
    {
    }
    /**
     * Determines whether the query is for an existing single post.
     *
     * Works for any post type, except attachments and pages
     *
     * If the $post parameter is specified, this function will additionally
     * check if the query is for one of the Posts specified.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @see is_page()
     * @see is_singular()
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param int|string|int[]|string[] $post Optional. Post ID, title, slug, or array of such
     *                                        to check against. Default empty.
     * @return bool Whether the query is for an existing single post.
     */
    function is_single($post = '')
    {
    }
    /**
     * Determines whether the query is for an existing single post of any post type
     * (post, attachment, page, custom post types).
     *
     * If the $post_types parameter is specified, this function will additionally
     * check if the query is for one of the Posts Types specified.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @see is_page()
     * @see is_single()
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param string|string[] $post_types Optional. Post type or array of post types
     *                                    to check against. Default empty.
     * @return bool Whether the query is for an existing single post
     *              or any of the given post types.
     */
    function is_singular($post_types = '')
    {
    }
    /**
     * Determines whether the query is for a specific time.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for a specific time.
     */
    function is_time()
    {
    }
    /**
     * Determines whether the query is for a trackback endpoint call.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for a trackback endpoint call.
     */
    function is_trackback()
    {
    }
    /**
     * Determines whether the query is for an existing year archive.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for an existing year archive.
     */
    function is_year()
    {
    }
    /**
     * Determines whether the query has resulted in a 404 (returns no results).
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is a 404 error.
     */
    function is_404()
    {
    }
    /**
     * Is the query for an embedded post?
     *
     * @since 4.4.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is for an embedded post.
     */
    function is_embed()
    {
    }
    /**
     * Determines whether the query is the main query.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 3.3.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool Whether the query is the main query.
     */
    function is_main_query()
    {
    }
    /**
     * Determines whether current WordPress query has posts to loop over.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool True if posts are available, false if end of the loop.
     * @phpstan-impure
     */
    function have_posts()
    {
    }
    /**
     * Determines whether the caller is in the Loop.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.0.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool True if caller is within loop, false if loop hasn't started or ended.
     */
    function in_the_loop()
    {
    }
    /**
     * Rewind the loop posts.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     * @phpstan-return void
     */
    function rewind_posts()
    {
    }
    /**
     * Iterate the post index in the loop.
     *
     * @since 1.5.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     * @phpstan-return void
     */
    function the_post()
    {
    }
    /**
     * Determines whether current WordPress query has comments to loop over.
     *
     * @since 2.2.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @return bool True if comments are available, false if no more comments.
     */
    function have_comments()
    {
    }
    /**
     * Iterate comment index in the comment loop.
     *
     * @since 2.2.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     * @phpstan-return void
     */
    function the_comment()
    {
    }
    /**
     * Redirect old slugs to the correct permalink.
     *
     * Attempts to find the current slug from the past slugs.
     *
     * @since 2.1.0
     * @phpstan-return void
     */
    function wp_old_slug_redirect()
    {
    }
    /**
     * Find the post ID for redirecting an old slug.
     *
     * @since 4.9.3
     * @access private
     *
     * @see wp_old_slug_redirect()
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $post_type The current post type based on the query vars.
     * @return int The Post ID.
     */
    function _find_post_by_old_slug($post_type)
    {
    }
    /**
     * Find the post ID for redirecting an old date.
     *
     * @since 4.9.3
     * @access private
     *
     * @see wp_old_slug_redirect()
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $post_type The current post type based on the query vars.
     * @return int The Post ID.
     */
    function _find_post_by_old_date($post_type)
    {
    }
    /**
     * Set up global post data.
     *
     * @since 1.5.0
     * @since 4.4.0 Added the ability to pass a post ID to `$post`.
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param WP_Post|object|int $post WP_Post instance or Post ID/object.
     * @return bool True when finished.
     */
    function setup_postdata($post)
    {
    }
    /**
     * Generates post data.
     *
     * @since 5.2.0
     *
     * @global WP_Query $wp_query WordPress Query object.
     *
     * @param WP_Post|object|int $post WP_Post instance or Post ID/object.
     * @return array|false Elements of post, or false on failure.
     */
    function generate_postdata($post)
    {
    }
    /**
     * Registers a REST API route.
     *
     * Note: Do not use before the {@see 'rest_api_init'} hook.
     *
     * @since 4.4.0
     * @since 5.1.0 Added a `_doing_it_wrong()` notice when not called on or after the `rest_api_init` hook.
     * @since 5.5.0 Added a `_doing_it_wrong()` notice when the required `permission_callback` argument is not set.
     *
     * @param string $route_namespace The first URL segment after core prefix. Should be unique to your package/plugin.
     * @param string $route           The base URL for route you are adding.
     * @param array  $args            Optional. Either an array of options for the endpoint, or an array of arrays for
     *                                multiple methods. Default empty array.
     * @param bool   $override        Optional. If the route already exists, should we override it? True overrides,
     *                                false merges (with newer overriding if duplicate keys exist). Default false.
     * @return bool True on success, false on error.
     */
    function register_rest_route($route_namespace, $route, $args = array(), $override = \false)
    {
    }
    /**
     * Registers a new field on an existing WordPress object type.
     *
     * @since 4.7.0
     *
     * @global array $wp_rest_additional_fields Holds registered fields, organized
     *                                          by object type.
     *
     * @param string|array $object_type Object(s) the field is being registered to,
     *                                  "post"|"term"|"comment" etc.
     * @param string       $attribute   The attribute name.
     * @param array        $args {
     *     Optional. An array of arguments used to handle the registered field.
     *
     *     @type callable|null $get_callback    Optional. The callback function used to retrieve the field value. Default is
     *                                          'null', the field will not be returned in the response. The function will
     *                                          be passed the prepared object data.
     *     @type callable|null $update_callback Optional. The callback function used to set and update the field value. Default
     *                                          is 'null', the value cannot be set or updated. The function will be passed
     *                                          the model object, like WP_Post.
     *     @type array|null $schema             Optional. The schema for this field.
     *                                          Default is 'null', no schema entry will be returned.
     * }
     * @phpstan-param array{
     *   get_callback?: callable|null,
     *   update_callback?: callable|null,
     *   schema?: array|null,
     * } $args
     */
    function register_rest_field($object_type, $attribute, $args = array())
    {
    }
    /**
     * Registers rewrite rules for the REST API.
     *
     * @since 4.4.0
     *
     * @see rest_api_register_rewrites()
     * @global WP $wp Current WordPress environment instance.
     */
    function rest_api_init()
    {
    }
    /**
     * Adds REST rewrite rules.
     *
     * @since 4.4.0
     *
     * @see add_rewrite_rule()
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     */
    function rest_api_register_rewrites()
    {
    }
    /**
     * Registers the default REST API filters.
     *
     * Attached to the {@see 'rest_api_init'} action
     * to make testing and disabling these filters easier.
     *
     * @since 4.4.0
     */
    function rest_api_default_filters()
    {
    }
    /**
     * Registers default REST API routes.
     *
     * @since 4.7.0
     */
    function create_initial_rest_routes()
    {
    }
    /**
     * Loads the REST API.
     *
     * @since 4.4.0
     *
     * @global WP $wp Current WordPress environment instance.
     * @phpstan-return void
     */
    function rest_api_loaded()
    {
    }
    /**
     * Retrieves the URL prefix for any API resource.
     *
     * @since 4.4.0
     *
     * @return string Prefix.
     */
    function rest_get_url_prefix()
    {
    }
    /**
     * Retrieves the URL to a REST endpoint on a site.
     *
     * Note: The returned URL is NOT escaped.
     *
     * @since 4.4.0
     *
     * @todo Check if this is even necessary
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param int|null $blog_id Optional. Blog ID. Default of null returns URL for current blog.
     * @param string   $path    Optional. REST route. Default '/'.
     * @param string   $scheme  Optional. Sanitization scheme. Default 'rest'.
     * @return string Full URL to the endpoint.
     */
    function get_rest_url($blog_id = \null, $path = '/', $scheme = 'rest')
    {
    }
    /**
     * Retrieves the URL to a REST endpoint.
     *
     * Note: The returned URL is NOT escaped.
     *
     * @since 4.4.0
     *
     * @param string $path   Optional. REST route. Default empty.
     * @param string $scheme Optional. Sanitization scheme. Default 'rest'.
     * @return string Full URL to the endpoint.
     */
    function rest_url($path = '', $scheme = 'rest')
    {
    }
    /**
     * Do a REST request.
     *
     * Used primarily to route internal requests through WP_REST_Server.
     *
     * @since 4.4.0
     *
     * @param WP_REST_Request|string $request Request.
     * @return WP_REST_Response REST response.
     */
    function rest_do_request($request)
    {
    }
    /**
     * Retrieves the current REST server instance.
     *
     * Instantiates a new instance if none exists already.
     *
     * @since 4.5.0
     *
     * @global WP_REST_Server $wp_rest_server REST server instance.
     *
     * @return WP_REST_Server REST server instance.
     */
    function rest_get_server()
    {
    }
    /**
     * Ensures request arguments are a request object (for consistency).
     *
     * @since 4.4.0
     * @since 5.3.0 Accept string argument for the request path.
     *
     * @param array|string|WP_REST_Request $request Request to check.
     * @return WP_REST_Request REST request instance.
     */
    function rest_ensure_request($request)
    {
    }
    /**
     * Ensures a REST response is a response object (for consistency).
     *
     * This implements WP_REST_Response, allowing usage of `set_status`/`header`/etc
     * without needing to double-check the object. Will also allow WP_Error to indicate error
     * responses, so users should immediately check for this value.
     *
     * @since 4.4.0
     *
     * @param WP_REST_Response|WP_Error|WP_HTTP_Response|mixed $response Response to check.
     * @return WP_REST_Response|WP_Error If response generated an error, WP_Error, if response
     *                                   is already an instance, WP_REST_Response, otherwise
     *                                   returns a new WP_REST_Response instance.
     * @phpstan-return ($response is WP_Error ? WP_Error : WP_REST_Response)
     */
    function rest_ensure_response($response)
    {
    }
    /**
     * Handles _deprecated_function() errors.
     *
     * @since 4.4.0
     *
     * @param string $function_name The function that was called.
     * @param string $replacement   The function that should have been called.
     * @param string $version       Version.
     * @phpstan-return void
     */
    function rest_handle_deprecated_function($function_name, $replacement, $version)
    {
    }
    /**
     * Handles _deprecated_argument() errors.
     *
     * @since 4.4.0
     *
     * @param string $function_name The function that was called.
     * @param string $message       A message regarding the change.
     * @param string $version       Version.
     * @phpstan-return void
     */
    function rest_handle_deprecated_argument($function_name, $message, $version)
    {
    }
    /**
     * Handles _doing_it_wrong errors.
     *
     * @since 5.5.0
     *
     * @param string      $function_name The function that was called.
     * @param string      $message       A message explaining what has been done incorrectly.
     * @param string|null $version       The version of WordPress where the message was added.
     * @phpstan-return void
     */
    function rest_handle_doing_it_wrong($function_name, $message, $version)
    {
    }
    /**
     * Sends Cross-Origin Resource Sharing headers with API requests.
     *
     * @since 4.4.0
     *
     * @param mixed $value Response data.
     * @return mixed Response data.
     */
    function rest_send_cors_headers($value)
    {
    }
    /**
     * Handles OPTIONS requests for the server.
     *
     * This is handled outside of the server code, as it doesn't obey normal route
     * mapping.
     *
     * @since 4.4.0
     *
     * @param mixed           $response Current response, either response or `null` to indicate pass-through.
     * @param WP_REST_Server  $handler  ResponseHandler instance (usually WP_REST_Server).
     * @param WP_REST_Request $request  The request that was used to make current response.
     * @return WP_REST_Response Modified response, either response or `null` to indicate pass-through.
     */
    function rest_handle_options_request($response, $handler, $request)
    {
    }
    /**
     * Sends the "Allow" header to state all methods that can be sent to the current route.
     *
     * @since 4.4.0
     *
     * @param WP_REST_Response $response Current response being served.
     * @param WP_REST_Server   $server   ResponseHandler instance (usually WP_REST_Server).
     * @param WP_REST_Request  $request  The request that was used to make current response.
     * @return WP_REST_Response Response to be served, with "Allow" header if route has allowed methods.
     */
    function rest_send_allow_header($response, $server, $request)
    {
    }
    /**
     * Recursively computes the intersection of arrays using keys for comparison.
     *
     * @since 5.3.0
     *
     * @param array $array1 The array with master keys to check.
     * @param array $array2 An array to compare keys against.
     * @return array An associative array containing all the entries of array1 which have keys
     *               that are present in all arguments.
     */
    function _rest_array_intersect_key_recursive($array1, $array2)
    {
    }
    /**
     * Filters the REST API response to include only an allow-listed set of response object fields.
     *
     * @since 4.8.0
     *
     * @param WP_REST_Response $response Current response being served.
     * @param WP_REST_Server   $server   ResponseHandler instance (usually WP_REST_Server).
     * @param WP_REST_Request  $request  The request that was used to make current response.
     * @return WP_REST_Response Response to be served, trimmed down to contain a subset of fields.
     */
    function rest_filter_response_fields($response, $server, $request)
    {
    }
    /**
     * Given an array of fields to include in a response, some of which may be
     * `nested.fields`, determine whether the provided field should be included
     * in the response body.
     *
     * If a parent field is passed in, the presence of any nested field within
     * that parent will cause the method to return `true`. For example "title"
     * will return true if any of `title`, `title.raw` or `title.rendered` is
     * provided.
     *
     * @since 5.3.0
     *
     * @param string $field  A field to test for inclusion in the response body.
     * @param array  $fields An array of string fields supported by the endpoint.
     * @return bool Whether to include the field or not.
     */
    function rest_is_field_included($field, $fields)
    {
    }
    /**
     * Adds the REST API URL to the WP RSD endpoint.
     *
     * @since 4.4.0
     *
     * @see get_rest_url()
     * @phpstan-return void
     */
    function rest_output_rsd()
    {
    }
    /**
     * Outputs the REST API link tag into page header.
     *
     * @since 4.4.0
     *
     * @see get_rest_url()
     * @phpstan-return void
     */
    function rest_output_link_wp_head()
    {
    }
    /**
     * Sends a Link header for the REST API.
     *
     * @since 4.4.0
     * @phpstan-return void
     */
    function rest_output_link_header()
    {
    }
    /**
     * Checks for errors when using cookie-based authentication.
     *
     * WordPress' built-in cookie authentication is always active
     * for logged in users. However, the API has to check nonces
     * for each request to ensure users are not vulnerable to CSRF.
     *
     * @since 4.4.0
     *
     * @global mixed          $wp_rest_auth_cookie
     *
     * @param WP_Error|mixed $result Error from another authentication handler,
     *                               null if we should handle it, or another value if not.
     * @return WP_Error|mixed|bool WP_Error if the cookie is invalid, the $result, otherwise true.
     */
    function rest_cookie_check_errors($result)
    {
    }
    /**
     * Collects cookie authentication status.
     *
     * Collects errors from wp_validate_auth_cookie for use by rest_cookie_check_errors.
     *
     * @since 4.4.0
     *
     * @see current_action()
     * @global mixed $wp_rest_auth_cookie
     * @phpstan-return void
     */
    function rest_cookie_collect_status()
    {
    }
    /**
     * Collects the status of authenticating with an application password.
     *
     * @since 5.6.0
     * @since 5.7.0 Added the `$app_password` parameter.
     *
     * @global WP_User|WP_Error|null $wp_rest_application_password_status
     * @global string|null $wp_rest_application_password_uuid
     *
     * @param WP_Error $user_or_error The authenticated user or error instance.
     * @param array    $app_password  The Application Password used to authenticate.
     */
    function rest_application_password_collect_status($user_or_error, $app_password = array())
    {
    }
    /**
     * Gets the Application Password used for authenticating the request.
     *
     * @since 5.7.0
     *
     * @global string|null $wp_rest_application_password_uuid
     *
     * @return string|null The Application Password UUID, or null if Application Passwords was not used.
     */
    function rest_get_authenticated_app_password()
    {
    }
    /**
     * Checks for errors when using application password-based authentication.
     *
     * @since 5.6.0
     *
     * @global WP_User|WP_Error|null $wp_rest_application_password_status
     *
     * @param WP_Error|null|true $result Error from another authentication handler,
     *                                   null if we should handle it, or another value if not.
     * @return WP_Error|null|true WP_Error if the application password is invalid, the $result, otherwise true.
     */
    function rest_application_password_check_errors($result)
    {
    }
    /**
     * Adds Application Passwords info to the REST API index.
     *
     * @since 5.6.0
     *
     * @param WP_REST_Response $response The index response object.
     * @return WP_REST_Response
     */
    function rest_add_application_passwords_to_index($response)
    {
    }
    /**
     * Retrieves the avatar URLs in various sizes.
     *
     * @since 4.7.0
     *
     * @see get_avatar_url()
     *
     * @param mixed $id_or_email The avatar to retrieve a URL for. Accepts a user ID, Gravatar MD5 hash,
     *                           user email, WP_User object, WP_Post object, or WP_Comment object.
     * @return (string|false)[] Avatar URLs keyed by size. Each value can be a URL string or boolean false.
     */
    function rest_get_avatar_urls($id_or_email)
    {
    }
    /**
     * Retrieves the pixel sizes for avatars.
     *
     * @since 4.7.0
     *
     * @return int[] List of pixel sizes for avatars. Default `[ 24, 48, 96 ]`.
     */
    function rest_get_avatar_sizes()
    {
    }
    /**
     * Parses an RFC3339 time into a Unix timestamp.
     *
     * Explicitly check for `false` to detect failure, as zero is a valid return
     * value on success.
     *
     * @since 4.4.0
     *
     * @param string $date      RFC3339 timestamp.
     * @param bool   $force_utc Optional. Whether to force UTC timezone instead of using
     *                          the timestamp's timezone. Default false.
     * @return int|false Unix timestamp on success, false on failure.
     */
    function rest_parse_date($date, $force_utc = \false)
    {
    }
    /**
     * Parses a 3 or 6 digit hex color (with #).
     *
     * @since 5.4.0
     *
     * @param string $color 3 or 6 digit hex color (with #).
     * @return string|false Color value on success, false on failure.
     */
    function rest_parse_hex_color($color)
    {
    }
    /**
     * Parses a date into both its local and UTC equivalent, in MySQL datetime format.
     *
     * @since 4.4.0
     *
     * @see rest_parse_date()
     *
     * @param string $date   RFC3339 timestamp.
     * @param bool   $is_utc Whether the provided date should be interpreted as UTC. Default false.
     * @return array|null {
     *     Local and UTC datetime strings, in MySQL datetime format (Y-m-d H:i:s),
     *     null on failure.
     *
     *     @type string $0 Local datetime string.
     *     @type string $1 UTC datetime string.
     * }
     * @phpstan-return null|array{
     *   0: string,
     *   1: string,
     * }
     */
    function rest_get_date_with_gmt($date, $is_utc = \false)
    {
    }
    /**
     * Returns a contextual HTTP error code for authorization failure.
     *
     * @since 4.7.0
     *
     * @return int 401 if the user is not logged in, 403 if the user is logged in.
     */
    function rest_authorization_required_code()
    {
    }
    /**
     * Validate a request argument based on details registered to the route.
     *
     * @since 4.7.0
     *
     * @param mixed           $value
     * @param WP_REST_Request $request
     * @param string          $param
     * @return true|WP_Error
     */
    function rest_validate_request_arg($value, $request, $param)
    {
    }
    /**
     * Sanitize a request argument based on details registered to the route.
     *
     * @since 4.7.0
     *
     * @param mixed           $value
     * @param WP_REST_Request $request
     * @param string          $param
     * @return mixed
     */
    function rest_sanitize_request_arg($value, $request, $param)
    {
    }
    /**
     * Parse a request argument based on details registered to the route.
     *
     * Runs a validation check and sanitizes the value, primarily to be used via
     * the `sanitize_callback` arguments in the endpoint args registration.
     *
     * @since 4.7.0
     *
     * @param mixed           $value
     * @param WP_REST_Request $request
     * @param string          $param
     * @return mixed
     */
    function rest_parse_request_arg($value, $request, $param)
    {
    }
    /**
     * Determines if an IP address is valid.
     *
     * Handles both IPv4 and IPv6 addresses.
     *
     * @since 4.7.0
     *
     * @param string $ip IP address.
     * @return string|false The valid IP address, otherwise false.
     */
    function rest_is_ip_address($ip)
    {
    }
    /**
     * Changes a boolean-like value into the proper boolean value.
     *
     * @since 4.7.0
     *
     * @param bool|string|int $value The value being evaluated.
     * @return bool Returns the proper associated boolean value.
     */
    function rest_sanitize_boolean($value)
    {
    }
    /**
     * Determines if a given value is boolean-like.
     *
     * @since 4.7.0
     *
     * @param bool|string $maybe_bool The value being evaluated.
     * @return bool True if a boolean, otherwise false.
     */
    function rest_is_boolean($maybe_bool)
    {
    }
    /**
     * Determines if a given value is integer-like.
     *
     * @since 5.5.0
     *
     * @param mixed $maybe_integer The value being evaluated.
     * @return bool True if an integer, otherwise false.
     */
    function rest_is_integer($maybe_integer)
    {
    }
    /**
     * Determines if a given value is array-like.
     *
     * @since 5.5.0
     *
     * @param mixed $maybe_array The value being evaluated.
     * @return bool
     */
    function rest_is_array($maybe_array)
    {
    }
    /**
     * Converts an array-like value to an array.
     *
     * @since 5.5.0
     *
     * @param mixed $maybe_array The value being evaluated.
     * @return array Returns the array extracted from the value.
     */
    function rest_sanitize_array($maybe_array)
    {
    }
    /**
     * Determines if a given value is object-like.
     *
     * @since 5.5.0
     *
     * @param mixed $maybe_object The value being evaluated.
     * @return bool True if object like, otherwise false.
     */
    function rest_is_object($maybe_object)
    {
    }
    /**
     * Converts an object-like value to an array.
     *
     * @since 5.5.0
     *
     * @param mixed $maybe_object The value being evaluated.
     * @return array Returns the object extracted from the value as an associative array.
     */
    function rest_sanitize_object($maybe_object)
    {
    }
    /**
     * Gets the best type for a value.
     *
     * @since 5.5.0
     *
     * @param mixed    $value The value to check.
     * @param string[] $types The list of possible types.
     * @return string The best matching type, an empty string if no types match.
     */
    function rest_get_best_type_for_value($value, $types)
    {
    }
    /**
     * Handles getting the best type for a multi-type schema.
     *
     * This is a wrapper for {@see rest_get_best_type_for_value()} that handles
     * backward compatibility for schemas that use invalid types.
     *
     * @since 5.5.0
     *
     * @param mixed  $value The value to check.
     * @param array  $args  The schema array to use.
     * @param string $param The parameter name, used in error messages.
     * @return string
     */
    function rest_handle_multi_type_schema($value, $args, $param = '')
    {
    }
    /**
     * Checks if an array is made up of unique items.
     *
     * @since 5.5.0
     *
     * @param array $input_array The array to check.
     * @return bool True if the array contains unique items, false otherwise.
     */
    function rest_validate_array_contains_unique_items($input_array)
    {
    }
    /**
     * Stabilizes a value following JSON Schema semantics.
     *
     * For lists, order is preserved. For objects, properties are reordered alphabetically.
     *
     * @since 5.5.0
     *
     * @param mixed $value The value to stabilize. Must already be sanitized. Objects should have been converted to arrays.
     * @return mixed The stabilized value.
     */
    function rest_stabilize_value($value)
    {
    }
    /**
     * Validates if the JSON Schema pattern matches a value.
     *
     * @since 5.6.0
     *
     * @param string $pattern The pattern to match against.
     * @param string $value   The value to check.
     * @return bool           True if the pattern matches the given value, false otherwise.
     */
    function rest_validate_json_schema_pattern($pattern, $value)
    {
    }
    /**
     * Finds the schema for a property using the patternProperties keyword.
     *
     * @since 5.6.0
     *
     * @param string $property The property name to check.
     * @param array  $args     The schema array to use.
     * @return array|null      The schema of matching pattern property, or null if no patterns match.
     */
    function rest_find_matching_pattern_property_schema($property, $args)
    {
    }
    /**
     * Formats a combining operation error into a WP_Error object.
     *
     * @since 5.6.0
     *
     * @param string $param The parameter name.
     * @param array $error  The error details.
     * @return WP_Error
     */
    function rest_format_combining_operation_error($param, $error)
    {
    }
    /**
     * Gets the error of combining operation.
     *
     * @since 5.6.0
     *
     * @param array  $value  The value to validate.
     * @param string $param  The parameter name, used in error messages.
     * @param array  $errors The errors array, to search for possible error.
     * @return WP_Error      The combining operation error.
     */
    function rest_get_combining_operation_error($value, $param, $errors)
    {
    }
    /**
     * Finds the matching schema among the "anyOf" schemas.
     *
     * @since 5.6.0
     *
     * @param mixed  $value   The value to validate.
     * @param array  $args    The schema array to use.
     * @param string $param   The parameter name, used in error messages.
     * @return array|WP_Error The matching schema or WP_Error instance if all schemas do not match.
     */
    function rest_find_any_matching_schema($value, $args, $param)
    {
    }
    /**
     * Finds the matching schema among the "oneOf" schemas.
     *
     * @since 5.6.0
     *
     * @param mixed  $value                  The value to validate.
     * @param array  $args                   The schema array to use.
     * @param string $param                  The parameter name, used in error messages.
     * @param bool   $stop_after_first_match Optional. Whether the process should stop after the first successful match.
     * @return array|WP_Error                The matching schema or WP_Error instance if the number of matching schemas is not equal to one.
     */
    function rest_find_one_matching_schema($value, $args, $param, $stop_after_first_match = \false)
    {
    }
    /**
     * Checks the equality of two values, following JSON Schema semantics.
     *
     * Property order is ignored for objects.
     *
     * Values must have been previously sanitized/coerced to their native types.
     *
     * @since 5.7.0
     *
     * @param mixed $value1 The first value to check.
     * @param mixed $value2 The second value to check.
     * @return bool True if the values are equal or false otherwise.
     */
    function rest_are_values_equal($value1, $value2)
    {
    }
    /**
     * Validates that the given value is a member of the JSON Schema "enum".
     *
     * @since 5.7.0
     *
     * @param mixed  $value  The value to validate.
     * @param array  $args   The schema array to use.
     * @param string $param  The parameter name, used in error messages.
     * @return true|WP_Error True if the "enum" contains the value or a WP_Error instance otherwise.
     */
    function rest_validate_enum($value, $args, $param)
    {
    }
    /**
     * Get all valid JSON schema properties.
     *
     * @since 5.6.0
     *
     * @return string[] All valid JSON schema properties.
     */
    function rest_get_allowed_schema_keywords()
    {
    }
    /**
     * Validate a value based on a schema.
     *
     * @since 4.7.0
     * @since 4.9.0 Support the "object" type.
     * @since 5.2.0 Support validating "additionalProperties" against a schema.
     * @since 5.3.0 Support multiple types.
     * @since 5.4.0 Convert an empty string to an empty object.
     * @since 5.5.0 Add the "uuid" and "hex-color" formats.
     *              Support the "minLength", "maxLength" and "pattern" keywords for strings.
     *              Support the "minItems", "maxItems" and "uniqueItems" keywords for arrays.
     *              Validate required properties.
     * @since 5.6.0 Support the "minProperties" and "maxProperties" keywords for objects.
     *              Support the "multipleOf" keyword for numbers and integers.
     *              Support the "patternProperties" keyword for objects.
     *              Support the "anyOf" and "oneOf" keywords.
     *
     * @param mixed  $value The value to validate.
     * @param array  $args  Schema array to use for validation.
     * @param string $param The parameter name, used in error messages.
     * @return true|WP_Error
     */
    function rest_validate_value_from_schema($value, $args, $param = '')
    {
    }
    /**
     * Validates a null value based on a schema.
     *
     * @since 5.7.0
     *
     * @param mixed  $value The value to validate.
     * @param string $param The parameter name, used in error messages.
     * @return true|WP_Error
     */
    function rest_validate_null_value_from_schema($value, $param)
    {
    }
    /**
     * Validates a boolean value based on a schema.
     *
     * @since 5.7.0
     *
     * @param mixed  $value The value to validate.
     * @param string $param The parameter name, used in error messages.
     * @return true|WP_Error
     */
    function rest_validate_boolean_value_from_schema($value, $param)
    {
    }
    /**
     * Validates an object value based on a schema.
     *
     * @since 5.7.0
     *
     * @param mixed  $value The value to validate.
     * @param array  $args  Schema array to use for validation.
     * @param string $param The parameter name, used in error messages.
     * @return true|WP_Error
     */
    function rest_validate_object_value_from_schema($value, $args, $param)
    {
    }
    /**
     * Validates an array value based on a schema.
     *
     * @since 5.7.0
     *
     * @param mixed  $value The value to validate.
     * @param array  $args  Schema array to use for validation.
     * @param string $param The parameter name, used in error messages.
     * @return true|WP_Error
     */
    function rest_validate_array_value_from_schema($value, $args, $param)
    {
    }
    /**
     * Validates a number value based on a schema.
     *
     * @since 5.7.0
     *
     * @param mixed  $value The value to validate.
     * @param array  $args  Schema array to use for validation.
     * @param string $param The parameter name, used in error messages.
     * @return true|WP_Error
     */
    function rest_validate_number_value_from_schema($value, $args, $param)
    {
    }
    /**
     * Validates a string value based on a schema.
     *
     * @since 5.7.0
     *
     * @param mixed  $value The value to validate.
     * @param array  $args  Schema array to use for validation.
     * @param string $param The parameter name, used in error messages.
     * @return true|WP_Error
     */
    function rest_validate_string_value_from_schema($value, $args, $param)
    {
    }
    /**
     * Validates an integer value based on a schema.
     *
     * @since 5.7.0
     *
     * @param mixed  $value The value to validate.
     * @param array  $args  Schema array to use for validation.
     * @param string $param The parameter name, used in error messages.
     * @return true|WP_Error
     */
    function rest_validate_integer_value_from_schema($value, $args, $param)
    {
    }
    /**
     * Sanitize a value based on a schema.
     *
     * @since 4.7.0
     * @since 5.5.0 Added the `$param` parameter.
     * @since 5.6.0 Support the "anyOf" and "oneOf" keywords.
     * @since 5.9.0 Added `text-field` and `textarea-field` formats.
     *
     * @param mixed  $value The value to sanitize.
     * @param array  $args  Schema array to use for sanitization.
     * @param string $param The parameter name, used in error messages.
     * @return mixed|WP_Error The sanitized value or a WP_Error instance if the value cannot be safely sanitized.
     */
    function rest_sanitize_value_from_schema($value, $args, $param = '')
    {
    }
    /**
     * Append result of internal request to REST API for purpose of preloading data to be attached to a page.
     * Expected to be called in the context of `array_reduce`.
     *
     * @since 5.0.0
     *
     * @param array  $memo Reduce accumulator.
     * @param string $path REST API path to preload.
     * @return array Modified reduce accumulator.
     */
    function rest_preload_api_request($memo, $path)
    {
    }
    /**
     * Parses the "_embed" parameter into the list of resources to embed.
     *
     * @since 5.4.0
     *
     * @param string|array $embed Raw "_embed" parameter value.
     * @return true|string[] Either true to embed all embeds, or a list of relations to embed.
     */
    function rest_parse_embed_param($embed)
    {
    }
    /**
     * Filters the response to remove any fields not available in the given context.
     *
     * @since 5.5.0
     * @since 5.6.0 Support the "patternProperties" keyword for objects.
     *              Support the "anyOf" and "oneOf" keywords.
     *
     * @param array|object $response_data The response data to modify.
     * @param array        $schema        The schema for the endpoint used to filter the response.
     * @param string       $context       The requested context.
     * @return array|object The filtered response data.
     */
    function rest_filter_response_by_context($response_data, $schema, $context)
    {
    }
    /**
     * Sets the "additionalProperties" to false by default for all object definitions in the schema.
     *
     * @since 5.5.0
     * @since 5.6.0 Support the "patternProperties" keyword.
     *
     * @param array $schema The schema to modify.
     * @return array The modified schema.
     */
    function rest_default_additional_properties_to_false($schema)
    {
    }
    /**
     * Gets the REST API route for a post.
     *
     * @since 5.5.0
     *
     * @param int|WP_Post $post Post ID or post object.
     * @return string The route path with a leading slash for the given post,
     *                or an empty string if there is not a route.
     */
    function rest_get_route_for_post($post)
    {
    }
    /**
     * Gets the REST API route for a post type.
     *
     * @since 5.9.0
     *
     * @param string $post_type The name of a registered post type.
     * @return string The route path with a leading slash for the given post type,
     *                or an empty string if there is not a route.
     */
    function rest_get_route_for_post_type_items($post_type)
    {
    }
    /**
     * Gets the REST API route for a term.
     *
     * @since 5.5.0
     *
     * @param int|WP_Term $term Term ID or term object.
     * @return string The route path with a leading slash for the given term,
     *                or an empty string if there is not a route.
     */
    function rest_get_route_for_term($term)
    {
    }
    /**
     * Gets the REST API route for a taxonomy.
     *
     * @since 5.9.0
     *
     * @param string $taxonomy Name of taxonomy.
     * @return string The route path with a leading slash for the given taxonomy.
     */
    function rest_get_route_for_taxonomy_items($taxonomy)
    {
    }
    /**
     * Gets the REST route for the currently queried object.
     *
     * @since 5.5.0
     *
     * @return string The REST route of the resource, or an empty string if no resource identified.
     */
    function rest_get_queried_resource_route()
    {
    }
    /**
     * Retrieves an array of endpoint arguments from the item schema and endpoint method.
     *
     * @since 5.6.0
     *
     * @param array  $schema The full JSON schema for the endpoint.
     * @param string $method Optional. HTTP method of the endpoint. The arguments for `CREATABLE` endpoints are
     *                       checked for required values and may fall-back to a given default, this is not done
     *                       on `EDITABLE` endpoints. Default WP_REST_Server::CREATABLE.
     * @return array The endpoint arguments.
     */
    function rest_get_endpoint_args_for_schema($schema, $method = \WP_REST_Server::CREATABLE)
    {
    }
    /**
     * Converts an error to a response object.
     *
     * This iterates over all error codes and messages to change it into a flat
     * array. This enables simpler client behavior, as it is represented as a
     * list in JSON rather than an object/map.
     *
     * @since 5.7.0
     *
     * @param WP_Error $error WP_Error instance.
     *
     * @return WP_REST_Response List of associative arrays with code and message keys.
     */
    function rest_convert_error_to_response($error)
    {
    }
    /**
     * Checks whether a REST API endpoint request is currently being handled.
     *
     * This may be a standalone REST API request, or an internal request dispatched from within a regular page load.
     *
     * @since 6.5.0
     *
     * @global WP_REST_Server $wp_rest_server REST server instance.
     *
     * @return bool True if a REST endpoint request is currently being handled, false otherwise.
     */
    function wp_is_rest_endpoint()
    {
    }
    /**
     * Determines which fields of posts are to be saved in revisions.
     *
     * @since 2.6.0
     * @since 4.5.0 A `WP_Post` object can now be passed to the `$post` parameter.
     * @since 4.5.0 The optional `$autosave` parameter was deprecated and renamed to `$deprecated`.
     * @access private
     *
     * @param array|WP_Post $post       Optional. A post array or a WP_Post object being processed
     *                                  for insertion as a post revision. Default empty array.
     * @param bool          $deprecated Not used.
     * @return string[] Array of fields that can be versioned.
     */
    function _wp_post_revision_fields($post = array(), $deprecated = \false)
    {
    }
    /**
     * Returns a post array ready to be inserted into the posts table as a post revision.
     *
     * @since 4.5.0
     * @access private
     *
     * @param array|WP_Post $post     Optional. A post array or a WP_Post object to be processed
     *                                for insertion as a post revision. Default empty array.
     * @param bool          $autosave Optional. Is the revision an autosave? Default false.
     * @return array Post array ready to be inserted as a post revision.
     */
    function _wp_post_revision_data($post = array(), $autosave = \false)
    {
    }
    /**
     * Saves revisions for a post after all changes have been made.
     *
     * @since 6.4.0
     *
     * @param int     $post_id The post id that was inserted.
     * @param WP_Post $post    The post object that was inserted.
     * @param bool    $update  Whether this insert is updating an existing post.
     * @phpstan-return void
     */
    function wp_save_post_revision_on_insert($post_id, $post, $update)
    {
    }
    /**
     * Creates a revision for the current version of a post.
     *
     * Typically used immediately after a post update, as every update is a revision,
     * and the most recent revision always matches the current post.
     *
     * @since 2.6.0
     *
     * @param int $post_id The ID of the post to save as a revision.
     * @return int|WP_Error|void Void or 0 if error, new revision ID, if success.
     */
    function wp_save_post_revision($post_id)
    {
    }
    /**
     * Retrieves the autosaved data of the specified post.
     *
     * Returns a post object with the information that was autosaved for the specified post.
     * If the optional $user_id is passed, returns the autosave for that user, otherwise
     * returns the latest autosave.
     *
     * @since 2.6.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $post_id The post ID.
     * @param int $user_id Optional. The post author ID. Default 0.
     * @return WP_Post|false The autosaved data or false on failure or when no autosave exists.
     */
    function wp_get_post_autosave($post_id, $user_id = 0)
    {
    }
    /**
     * Determines if the specified post is a revision.
     *
     * @since 2.6.0
     *
     * @param int|WP_Post $post Post ID or post object.
     * @return int|false ID of revision's parent on success, false if not a revision.
     */
    function wp_is_post_revision($post)
    {
    }
    /**
     * Determines if the specified post is an autosave.
     *
     * @since 2.6.0
     *
     * @param int|WP_Post $post Post ID or post object.
     * @return int|false ID of autosave's parent on success, false if not a revision.
     */
    function wp_is_post_autosave($post)
    {
    }
    /**
     * Inserts post data into the posts table as a post revision.
     *
     * @since 2.6.0
     * @access private
     *
     * @param int|WP_Post|array|null $post     Post ID, post object OR post array.
     * @param bool                   $autosave Optional. Whether the revision is an autosave or not.
     *                                         Default false.
     * @return int|WP_Error WP_Error or 0 if error, new revision ID if success.
     */
    function _wp_put_post_revision($post = \null, $autosave = \false)
    {
    }
    /**
     * Save the revisioned meta fields.
     *
     * @since 6.4.0
     *
     * @param int $revision_id The ID of the revision to save the meta to.
     * @param int $post_id     The ID of the post the revision is associated with.
     * @phpstan-return void
     */
    function wp_save_revisioned_meta_fields($revision_id, $post_id)
    {
    }
    /**
     * Gets a post revision.
     *
     * @since 2.6.0
     *
     * @param int|WP_Post $post   Post ID or post object.
     * @param string      $output Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
     *                            correspond to a WP_Post object, an associative array, or a numeric array,
     *                            respectively. Default OBJECT.
     * @param string      $filter Optional sanitization filter. See sanitize_post(). Default 'raw'.
     * @return WP_Post|array|null WP_Post (or array) on success, or null on failure.
     */
    function wp_get_post_revision(&$post, $output = \OBJECT, $filter = 'raw')
    {
    }
    /**
     * Restores a post to the specified revision.
     *
     * Can restore a past revision using all fields of the post revision, or only selected fields.
     *
     * @since 2.6.0
     *
     * @param int|WP_Post $revision Revision ID or revision object.
     * @param array       $fields   Optional. What fields to restore from. Defaults to all.
     * @return int|false|null Null if error, false if no fields to restore, (int) post ID if success.
     */
    function wp_restore_post_revision($revision, $fields = \null)
    {
    }
    /**
     * Restore the revisioned meta values for a post.
     *
     * @since 6.4.0
     *
     * @param int $post_id     The ID of the post to restore the meta to.
     * @param int $revision_id The ID of the revision to restore the meta from.
     * @phpstan-return void
     */
    function wp_restore_post_revision_meta($post_id, $revision_id)
    {
    }
    /**
     * Copy post meta for the given key from one post to another.
     *
     * @since 6.4.0
     *
     * @param int    $source_post_id Post ID to copy meta value(s) from.
     * @param int    $target_post_id Post ID to copy meta value(s) to.
     * @param string $meta_key       Meta key to copy.
     */
    function _wp_copy_post_meta($source_post_id, $target_post_id, $meta_key)
    {
    }
    /**
     * Determine which post meta fields should be revisioned.
     *
     * @since 6.4.0
     *
     * @param string $post_type The post type being revisioned.
     * @return array An array of meta keys to be revisioned.
     */
    function wp_post_revision_meta_keys($post_type)
    {
    }
    /**
     * Check whether revisioned post meta fields have changed.
     *
     * @since 6.4.0
     *
     * @param bool    $post_has_changed Whether the post has changed.
     * @param WP_Post $last_revision    The last revision post object.
     * @param WP_Post $post             The post object.
     * @return bool Whether the post has changed.
     */
    function wp_check_revisioned_meta_fields_have_changed($post_has_changed, \WP_Post $last_revision, \WP_Post $post)
    {
    }
    /**
     * Deletes a revision.
     *
     * Deletes the row from the posts table corresponding to the specified revision.
     *
     * @since 2.6.0
     *
     * @param int|WP_Post $revision Revision ID or revision object.
     * @return WP_Post|false|null Null or false if error, deleted post object if success.
     */
    function wp_delete_post_revision($revision)
    {
    }
    /**
     * Returns all revisions of specified post.
     *
     * @since 2.6.0
     *
     * @see get_children()
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global `$post`.
     * @param array|null  $args Optional. Arguments for retrieving post revisions. Default null.
     * @return WP_Post[]|int[] Array of revision objects or IDs, or an empty array if none.
     */
    function wp_get_post_revisions($post = 0, $args = \null)
    {
    }
    /**
     * Returns the latest revision ID and count of revisions for a post.
     *
     * @since 6.1.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return array|WP_Error {
     *     Returns associative array with latest revision ID and total count,
     *     or a WP_Error if the post does not exist or revisions are not enabled.
     *
     *     @type int $latest_id The latest revision post ID or 0 if no revisions exist.
     *     @type int $count     The total count of revisions for the given post.
     * }
     * @phpstan-return \WP_Error|array{
     *   latest_id: int,
     *   count: int,
     * }
     */
    function wp_get_latest_revision_id_and_total_count($post = 0)
    {
    }
    /**
     * Returns the url for viewing and potentially restoring revisions of a given post.
     *
     * @since 5.9.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global `$post`.
     * @return string|null The URL for editing revisions on the given post, otherwise null.
     */
    function wp_get_post_revisions_url($post = 0)
    {
    }
    /**
     * Determines whether revisions are enabled for a given post.
     *
     * @since 3.6.0
     *
     * @param WP_Post $post The post object.
     * @return bool True if number of revisions to keep isn't zero, false otherwise.
     */
    function wp_revisions_enabled($post)
    {
    }
    /**
     * Determines how many revisions to retain for a given post.
     *
     * By default, an infinite number of revisions are kept.
     *
     * The constant WP_POST_REVISIONS can be set in wp-config to specify the limit
     * of revisions to keep.
     *
     * @since 3.6.0
     *
     * @param WP_Post $post The post object.
     * @return int The number of revisions to keep.
     */
    function wp_revisions_to_keep($post)
    {
    }
    /**
     * Sets up the post object for preview based on the post autosave.
     *
     * @since 2.7.0
     * @access private
     *
     * @param WP_Post $post
     * @return WP_Post|false
     */
    function _set_preview($post)
    {
    }
    /**
     * Filters the latest content for preview from the post autosave.
     *
     * @since 2.7.0
     * @access private
     */
    function _show_post_preview()
    {
    }
    /**
     * Filters terms lookup to set the post format.
     *
     * @since 3.6.0
     * @access private
     *
     * @param array  $terms
     * @param int    $post_id
     * @param string $taxonomy
     * @return array
     */
    function _wp_preview_terms_filter($terms, $post_id, $taxonomy)
    {
    }
    /**
     * Filters post thumbnail lookup to set the post thumbnail.
     *
     * @since 4.6.0
     * @access private
     *
     * @param null|array|string $value    The value to return - a single metadata value, or an array of values.
     * @param int               $post_id  Post ID.
     * @param string            $meta_key Meta key.
     * @return null|array The default return value or the post thumbnail meta array.
     */
    function _wp_preview_post_thumbnail_filter($value, $post_id, $meta_key)
    {
    }
    /**
     * Gets the post revision version.
     *
     * @since 3.6.0
     * @access private
     *
     * @param WP_Post $revision
     * @return int|false
     */
    function _wp_get_post_revision_version($revision)
    {
    }
    /**
     * Upgrades the revisions author, adds the current post as a revision and sets the revisions version to 1.
     *
     * @since 3.6.0
     * @access private
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param WP_Post $post      Post object.
     * @param array   $revisions Current revisions of the post.
     * @return bool true if the revisions were upgraded, false if problems.
     */
    function _wp_upgrade_revisions_of_post($post, $revisions)
    {
    }
    /**
     * Filters preview post meta retrieval to get values from the autosave.
     *
     * Filters revisioned meta keys only.
     *
     * @since 6.4.0
     *
     * @param mixed  $value     Meta value to filter.
     * @param int    $object_id Object ID.
     * @param string $meta_key  Meta key to filter a value for.
     * @param bool   $single    Whether to return a single value.
     * @return mixed Original meta value if the meta key isn't revisioned, the object doesn't exist,
     *               the post type is a revision or the post ID doesn't match the object ID.
     *               Otherwise, the revisioned meta value is returned for the preview.
     */
    function _wp_preview_meta_filter($value, $object_id, $meta_key, $single)
    {
    }
    /**
     * Adds a rewrite rule that transforms a URL structure to a set of query vars.
     *
     * Any value in the $after parameter that isn't 'bottom' will result in the rule
     * being placed at the top of the rewrite rules.
     *
     * @since 2.1.0
     * @since 4.4.0 Array support was added to the `$query` parameter.
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string       $regex Regular expression to match request against.
     * @param string|array $query The corresponding query vars for this rewrite rule.
     * @param string       $after Optional. Priority of the new rule. Accepts 'top'
     *                            or 'bottom'. Default 'bottom'.
     * @phpstan-param 'top'|'bottom' $after
     */
    function add_rewrite_rule($regex, $query, $after = 'bottom')
    {
    }
    /**
     * Adds a new rewrite tag (like %postname%).
     *
     * The `$query` parameter is optional. If it is omitted you must ensure that you call
     * this on, or before, the {@see 'init'} hook. This is because `$query` defaults to
     * `$tag=`, and for this to work a new query var has to be added.
     *
     * @since 2.1.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     * @global WP         $wp         Current WordPress environment instance.
     *
     * @param string $tag   Name of the new rewrite tag.
     * @param string $regex Regular expression to substitute the tag for in rewrite rules.
     * @param string $query Optional. String to append to the rewritten query. Must end in '='. Default empty.
     * @phpstan-return void
     */
    function add_rewrite_tag($tag, $regex, $query = '')
    {
    }
    /**
     * Removes an existing rewrite tag (like %postname%).
     *
     * @since 4.5.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string $tag Name of the rewrite tag.
     */
    function remove_rewrite_tag($tag)
    {
    }
    /**
     * Adds a permalink structure.
     *
     * @since 3.0.0
     *
     * @see WP_Rewrite::add_permastruct()
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string $name   Name for permalink structure.
     * @param string $struct Permalink structure.
     * @param array  $args   Optional. Arguments for building the rules from the permalink structure,
     *                       see WP_Rewrite::add_permastruct() for full details. Default empty array.
     * @phpstan-param array{
     *   with_front?: bool,
     *   ep_mask?: int,
     *   paged?: bool,
     *   feed?: bool,
     *   forcomments?: bool,
     *   walk_dirs?: bool,
     *   endpoints?: bool,
     * } $args See WP_Rewrite::add_permastruct()
     */
    function add_permastruct($name, $struct, $args = array())
    {
    }
    /**
     * Removes a permalink structure.
     *
     * Can only be used to remove permastructs that were added using add_permastruct().
     * Built-in permastructs cannot be removed.
     *
     * @since 4.5.0
     *
     * @see WP_Rewrite::remove_permastruct()
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string $name Name for permalink structure.
     */
    function remove_permastruct($name)
    {
    }
    /**
     * Adds a new feed type like /atom1/.
     *
     * @since 2.1.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string   $feedname Feed name. Should not start with '_'.
     * @param callable $callback Callback to run on feed display.
     * @return string Feed action name.
     */
    function add_feed($feedname, $callback)
    {
    }
    /**
     * Removes rewrite rules and then recreate rewrite rules.
     *
     * @since 3.0.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param bool $hard Whether to update .htaccess (hard flush) or just update
     *                   rewrite_rules option (soft flush). Default is true (hard).
     */
    function flush_rewrite_rules($hard = \true)
    {
    }
    /**
     * Adds an endpoint, like /trackback/.
     *
     * Adding an endpoint creates extra rewrite rules for each of the matching
     * places specified by the provided bitmask. For example:
     *
     *     add_rewrite_endpoint( 'json', EP_PERMALINK | EP_PAGES );
     *
     * will add a new rewrite rule ending with "json(/(.*))?/?$" for every permastruct
     * that describes a permalink (post) or page. This is rewritten to "json=$match"
     * where $match is the part of the URL matched by the endpoint regex (e.g. "foo" in
     * "[permalink]/json/foo/").
     *
     * A new query var with the same name as the endpoint will also be created.
     *
     * When specifying $places ensure that you are using the EP_* constants (or a
     * combination of them using the bitwise OR operator) as their values are not
     * guaranteed to remain static (especially `EP_ALL`).
     *
     * Be sure to flush the rewrite rules - see flush_rewrite_rules() - when your plugin gets
     * activated and deactivated.
     *
     * @since 2.1.0
     * @since 4.3.0 Added support for skipping query var registration by passing `false` to `$query_var`.
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param string      $name      Name of the endpoint.
     * @param int         $places    Endpoint mask describing the places the endpoint should be added.
     *                               Accepts a mask of:
     *                               - `EP_ALL`
     *                               - `EP_NONE`
     *                               - `EP_ALL_ARCHIVES`
     *                               - `EP_ATTACHMENT`
     *                               - `EP_AUTHORS`
     *                               - `EP_CATEGORIES`
     *                               - `EP_COMMENTS`
     *                               - `EP_DATE`
     *                               - `EP_DAY`
     *                               - `EP_MONTH`
     *                               - `EP_PAGES`
     *                               - `EP_PERMALINK`
     *                               - `EP_ROOT`
     *                               - `EP_SEARCH`
     *                               - `EP_TAGS`
     *                               - `EP_YEAR`
     * @param string|bool $query_var Name of the corresponding query variable. Pass `false` to skip registering a query_var
     *                               for this endpoint. Defaults to the value of `$name`.
     */
    function add_rewrite_endpoint($name, $places, $query_var = \true)
    {
    }
    /**
     * Filters the URL base for taxonomies.
     *
     * To remove any manually prepended /index.php/.
     *
     * @access private
     * @since 2.6.0
     *
     * @param string $base The taxonomy base that we're going to filter
     * @return string
     */
    function _wp_filter_taxonomy_base($base)
    {
    }
    /**
     * Resolves numeric slugs that collide with date permalinks.
     *
     * Permalinks of posts with numeric slugs can sometimes look to WP_Query::parse_query()
     * like a date archive, as when your permalink structure is `/%year%/%postname%/` and
     * a post with post_name '05' has the URL `/2015/05/`.
     *
     * This function detects conflicts of this type and resolves them in favor of the
     * post permalink.
     *
     * Note that, since 4.3.0, wp_unique_post_slug() prevents the creation of post slugs
     * that would result in a date archive conflict. The resolution performed in this
     * function is primarily for legacy content, as well as cases when the admin has changed
     * the site's permalink structure in a way that introduces URL conflicts.
     *
     * @since 4.3.0
     *
     * @param array $query_vars Optional. Query variables for setting up the loop, as determined in
     *                          WP::parse_request(). Default empty array.
     * @return array Returns the original array of query vars, with date/post conflicts resolved.
     */
    function wp_resolve_numeric_slug_conflicts($query_vars = array())
    {
    }
    /**
     * Examines a URL and try to determine the post ID it represents.
     *
     * Checks are supposedly from the hosted site blog.
     *
     * @since 1.0.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     * @global WP         $wp         Current WordPress environment instance.
     *
     * @param string $url Permalink to check.
     * @return int Post ID, or 0 on failure.
     */
    function url_to_postid($url)
    {
    }
    /**
     * Displays the robots meta tag as necessary.
     *
     * Gathers robots directives to include for the current context, using the
     * {@see 'wp_robots'} filter. The directives are then sanitized, and the
     * robots meta tag is output if there is at least one relevant directive.
     *
     * @since 5.7.0
     * @since 5.7.1 No longer prevents specific directives to occur together.
     * @phpstan-return void
     */
    function wp_robots()
    {
    }
    /**
     * Adds `noindex` to the robots meta tag if required by the site configuration.
     *
     * If a blog is marked as not being public then noindex will be output to
     * tell web robots not to index the page content. Add this to the
     * {@see 'wp_robots'} filter.
     *
     * Typical usage is as a {@see 'wp_robots'} callback:
     *
     *     add_filter( 'wp_robots', 'wp_robots_noindex' );
     *
     * @since 5.7.0
     *
     * @see wp_robots_no_robots()
     *
     * @param array $robots Associative array of robots directives.
     * @return array Filtered robots directives.
     */
    function wp_robots_noindex(array $robots)
    {
    }
    /**
     * Adds `noindex` to the robots meta tag for embeds.
     *
     * Typical usage is as a {@see 'wp_robots'} callback:
     *
     *     add_filter( 'wp_robots', 'wp_robots_noindex_embeds' );
     *
     * @since 5.7.0
     *
     * @see wp_robots_no_robots()
     *
     * @param array $robots Associative array of robots directives.
     * @return array Filtered robots directives.
     */
    function wp_robots_noindex_embeds(array $robots)
    {
    }
    /**
     * Adds `noindex` to the robots meta tag if a search is being performed.
     *
     * If a search is being performed then noindex will be output to
     * tell web robots not to index the page content. Add this to the
     * {@see 'wp_robots'} filter.
     *
     * Typical usage is as a {@see 'wp_robots'} callback:
     *
     *     add_filter( 'wp_robots', 'wp_robots_noindex_search' );
     *
     * @since 5.7.0
     *
     * @see wp_robots_no_robots()
     *
     * @param array $robots Associative array of robots directives.
     * @return array Filtered robots directives.
     */
    function wp_robots_noindex_search(array $robots)
    {
    }
    /**
     * Adds `noindex` to the robots meta tag.
     *
     * This directive tells web robots not to index the page content.
     *
     * Typical usage is as a {@see 'wp_robots'} callback:
     *
     *     add_filter( 'wp_robots', 'wp_robots_no_robots' );
     *
     * @since 5.7.0
     *
     * @param array $robots Associative array of robots directives.
     * @return array Filtered robots directives.
     */
    function wp_robots_no_robots(array $robots)
    {
    }
    /**
     * Adds `noindex` and `noarchive` to the robots meta tag.
     *
     * This directive tells web robots not to index or archive the page content and
     * is recommended to be used for sensitive pages.
     *
     * Typical usage is as a {@see 'wp_robots'} callback:
     *
     *     add_filter( 'wp_robots', 'wp_robots_sensitive_page' );
     *
     * @since 5.7.0
     *
     * @param array $robots Associative array of robots directives.
     * @return array Filtered robots directives.
     */
    function wp_robots_sensitive_page(array $robots)
    {
    }
    /**
     * Adds `max-image-preview:large` to the robots meta tag.
     *
     * This directive tells web robots that large image previews are allowed to be
     * displayed, e.g. in search engines, unless the blog is marked as not being public.
     *
     * Typical usage is as a {@see 'wp_robots'} callback:
     *
     *     add_filter( 'wp_robots', 'wp_robots_max_image_preview_large' );
     *
     * @since 5.7.0
     *
     * @param array $robots Associative array of robots directives.
     * @return array Filtered robots directives.
     */
    function wp_robots_max_image_preview_large(array $robots)
    {
    }
    /**
     * Registers TinyMCE scripts.
     *
     * @since 5.0.0
     *
     * @global string $tinymce_version
     * @global bool   $concatenate_scripts
     * @global bool   $compress_scripts
     *
     * @param WP_Scripts $scripts            WP_Scripts object.
     * @param bool       $force_uncompressed Whether to forcibly prevent gzip compression. Default false.
     */
    function wp_register_tinymce_scripts($scripts, $force_uncompressed = \false)
    {
    }
    /**
     * Registers all the WordPress vendor scripts that are in the standardized
     * `js/dist/vendor/` location.
     *
     * For the order of `$scripts->add` see `wp_default_scripts`.
     *
     * @since 5.0.0
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     *
     * @param WP_Scripts $scripts WP_Scripts object.
     */
    function wp_default_packages_vendor($scripts)
    {
    }
    /**
     * Returns contents of an inline script used in appending polyfill scripts for
     * browsers which fail the provided tests. The provided array is a mapping from
     * a condition to verify feature support to its polyfill script handle.
     *
     * @since 5.0.0
     *
     * @param WP_Scripts $scripts WP_Scripts object.
     * @param string[]   $tests   Features to detect.
     * @return string Conditional polyfill inline script.
     */
    function wp_get_script_polyfill($scripts, $tests)
    {
    }
    /**
     * Registers development scripts that integrate with `@wordpress/scripts`.
     *
     * @see https://github.com/WordPress/gutenberg/tree/trunk/packages/scripts#start
     *
     * @since 6.0.0
     *
     * @param WP_Scripts $scripts WP_Scripts object.
     * @phpstan-return void
     */
    function wp_register_development_scripts($scripts)
    {
    }
    /**
     * Registers all the WordPress packages scripts that are in the standardized
     * `js/dist/` location.
     *
     * For the order of `$scripts->add` see `wp_default_scripts`.
     *
     * @since 5.0.0
     *
     * @param WP_Scripts $scripts WP_Scripts object.
     */
    function wp_default_packages_scripts($scripts)
    {
    }
    /**
     * Adds inline scripts required for the WordPress JavaScript packages.
     *
     * @since 5.0.0
     * @since 6.4.0 Added relative time strings for the `wp-date` inline script output.
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     * @global wpdb      $wpdb      WordPress database abstraction object.
     *
     * @param WP_Scripts $scripts WP_Scripts object.
     */
    function wp_default_packages_inline_scripts($scripts)
    {
    }
    /**
     * Adds inline scripts required for the TinyMCE in the block editor.
     *
     * These TinyMCE init settings are used to extend and override the default settings
     * from `_WP_Editors::default_settings()` for the Classic block.
     *
     * @since 5.0.0
     *
     * @global WP_Scripts $wp_scripts
     */
    function wp_tinymce_inline_scripts()
    {
    }
    /**
     * Registers all the WordPress packages scripts.
     *
     * @since 5.0.0
     *
     * @param WP_Scripts $scripts WP_Scripts object.
     */
    function wp_default_packages($scripts)
    {
    }
    /**
     * Returns the suffix that can be used for the scripts.
     *
     * There are two suffix types, the normal one and the dev suffix.
     *
     * @since 5.0.0
     *
     * @param string $type The type of suffix to retrieve.
     * @return string The script suffix.
     */
    function wp_scripts_get_suffix($type = '')
    {
    }
    /**
     * Registers all WordPress scripts.
     *
     * Localizes some of them.
     * args order: `$scripts->add( 'handle', 'url', 'dependencies', 'query-string', 1 );`
     * when last arg === 1 queues the script for the footer
     *
     * @since 2.6.0
     *
     * @param WP_Scripts $scripts WP_Scripts object.
     */
    function wp_default_scripts($scripts)
    {
    }
    /**
     * Assigns default styles to $styles object.
     *
     * Nothing is returned, because the $styles parameter is passed by reference.
     * Meaning that whatever object is passed will be updated without having to
     * reassign the variable that was passed back to the same value. This saves
     * memory.
     *
     * Adding default styles is not the only task, it also assigns the base_url
     * property, the default version, and text direction for the object.
     *
     * @since 2.6.0
     *
     * @global array $editor_styles
     *
     * @param WP_Styles $styles
     */
    function wp_default_styles($styles)
    {
    }
    /**
     * Reorders JavaScript scripts array to place prototype before jQuery.
     *
     * @since 2.3.1
     *
     * @param string[] $js_array JavaScript scripts array
     * @return string[] Reordered array, if needed.
     */
    function wp_prototype_before_jquery($js_array)
    {
    }
    /**
     * Loads localized data on print rather than initialization.
     *
     * These localizations require information that may not be loaded even by init.
     *
     * @since 2.5.0
     *
     * @global array $shortcode_tags
     */
    function wp_just_in_time_script_localization()
    {
    }
    /**
     * Localizes the jQuery UI datepicker.
     *
     * @since 4.6.0
     *
     * @link https://api.jqueryui.com/datepicker/#options
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     * @phpstan-return void
     */
    function wp_localize_jquery_ui_datepicker()
    {
    }
    /**
     * Localizes community events data that needs to be passed to dashboard.js.
     *
     * @since 4.8.0
     * @phpstan-return void
     */
    function wp_localize_community_events()
    {
    }
    /**
     * Administration Screen CSS for changing the styles.
     *
     * If installing the 'wp-admin/' directory will be replaced with './'.
     *
     * The $_wp_admin_css_colors global manages the Administration Screens CSS
     * stylesheet that is loaded. The option that is set is 'admin_color' and is the
     * color and key for the array. The value for the color key is an object with
     * a 'url' parameter that has the URL path to the CSS file.
     *
     * The query from $src parameter will be appended to the URL that is given from
     * the $_wp_admin_css_colors array value URL.
     *
     * @since 2.6.0
     *
     * @global array $_wp_admin_css_colors
     *
     * @param string $src    Source URL.
     * @param string $handle Either 'colors' or 'colors-rtl'.
     * @return string|false URL path to CSS stylesheet for Administration Screens.
     * @phpstan-param 'colors'|'colors-rtl' $handle
     */
    function wp_style_loader_src($src, $handle)
    {
    }
    /**
     * Prints the script queue in the HTML head on admin pages.
     *
     * Postpones the scripts that were queued for the footer.
     * print_footer_scripts() is called in the footer to print these scripts.
     *
     * @since 2.8.0
     *
     * @see wp_print_scripts()
     *
     * @global bool $concatenate_scripts
     *
     * @return array
     */
    function print_head_scripts()
    {
    }
    /**
     * Prints the scripts that were queued for the footer or too late for the HTML head.
     *
     * @since 2.8.0
     *
     * @global WP_Scripts $wp_scripts
     * @global bool       $concatenate_scripts
     *
     * @return array
     */
    function print_footer_scripts()
    {
    }
    /**
     * Prints scripts (internal use only)
     *
     * @ignore
     *
     * @global WP_Scripts $wp_scripts
     * @global bool       $compress_scripts
     */
    function _print_scripts()
    {
    }
    /**
     * Prints the script queue in the HTML head on the front end.
     *
     * Postpones the scripts that were queued for the footer.
     * wp_print_footer_scripts() is called in the footer to print these scripts.
     *
     * @since 2.8.0
     *
     * @global WP_Scripts $wp_scripts
     *
     * @return array
     */
    function wp_print_head_scripts()
    {
    }
    /**
     * Private, for use in *_footer_scripts hooks
     *
     * @since 3.3.0
     */
    function _wp_footer_scripts()
    {
    }
    /**
     * Hooks to print the scripts and styles in the footer.
     *
     * @since 2.8.0
     */
    function wp_print_footer_scripts()
    {
    }
    /**
     * Wrapper for do_action( 'wp_enqueue_scripts' ).
     *
     * Allows plugins to queue scripts for the front end using wp_enqueue_script().
     * Runs first in wp_head() where all is_home(), is_page(), etc. functions are available.
     *
     * @since 2.8.0
     */
    function wp_enqueue_scripts()
    {
    }
    /**
     * Prints the styles queue in the HTML head on admin pages.
     *
     * @since 2.8.0
     *
     * @global bool $concatenate_scripts
     *
     * @return array
     */
    function print_admin_styles()
    {
    }
    /**
     * Prints the styles that were queued too late for the HTML head.
     *
     * @since 3.3.0
     *
     * @global WP_Styles $wp_styles
     * @global bool      $concatenate_scripts
     *
     * @return array|void
     */
    function print_late_styles()
    {
    }
    /**
     * Prints styles (internal use only).
     *
     * @ignore
     * @since 3.3.0
     *
     * @global bool $compress_css
     */
    function _print_styles()
    {
    }
    /**
     * Determines the concatenation and compression settings for scripts and styles.
     *
     * @since 2.8.0
     *
     * @global bool $concatenate_scripts
     * @global bool $compress_scripts
     * @global bool $compress_css
     */
    function script_concat_settings()
    {
    }
    /**
     * Handles the enqueueing of block scripts and styles that are common to both
     * the editor and the front-end.
     *
     * @since 5.0.0
     * @phpstan-return void
     */
    function wp_common_block_scripts_and_styles()
    {
    }
    /**
     * Applies a filter to the list of style nodes that comes from WP_Theme_JSON::get_style_nodes().
     *
     * This particular filter removes all of the blocks from the array.
     *
     * We want WP_Theme_JSON to be ignorant of the implementation details of how the CSS is being used.
     * This filter allows us to modify the output of WP_Theme_JSON depending on whether or not we are
     * loading separate assets, without making the class aware of that detail.
     *
     * @since 6.1.0
     *
     * @param array $nodes The nodes to filter.
     * @return array A filtered array of style nodes.
     */
    function wp_filter_out_block_nodes($nodes)
    {
    }
    /**
     * Enqueues the global styles defined via theme.json.
     *
     * @since 5.8.0
     * @phpstan-return void
     */
    function wp_enqueue_global_styles()
    {
    }
    /**
     * Checks if the editor scripts and styles for all registered block types
     * should be enqueued on the current screen.
     *
     * @since 5.6.0
     *
     * @global WP_Screen $current_screen WordPress current screen object.
     *
     * @return bool Whether scripts and styles should be enqueued.
     */
    function wp_should_load_block_editor_scripts_and_styles()
    {
    }
    /**
     * Checks whether separate styles should be loaded for core blocks on-render.
     *
     * When this function returns true, other functions ensure that core blocks
     * only load their assets on-render, and each block loads its own, individual
     * assets. Third-party blocks only load their assets when rendered.
     *
     * When this function returns false, all core block assets are loaded regardless
     * of whether they are rendered in a page or not, because they are all part of
     * the `block-library/style.css` file. Assets for third-party blocks are always
     * enqueued regardless of whether they are rendered or not.
     *
     * This only affects front end and not the block editor screens.
     *
     * @see wp_enqueue_registered_block_scripts_and_styles()
     * @see register_block_style_handle()
     *
     * @since 5.8.0
     *
     * @return bool Whether separate assets will be loaded.
     */
    function wp_should_load_separate_core_block_assets()
    {
    }
    /**
     * Enqueues registered block scripts and styles, depending on current rendered
     * context (only enqueuing editor scripts while in context of the editor).
     *
     * @since 5.0.0
     *
     * @global WP_Screen $current_screen WordPress current screen object.
     * @phpstan-return void
     */
    function wp_enqueue_registered_block_scripts_and_styles()
    {
    }
    /**
     * Function responsible for enqueuing the styles required for block styles functionality on the editor and on the frontend.
     *
     * @since 5.3.0
     *
     * @global WP_Styles $wp_styles
     */
    function enqueue_block_styles_assets()
    {
    }
    /**
     * Function responsible for enqueuing the assets required for block styles functionality on the editor.
     *
     * @since 5.3.0
     */
    function enqueue_editor_block_styles_assets()
    {
    }
    /**
     * Enqueues the assets required for the block directory within the block editor.
     *
     * @since 5.5.0
     */
    function wp_enqueue_editor_block_directory_assets()
    {
    }
    /**
     * Enqueues the assets required for the format library within the block editor.
     *
     * @since 5.8.0
     */
    function wp_enqueue_editor_format_library_assets()
    {
    }
    /**
     * Sanitizes an attributes array into an attributes string to be placed inside a `<script>` tag.
     *
     * Automatically injects type attribute if needed.
     * Used by {@see wp_get_script_tag()} and {@see wp_get_inline_script_tag()}.
     *
     * @since 5.7.0
     *
     * @param array $attributes Key-value pairs representing `<script>` tag attributes.
     * @return string String made of sanitized `<script>` tag attributes.
     */
    function wp_sanitize_script_attributes($attributes)
    {
    }
    /**
     * Formats `<script>` loader tags.
     *
     * It is possible to inject attributes in the `<script>` tag via the {@see 'wp_script_attributes'} filter.
     * Automatically injects type attribute if needed.
     *
     * @since 5.7.0
     *
     * @param array $attributes Key-value pairs representing `<script>` tag attributes.
     * @return string String containing `<script>` opening and closing tags.
     */
    function wp_get_script_tag($attributes)
    {
    }
    /**
     * Prints formatted `<script>` loader tag.
     *
     * It is possible to inject attributes in the `<script>` tag via the  {@see 'wp_script_attributes'}  filter.
     * Automatically injects type attribute if needed.
     *
     * @since 5.7.0
     *
     * @param array $attributes Key-value pairs representing `<script>` tag attributes.
     */
    function wp_print_script_tag($attributes)
    {
    }
    /**
     * Constructs an inline script tag.
     *
     * It is possible to inject attributes in the `<script>` tag via the  {@see 'wp_script_attributes'}  filter.
     * Automatically injects type attribute if needed.
     *
     * @since 5.7.0
     *
     * @param string $data       Data for script tag: JavaScript, importmap, speculationrules, etc.
     * @param array  $attributes Optional. Key-value pairs representing `<script>` tag attributes.
     * @return string String containing inline JavaScript code wrapped around `<script>` tag.
     */
    function wp_get_inline_script_tag($data, $attributes = array())
    {
    }
    /**
     * Prints an inline script tag.
     *
     * It is possible to inject attributes in the `<script>` tag via the  {@see 'wp_script_attributes'}  filter.
     * Automatically injects type attribute if needed.
     *
     * @since 5.7.0
     *
     * @param string $data       Data for script tag: JavaScript, importmap, speculationrules, etc.
     * @param array  $attributes Optional. Key-value pairs representing `<script>` tag attributes.
     */
    function wp_print_inline_script_tag($data, $attributes = array())
    {
    }
    /**
     * Allows small styles to be inlined.
     *
     * This improves performance and sustainability, and is opt-in. Stylesheets can opt in
     * by adding `path` data using `wp_style_add_data`, and defining the file's absolute path:
     *
     *     wp_style_add_data( $style_handle, 'path', $file_path );
     *
     * @since 5.8.0
     *
     * @global WP_Styles $wp_styles
     */
    function wp_maybe_inline_styles()
    {
    }
    /**
     * Makes URLs relative to the WordPress installation.
     *
     * @since 5.9.0
     * @access private
     *
     * @param string $css            The CSS to make URLs relative to the WordPress installation.
     * @param string $stylesheet_url The URL to the stylesheet.
     *
     * @return string The CSS with URLs made relative to the WordPress installation.
     */
    function _wp_normalize_relative_css_links($css, $stylesheet_url)
    {
    }
    /**
     * Function that enqueues the CSS Custom Properties coming from theme.json.
     *
     * @since 5.9.0
     */
    function wp_enqueue_global_styles_css_custom_properties()
    {
    }
    /**
     * Hooks inline styles in the proper place, depending on the active theme.
     *
     * @since 5.9.1
     * @since 6.1.0 Added the `$priority` parameter.
     *
     * For block themes, styles are loaded in the head.
     * For classic ones, styles are loaded in the body because the wp_head action happens before render_block.
     *
     * @link https://core.trac.wordpress.org/ticket/53494.
     *
     * @param string $style    String containing the CSS styles to be added.
     * @param int    $priority To set the priority for the add_action.
     */
    function wp_enqueue_block_support_styles($style, $priority = 10)
    {
    }
    /**
     * Fetches, processes and compiles stored core styles, then combines and renders them to the page.
     * Styles are stored via the style engine API.
     *
     * @link https://developer.wordpress.org/block-editor/reference-guides/packages/packages-style-engine/
     *
     * @since 6.1.0
     *
     * @param array $options {
     *     Optional. An array of options to pass to wp_style_engine_get_stylesheet_from_context().
     *     Default empty array.
     *
     *     @type bool $optimize Whether to optimize the CSS output, e.g., combine rules.
     *                          Default false.
     *     @type bool $prettify Whether to add new lines and indents to output.
     *                          Default to whether the `SCRIPT_DEBUG` constant is defined.
     * }
     * @phpstan-param array{
     *   optimize?: bool,
     *   prettify?: bool,
     * } $options
     * @phpstan-return void
     */
    function wp_enqueue_stored_styles($options = array())
    {
    }
    /**
     * Enqueues a stylesheet for a specific block.
     *
     * If the theme has opted-in to separate-styles loading,
     * then the stylesheet will be enqueued on-render,
     * otherwise when the block inits.
     *
     * @since 5.9.0
     *
     * @param string $block_name The block-name, including namespace.
     * @param array  $args       {
     *     An array of arguments. See wp_register_style() for full information about each argument.
     *
     *     @type string           $handle The handle for the stylesheet.
     *     @type string|false     $src    The source URL of the stylesheet.
     *     @type string[]         $deps   Array of registered stylesheet handles this stylesheet depends on.
     *     @type string|bool|null $ver    Stylesheet version number.
     *     @type string           $media  The media for which this stylesheet has been defined.
     *     @type string|null      $path   Absolute path to the stylesheet, so that it can potentially be inlined.
     * }
     * @phpstan-param array{
     *   handle?: string,
     *   src?: string|false,
     *   deps?: string[],
     *   ver?: string|bool|null,
     *   media?: string,
     *   path?: string|null,
     * } $args
     */
    function wp_enqueue_block_style($block_name, $args)
    {
    }
    /**
     * Loads classic theme styles on classic themes in the frontend.
     *
     * This is needed for backwards compatibility for button blocks specifically.
     *
     * @since 6.1.0
     */
    function wp_enqueue_classic_theme_styles()
    {
    }
    /**
     * Loads classic theme styles on classic themes in the editor.
     *
     * This is needed for backwards compatibility for button blocks specifically.
     *
     * @since 6.1.0
     *
     * @param array $editor_settings The array of editor settings.
     * @return array A filtered array of editor settings.
     */
    function wp_add_editor_classic_theme_styles($editor_settings)
    {
    }
    /**
     * Removes leading and trailing _empty_ script tags.
     *
     * This is a helper meant to be used for literal script tag construction
     * within `wp_get_inline_script_tag()` or `wp_print_inline_script_tag()`.
     * It removes the literal values of "<script>" and "</script>" from
     * around an inline script after trimming whitespace. Typically this
     * is used in conjunction with output buffering, where `ob_get_clean()`
     * is passed as the `$contents` argument.
     *
     * Example:
     *
     *     // Strips exact literal empty SCRIPT tags.
     *     $js = '<script>sayHello();</script>;
     *     'sayHello();' === wp_remove_surrounding_empty_script_tags( $js );
     *
     *     // Otherwise if anything is different it warns in the JS console.
     *     $js = '<script type="text/javascript">console.log( "hi" );</script>';
     *     'console.error( ... )' === wp_remove_surrounding_empty_script_tags( $js );
     *
     * @since 6.4.0
     * @access private
     *
     * @see wp_print_inline_script_tag()
     * @see wp_get_inline_script_tag()
     *
     * @param string $contents Script body with manually created SCRIPT tag literals.
     * @return string Script body without surrounding script tag literals, or
     *                original contents if both exact literals aren't present.
     */
    function wp_remove_surrounding_empty_script_tags($contents)
    {
    }
    /**
     * Retrieves the main WP_Script_Modules instance.
     *
     * This function provides access to the WP_Script_Modules instance, creating one
     * if it doesn't exist yet.
     *
     * @since 6.5.0
     *
     * @global WP_Script_Modules $wp_script_modules
     *
     * @return WP_Script_Modules The main WP_Script_Modules instance.
     */
    function wp_script_modules() : \WP_Script_Modules
    {
    }
    /**
     * Registers the script module if no script module with that script module
     * identifier has already been registered.
     *
     * @since 6.5.0
     *
     * @param string            $id      The identifier of the script module. Should be unique. It will be used in the
     *                                   final import map.
     * @param string            $src     Optional. Full URL of the script module, or path of the script module relative
     *                                   to the WordPress root directory. If it is provided and the script module has
     *                                   not been registered yet, it will be registered.
     * @param array             $deps    {
     *                                       Optional. List of dependencies.
     *
     *                                       @type string|array ...$0 {
     *                                           An array of script module identifiers of the dependencies of this script
     *                                           module. The dependencies can be strings or arrays. If they are arrays,
     *                                           they need an `id` key with the script module identifier, and can contain
     *                                           an `import` key with either `static` or `dynamic`. By default,
     *                                           dependencies that don't contain an `import` key are considered static.
     *
     *                                           @type string $id     The script module identifier.
     *                                           @type string $import Optional. Import type. May be either `static` or
     *                                                                `dynamic`. Defaults to `static`.
     *                                       }
     *                                   }
     * @param string|false|null $version Optional. String specifying the script module version number. Defaults to false.
     *                                   It is added to the URL as a query string for cache busting purposes. If $version
     *                                   is set to false, the version number is the currently installed WordPress version.
     *                                   If $version is set to null, no version is added.
     * @phpstan-param array<int|string, array{
     *   id: string,
     *   import?: string,
     * }> $deps
     */
    function wp_register_script_module(string $id, string $src, array $deps = array(), $version = \false)
    {
    }
    /**
     * Marks the script module to be enqueued in the page.
     *
     * If a src is provided and the script module has not been registered yet, it
     * will be registered.
     *
     * @since 6.5.0
     *
     * @param string            $id      The identifier of the script module. Should be unique. It will be used in the
     *                                   final import map.
     * @param string            $src     Optional. Full URL of the script module, or path of the script module relative
     *                                   to the WordPress root directory. If it is provided and the script module has
     *                                   not been registered yet, it will be registered.
     * @param array             $deps    {
     *                                       Optional. List of dependencies.
     *
     *                                       @type string|array ...$0 {
     *                                           An array of script module identifiers of the dependencies of this script
     *                                           module. The dependencies can be strings or arrays. If they are arrays,
     *                                           they need an `id` key with the script module identifier, and can contain
     *                                           an `import` key with either `static` or `dynamic`. By default,
     *                                           dependencies that don't contain an `import` key are considered static.
     *
     *                                           @type string $id     The script module identifier.
     *                                           @type string $import Optional. Import type. May be either `static` or
     *                                                                `dynamic`. Defaults to `static`.
     *                                       }
     *                                   }
     * @param string|false|null $version Optional. String specifying the script module version number. Defaults to false.
     *                                   It is added to the URL as a query string for cache busting purposes. If $version
     *                                   is set to false, the version number is the currently installed WordPress version.
     *                                   If $version is set to null, no version is added.
     * @phpstan-param array<int|string, array{
     *   id: string,
     *   import?: string,
     * }> $deps
     */
    function wp_enqueue_script_module(string $id, string $src = '', array $deps = array(), $version = \false)
    {
    }
    /**
     * Unmarks the script module so it is no longer enqueued in the page.
     *
     * @since 6.5.0
     *
     * @param string $id The identifier of the script module.
     */
    function wp_dequeue_script_module(string $id)
    {
    }
    /**
     * Deregisters the script module.
     *
     * @since 6.5.0
     *
     * @param string $id The identifier of the script module.
     */
    function wp_deregister_script_module(string $id)
    {
    }
    /**
     * Registers all the default WordPress Script Modules.
     *
     * @since 6.7.0
     */
    function wp_default_script_modules()
    {
    }
    /**
     * Adds a new shortcode.
     *
     * Care should be taken through prefixing or other means to ensure that the
     * shortcode tag being added is unique and will not conflict with other,
     * already-added shortcode tags. In the event of a duplicated tag, the tag
     * loaded last will take precedence.
     *
     * @since 2.5.0
     *
     * @global array $shortcode_tags
     *
     * @param string   $tag      Shortcode tag to be searched in post content.
     * @param callable $callback The callback function to run when the shortcode is found.
     *                           Every shortcode callback is passed three parameters by default,
     *                           including an array of attributes (`$atts`), the shortcode content
     *                           or null if not set (`$content`), and finally the shortcode tag
     *                           itself (`$shortcode_tag`), in that order.
     * @phpstan-return void
     */
    function add_shortcode($tag, $callback)
    {
    }
    /**
     * Removes hook for shortcode.
     *
     * @since 2.5.0
     *
     * @global array $shortcode_tags
     *
     * @param string $tag Shortcode tag to remove hook for.
     */
    function remove_shortcode($tag)
    {
    }
    /**
     * Clears all shortcodes.
     *
     * This function clears all of the shortcode tags by replacing the shortcodes global with
     * an empty array. This is actually an efficient method for removing all shortcodes.
     *
     * @since 2.5.0
     *
     * @global array $shortcode_tags
     */
    function remove_all_shortcodes()
    {
    }
    /**
     * Determines whether a registered shortcode exists named $tag.
     *
     * @since 3.6.0
     *
     * @global array $shortcode_tags List of shortcode tags and their callback hooks.
     *
     * @param string $tag Shortcode tag to check.
     * @return bool Whether the given shortcode exists.
     */
    function shortcode_exists($tag)
    {
    }
    /**
     * Determines whether the passed content contains the specified shortcode.
     *
     * @since 3.6.0
     *
     * @global array $shortcode_tags
     *
     * @param string $content Content to search for shortcodes.
     * @param string $tag     Shortcode tag to check.
     * @return bool Whether the passed content contains the given shortcode.
     */
    function has_shortcode($content, $tag)
    {
    }
    /**
     * Returns a list of registered shortcode names found in the given content.
     *
     * Example usage:
     *
     *     get_shortcode_tags_in_content( '[audio src="file.mp3"][/audio] [foo] [gallery ids="1,2,3"]' );
     *     // array( 'audio', 'gallery' )
     *
     * @since 6.3.2
     *
     * @param string $content The content to check.
     * @return string[] An array of registered shortcode names found in the content.
     */
    function get_shortcode_tags_in_content($content)
    {
    }
    /**
     * Searches content for shortcodes and filter shortcodes through their hooks.
     *
     * This function is an alias for do_shortcode().
     *
     * @since 5.4.0
     *
     * @see do_shortcode()
     *
     * @param string $content     Content to search for shortcodes.
     * @param bool   $ignore_html When true, shortcodes inside HTML elements will be skipped.
     *                            Default false.
     * @return string Content with shortcodes filtered out.
     */
    function apply_shortcodes($content, $ignore_html = \false)
    {
    }
    /**
     * Searches content for shortcodes and filter shortcodes through their hooks.
     *
     * If there are no shortcode tags defined, then the content will be returned
     * without any filtering. This might cause issues when plugins are disabled but
     * the shortcode will still show up in the post or content.
     *
     * @since 2.5.0
     *
     * @global array $shortcode_tags List of shortcode tags and their callback hooks.
     *
     * @param string $content     Content to search for shortcodes.
     * @param bool   $ignore_html When true, shortcodes inside HTML elements will be skipped.
     *                            Default false.
     * @return string Content with shortcodes filtered out.
     */
    function do_shortcode($content, $ignore_html = \false)
    {
    }
    /**
     * Filter the `wp_get_attachment_image_context` hook during shortcode rendering.
     *
     * When wp_get_attachment_image() is called during shortcode rendering, we need to make clear
     * that the context is a shortcode and not part of the theme's template rendering logic.
     *
     * @since 6.3.0
     * @access private
     *
     * @return string The filtered context value for wp_get_attachment_images when doing shortcodes.
     */
    function _filter_do_shortcode_context()
    {
    }
    /**
     * Retrieves the shortcode regular expression for searching.
     *
     * The regular expression combines the shortcode tags in the regular expression
     * in a regex class.
     *
     * The regular expression contains 6 different sub matches to help with parsing.
     *
     * 1 - An extra [ to allow for escaping shortcodes with double [[]]
     * 2 - The shortcode name
     * 3 - The shortcode argument list
     * 4 - The self closing /
     * 5 - The content of a shortcode when it wraps some content.
     * 6 - An extra ] to allow for escaping shortcodes with double [[]]
     *
     * @since 2.5.0
     * @since 4.4.0 Added the `$tagnames` parameter.
     *
     * @global array $shortcode_tags
     *
     * @param array $tagnames Optional. List of shortcodes to find. Defaults to all registered shortcodes.
     * @return string The shortcode search regular expression
     */
    function get_shortcode_regex($tagnames = \null)
    {
    }
    /**
     * Regular Expression callable for do_shortcode() for calling shortcode hook.
     *
     * @see get_shortcode_regex() for details of the match array contents.
     *
     * @since 2.5.0
     * @access private
     *
     * @global array $shortcode_tags
     *
     * @param array $m {
     *     Regular expression match array.
     *
     *     @type string $0 Entire matched shortcode text.
     *     @type string $1 Optional second opening bracket for escaping shortcodes.
     *     @type string $2 Shortcode name.
     *     @type string $3 Shortcode arguments list.
     *     @type string $4 Optional self closing slash.
     *     @type string $5 Content of a shortcode when it wraps some content.
     *     @type string $6 Optional second closing bracket for escaping shortcodes.
     * }
     * @return string Shortcode output.
     * @phpstan-param array{
     *   0: string,
     *   1: string,
     *   2: string,
     *   3: string,
     *   4: string,
     *   5: string,
     *   6: string,
     * } $m
     */
    function do_shortcode_tag($m)
    {
    }
    /**
     * Searches only inside HTML elements for shortcodes and process them.
     *
     * Any [ or ] characters remaining inside elements will be HTML encoded
     * to prevent interference with shortcodes that are outside the elements.
     * Assumes $content processed by KSES already.  Users with unfiltered_html
     * capability may get unexpected output if angle braces are nested in tags.
     *
     * @since 4.2.3
     *
     * @param string $content     Content to search for shortcodes.
     * @param bool   $ignore_html When true, all square braces inside elements will be encoded.
     * @param array  $tagnames    List of shortcodes to find.
     * @return string Content with shortcodes filtered out.
     */
    function do_shortcodes_in_html_tags($content, $ignore_html, $tagnames)
    {
    }
    /**
     * Removes placeholders added by do_shortcodes_in_html_tags().
     *
     * @since 4.2.3
     *
     * @param string $content Content to search for placeholders.
     * @return string Content with placeholders removed.
     */
    function unescape_invalid_shortcodes($content)
    {
    }
    /**
     * Retrieves the shortcode attributes regex.
     *
     * @since 4.4.0
     *
     * @return string The shortcode attribute regular expression.
     */
    function get_shortcode_atts_regex()
    {
    }
    /**
     * Retrieves all attributes from the shortcodes tag.
     *
     * The attributes list has the attribute name as the key and the value of the
     * attribute as the value in the key/value pair. This allows for easier
     * retrieval of the attributes, since all attributes have to be known.
     *
     * @since 2.5.0
     * @since 6.5.0 The function now always returns an array,
     *              even if the original arguments string cannot be parsed or is empty.
     *
     * @param string $text Shortcode arguments list.
     * @return array Array of attribute values keyed by attribute name.
     *               Returns empty array if there are no attributes
     *               or if the original arguments string cannot be parsed.
     */
    function shortcode_parse_atts($text)
    {
    }
    /**
     * Combines user attributes with known attributes and fill in defaults when needed.
     *
     * The pairs should be considered to be all of the attributes which are
     * supported by the caller and given as a list. The returned attributes will
     * only contain the attributes in the $pairs list.
     *
     * If the $atts list has unsupported attributes, then they will be ignored and
     * removed from the final returned list.
     *
     * @since 2.5.0
     *
     * @param array  $pairs     Entire list of supported attributes and their defaults.
     * @param array  $atts      User defined attributes in shortcode tag.
     * @param string $shortcode Optional. The name of the shortcode, provided for context to enable filtering
     * @return array Combined and filtered attribute list.
     */
    function shortcode_atts($pairs, $atts, $shortcode = '')
    {
    }
    /**
     * Removes all shortcode tags from the given content.
     *
     * @since 2.5.0
     *
     * @global array $shortcode_tags
     *
     * @param string $content Content to remove shortcode tags.
     * @return string Content without shortcode tags.
     */
    function strip_shortcodes($content)
    {
    }
    /**
     * Strips a shortcode tag based on RegEx matches against post content.
     *
     * @since 3.3.0
     *
     * @param array $m RegEx matches against post content.
     * @return string|false The content stripped of the tag, otherwise false.
     */
    function strip_shortcode_tag($m)
    {
    }
    /**
     * Retrieves the current Sitemaps server instance.
     *
     * @since 5.5.0
     *
     * @global WP_Sitemaps $wp_sitemaps Global Core Sitemaps instance.
     *
     * @return WP_Sitemaps Sitemaps instance.
     */
    function wp_sitemaps_get_server()
    {
    }
    /**
     * Gets an array of sitemap providers.
     *
     * @since 5.5.0
     *
     * @return WP_Sitemaps_Provider[] Array of sitemap providers.
     */
    function wp_get_sitemap_providers()
    {
    }
    /**
     * Registers a new sitemap provider.
     *
     * @since 5.5.0
     *
     * @param string               $name     Unique name for the sitemap provider.
     * @param WP_Sitemaps_Provider $provider The `Sitemaps_Provider` instance implementing the sitemap.
     * @return bool Whether the sitemap was added.
     */
    function wp_register_sitemap_provider($name, \WP_Sitemaps_Provider $provider)
    {
    }
    /**
     * Gets the maximum number of URLs for a sitemap.
     *
     * @since 5.5.0
     *
     * @param string $object_type Object type for sitemap to be filtered (e.g. 'post', 'term', 'user').
     * @return int The maximum number of URLs.
     */
    function wp_sitemaps_get_max_urls($object_type)
    {
    }
    /**
     * Retrieves the full URL for a sitemap.
     *
     * @since 5.5.1
     *
     * @param string $name         The sitemap name.
     * @param string $subtype_name The sitemap subtype name. Default empty string.
     * @param int    $page         The page of the sitemap. Default 1.
     * @return string|false The sitemap URL or false if the sitemap doesn't exist.
     */
    function get_sitemap_url($name, $subtype_name = '', $page = 1)
    {
    }
    /**
     * Global public interface method to generate styles from a single style object,
     * e.g. the value of a block's attributes.style object or the top level styles in theme.json.
     *
     * Example usage:
     *
     *     $styles = wp_style_engine_get_styles(
     *         array(
     *             'color' => array( 'text' => '#cccccc' ),
     *         )
     *     );
     *
     * Returns:
     *
     *     array(
     *         'css'          => 'color: #cccccc',
     *         'declarations' => array( 'color' => '#cccccc' ),
     *         'classnames'   => 'has-color',
     *     )
     *
     * @since 6.1.0
     *
     * @see https://developer.wordpress.org/block-editor/reference-guides/theme-json-reference/theme-json-living/#styles
     * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-supports/
     *
     * @param array $block_styles The style object.
     * @param array $options {
     *     Optional. An array of options. Default empty array.
     *
     *     @type string|null $context                    An identifier describing the origin of the style object,
     *                                                   e.g. 'block-supports' or 'global-styles'. Default null.
     *                                                   When set, the style engine will attempt to store the CSS rules,
     *                                                   where a selector is also passed.
     *     @type bool        $convert_vars_to_classnames Whether to skip converting incoming CSS var patterns,
     *                                                   e.g. `var:preset|<PRESET_TYPE>|<PRESET_SLUG>`,
     *                                                   to `var( --wp--preset--* )` values. Default false.
     *     @type string      $selector                   Optional. When a selector is passed,
     *                                                   the value of `$css` in the return value will comprise
     *                                                   a full CSS rule `$selector { ...$css_declarations }`,
     *                                                   otherwise, the value will be a concatenated string
     *                                                   of CSS declarations.
     * }
     * @return array {
     *     @type string   $css          A CSS ruleset or declarations block
     *                                  formatted to be placed in an HTML `style` attribute or tag.
     *     @type string[] $declarations An associative array of CSS definitions,
     *                                  e.g. `array( "$property" => "$value", "$property" => "$value" )`.
     *     @type string   $classnames   Classnames separated by a space.
     * }
     * @phpstan-param array{
     *   context?: string|null,
     *   convert_vars_to_classnames?: bool,
     *   selector?: string,
     * } $options
     * @phpstan-return array{
     *   css: string,
     *   declarations: string[],
     *   classnames: string,
     * }
     */
    function wp_style_engine_get_styles($block_styles, $options = array())
    {
    }
    /**
     * Returns compiled CSS from a collection of selectors and declarations.
     * Useful for returning a compiled stylesheet from any collection of CSS selector + declarations.
     *
     * Example usage:
     *
     *     $css_rules = array(
     *         array(
     *             'selector'     => '.elephant-are-cool',
     *             'declarations' => array(
     *                 'color' => 'gray',
     *                 'width' => '3em',
     *             ),
     *         ),
     *     );
     *
     *     $css = wp_style_engine_get_stylesheet_from_css_rules( $css_rules );
     *
     * Returns:
     *
     *     .elephant-are-cool{color:gray;width:3em}
     *
     * @since 6.1.0
     * @since 6.6.0 Added support for `$rules_group` in the `$css_rules` array.
     *
     * @param array $css_rules {
     *     Required. A collection of CSS rules.
     *
     *     @type array ...$0 {
     *         @type string   $rules_group  A parent CSS selector in the case of nested CSS,
     *                                      or a CSS nested @rule, such as `@media (min-width: 80rem)` or `@layer module`.
     *         @type string   $selector     A CSS selector.
     *         @type string[] $declarations An associative array of CSS definitions,
     *                                      e.g. `array( "$property" => "$value", "$property" => "$value" )`.
     *     }
     * }
     * @param array $options {
     *     Optional. An array of options. Default empty array.
     *
     *     @type string|null $context  An identifier describing the origin of the style object,
     *                                 e.g. 'block-supports' or 'global-styles'. Default 'block-supports'.
     *                                 When set, the style engine will attempt to store the CSS rules.
     *     @type bool        $optimize Whether to optimize the CSS output, e.g. combine rules.
     *                                 Default false.
     *     @type bool        $prettify Whether to add new lines and indents to output.
     *                                 Defaults to whether the `SCRIPT_DEBUG` constant is defined.
     * }
     * @return string A string of compiled CSS declarations, or empty string.
     * @phpstan-param array<int|string, array{
     *   rules_group: string,
     *   selector: string,
     *   declarations: string[],
     * }> $css_rules
     * @phpstan-param array{
     *   context?: string|null,
     *   optimize?: bool,
     *   prettify?: bool,
     * } $options
     */
    function wp_style_engine_get_stylesheet_from_css_rules($css_rules, $options = array())
    {
    }
    /**
     * Returns compiled CSS from a store, if found.
     *
     * @since 6.1.0
     *
     * @param string $context A valid context name, corresponding to an existing store key.
     * @param array  $options {
     *     Optional. An array of options. Default empty array.
     *
     *     @type bool $optimize Whether to optimize the CSS output, e.g. combine rules.
     *                          Default false.
     *     @type bool $prettify Whether to add new lines and indents to output.
     *                          Defaults to whether the `SCRIPT_DEBUG` constant is defined.
     * }
     * @return string A compiled CSS string.
     * @phpstan-param array{
     *   optimize?: bool,
     *   prettify?: bool,
     * } $options
     */
    function wp_style_engine_get_stylesheet_from_context($context, $options = array())
    {
    }
    /**
     * Creates the initial taxonomies.
     *
     * This function fires twice: in wp-settings.php before plugins are loaded (for
     * backward compatibility reasons), and again on the {@see 'init'} action. We must
     * avoid registering rewrite rules before the {@see 'init'} action.
     *
     * @since 2.8.0
     * @since 5.9.0 Added `'wp_template_part_area'` taxonomy.
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     */
    function create_initial_taxonomies()
    {
    }
    /**
     * Retrieves a list of registered taxonomy names or objects.
     *
     * @since 3.0.0
     *
     * @global WP_Taxonomy[] $wp_taxonomies The registered taxonomies.
     *
     * @param array  $args     Optional. An array of `key => value` arguments to match against the taxonomy objects.
     *                         Default empty array.
     * @param string $output   Optional. The type of output to return in the array. Either 'names'
     *                         or 'objects'. Default 'names'.
     * @param string $operator Optional. The logical operation to perform. Accepts 'and' or 'or'. 'or' means only
     *                         one element from the array needs to match; 'and' means all elements must match.
     *                         Default 'and'.
     * @return string[]|WP_Taxonomy[] An array of taxonomy names or objects.
     * @phpstan-param 'names'|'objects' $output
     * @phpstan-param 'and'|'or' $operator
     * @phpstan-return ($output is 'names' ? array<int, string> : array<int, \WP_Taxonomy>)
     */
    function get_taxonomies($args = array(), $output = 'names', $operator = 'and')
    {
    }
    /**
     * Returns the names or objects of the taxonomies which are registered for the requested object or object type,
     * such as a post object or post type name.
     *
     * Example:
     *
     *     $taxonomies = get_object_taxonomies( 'post' );
     *
     * This results in:
     *
     *     Array( 'category', 'post_tag' )
     *
     * @since 2.3.0
     *
     * @global WP_Taxonomy[] $wp_taxonomies The registered taxonomies.
     *
     * @param string|string[]|WP_Post $object_type Name of the type of taxonomy object, or an object (row from posts).
     * @param string                  $output      Optional. The type of output to return in the array. Accepts either
     *                                             'names' or 'objects'. Default 'names'.
     * @return string[]|WP_Taxonomy[] The names or objects of all taxonomies of `$object_type`.
     * @phpstan-param 'names'|'objects' $output
     * @phpstan-return ($output is 'names' ? array<int, string> : array<string, \WP_Taxonomy>)
     */
    function get_object_taxonomies($object_type, $output = 'names')
    {
    }
    /**
     * Retrieves the taxonomy object of $taxonomy.
     *
     * The get_taxonomy function will first check that the parameter string given
     * is a taxonomy object and if it is, it will return it.
     *
     * @since 2.3.0
     *
     * @global WP_Taxonomy[] $wp_taxonomies The registered taxonomies.
     *
     * @param string $taxonomy Name of taxonomy object to return.
     * @return WP_Taxonomy|false The taxonomy object or false if $taxonomy doesn't exist.
     */
    function get_taxonomy($taxonomy)
    {
    }
    /**
     * Determines whether the taxonomy name exists.
     *
     * Formerly is_taxonomy(), introduced in 2.3.0.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 3.0.0
     *
     * @global WP_Taxonomy[] $wp_taxonomies The registered taxonomies.
     *
     * @param string $taxonomy Name of taxonomy object.
     * @return bool Whether the taxonomy exists.
     */
    function taxonomy_exists($taxonomy)
    {
    }
    /**
     * Determines whether the taxonomy object is hierarchical.
     *
     * Checks to make sure that the taxonomy is an object first. Then Gets the
     * object, and finally returns the hierarchical value in the object.
     *
     * A false return value might also mean that the taxonomy does not exist.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.3.0
     *
     * @param string $taxonomy Name of taxonomy object.
     * @return bool Whether the taxonomy is hierarchical.
     */
    function is_taxonomy_hierarchical($taxonomy)
    {
    }
    /**
     * Creates or modifies a taxonomy object.
     *
     * Note: Do not use before the {@see 'init'} hook.
     *
     * A simple function for creating or modifying a taxonomy object based on
     * the parameters given. If modifying an existing taxonomy object, note
     * that the `$object_type` value from the original registration will be
     * overwritten.
     *
     * @since 2.3.0
     * @since 4.2.0 Introduced `show_in_quick_edit` argument.
     * @since 4.4.0 The `show_ui` argument is now enforced on the term editing screen.
     * @since 4.4.0 The `public` argument now controls whether the taxonomy can be queried on the front end.
     * @since 4.5.0 Introduced `publicly_queryable` argument.
     * @since 4.7.0 Introduced `show_in_rest`, 'rest_base' and 'rest_controller_class'
     *              arguments to register the taxonomy in REST API.
     * @since 5.1.0 Introduced `meta_box_sanitize_cb` argument.
     * @since 5.4.0 Added the registered taxonomy object as a return value.
     * @since 5.5.0 Introduced `default_term` argument.
     * @since 5.9.0 Introduced `rest_namespace` argument.
     *
     * @global WP_Taxonomy[] $wp_taxonomies Registered taxonomies.
     *
     * @param string       $taxonomy    Taxonomy key. Must not exceed 32 characters and may only contain
     *                                  lowercase alphanumeric characters, dashes, and underscores. See sanitize_key().
     * @param array|string $object_type Object type or array of object types with which the taxonomy should be associated.
     * @param array|string $args        {
     *     Optional. Array or query string of arguments for registering a taxonomy.
     *
     *     @type string[]      $labels                An array of labels for this taxonomy. By default, Tag labels are
     *                                                used for non-hierarchical taxonomies, and Category labels are used
     *                                                for hierarchical taxonomies. See accepted values in
     *                                                get_taxonomy_labels(). Default empty array.
     *     @type string        $description           A short descriptive summary of what the taxonomy is for. Default empty.
     *     @type bool          $public                Whether a taxonomy is intended for use publicly either via
     *                                                the admin interface or by front-end users. The default settings
     *                                                of `$publicly_queryable`, `$show_ui`, and `$show_in_nav_menus`
     *                                                are inherited from `$public`.
     *     @type bool          $publicly_queryable    Whether the taxonomy is publicly queryable.
     *                                                If not set, the default is inherited from `$public`
     *     @type bool          $hierarchical          Whether the taxonomy is hierarchical. Default false.
     *     @type bool          $show_ui               Whether to generate and allow a UI for managing terms in this taxonomy in
     *                                                the admin. If not set, the default is inherited from `$public`
     *                                                (default true).
     *     @type bool          $show_in_menu          Whether to show the taxonomy in the admin menu. If true, the taxonomy is
     *                                                shown as a submenu of the object type menu. If false, no menu is shown.
     *                                                `$show_ui` must be true. If not set, default is inherited from `$show_ui`
     *                                                (default true).
     *     @type bool          $show_in_nav_menus     Makes this taxonomy available for selection in navigation menus. If not
     *                                                set, the default is inherited from `$public` (default true).
     *     @type bool          $show_in_rest          Whether to include the taxonomy in the REST API. Set this to true
     *                                                for the taxonomy to be available in the block editor.
     *     @type string        $rest_base             To change the base url of REST API route. Default is $taxonomy.
     *     @type string        $rest_namespace        To change the namespace URL of REST API route. Default is wp/v2.
     *     @type string        $rest_controller_class REST API Controller class name. Default is 'WP_REST_Terms_Controller'.
     *     @type bool          $show_tagcloud         Whether to list the taxonomy in the Tag Cloud Widget controls. If not set,
     *                                                the default is inherited from `$show_ui` (default true).
     *     @type bool          $show_in_quick_edit    Whether to show the taxonomy in the quick/bulk edit panel. It not set,
     *                                                the default is inherited from `$show_ui` (default true).
     *     @type bool          $show_admin_column     Whether to display a column for the taxonomy on its post type listing
     *                                                screens. Default false.
     *     @type bool|callable $meta_box_cb           Provide a callback function for the meta box display. If not set,
     *                                                post_categories_meta_box() is used for hierarchical taxonomies, and
     *                                                post_tags_meta_box() is used for non-hierarchical. If false, no meta
     *                                                box is shown.
     *     @type callable      $meta_box_sanitize_cb  Callback function for sanitizing taxonomy data saved from a meta
     *                                                box. If no callback is defined, an appropriate one is determined
     *                                                based on the value of `$meta_box_cb`.
     *     @type string[]      $capabilities {
     *         Array of capabilities for this taxonomy.
     *
     *         @type string $manage_terms Default 'manage_categories'.
     *         @type string $edit_terms   Default 'manage_categories'.
     *         @type string $delete_terms Default 'manage_categories'.
     *         @type string $assign_terms Default 'edit_posts'.
     *     }
     *     @type bool|array    $rewrite {
     *         Triggers the handling of rewrites for this taxonomy. Default true, using $taxonomy as slug. To prevent
     *         rewrite, set to false. To specify rewrite rules, an array can be passed with any of these keys:
     *
     *         @type string $slug         Customize the permastruct slug. Default `$taxonomy` key.
     *         @type bool   $with_front   Should the permastruct be prepended with WP_Rewrite::$front. Default true.
     *         @type bool   $hierarchical Either hierarchical rewrite tag or not. Default false.
     *         @type int    $ep_mask      Assign an endpoint mask. Default `EP_NONE`.
     *     }
     *     @type string|bool   $query_var             Sets the query var key for this taxonomy. Default `$taxonomy` key. If
     *                                                false, a taxonomy cannot be loaded at `?{query_var}={term_slug}`. If a
     *                                                string, the query `?{query_var}={term_slug}` will be valid.
     *     @type callable      $update_count_callback Works much like a hook, in that it will be called when the count is
     *                                                updated. Default _update_post_term_count() for taxonomies attached
     *                                                to post types, which confirms that the objects are published before
     *                                                counting them. Default _update_generic_term_count() for taxonomies
     *                                                attached to other object types, such as users.
     *     @type string|array  $default_term {
     *         Default term to be used for the taxonomy.
     *
     *         @type string $name         Name of default term.
     *         @type string $slug         Slug for default term. Default empty.
     *         @type string $description  Description for default term. Default empty.
     *     }
     *     @type bool          $sort                  Whether terms in this taxonomy should be sorted in the order they are
     *                                                provided to `wp_set_object_terms()`. Default null which equates to false.
     *     @type array         $args                  Array of arguments to automatically use inside `wp_get_object_terms()`
     *                                                for this taxonomy.
     *     @type bool          $_builtin              This taxonomy is a "built-in" taxonomy. INTERNAL USE ONLY!
     *                                                Default false.
     * }
     * @return WP_Taxonomy|WP_Error The registered taxonomy object on success, WP_Error object on failure.
     * @phpstan-param array{
     *   labels?: string[],
     *   description?: string,
     *   public?: bool,
     *   publicly_queryable?: bool,
     *   hierarchical?: bool,
     *   show_ui?: bool,
     *   show_in_menu?: bool,
     *   show_in_nav_menus?: bool,
     *   show_in_rest?: bool,
     *   rest_base?: string,
     *   rest_namespace?: string,
     *   rest_controller_class?: string,
     *   show_tagcloud?: bool,
     *   show_in_quick_edit?: bool,
     *   show_admin_column?: bool,
     *   meta_box_cb?: bool|callable,
     *   meta_box_sanitize_cb?: callable,
     *   capabilities?: array{
     *     manage_terms?: string,
     *     edit_terms?: string,
     *     delete_terms?: string,
     *     assign_terms?: string,
     *   },
     *   rewrite?: bool|array{
     *     slug?: string,
     *     with_front?: bool,
     *     hierarchical?: bool,
     *     ep_mask?: int,
     *   },
     *   query_var?: string|bool,
     *   update_count_callback?: callable,
     *   default_term?: string|array{
     *     name?: string,
     *     slug?: string,
     *     description?: string,
     *   },
     *   sort?: bool,
     *   args?: array,
     *   _builtin?: bool,
     * } $args
     */
    function register_taxonomy($taxonomy, $object_type, $args = array())
    {
    }
    /**
     * Unregisters a taxonomy.
     *
     * Can not be used to unregister built-in taxonomies.
     *
     * @since 4.5.0
     *
     * @global WP_Taxonomy[] $wp_taxonomies List of taxonomies.
     *
     * @param string $taxonomy Taxonomy name.
     * @return true|WP_Error True on success, WP_Error on failure or if the taxonomy doesn't exist.
     */
    function unregister_taxonomy($taxonomy)
    {
    }
    /**
     * Builds an object with all taxonomy labels out of a taxonomy object.
     *
     * @since 3.0.0
     * @since 4.3.0 Added the `no_terms` label.
     * @since 4.4.0 Added the `items_list_navigation` and `items_list` labels.
     * @since 4.9.0 Added the `most_used` and `back_to_items` labels.
     * @since 5.7.0 Added the `filter_by_item` label.
     * @since 5.8.0 Added the `item_link` and `item_link_description` labels.
     * @since 5.9.0 Added the `name_field_description`, `slug_field_description`,
     *              `parent_field_description`, and `desc_field_description` labels.
     * @since 6.6.0 Added the `template_name` label.
     *
     * @param WP_Taxonomy $tax Taxonomy object.
     * @return object {
     *     Taxonomy labels object. The first default value is for non-hierarchical taxonomies
     *     (like tags) and the second one is for hierarchical taxonomies (like categories).
     *
     *     @type string $name                       General name for the taxonomy, usually plural. The same
     *                                              as and overridden by `$tax->label`. Default 'Tags'/'Categories'.
     *     @type string $singular_name              Name for one object of this taxonomy. Default 'Tag'/'Category'.
     *     @type string $search_items               Default 'Search Tags'/'Search Categories'.
     *     @type string $popular_items              This label is only used for non-hierarchical taxonomies.
     *                                              Default 'Popular Tags'.
     *     @type string $all_items                  Default 'All Tags'/'All Categories'.
     *     @type string $parent_item                This label is only used for hierarchical taxonomies. Default
     *                                              'Parent Category'.
     *     @type string $parent_item_colon          The same as `parent_item`, but with colon `:` in the end.
     *     @type string $name_field_description     Description for the Name field on Edit Tags screen.
     *                                              Default 'The name is how it appears on your site'.
     *     @type string $slug_field_description     Description for the Slug field on Edit Tags screen.
     *                                              Default 'The &#8220;slug&#8221; is the URL-friendly version
     *                                              of the name. It is usually all lowercase and contains
     *                                              only letters, numbers, and hyphens'.
     *     @type string $parent_field_description   Description for the Parent field on Edit Tags screen.
     *                                              Default 'Assign a parent term to create a hierarchy.
     *                                              The term Jazz, for example, would be the parent
     *                                              of Bebop and Big Band'.
     *     @type string $desc_field_description     Description for the Description field on Edit Tags screen.
     *                                              Default 'The description is not prominent by default;
     *                                              however, some themes may show it'.
     *     @type string $edit_item                  Default 'Edit Tag'/'Edit Category'.
     *     @type string $view_item                  Default 'View Tag'/'View Category'.
     *     @type string $update_item                Default 'Update Tag'/'Update Category'.
     *     @type string $add_new_item               Default 'Add New Tag'/'Add New Category'.
     *     @type string $new_item_name              Default 'New Tag Name'/'New Category Name'.
     *     @type string $template_name              Default 'Tag Archives'/'Category Archives'.
     *     @type string $separate_items_with_commas This label is only used for non-hierarchical taxonomies. Default
     *                                              'Separate tags with commas', used in the meta box.
     *     @type string $add_or_remove_items        This label is only used for non-hierarchical taxonomies. Default
     *                                              'Add or remove tags', used in the meta box when JavaScript
     *                                              is disabled.
     *     @type string $choose_from_most_used      This label is only used on non-hierarchical taxonomies. Default
     *                                              'Choose from the most used tags', used in the meta box.
     *     @type string $not_found                  Default 'No tags found'/'No categories found', used in
     *                                              the meta box and taxonomy list table.
     *     @type string $no_terms                   Default 'No tags'/'No categories', used in the posts and media
     *                                              list tables.
     *     @type string $filter_by_item             This label is only used for hierarchical taxonomies. Default
     *                                              'Filter by category', used in the posts list table.
     *     @type string $items_list_navigation      Label for the table pagination hidden heading.
     *     @type string $items_list                 Label for the table hidden heading.
     *     @type string $most_used                  Title for the Most Used tab. Default 'Most Used'.
     *     @type string $back_to_items              Label displayed after a term has been updated.
     *     @type string $item_link                  Used in the block editor. Title for a navigation link block variation.
     *                                              Default 'Tag Link'/'Category Link'.
     *     @type string $item_link_description      Used in the block editor. Description for a navigation link block
     *                                              variation. Default 'A link to a tag'/'A link to a category'.
     * }
     * @phpstan-return object{
     *   name: string,
     *   singular_name: string,
     *   search_items: string,
     *   popular_items: string,
     *   all_items: string,
     *   parent_item: string,
     *   parent_item_colon: string,
     *   name_field_description: string,
     *   slug_field_description: string,
     *   parent_field_description: string,
     *   desc_field_description: string,
     *   edit_item: string,
     *   view_item: string,
     *   update_item: string,
     *   add_new_item: string,
     *   new_item_name: string,
     *   template_name: string,
     *   separate_items_with_commas: string,
     *   add_or_remove_items: string,
     *   choose_from_most_used: string,
     *   not_found: string,
     *   no_terms: string,
     *   filter_by_item: string,
     *   items_list_navigation: string,
     *   items_list: string,
     *   most_used: string,
     *   back_to_items: string,
     *   item_link: string,
     *   item_link_description: string,
     * }
     */
    function get_taxonomy_labels($tax)
    {
    }
    /**
     * Adds an already registered taxonomy to an object type.
     *
     * @since 3.0.0
     *
     * @global WP_Taxonomy[] $wp_taxonomies The registered taxonomies.
     *
     * @param string $taxonomy    Name of taxonomy object.
     * @param string $object_type Name of the object type.
     * @return bool True if successful, false if not.
     */
    function register_taxonomy_for_object_type($taxonomy, $object_type)
    {
    }
    /**
     * Removes an already registered taxonomy from an object type.
     *
     * @since 3.7.0
     *
     * @global WP_Taxonomy[] $wp_taxonomies The registered taxonomies.
     *
     * @param string $taxonomy    Name of taxonomy object.
     * @param string $object_type Name of the object type.
     * @return bool True if successful, false if not.
     */
    function unregister_taxonomy_for_object_type($taxonomy, $object_type)
    {
    }
    /**
     * Retrieves object IDs of valid taxonomy and term.
     *
     * The strings of `$taxonomies` must exist before this function will continue.
     * On failure of finding a valid taxonomy, it will return a WP_Error.
     *
     * The `$terms` aren't checked the same as `$taxonomies`, but still need to exist
     * for object IDs to be returned.
     *
     * It is possible to change the order that object IDs are returned by using `$args`
     * with either ASC or DESC array. The value should be in the key named 'order'.
     *
     * @since 2.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|int[]       $term_ids   Term ID or array of term IDs of terms that will be used.
     * @param string|string[] $taxonomies String of taxonomy name or Array of string values of taxonomy names.
     * @param array|string    $args       {
     *     Change the order of the object IDs.
     *
     *     @type string $order Order to retrieve terms. Accepts 'ASC' or 'DESC'. Default 'ASC'.
     * }
     * @return string[]|WP_Error An array of object IDs as numeric strings on success,
     *                           WP_Error if the taxonomy does not exist.
     * @phpstan-param array{
     *   order?: string,
     * } $args
     */
    function get_objects_in_term($term_ids, $taxonomies, $args = array())
    {
    }
    /**
     * Given a taxonomy query, generates SQL to be appended to a main query.
     *
     * @since 3.1.0
     *
     * @see WP_Tax_Query
     *
     * @param array  $tax_query         A compact tax query
     * @param string $primary_table
     * @param string $primary_id_column
     * @return string[]
     */
    function get_tax_sql($tax_query, $primary_table, $primary_id_column)
    {
    }
    /**
     * Gets all term data from database by term ID.
     *
     * The usage of the get_term function is to apply filters to a term object. It
     * is possible to get a term object from the database before applying the
     * filters.
     *
     * $term ID must be part of $taxonomy, to get from the database. Failure, might
     * be able to be captured by the hooks. Failure would be the same value as $wpdb
     * returns for the get_row method.
     *
     * There are two hooks, one is specifically for each term, named 'get_term', and
     * the second is for the taxonomy name, 'term_$taxonomy'. Both hooks gets the
     * term object, and the taxonomy name as parameters. Both hooks are expected to
     * return a term object.
     *
     * {@see 'get_term'} hook - Takes two parameters the term Object and the taxonomy name.
     * Must return term object. Used in get_term() as a catch-all filter for every
     * $term.
     *
     * {@see 'get_$taxonomy'} hook - Takes two parameters the term Object and the taxonomy
     * name. Must return term object. $taxonomy will be the taxonomy name, so for
     * example, if 'category', it would be 'get_category' as the filter name. Useful
     * for custom taxonomies or plugging into default taxonomies.
     *
     * @todo Better formatting for DocBlock
     *
     * @since 2.3.0
     * @since 4.4.0 Converted to return a WP_Term object if `$output` is `OBJECT`.
     *              The `$taxonomy` parameter was made optional.
     *
     * @see sanitize_term_field() The $context param lists the available values for get_term_by() $filter param.
     *
     * @param int|WP_Term|object $term     If integer, term data will be fetched from the database,
     *                                     or from the cache if available.
     *                                     If stdClass object (as in the results of a database query),
     *                                     will apply filters and return a `WP_Term` object with the `$term` data.
     *                                     If `WP_Term`, will return `$term`.
     * @param string             $taxonomy Optional. Taxonomy name that `$term` is part of.
     * @param string             $output   Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
     *                                     correspond to a WP_Term object, an associative array, or a numeric array,
     *                                     respectively. Default OBJECT.
     * @param string             $filter   Optional. How to sanitize term fields. Default 'raw'.
     * @return WP_Term|array|WP_Error|null WP_Term instance (or array) on success, depending on the `$output` value.
     *                                     WP_Error if `$taxonomy` does not exist. Null for miscellaneous failure.
     * @phpstan-param 'OBJECT'|'ARRAY_A'|'ARRAY_N' $output
     * @phpstan-return ($output is 'ARRAY_A' ? array<string, string|int>|\WP_Error|null : ($output is 'ARRAY_N' ? list<string|int>|\WP_Error|null : \WP_Term|\WP_Error|null))
     */
    function get_term($term, $taxonomy = '', $output = \OBJECT, $filter = 'raw')
    {
    }
    /**
     * Gets all term data from database by term field and data.
     *
     * Warning: $value is not escaped for 'name' $field. You must do it yourself, if
     * required.
     *
     * The default $field is 'id', therefore it is possible to also use null for
     * field, but not recommended that you do so.
     *
     * If $value does not exist, the return value will be false. If $taxonomy exists
     * and $field and $value combinations exist, the term will be returned.
     *
     * This function will always return the first term that matches the `$field`-
     * `$value`-`$taxonomy` combination specified in the parameters. If your query
     * is likely to match more than one term (as is likely to be the case when
     * `$field` is 'name', for example), consider using get_terms() instead; that
     * way, you will get all matching terms, and can provide your own logic for
     * deciding which one was intended.
     *
     * @todo Better formatting for DocBlock.
     *
     * @since 2.3.0
     * @since 4.4.0 `$taxonomy` is optional if `$field` is 'term_taxonomy_id'. Converted to return
     *              a WP_Term object if `$output` is `OBJECT`.
     * @since 5.5.0 Added 'ID' as an alias of 'id' for the `$field` parameter.
     *
     * @see sanitize_term_field() The $context param lists the available values for get_term_by() $filter param.
     *
     * @param string     $field    Either 'slug', 'name', 'term_id' (or 'id', 'ID'), or 'term_taxonomy_id'.
     * @param string|int $value    Search for this term value.
     * @param string     $taxonomy Taxonomy name. Optional, if `$field` is 'term_taxonomy_id'.
     * @param string     $output   Optional. The required return type. One of OBJECT, ARRAY_A, or ARRAY_N, which
     *                             correspond to a WP_Term object, an associative array, or a numeric array,
     *                             respectively. Default OBJECT.
     * @param string     $filter   Optional. How to sanitize term fields. Default 'raw'.
     * @return WP_Term|array|false WP_Term instance (or array) on success, depending on the `$output` value.
     *                             False if `$taxonomy` does not exist or `$term` was not found.
     * @phpstan-return ($output is 'ARRAY_A' ? array<string, string|int>|\WP_Error|false : ($output is 'ARRAY_N' ? list<string|int>|\WP_Error|false : \WP_Term|\WP_Error|false))
     */
    function get_term_by($field, $value, $taxonomy = '', $output = \OBJECT, $filter = 'raw')
    {
    }
    /**
     * Merges all term children into a single array of their IDs.
     *
     * This recursive function will merge all of the children of $term into the same
     * array of term IDs. Only useful for taxonomies which are hierarchical.
     *
     * Will return an empty array if $term does not exist in $taxonomy.
     *
     * @since 2.3.0
     *
     * @param int    $term_id  ID of term to get children.
     * @param string $taxonomy Taxonomy name.
     * @return array|WP_Error List of term IDs. WP_Error returned if `$taxonomy` does not exist.
     */
    function get_term_children($term_id, $taxonomy)
    {
    }
    /**
     * Gets sanitized term field.
     *
     * The function is for contextual reasons and for simplicity of usage.
     *
     * @since 2.3.0
     * @since 4.4.0 The `$taxonomy` parameter was made optional. `$term` can also now accept a WP_Term object.
     *
     * @see sanitize_term_field()
     *
     * @param string      $field    Term field to fetch.
     * @param int|WP_Term $term     Term ID or object.
     * @param string      $taxonomy Optional. Taxonomy name. Default empty.
     * @param string      $context  Optional. How to sanitize term fields. Look at sanitize_term_field() for available options.
     *                              Default 'display'.
     * @return string|int|null|WP_Error Will return an empty string if $term is not an object or if $field is not set in $term.
     */
    function get_term_field($field, $term, $taxonomy = '', $context = 'display')
    {
    }
    /**
     * Sanitizes term for editing.
     *
     * Return value is sanitize_term() and usage is for sanitizing the term for
     * editing. Function is for contextual and simplicity.
     *
     * @since 2.3.0
     *
     * @param int|object $id       Term ID or object.
     * @param string     $taxonomy Taxonomy name.
     * @return string|int|null|WP_Error Will return empty string if $term is not an object.
     */
    function get_term_to_edit($id, $taxonomy)
    {
    }
    /**
     * Retrieves the terms in a given taxonomy or list of taxonomies.
     *
     * You can fully inject any customizations to the query before it is sent, as
     * well as control the output with a filter.
     *
     * The return type varies depending on the value passed to `$args['fields']`. See
     * WP_Term_Query::get_terms() for details. In all cases, a `WP_Error` object will
     * be returned if an invalid taxonomy is requested.
     *
     * The {@see 'get_terms'} filter will be called when the cache has the term and will
     * pass the found term along with the array of $taxonomies and array of $args.
     * This filter is also called before the array of terms is passed and will pass
     * the array of terms, along with the $taxonomies and $args.
     *
     * The {@see 'list_terms_exclusions'} filter passes the compiled exclusions along with
     * the $args.
     *
     * The {@see 'get_terms_orderby'} filter passes the `ORDER BY` clause for the query
     * along with the $args array.
     *
     * Taxonomy or an array of taxonomies should be passed via the 'taxonomy' argument
     * in the `$args` array:
     *
     *     $terms = get_terms( array(
     *         'taxonomy'   => 'post_tag',
     *         'hide_empty' => false,
     *     ) );
     *
     * Prior to 4.5.0, taxonomy was passed as the first parameter of `get_terms()`.
     *
     * @since 2.3.0
     * @since 4.2.0 Introduced 'name' and 'childless' parameters.
     * @since 4.4.0 Introduced the ability to pass 'term_id' as an alias of 'id' for the `orderby` parameter.
     *              Introduced the 'meta_query' and 'update_term_meta_cache' parameters. Converted to return
     *              a list of WP_Term objects.
     * @since 4.5.0 Changed the function signature so that the `$args` array can be provided as the first parameter.
     *              Introduced 'meta_key' and 'meta_value' parameters. Introduced the ability to order results by metadata.
     * @since 4.8.0 Introduced 'suppress_filter' parameter.
     *
     * @internal The `$deprecated` parameter is parsed for backward compatibility only.
     *
     * @param array|string $args       Optional. Array or string of arguments. See WP_Term_Query::__construct()
     *                                 for information on accepted arguments. Default empty array.
     * @param array|string $deprecated Optional. Argument array, when using the legacy function parameter format.
     *                                 If present, this parameter will be interpreted as `$args`, and the first
     *                                 function parameter will be parsed as a taxonomy or array of taxonomies.
     *                                 Default empty.
     * @return WP_Term[]|int[]|string[]|string|WP_Error Array of terms, a count thereof as a numeric string,
     *                                                  or WP_Error if any of the taxonomies do not exist.
     *                                                  See the function description for more information.
     * @phpstan-param array{
     *   taxonomy?: string|string[],
     *   object_ids?: int|int[],
     *   orderby?: string,
     *   order?: string,
     *   hide_empty?: bool|int,
     *   include?: int[]|string,
     *   exclude?: int[]|string,
     *   exclude_tree?: int[]|string,
     *   number?: int|string,
     *   offset?: int,
     *   fields?: string,
     *   name?: string|string[],
     *   slug?: string|string[],
     *   term_taxonomy_id?: int|int[],
     *   hierarchical?: bool,
     *   search?: string,
     *   name__like?: string,
     *   description__like?: string,
     *   pad_counts?: bool,
     *   get?: string,
     *   child_of?: int,
     *   parent?: int,
     *   childless?: bool,
     *   cache_domain?: string,
     *   cache_results?: bool,
     *   update_term_meta_cache?: bool,
     *   meta_key?: string|string[],
     *   meta_value?: string|string[],
     *   meta_compare?: string,
     *   meta_compare_key?: string,
     *   meta_type?: string,
     *   meta_type_key?: string,
     *   meta_query?: array,
     * } $args See WP_Term_Query::__construct()
     * @phpstan-return ($args is array{fields: 'count'}&array ? numeric-string : ($args is array{fields: 'names'|'slugs'}&array ? list<string> : ($args is array{fields: 'id=>name'|'id=>slug'}&array ? array<int, string> : ($args is array{fields: 'id=>parent'}&array ? array<int, int> : ($args is array{fields: 'ids'|'tt_ids'}&array ? list<int> : array<int, \WP_Term>)))))|\WP_Error
     */
    function get_terms($args = array(), $deprecated = '')
    {
    }
    /**
     * Adds metadata to a term.
     *
     * @since 4.4.0
     *
     * @param int    $term_id    Term ID.
     * @param string $meta_key   Metadata name.
     * @param mixed  $meta_value Metadata value. Must be serializable if non-scalar.
     * @param bool   $unique     Optional. Whether the same key should not be added.
     *                           Default false.
     * @return int|false|WP_Error Meta ID on success, false on failure.
     *                            WP_Error when term_id is ambiguous between taxonomies.
     */
    function add_term_meta($term_id, $meta_key, $meta_value, $unique = \false)
    {
    }
    /**
     * Removes metadata matching criteria from a term.
     *
     * @since 4.4.0
     *
     * @param int    $term_id    Term ID.
     * @param string $meta_key   Metadata name.
     * @param mixed  $meta_value Optional. Metadata value. If provided,
     *                           rows will only be removed that match the value.
     *                           Must be serializable if non-scalar. Default empty.
     * @return bool True on success, false on failure.
     */
    function delete_term_meta($term_id, $meta_key, $meta_value = '')
    {
    }
    /**
     * Retrieves metadata for a term.
     *
     * @since 4.4.0
     *
     * @param int    $term_id Term ID.
     * @param string $key     Optional. The meta key to retrieve. By default,
     *                        returns data for all keys. Default empty.
     * @param bool   $single  Optional. Whether to return a single value.
     *                        This parameter has no effect if `$key` is not specified.
     *                        Default false.
     * @return mixed An array of values if `$single` is false.
     *               The value of the meta field if `$single` is true.
     *               False for an invalid `$term_id` (non-numeric, zero, or negative value).
     *               An empty array if a valid but non-existing term ID is passed and `$single` is false.
     *               An empty string if a valid but non-existing term ID is passed and `$single` is true.
     */
    function get_term_meta($term_id, $key = '', $single = \false)
    {
    }
    /**
     * Updates term metadata.
     *
     * Use the `$prev_value` parameter to differentiate between meta fields with the same key and term ID.
     *
     * If the meta field for the term does not exist, it will be added.
     *
     * @since 4.4.0
     *
     * @param int    $term_id    Term ID.
     * @param string $meta_key   Metadata key.
     * @param mixed  $meta_value Metadata value. Must be serializable if non-scalar.
     * @param mixed  $prev_value Optional. Previous value to check before updating.
     *                           If specified, only update existing metadata entries with
     *                           this value. Otherwise, update all entries. Default empty.
     * @return int|bool|WP_Error Meta ID if the key didn't exist. true on successful update,
     *                           false on failure or if the value passed to the function
     *                           is the same as the one that is already in the database.
     *                           WP_Error when term_id is ambiguous between taxonomies.
     */
    function update_term_meta($term_id, $meta_key, $meta_value, $prev_value = '')
    {
    }
    /**
     * Updates metadata cache for list of term IDs.
     *
     * Performs SQL query to retrieve all metadata for the terms matching `$term_ids` and stores them in the cache.
     * Subsequent calls to `get_term_meta()` will not need to query the database.
     *
     * @since 4.4.0
     *
     * @param array $term_ids List of term IDs.
     * @return array|false An array of metadata on success, false if there is nothing to update.
     */
    function update_termmeta_cache($term_ids)
    {
    }
    /**
     * Queue term meta for lazy-loading.
     *
     * @since 6.3.0
     *
     * @param array $term_ids List of term IDs.
     * @phpstan-return void
     */
    function wp_lazyload_term_meta(array $term_ids)
    {
    }
    /**
     * Gets all meta data, including meta IDs, for the given term ID.
     *
     * @since 4.9.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $term_id Term ID.
     * @return array|false Array with meta data, or false when the meta table is not installed.
     */
    function has_term_meta($term_id)
    {
    }
    /**
     * Registers a meta key for terms.
     *
     * @since 4.9.8
     *
     * @param string $taxonomy Taxonomy to register a meta key for. Pass an empty string
     *                         to register the meta key across all existing taxonomies.
     * @param string $meta_key The meta key to register.
     * @param array  $args     Data used to describe the meta key when registered. See
     *                         {@see register_meta()} for a list of supported arguments.
     * @return bool True if the meta key was successfully registered, false if not.
     * @phpstan-param array{
     *   object_subtype?: string,
     *   type?: string,
     *   label?: string,
     *   description?: string,
     *   single?: bool,
     *   default?: mixed,
     *   sanitize_callback?: callable,
     *   auth_callback?: callable,
     *   show_in_rest?: bool|array,
     *   revisions_enabled?: bool,
     * } $args See register_meta()
     */
    function register_term_meta($taxonomy, $meta_key, array $args)
    {
    }
    /**
     * Unregisters a meta key for terms.
     *
     * @since 4.9.8
     *
     * @param string $taxonomy Taxonomy the meta key is currently registered for. Pass
     *                         an empty string if the meta key is registered across all
     *                         existing taxonomies.
     * @param string $meta_key The meta key to unregister.
     * @return bool True on success, false if the meta key was not previously registered.
     */
    function unregister_term_meta($taxonomy, $meta_key)
    {
    }
    /**
     * Determines whether a taxonomy term exists.
     *
     * Formerly is_term(), introduced in 2.3.0.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 3.0.0
     * @since 6.0.0 Converted to use `get_terms()`.
     *
     * @global bool $_wp_suspend_cache_invalidation
     *
     * @param int|string $term        The term to check. Accepts term ID, slug, or name.
     * @param string     $taxonomy    Optional. The taxonomy name to use.
     * @param int        $parent_term Optional. ID of parent term under which to confine the exists search.
     * @return mixed Returns null if the term does not exist.
     *               Returns the term ID if no taxonomy is specified and the term ID exists.
     *               Returns an array of the term ID and the term taxonomy ID if the taxonomy is specified and the pairing exists.
     *               Returns 0 if term ID 0 is passed to the function.
     * @phpstan-return ($term is 0 ? 0 : ($term is '' ? null : ($taxonomy is '' ? string|null : array{term_id: string, term_taxonomy_id: string}|null)))
     */
    function term_exists($term, $taxonomy = '', $parent_term = \null)
    {
    }
    /**
     * Checks if a term is an ancestor of another term.
     *
     * You can use either an ID or the term object for both parameters.
     *
     * @since 3.4.0
     *
     * @param int|object $term1    ID or object to check if this is the parent term.
     * @param int|object $term2    The child term.
     * @param string     $taxonomy Taxonomy name that $term1 and `$term2` belong to.
     * @return bool Whether `$term2` is a child of `$term1`.
     */
    function term_is_ancestor_of($term1, $term2, $taxonomy)
    {
    }
    /**
     * Sanitizes all term fields.
     *
     * Relies on sanitize_term_field() to sanitize the term. The difference is that
     * this function will sanitize **all** fields. The context is based
     * on sanitize_term_field().
     *
     * The `$term` is expected to be either an array or an object.
     *
     * @since 2.3.0
     *
     * @param array|object $term     The term to check.
     * @param string       $taxonomy The taxonomy name to use.
     * @param string       $context  Optional. Context in which to sanitize the term.
     *                               Accepts 'raw', 'edit', 'db', 'display', 'rss',
     *                               'attribute', or 'js'. Default 'display'.
     * @return array|object Term with all fields sanitized.
     * @phpstan-param 'raw'|'edit'|'db'|'display'|'rss'|'attribute'|'js' $context
     * @phpstan-template T of array|object
     * @phpstan-param T $term
     * @phpstan-return T
     */
    function sanitize_term($term, $taxonomy, $context = 'display')
    {
    }
    /**
     * Sanitizes the field value in the term based on the context.
     *
     * Passing a term field value through the function should be assumed to have
     * cleansed the value for whatever context the term field is going to be used.
     *
     * If no context or an unsupported context is given, then default filters will
     * be applied.
     *
     * There are enough filters for each context to support a custom filtering
     * without creating your own filter function. Simply create a function that
     * hooks into the filter you need.
     *
     * @since 2.3.0
     *
     * @param string $field    Term field to sanitize.
     * @param string $value    Search for this term value.
     * @param int    $term_id  Term ID.
     * @param string $taxonomy Taxonomy name.
     * @param string $context  Context in which to sanitize the term field.
     *                         Accepts 'raw', 'edit', 'db', 'display', 'rss',
     *                         'attribute', or 'js'. Default 'display'.
     * @return mixed Sanitized field.
     * @phpstan-param 'raw'|'edit'|'db'|'display'|'rss'|'attribute'|'js' $context
     */
    function sanitize_term_field($field, $value, $term_id, $taxonomy, $context)
    {
    }
    /**
     * Counts how many terms are in taxonomy.
     *
     * Default $args is 'hide_empty' which can be 'hide_empty=true' or array('hide_empty' => true).
     *
     * @since 2.3.0
     * @since 5.6.0 Changed the function signature so that the `$args` array can be provided as the first parameter.
     *
     * @internal The `$deprecated` parameter is parsed for backward compatibility only.
     *
     * @param array|string $args       Optional. Array or string of arguments. See WP_Term_Query::__construct()
     *                                 for information on accepted arguments. Default empty array.
     * @param array|string $deprecated Optional. Argument array, when using the legacy function parameter format.
     *                                 If present, this parameter will be interpreted as `$args`, and the first
     *                                 function parameter will be parsed as a taxonomy or array of taxonomies.
     *                                 Default empty.
     * @return string|WP_Error Numeric string containing the number of terms in that
     *                         taxonomy or WP_Error if the taxonomy does not exist.
     * @phpstan-param array{
     *   taxonomy?: string|string[],
     *   object_ids?: int|int[],
     *   orderby?: string,
     *   order?: string,
     *   hide_empty?: bool|int,
     *   include?: int[]|string,
     *   exclude?: int[]|string,
     *   exclude_tree?: int[]|string,
     *   number?: int|string,
     *   offset?: int,
     *   fields?: string,
     *   name?: string|string[],
     *   slug?: string|string[],
     *   term_taxonomy_id?: int|int[],
     *   hierarchical?: bool,
     *   search?: string,
     *   name__like?: string,
     *   description__like?: string,
     *   pad_counts?: bool,
     *   get?: string,
     *   child_of?: int,
     *   parent?: int,
     *   childless?: bool,
     *   cache_domain?: string,
     *   cache_results?: bool,
     *   update_term_meta_cache?: bool,
     *   meta_key?: string|string[],
     *   meta_value?: string|string[],
     *   meta_compare?: string,
     *   meta_compare_key?: string,
     *   meta_type?: string,
     *   meta_type_key?: string,
     *   meta_query?: array,
     * } $args See WP_Term_Query::__construct()
     */
    function wp_count_terms($args = array(), $deprecated = '')
    {
    }
    /**
     * Unlinks the object from the taxonomy or taxonomies.
     *
     * Will remove all relationships between the object and any terms in
     * a particular taxonomy or taxonomies. Does not remove the term or
     * taxonomy itself.
     *
     * @since 2.3.0
     *
     * @param int          $object_id  The term object ID that refers to the term.
     * @param string|array $taxonomies List of taxonomy names or single taxonomy name.
     */
    function wp_delete_object_term_relationships($object_id, $taxonomies)
    {
    }
    /**
     * Removes a term from the database.
     *
     * If the term is a parent of other terms, then the children will be updated to
     * that term's parent.
     *
     * Metadata associated with the term will be deleted.
     *
     * @since 2.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int          $term     Term ID.
     * @param string       $taxonomy Taxonomy name.
     * @param array|string $args {
     *     Optional. Array of arguments to override the default term ID. Default empty array.
     *
     *     @type int  $default       The term ID to make the default term. This will only override
     *                               the terms found if there is only one term found. Any other and
     *                               the found terms are used.
     *     @type bool $force_default Optional. Whether to force the supplied term as default to be
     *                               assigned even if the object was not going to be term-less.
     *                               Default false.
     * }
     * @return bool|int|WP_Error True on success, false if term does not exist. Zero on attempted
     *                           deletion of default Category. WP_Error if the taxonomy does not exist.
     * @phpstan-param array{
     *   default?: int,
     *   force_default?: bool,
     * } $args
     */
    function wp_delete_term($term, $taxonomy, $args = array())
    {
    }
    /**
     * Deletes one existing category.
     *
     * @since 2.0.0
     *
     * @param int $cat_id Category term ID.
     * @return bool|int|WP_Error Returns true if completes delete action; false if term doesn't exist;
     *                           Zero on attempted deletion of default Category; WP_Error object is
     *                           also a possibility.
     */
    function wp_delete_category($cat_id)
    {
    }
    /**
     * Retrieves the terms associated with the given object(s), in the supplied taxonomies.
     *
     * @since 2.3.0
     * @since 4.2.0 Added support for 'taxonomy', 'parent', and 'term_taxonomy_id' values of `$orderby`.
     *              Introduced `$parent` argument.
     * @since 4.4.0 Introduced `$meta_query` and `$update_term_meta_cache` arguments. When `$fields` is 'all' or
     *              'all_with_object_id', an array of `WP_Term` objects will be returned.
     * @since 4.7.0 Refactored to use WP_Term_Query, and to support any WP_Term_Query arguments.
     * @since 6.3.0 Passing `update_term_meta_cache` argument value false by default resulting in get_terms() to not
     *              prime the term meta cache.
     *
     * @param int|int[]       $object_ids The ID(s) of the object(s) to retrieve.
     * @param string|string[] $taxonomies The taxonomy names to retrieve terms from.
     * @param array|string    $args       See WP_Term_Query::__construct() for supported arguments.
     * @return WP_Term[]|int[]|string[]|string|WP_Error Array of terms, a count thereof as a numeric string,
     *                                                  or WP_Error if any of the taxonomies do not exist.
     *                                                  See WP_Term_Query::get_terms() for more information.
     * @phpstan-param array{
     *   taxonomy?: string|string[],
     *   object_ids?: int|int[],
     *   orderby?: string,
     *   order?: string,
     *   hide_empty?: bool|int,
     *   include?: int[]|string,
     *   exclude?: int[]|string,
     *   exclude_tree?: int[]|string,
     *   number?: int|string,
     *   offset?: int,
     *   fields?: string,
     *   name?: string|string[],
     *   slug?: string|string[],
     *   term_taxonomy_id?: int|int[],
     *   hierarchical?: bool,
     *   search?: string,
     *   name__like?: string,
     *   description__like?: string,
     *   pad_counts?: bool,
     *   get?: string,
     *   child_of?: int,
     *   parent?: int,
     *   childless?: bool,
     *   cache_domain?: string,
     *   cache_results?: bool,
     *   update_term_meta_cache?: bool,
     *   meta_key?: string|string[],
     *   meta_value?: string|string[],
     *   meta_compare?: string,
     *   meta_compare_key?: string,
     *   meta_type?: string,
     *   meta_type_key?: string,
     *   meta_query?: array,
     * } $args See WP_Term_Query::__construct()
     * @phpstan-return ($object_ids is empty ? array{} : ($taxonomies is empty ? array{} : (($args is array{fields: 'names'|'slugs'}&array ? list<string> : ($args is array{fields: 'id=>name'|'id=>slug'}&array ? array<int, string> : ($args is array{fields: 'id=>parent'}&array ? array<int, int> : ($args is array{fields: 'ids'|'tt_ids'}&array ? list<int> : ($args is array{fields: 'count'}&array ? numeric-string : array<int, \WP_Term>)))))|\WP_Error)))
     */
    function wp_get_object_terms($object_ids, $taxonomies, $args = array())
    {
    }
    /**
     * Adds a new term to the database.
     *
     * A non-existent term is inserted in the following sequence:
     * 1. The term is added to the term table, then related to the taxonomy.
     * 2. If everything is correct, several actions are fired.
     * 3. The 'term_id_filter' is evaluated.
     * 4. The term cache is cleaned.
     * 5. Several more actions are fired.
     * 6. An array is returned containing the `term_id` and `term_taxonomy_id`.
     *
     * If the 'slug' argument is not empty, then it is checked to see if the term
     * is invalid. If it is not a valid, existing term, it is added and the term_id
     * is given.
     *
     * If the taxonomy is hierarchical, and the 'parent' argument is not empty,
     * the term is inserted and the term_id will be given.
     *
     * Error handling:
     * If `$taxonomy` does not exist or `$term` is empty,
     * a WP_Error object will be returned.
     *
     * If the term already exists on the same hierarchical level,
     * or the term slug and name are not unique, a WP_Error object will be returned.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @since 2.3.0
     *
     * @param string       $term     The term name to add.
     * @param string       $taxonomy The taxonomy to which to add the term.
     * @param array|string $args {
     *     Optional. Array or query string of arguments for inserting a term.
     *
     *     @type string $alias_of    Slug of the term to make this term an alias of.
     *                               Default empty string. Accepts a term slug.
     *     @type string $description The term description. Default empty string.
     *     @type int    $parent      The id of the parent term. Default 0.
     *     @type string $slug        The term slug to use. Default empty string.
     * }
     * @return array|WP_Error {
     *     An array of the new term data, WP_Error otherwise.
     *
     *     @type int        $term_id          The new term ID.
     *     @type int|string $term_taxonomy_id The new term taxonomy ID. Can be a numeric string.
     * }
     * @phpstan-param array{
     *   alias_of?: string,
     *   description?: string,
     *   parent?: int,
     *   slug?: string,
     * } $args
     * @phpstan-return \WP_Error|array{
     *   term_id: int,
     *   term_taxonomy_id: int|string,
     * }
     */
    function wp_insert_term($term, $taxonomy, $args = array())
    {
    }
    /**
     * Creates term and taxonomy relationships.
     *
     * Relates an object (post, link, etc.) to a term and taxonomy type. Creates the
     * term and taxonomy relationship if it doesn't already exist. Creates a term if
     * it doesn't exist (using the slug).
     *
     * A relationship means that the term is grouped in or belongs to the taxonomy.
     * A term has no meaning until it is given context by defining which taxonomy it
     * exists under.
     *
     * @since 2.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int              $object_id The object to relate to.
     * @param string|int|array $terms     A single term slug, single term ID, or array of either term slugs or IDs.
     *                                    Will replace all existing related terms in this taxonomy. Passing an
     *                                    empty array will remove all related terms.
     * @param string           $taxonomy  The context in which to relate the term to the object.
     * @param bool             $append    Optional. If false will delete difference of terms. Default false.
     * @return array|WP_Error Term taxonomy IDs of the affected terms or WP_Error on failure.
     */
    function wp_set_object_terms($object_id, $terms, $taxonomy, $append = \false)
    {
    }
    /**
     * Adds term(s) associated with a given object.
     *
     * @since 3.6.0
     *
     * @param int              $object_id The ID of the object to which the terms will be added.
     * @param string|int|array $terms     The slug(s) or ID(s) of the term(s) to add.
     * @param array|string     $taxonomy  Taxonomy name.
     * @return array|WP_Error Term taxonomy IDs of the affected terms.
     */
    function wp_add_object_terms($object_id, $terms, $taxonomy)
    {
    }
    /**
     * Removes term(s) associated with a given object.
     *
     * @since 3.6.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int              $object_id The ID of the object from which the terms will be removed.
     * @param string|int|array $terms     The slug(s) or ID(s) of the term(s) to remove.
     * @param string           $taxonomy  Taxonomy name.
     * @return bool|WP_Error True on success, false or WP_Error on failure.
     */
    function wp_remove_object_terms($object_id, $terms, $taxonomy)
    {
    }
    /**
     * Makes term slug unique, if it isn't already.
     *
     * The `$slug` has to be unique global to every taxonomy, meaning that one
     * taxonomy term can't have a matching slug with another taxonomy term. Each
     * slug has to be globally unique for every taxonomy.
     *
     * The way this works is that if the taxonomy that the term belongs to is
     * hierarchical and has a parent, it will append that parent to the $slug.
     *
     * If that still doesn't return a unique slug, then it tries to append a number
     * until it finds a number that is truly unique.
     *
     * The only purpose for `$term` is for appending a parent, if one exists.
     *
     * @since 2.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $slug The string that will be tried for a unique slug.
     * @param object $term The term object that the `$slug` will belong to.
     * @return string Will return a true unique slug.
     */
    function wp_unique_term_slug($slug, $term)
    {
    }
    /**
     * Updates term based on arguments provided.
     *
     * The `$args` will indiscriminately override all values with the same field name.
     * Care must be taken to not override important information need to update or
     * update will fail (or perhaps create a new term, neither would be acceptable).
     *
     * Defaults will set 'alias_of', 'description', 'parent', and 'slug' if not
     * defined in `$args` already.
     *
     * 'alias_of' will create a term group, if it doesn't already exist, and
     * update it for the `$term`.
     *
     * If the 'slug' argument in `$args` is missing, then the 'name' will be used.
     * If you set 'slug' and it isn't unique, then a WP_Error is returned.
     * If you don't pass any slug, then a unique one will be created.
     *
     * @since 2.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int          $term_id  The ID of the term.
     * @param string       $taxonomy The taxonomy of the term.
     * @param array        $args {
     *     Optional. Array of arguments for updating a term.
     *
     *     @type string $alias_of    Slug of the term to make this term an alias of.
     *                               Default empty string. Accepts a term slug.
     *     @type string $description The term description. Default empty string.
     *     @type int    $parent      The id of the parent term. Default 0.
     *     @type string $slug        The term slug to use. Default empty string.
     * }
     * @return array|WP_Error An array containing the `term_id` and `term_taxonomy_id`,
     *                        WP_Error otherwise.
     * @phpstan-param array{
     *   alias_of?: string,
     *   description?: string,
     *   parent?: int,
     *   slug?: string,
     * } $args
     */
    function wp_update_term($term_id, $taxonomy, $args = array())
    {
    }
    /**
     * Enables or disables term counting.
     *
     * @since 2.5.0
     *
     * @param bool $defer Optional. Enable if true, disable if false.
     * @return bool Whether term counting is enabled or disabled.
     */
    function wp_defer_term_counting($defer = \null)
    {
    }
    /**
     * Updates the amount of terms in taxonomy.
     *
     * If there is a taxonomy callback applied, then it will be called for updating
     * the count.
     *
     * The default action is to count what the amount of terms have the relationship
     * of term ID. Once that is done, then update the database.
     *
     * @since 2.3.0
     *
     * @param int|array $terms       The term_taxonomy_id of the terms.
     * @param string    $taxonomy    The context of the term.
     * @param bool      $do_deferred Whether to flush the deferred term counts too. Default false.
     * @return bool If no terms will return false, and if successful will return true.
     */
    function wp_update_term_count($terms, $taxonomy, $do_deferred = \false)
    {
    }
    /**
     * Performs term count update immediately.
     *
     * @since 2.5.0
     *
     * @param array  $terms    The term_taxonomy_id of terms to update.
     * @param string $taxonomy The context of the term.
     * @return true Always true when complete.
     */
    function wp_update_term_count_now($terms, $taxonomy)
    {
    }
    /**
     * Removes the taxonomy relationship to terms from the cache.
     *
     * Will remove the entire taxonomy relationship containing term `$object_id`. The
     * term IDs have to exist within the taxonomy `$object_type` for the deletion to
     * take place.
     *
     * @since 2.3.0
     *
     * @global bool $_wp_suspend_cache_invalidation
     *
     * @see get_object_taxonomies() for more on $object_type.
     *
     * @param int|array    $object_ids  Single or list of term object ID(s).
     * @param array|string $object_type The taxonomy object type.
     * @phpstan-return void
     */
    function clean_object_term_cache($object_ids, $object_type)
    {
    }
    /**
     * Removes all of the term IDs from the cache.
     *
     * @since 2.3.0
     *
     * @global wpdb $wpdb                           WordPress database abstraction object.
     * @global bool $_wp_suspend_cache_invalidation
     *
     * @param int|int[] $ids            Single or array of term IDs.
     * @param string    $taxonomy       Optional. Taxonomy slug. Can be empty, in which case the taxonomies of the passed
     *                                  term IDs will be used. Default empty.
     * @param bool      $clean_taxonomy Optional. Whether to clean taxonomy wide caches (true), or just individual
     *                                  term object caches (false). Default true.
     * @phpstan-return void
     */
    function clean_term_cache($ids, $taxonomy = '', $clean_taxonomy = \true)
    {
    }
    /**
     * Cleans the caches for a taxonomy.
     *
     * @since 4.9.0
     *
     * @param string $taxonomy Taxonomy slug.
     */
    function clean_taxonomy_cache($taxonomy)
    {
    }
    /**
     * Retrieves the cached term objects for the given object ID.
     *
     * Upstream functions (like get_the_terms() and is_object_in_term()) are
     * responsible for populating the object-term relationship cache. The current
     * function only fetches relationship data that is already in the cache.
     *
     * @since 2.3.0
     * @since 4.7.0 Returns a `WP_Error` object if there's an error with
     *              any of the matched terms.
     *
     * @param int    $id       Term object ID, for example a post, comment, or user ID.
     * @param string $taxonomy Taxonomy name.
     * @return bool|WP_Term[]|WP_Error Array of `WP_Term` objects, if cached.
     *                                 False if cache is empty for `$taxonomy` and `$id`.
     *                                 WP_Error if get_term() returns an error object for any term.
     */
    function get_object_term_cache($id, $taxonomy)
    {
    }
    /**
     * Updates the cache for the given term object ID(s).
     *
     * Note: Due to performance concerns, great care should be taken to only update
     * term caches when necessary. Processing time can increase exponentially depending
     * on both the number of passed term IDs and the number of taxonomies those terms
     * belong to.
     *
     * Caches will only be updated for terms not already cached.
     *
     * @since 2.3.0
     *
     * @param string|int[]    $object_ids  Comma-separated list or array of term object IDs.
     * @param string|string[] $object_type The taxonomy object type or array of the same.
     * @return void|false Void on success or if the `$object_ids` parameter is empty,
     *                    false if all of the terms in `$object_ids` are already cached.
     */
    function update_object_term_cache($object_ids, $object_type)
    {
    }
    /**
     * Updates terms in cache.
     *
     * @since 2.3.0
     *
     * @param WP_Term[] $terms    Array of term objects to change.
     * @param string    $taxonomy Not used.
     */
    function update_term_cache($terms, $taxonomy = '')
    {
    }
    /**
     * Retrieves children of taxonomy as term IDs.
     *
     * @access private
     * @since 2.3.0
     *
     * @param string $taxonomy Taxonomy name.
     * @return array Empty if $taxonomy isn't hierarchical or returns children as term IDs.
     */
    function _get_term_hierarchy($taxonomy)
    {
    }
    /**
     * Gets the subset of $terms that are descendants of $term_id.
     *
     * If `$terms` is an array of objects, then _get_term_children() returns an array of objects.
     * If `$terms` is an array of IDs, then _get_term_children() returns an array of IDs.
     *
     * @access private
     * @since 2.3.0
     *
     * @param int    $term_id   The ancestor term: all returned terms should be descendants of `$term_id`.
     * @param array  $terms     The set of terms - either an array of term objects or term IDs - from which those that
     *                          are descendants of $term_id will be chosen.
     * @param string $taxonomy  The taxonomy which determines the hierarchy of the terms.
     * @param array  $ancestors Optional. Term ancestors that have already been identified. Passed by reference, to keep
     *                          track of found terms when recursing the hierarchy. The array of located ancestors is used
     *                          to prevent infinite recursion loops. For performance, `term_ids` are used as array keys,
     *                          with 1 as value. Default empty array.
     * @return array|WP_Error The subset of $terms that are descendants of $term_id.
     */
    function _get_term_children($term_id, $terms, $taxonomy, &$ancestors = array())
    {
    }
    /**
     * Adds count of children to parent count.
     *
     * Recalculates term counts by including items from child terms. Assumes all
     * relevant children are already in the $terms argument.
     *
     * @access private
     * @since 2.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param object[]|WP_Term[] $terms    List of term objects (passed by reference).
     * @param string             $taxonomy Term context.
     * @phpstan-return void
     */
    function _pad_term_counts(&$terms, $taxonomy)
    {
    }
    /**
     * Adds any terms from the given IDs to the cache that do not already exist in cache.
     *
     * @since 4.6.0
     * @since 6.1.0 This function is no longer marked as "private".
     * @since 6.3.0 Use wp_lazyload_term_meta() for lazy-loading of term meta.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array $term_ids          Array of term IDs.
     * @param bool  $update_meta_cache Optional. Whether to update the meta cache. Default true.
     */
    function _prime_term_caches($term_ids, $update_meta_cache = \true)
    {
    }
    /**
     * Updates term count based on object types of the current taxonomy.
     *
     * Private function for the default callback for post_tag and category
     * taxonomies.
     *
     * @access private
     * @since 2.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int[]       $terms    List of term taxonomy IDs.
     * @param WP_Taxonomy $taxonomy Current taxonomy object of terms.
     */
    function _update_post_term_count($terms, $taxonomy)
    {
    }
    /**
     * Updates term count based on number of objects.
     *
     * Default callback for the 'link_category' taxonomy.
     *
     * @since 3.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int[]       $terms    List of term taxonomy IDs.
     * @param WP_Taxonomy $taxonomy Current taxonomy object of terms.
     */
    function _update_generic_term_count($terms, $taxonomy)
    {
    }
    /**
     * Creates a new term for a term_taxonomy item that currently shares its term
     * with another term_taxonomy.
     *
     * @ignore
     * @since 4.2.0
     * @since 4.3.0 Introduced `$record` parameter. Also, `$term_id` and
     *              `$term_taxonomy_id` can now accept objects.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|object $term_id          ID of the shared term, or the shared term object.
     * @param int|object $term_taxonomy_id ID of the term_taxonomy item to receive a new term, or the term_taxonomy object
     *                                     (corresponding to a row from the term_taxonomy table).
     * @param bool       $record           Whether to record data about the split term in the options table. The recording
     *                                     process has the potential to be resource-intensive, so during batch operations
     *                                     it can be beneficial to skip inline recording and do it just once, after the
     *                                     batch is processed. Only set this to `false` if you know what you are doing.
     *                                     Default: true.
     * @return int|WP_Error When the current term does not need to be split (or cannot be split on the current
     *                      database schema), `$term_id` is returned. When the term is successfully split, the
     *                      new term_id is returned. A WP_Error is returned for miscellaneous errors.
     */
    function _split_shared_term($term_id, $term_taxonomy_id, $record = \true)
    {
    }
    /**
     * Splits a batch of shared taxonomy terms.
     *
     * @since 4.3.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     * @phpstan-return void
     */
    function _wp_batch_split_terms()
    {
    }
    /**
     * In order to avoid the _wp_batch_split_terms() job being accidentally removed,
     * checks that it's still scheduled while we haven't finished splitting terms.
     *
     * @ignore
     * @since 4.3.0
     */
    function _wp_check_for_scheduled_split_terms()
    {
    }
    /**
     * Checks default categories when a term gets split to see if any of them need to be updated.
     *
     * @ignore
     * @since 4.2.0
     *
     * @param int    $term_id          ID of the formerly shared term.
     * @param int    $new_term_id      ID of the new term created for the $term_taxonomy_id.
     * @param int    $term_taxonomy_id ID for the term_taxonomy row affected by the split.
     * @param string $taxonomy         Taxonomy for the split term.
     * @phpstan-return void
     */
    function _wp_check_split_default_terms($term_id, $new_term_id, $term_taxonomy_id, $taxonomy)
    {
    }
    /**
     * Checks menu items when a term gets split to see if any of them need to be updated.
     *
     * @ignore
     * @since 4.2.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $term_id          ID of the formerly shared term.
     * @param int    $new_term_id      ID of the new term created for the $term_taxonomy_id.
     * @param int    $term_taxonomy_id ID for the term_taxonomy row affected by the split.
     * @param string $taxonomy         Taxonomy for the split term.
     */
    function _wp_check_split_terms_in_menus($term_id, $new_term_id, $term_taxonomy_id, $taxonomy)
    {
    }
    /**
     * If the term being split is a nav_menu, changes associations.
     *
     * @ignore
     * @since 4.3.0
     *
     * @param int    $term_id          ID of the formerly shared term.
     * @param int    $new_term_id      ID of the new term created for the $term_taxonomy_id.
     * @param int    $term_taxonomy_id ID for the term_taxonomy row affected by the split.
     * @param string $taxonomy         Taxonomy for the split term.
     * @phpstan-return void
     */
    function _wp_check_split_nav_menu_terms($term_id, $new_term_id, $term_taxonomy_id, $taxonomy)
    {
    }
    /**
     * Gets data about terms that previously shared a single term_id, but have since been split.
     *
     * @since 4.2.0
     *
     * @param int $old_term_id Term ID. This is the old, pre-split term ID.
     * @return array Array of new term IDs, keyed by taxonomy.
     */
    function wp_get_split_terms($old_term_id)
    {
    }
    /**
     * Gets the new term ID corresponding to a previously split term.
     *
     * @since 4.2.0
     *
     * @param int    $old_term_id Term ID. This is the old, pre-split term ID.
     * @param string $taxonomy    Taxonomy that the term belongs to.
     * @return int|false If a previously split term is found corresponding to the old term_id and taxonomy,
     *                   the new term_id will be returned. If no previously split term is found matching
     *                   the parameters, returns false.
     */
    function wp_get_split_term($old_term_id, $taxonomy)
    {
    }
    /**
     * Determines whether a term is shared between multiple taxonomies.
     *
     * Shared taxonomy terms began to be split in 4.3, but failed cron tasks or
     * other delays in upgrade routines may cause shared terms to remain.
     *
     * @since 4.4.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $term_id Term ID.
     * @return bool Returns false if a term is not shared between multiple taxonomies or
     *              if splitting shared taxonomy terms is finished.
     */
    function wp_term_is_shared($term_id)
    {
    }
    /**
     * Generates a permalink for a taxonomy term archive.
     *
     * @since 2.5.0
     *
     * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
     *
     * @param WP_Term|int|string $term     The term object, ID, or slug whose link will be retrieved.
     * @param string             $taxonomy Optional. Taxonomy. Default empty.
     * @return string|WP_Error URL of the taxonomy term archive on success, WP_Error if term does not exist.
     */
    function get_term_link($term, $taxonomy = '')
    {
    }
    /**
     * Displays the taxonomies of a post with available options.
     *
     * This function can be used within the loop to display the taxonomies for a
     * post without specifying the Post ID. You can also use it outside the Loop to
     * display the taxonomies for a specific post.
     *
     * @since 2.5.0
     *
     * @param array $args {
     *     Arguments about which post to use and how to format the output. Shares all of the arguments
     *     supported by get_the_taxonomies(), in addition to the following.
     *
     *     @type int|WP_Post $post   Post ID or object to get taxonomies of. Default current post.
     *     @type string      $before Displays before the taxonomies. Default empty string.
     *     @type string      $sep    Separates each taxonomy. Default is a space.
     *     @type string      $after  Displays after the taxonomies. Default empty string.
     * }
     * @phpstan-param array{
     *   post?: int|WP_Post,
     *   before?: string,
     *   sep?: string,
     *   after?: string,
     * } $args
     */
    function the_taxonomies($args = array())
    {
    }
    /**
     * Retrieves all taxonomies associated with a post.
     *
     * This function can be used within the loop. It will also return an array of
     * the taxonomies with links to the taxonomy and name.
     *
     * @since 2.5.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @param array       $args {
     *           Optional. Arguments about how to format the list of taxonomies. Default empty array.
     *
     *     @type string $template      Template for displaying a taxonomy label and list of terms.
     *                                 Default is "Label: Terms."
     *     @type string $term_template Template for displaying a single term in the list. Default is the term name
     *                                 linked to its archive.
     * }
     * @return string[] List of taxonomies.
     * @phpstan-param array{
     *   template?: string,
     *   term_template?: string,
     * } $args
     */
    function get_the_taxonomies($post = 0, $args = array())
    {
    }
    /**
     * Retrieves all taxonomy names for the given post.
     *
     * @since 2.5.0
     *
     * @param int|WP_Post $post Optional. Post ID or WP_Post object. Default is global $post.
     * @return string[] An array of all taxonomy names for the given post.
     */
    function get_post_taxonomies($post = 0)
    {
    }
    /**
     * Determines if the given object is associated with any of the given terms.
     *
     * The given terms are checked against the object's terms' term_ids, names and slugs.
     * Terms given as integers will only be checked against the object's terms' term_ids.
     * If no terms are given, determines if object is associated with any terms in the given taxonomy.
     *
     * @since 2.7.0
     *
     * @param int                       $object_id ID of the object (post ID, link ID, ...).
     * @param string                    $taxonomy  Single taxonomy name.
     * @param int|string|int[]|string[] $terms     Optional. Term ID, name, slug, or array of such
     *                                             to check against. Default null.
     * @return bool|WP_Error WP_Error on input error.
     */
    function is_object_in_term($object_id, $taxonomy, $terms = \null)
    {
    }
    /**
     * Determines if the given object type is associated with the given taxonomy.
     *
     * @since 3.0.0
     *
     * @param string $object_type Object type string.
     * @param string $taxonomy    Single taxonomy name.
     * @return bool True if object is associated with the taxonomy, otherwise false.
     */
    function is_object_in_taxonomy($object_type, $taxonomy)
    {
    }
    /**
     * Gets an array of ancestor IDs for a given object.
     *
     * @since 3.1.0
     * @since 4.1.0 Introduced the `$resource_type` argument.
     *
     * @param int    $object_id     Optional. The ID of the object. Default 0.
     * @param string $object_type   Optional. The type of object for which we'll be retrieving
     *                              ancestors. Accepts a post type or a taxonomy name. Default empty.
     * @param string $resource_type Optional. Type of resource $object_type is. Accepts 'post_type'
     *                              or 'taxonomy'. Default empty.
     * @return int[] An array of IDs of ancestors from lowest to highest in the hierarchy.
     * @phpstan-param 'post_type'|'taxonomy' $resource_type
     */
    function get_ancestors($object_id = 0, $object_type = '', $resource_type = '')
    {
    }
    /**
     * Returns the term's parent's term ID.
     *
     * @since 3.1.0
     *
     * @param int    $term_id  Term ID.
     * @param string $taxonomy Taxonomy name.
     * @return int|false Parent term ID on success, false on failure.
     */
    function wp_get_term_taxonomy_parent_id($term_id, $taxonomy)
    {
    }
    /**
     * Checks the given subset of the term hierarchy for hierarchy loops.
     * Prevents loops from forming and breaks those that it finds.
     *
     * Attached to the {@see 'wp_update_term_parent'} filter.
     *
     * @since 3.1.0
     *
     * @param int    $parent_term `term_id` of the parent for the term we're checking.
     * @param int    $term_id     The term we're checking.
     * @param string $taxonomy    The taxonomy of the term we're checking.
     * @return int The new parent for the term.
     */
    function wp_check_term_hierarchy_for_loops($parent_term, $term_id, $taxonomy)
    {
    }
    /**
     * Determines whether a taxonomy is considered "viewable".
     *
     * @since 5.1.0
     *
     * @param string|WP_Taxonomy $taxonomy Taxonomy name or object.
     * @return bool Whether the taxonomy should be considered viewable.
     */
    function is_taxonomy_viewable($taxonomy)
    {
    }
    /**
     * Determines whether a term is publicly viewable.
     *
     * A term is considered publicly viewable if its taxonomy is viewable.
     *
     * @since 6.1.0
     *
     * @param int|WP_Term $term Term ID or term object.
     * @return bool Whether the term is publicly viewable.
     */
    function is_term_publicly_viewable($term)
    {
    }
    /**
     * Sets the last changed time for the 'terms' cache group.
     *
     * @since 5.0.0
     */
    function wp_cache_set_terms_last_changed()
    {
    }
    /**
     * Aborts calls to term meta if it is not supported.
     *
     * @since 5.0.0
     *
     * @param mixed $check Skip-value for whether to proceed term meta function execution.
     * @return mixed Original value of $check, or false if term meta is not supported.
     */
    function wp_check_term_meta_support_prefilter($check)
    {
    }
    /**
     * Retrieves path to a template.
     *
     * Used to quickly retrieve the path of a template without including the file
     * extension. It will also check the parent theme, if the file exists, with
     * the use of locate_template(). Allows for more generic template location
     * without the use of the other get_*_template() functions.
     *
     * @since 1.5.0
     *
     * @param string   $type      Filename without extension.
     * @param string[] $templates An optional list of template candidates.
     * @return string Full path to template file.
     */
    function get_query_template($type, $templates = array())
    {
    }
    /**
     * Retrieves path of index template in current or parent template.
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'index'.
     *
     * @since 3.0.0
     *
     * @see get_query_template()
     *
     * @return string Full path to index template file.
     */
    function get_index_template()
    {
    }
    /**
     * Retrieves path of 404 template in current or parent template.
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is '404'.
     *
     * @since 1.5.0
     *
     * @see get_query_template()
     *
     * @return string Full path to 404 template file.
     */
    function get_404_template()
    {
    }
    /**
     * Retrieves path of archive template in current or parent template.
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'archive'.
     *
     * @since 1.5.0
     *
     * @see get_query_template()
     *
     * @return string Full path to archive template file.
     */
    function get_archive_template()
    {
    }
    /**
     * Retrieves path of post type archive template in current or parent template.
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'archive'.
     *
     * @since 3.7.0
     *
     * @see get_archive_template()
     *
     * @return string Full path to archive template file.
     */
    function get_post_type_archive_template()
    {
    }
    /**
     * Retrieves path of author template in current or parent template.
     *
     * The hierarchy for this template looks like:
     *
     * 1. author-{nicename}.php
     * 2. author-{id}.php
     * 3. author.php
     *
     * An example of this is:
     *
     * 1. author-john.php
     * 2. author-1.php
     * 3. author.php
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'author'.
     *
     * @since 1.5.0
     *
     * @see get_query_template()
     *
     * @return string Full path to author template file.
     */
    function get_author_template()
    {
    }
    /**
     * Retrieves path of category template in current or parent template.
     *
     * The hierarchy for this template looks like:
     *
     * 1. category-{slug}.php
     * 2. category-{id}.php
     * 3. category.php
     *
     * An example of this is:
     *
     * 1. category-news.php
     * 2. category-2.php
     * 3. category.php
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'category'.
     *
     * @since 1.5.0
     * @since 4.7.0 The decoded form of `category-{slug}.php` was added to the top of the
     *              template hierarchy when the category slug contains multibyte characters.
     *
     * @see get_query_template()
     *
     * @return string Full path to category template file.
     */
    function get_category_template()
    {
    }
    /**
     * Retrieves path of tag template in current or parent template.
     *
     * The hierarchy for this template looks like:
     *
     * 1. tag-{slug}.php
     * 2. tag-{id}.php
     * 3. tag.php
     *
     * An example of this is:
     *
     * 1. tag-wordpress.php
     * 2. tag-3.php
     * 3. tag.php
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'tag'.
     *
     * @since 2.3.0
     * @since 4.7.0 The decoded form of `tag-{slug}.php` was added to the top of the
     *              template hierarchy when the tag slug contains multibyte characters.
     *
     * @see get_query_template()
     *
     * @return string Full path to tag template file.
     */
    function get_tag_template()
    {
    }
    /**
     * Retrieves path of custom taxonomy term template in current or parent template.
     *
     * The hierarchy for this template looks like:
     *
     * 1. taxonomy-{taxonomy_slug}-{term_slug}.php
     * 2. taxonomy-{taxonomy_slug}.php
     * 3. taxonomy.php
     *
     * An example of this is:
     *
     * 1. taxonomy-location-texas.php
     * 2. taxonomy-location.php
     * 3. taxonomy.php
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'taxonomy'.
     *
     * @since 2.5.0
     * @since 4.7.0 The decoded form of `taxonomy-{taxonomy_slug}-{term_slug}.php` was added to the top of the
     *              template hierarchy when the term slug contains multibyte characters.
     *
     * @see get_query_template()
     *
     * @return string Full path to custom taxonomy term template file.
     */
    function get_taxonomy_template()
    {
    }
    /**
     * Retrieves path of date template in current or parent template.
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'date'.
     *
     * @since 1.5.0
     *
     * @see get_query_template()
     *
     * @return string Full path to date template file.
     */
    function get_date_template()
    {
    }
    /**
     * Retrieves path of home template in current or parent template.
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'home'.
     *
     * @since 1.5.0
     *
     * @see get_query_template()
     *
     * @return string Full path to home template file.
     */
    function get_home_template()
    {
    }
    /**
     * Retrieves path of front page template in current or parent template.
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'frontpage'.
     *
     * @since 3.0.0
     *
     * @see get_query_template()
     *
     * @return string Full path to front page template file.
     */
    function get_front_page_template()
    {
    }
    /**
     * Retrieves path of Privacy Policy page template in current or parent template.
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'privacypolicy'.
     *
     * @since 5.2.0
     *
     * @see get_query_template()
     *
     * @return string Full path to privacy policy template file.
     */
    function get_privacy_policy_template()
    {
    }
    /**
     * Retrieves path of page template in current or parent template.
     *
     * Note: For block themes, use locate_block_template() function instead.
     *
     * The hierarchy for this template looks like:
     *
     * 1. {Page Template}.php
     * 2. page-{page_name}.php
     * 3. page-{id}.php
     * 4. page.php
     *
     * An example of this is:
     *
     * 1. page-templates/full-width.php
     * 2. page-about.php
     * 3. page-4.php
     * 4. page.php
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'page'.
     *
     * @since 1.5.0
     * @since 4.7.0 The decoded form of `page-{page_name}.php` was added to the top of the
     *              template hierarchy when the page name contains multibyte characters.
     *
     * @see get_query_template()
     *
     * @return string Full path to page template file.
     */
    function get_page_template()
    {
    }
    /**
     * Retrieves path of search template in current or parent template.
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'search'.
     *
     * @since 1.5.0
     *
     * @see get_query_template()
     *
     * @return string Full path to search template file.
     */
    function get_search_template()
    {
    }
    /**
     * Retrieves path of single template in current or parent template. Applies to single Posts,
     * single Attachments, and single custom post types.
     *
     * The hierarchy for this template looks like:
     *
     * 1. {Post Type Template}.php
     * 2. single-{post_type}-{post_name}.php
     * 3. single-{post_type}.php
     * 4. single.php
     *
     * An example of this is:
     *
     * 1. templates/full-width.php
     * 2. single-post-hello-world.php
     * 3. single-post.php
     * 4. single.php
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'single'.
     *
     * @since 1.5.0
     * @since 4.4.0 `single-{post_type}-{post_name}.php` was added to the top of the template hierarchy.
     * @since 4.7.0 The decoded form of `single-{post_type}-{post_name}.php` was added to the top of the
     *              template hierarchy when the post name contains multibyte characters.
     * @since 4.7.0 `{Post Type Template}.php` was added to the top of the template hierarchy.
     *
     * @see get_query_template()
     *
     * @return string Full path to single template file.
     */
    function get_single_template()
    {
    }
    /**
     * Retrieves an embed template path in the current or parent template.
     *
     * The hierarchy for this template looks like:
     *
     * 1. embed-{post_type}-{post_format}.php
     * 2. embed-{post_type}.php
     * 3. embed.php
     *
     * An example of this is:
     *
     * 1. embed-post-audio.php
     * 2. embed-post.php
     * 3. embed.php
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'embed'.
     *
     * @since 4.5.0
     *
     * @see get_query_template()
     *
     * @return string Full path to embed template file.
     */
    function get_embed_template()
    {
    }
    /**
     * Retrieves the path of the singular template in current or parent template.
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'singular'.
     *
     * @since 4.3.0
     *
     * @see get_query_template()
     *
     * @return string Full path to singular template file
     */
    function get_singular_template()
    {
    }
    /**
     * Retrieves path of attachment template in current or parent template.
     *
     * The hierarchy for this template looks like:
     *
     * 1. {mime_type}-{sub_type}.php
     * 2. {sub_type}.php
     * 3. {mime_type}.php
     * 4. attachment.php
     *
     * An example of this is:
     *
     * 1. image-jpeg.php
     * 2. jpeg.php
     * 3. image.php
     * 4. attachment.php
     *
     * The template hierarchy and template path are filterable via the {@see '$type_template_hierarchy'}
     * and {@see '$type_template'} dynamic hooks, where `$type` is 'attachment'.
     *
     * @since 2.0.0
     * @since 4.3.0 The order of the mime type logic was reversed so the hierarchy is more logical.
     *
     * @see get_query_template()
     *
     * @return string Full path to attachment template file.
     */
    function get_attachment_template()
    {
    }
    /**
     * Set up the globals used for template loading.
     *
     * @since 6.5.0
     *
     * @global string $wp_stylesheet_path Path to current theme's stylesheet directory.
     * @global string $wp_template_path   Path to current theme's template directory.
     */
    function wp_set_template_globals()
    {
    }
    /**
     * Retrieves the name of the highest priority template file that exists.
     *
     * Searches in the stylesheet directory before the template directory and
     * wp-includes/theme-compat so that themes which inherit from a parent theme
     * can just overload one file.
     *
     * @since 2.7.0
     * @since 5.5.0 The `$args` parameter was added.
     *
     * @global string $wp_stylesheet_path Path to current theme's stylesheet directory.
     * @global string $wp_template_path   Path to current theme's template directory.
     *
     * @param string|array $template_names Template file(s) to search for, in order.
     * @param bool         $load           If true the template file will be loaded if it is found.
     * @param bool         $load_once      Whether to require_once or require. Has no effect if `$load` is false.
     *                                     Default true.
     * @param array        $args           Optional. Additional arguments passed to the template.
     *                                     Default empty array.
     * @return string The template filename if one is located.
     */
    function locate_template($template_names, $load = \false, $load_once = \true, $args = array())
    {
    }
    /**
     * Requires the template file with WordPress environment.
     *
     * The globals are set up for the template file to ensure that the WordPress
     * environment is available from within the function. The query variables are
     * also available.
     *
     * @since 1.5.0
     * @since 5.5.0 The `$args` parameter was added.
     *
     * @global array      $posts
     * @global WP_Post    $post          Global post object.
     * @global bool       $wp_did_header
     * @global WP_Query   $wp_query      WordPress Query object.
     * @global WP_Rewrite $wp_rewrite    WordPress rewrite component.
     * @global wpdb       $wpdb          WordPress database abstraction object.
     * @global string     $wp_version
     * @global WP         $wp            Current WordPress environment instance.
     * @global int        $id
     * @global WP_Comment $comment       Global comment object.
     * @global int        $user_ID
     *
     * @param string $_template_file Path to template file.
     * @param bool   $load_once      Whether to require_once or require. Default true.
     * @param array  $args           Optional. Additional arguments passed to the template.
     *                               Default empty array.
     */
    function load_template($_template_file, $load_once = \true, $args = array())
    {
    }
    /**
     * Filters the blog option to return the path for the previewed theme.
     *
     * @since 6.3.0
     *
     * @param string $current_stylesheet The current theme's stylesheet or template path.
     * @return string The previewed theme's stylesheet or template path.
     */
    function wp_get_theme_preview_path($current_stylesheet = \null)
    {
    }
    /**
     * Adds a middleware to `apiFetch` to set the theme for the preview.
     * This adds a `wp_theme_preview` URL parameter to API requests from the Site Editor, so they also respond as if the theme is set to the value of the parameter.
     *
     * @since 6.3.0
     * @phpstan-return void
     */
    function wp_attach_theme_preview_middleware()
    {
    }
    /**
     * Set a JavaScript constant for theme activation.
     *
     * Sets the JavaScript global WP_BLOCK_THEME_ACTIVATE_NONCE containing the nonce
     * required to activate a theme. For use within the site editor.
     *
     * @see https://github.com/WordPress/gutenberg/pull/41836
     *
     * @since 6.3.0
     * @access private
     */
    function wp_block_theme_activate_nonce()
    {
    }
    /**
     * Add filters and actions to enable Block Theme Previews in the Site Editor.
     *
     * The filters and actions should be added after `pluggable.php` is included as they may
     * trigger code that uses `current_user_can()` which requires functionality from `pluggable.php`.
     *
     * @since 6.3.2
     */
    function wp_initialize_theme_preview_hooks()
    {
    }
    /**
     * Sets a custom slug when creating auto-draft template parts.
     *
     * This is only needed for auto-drafts created by the regular WP editor.
     * If this page is to be removed, this will not be necessary.
     *
     * @since 5.9.0
     *
     * @param int $post_id Post ID.
     * @phpstan-return void
     */
    function wp_set_unique_slug_on_create_template_part($post_id)
    {
    }
    /**
     * Generates a unique slug for templates.
     *
     * @access private
     * @since 5.8.0
     *
     * @param string $override_slug The filtered value of the slug (starts as `null` from apply_filter).
     * @param string $slug          The original/un-filtered slug (post_name).
     * @param int    $post_id       Post ID.
     * @param string $post_status   No uniqueness checks are made if the post is still draft or pending.
     * @param string $post_type     Post type.
     * @return string The original, desired slug.
     */
    function wp_filter_wp_template_unique_post_slug($override_slug, $slug, $post_id, $post_status, $post_type)
    {
    }
    /**
     * Enqueues the skip-link script & styles.
     *
     * @access private
     * @since 6.4.0
     *
     * @global string $_wp_current_template_content
     * @phpstan-return void
     */
    function wp_enqueue_block_template_skip_link()
    {
    }
    /**
     * Enables the block templates (editor mode) for themes with theme.json by default.
     *
     * @access private
     * @since 5.8.0
     */
    function wp_enable_block_templates()
    {
    }
    /**
     * Returns an array of WP_Theme objects based on the arguments.
     *
     * Despite advances over get_themes(), this function is quite expensive, and grows
     * linearly with additional themes. Stick to wp_get_theme() if possible.
     *
     * @since 3.4.0
     *
     * @global array $wp_theme_directories
     *
     * @param array $args {
     *     Optional. The search arguments.
     *
     *     @type mixed $errors  True to return themes with errors, false to return
     *                          themes without errors, null to return all themes.
     *                          Default false.
     *     @type mixed $allowed (Multisite) True to return only allowed themes for a site.
     *                          False to return only disallowed themes for a site.
     *                          'site' to return only site-allowed themes.
     *                          'network' to return only network-allowed themes.
     *                          Null to return all themes. Default null.
     *     @type int   $blog_id (Multisite) The blog ID used to calculate which themes
     *                          are allowed. Default 0, synonymous for the current blog.
     * }
     * @return WP_Theme[] Array of WP_Theme objects.
     * @phpstan-param array{
     *   errors?: mixed,
     *   allowed?: mixed,
     *   blog_id?: int,
     * } $args
     */
    function wp_get_themes($args = array())
    {
    }
    /**
     * Gets a WP_Theme object for a theme.
     *
     * @since 3.4.0
     *
     * @global array $wp_theme_directories
     *
     * @param string $stylesheet Optional. Directory name for the theme. Defaults to active theme.
     * @param string $theme_root Optional. Absolute path of the theme root to look in.
     *                           If not specified, get_raw_theme_root() is used to calculate
     *                           the theme root for the $stylesheet provided (or active theme).
     * @return WP_Theme Theme object. Be sure to check the object's exists() method
     *                  if you need to confirm the theme's existence.
     */
    function wp_get_theme($stylesheet = '', $theme_root = '')
    {
    }
    /**
     * Clears the cache held by get_theme_roots() and WP_Theme.
     *
     * @since 3.5.0
     * @param bool $clear_update_cache Whether to clear the theme updates cache.
     */
    function wp_clean_themes_cache($clear_update_cache = \true)
    {
    }
    /**
     * Whether a child theme is in use.
     *
     * @since 3.0.0
     * @since 6.5.0 Makes use of global template variables.
     *
     * @global string $wp_stylesheet_path Path to current theme's stylesheet directory.
     * @global string $wp_template_path   Path to current theme's template directory.
     *
     * @return bool True if a child theme is in use, false otherwise.
     */
    function is_child_theme()
    {
    }
    /**
     * Retrieves name of the current stylesheet.
     *
     * The theme name that is currently set as the front end theme.
     *
     * For all intents and purposes, the template name and the stylesheet name
     * are going to be the same for most cases.
     *
     * @since 1.5.0
     *
     * @return string Stylesheet name.
     */
    function get_stylesheet()
    {
    }
    /**
     * Retrieves stylesheet directory path for the active theme.
     *
     * @since 1.5.0
     * @since 6.4.0 Memoizes filter execution so that it only runs once for the current theme.
     * @since 6.4.2 Memoization removed.
     *
     * @return string Path to active theme's stylesheet directory.
     */
    function get_stylesheet_directory()
    {
    }
    /**
     * Retrieves stylesheet directory URI for the active theme.
     *
     * @since 1.5.0
     *
     * @return string URI to active theme's stylesheet directory.
     */
    function get_stylesheet_directory_uri()
    {
    }
    /**
     * Retrieves stylesheet URI for the active theme.
     *
     * The stylesheet file name is 'style.css' which is appended to the stylesheet directory URI path.
     * See get_stylesheet_directory_uri().
     *
     * @since 1.5.0
     *
     * @return string URI to active theme's stylesheet.
     */
    function get_stylesheet_uri()
    {
    }
    /**
     * Retrieves the localized stylesheet URI.
     *
     * The stylesheet directory for the localized stylesheet files are located, by
     * default, in the base theme directory. The name of the locale file will be the
     * locale followed by '.css'. If that does not exist, then the text direction
     * stylesheet will be checked for existence, for example 'ltr.css'.
     *
     * The theme may change the location of the stylesheet directory by either using
     * the {@see 'stylesheet_directory_uri'} or {@see 'locale_stylesheet_uri'} filters.
     *
     * If you want to change the location of the stylesheet files for the entire
     * WordPress workflow, then change the former. If you just have the locale in a
     * separate folder, then change the latter.
     *
     * @since 2.1.0
     *
     * @global WP_Locale $wp_locale WordPress date and time locale object.
     *
     * @return string URI to active theme's localized stylesheet.
     */
    function get_locale_stylesheet_uri()
    {
    }
    /**
     * Retrieves name of the active theme.
     *
     * @since 1.5.0
     *
     * @return string Template name.
     */
    function get_template()
    {
    }
    /**
     * Retrieves template directory path for the active theme.
     *
     * @since 1.5.0
     * @since 6.4.0 Memoizes filter execution so that it only runs once for the current theme.
     * @since 6.4.1 Memoization removed.
     *
     * @return string Path to active theme's template directory.
     */
    function get_template_directory()
    {
    }
    /**
     * Retrieves template directory URI for the active theme.
     *
     * @since 1.5.0
     *
     * @return string URI to active theme's template directory.
     */
    function get_template_directory_uri()
    {
    }
    /**
     * Retrieves theme roots.
     *
     * @since 2.9.0
     *
     * @global array $wp_theme_directories
     *
     * @return array|string An array of theme roots keyed by template/stylesheet
     *                      or a single theme root if all themes have the same root.
     */
    function get_theme_roots()
    {
    }
    /**
     * Registers a directory that contains themes.
     *
     * @since 2.9.0
     *
     * @global array $wp_theme_directories
     *
     * @param string $directory Either the full filesystem path to a theme folder
     *                          or a folder within WP_CONTENT_DIR.
     * @return bool True if successfully registered a directory that contains themes,
     *              false if the directory does not exist.
     */
    function register_theme_directory($directory)
    {
    }
    /**
     * Searches all registered theme directories for complete and valid themes.
     *
     * @since 2.9.0
     *
     * @global array $wp_theme_directories
     *
     * @param bool $force Optional. Whether to force a new directory scan. Default false.
     * @return array|false Valid themes found on success, false on failure.
     */
    function search_theme_directories($force = \false)
    {
    }
    /**
     * Retrieves path to themes directory.
     *
     * Does not have trailing slash.
     *
     * @since 1.5.0
     *
     * @global array $wp_theme_directories
     *
     * @param string $stylesheet_or_template Optional. The stylesheet or template name of the theme.
     *                                       Default is to leverage the main theme root.
     * @return string Themes directory path.
     */
    function get_theme_root($stylesheet_or_template = '')
    {
    }
    /**
     * Retrieves URI for themes directory.
     *
     * Does not have trailing slash.
     *
     * @since 1.5.0
     *
     * @global array $wp_theme_directories
     *
     * @param string $stylesheet_or_template Optional. The stylesheet or template name of the theme.
     *                                       Default is to leverage the main theme root.
     * @param string $theme_root             Optional. The theme root for which calculations will be based,
     *                                       preventing the need for a get_raw_theme_root() call. Default empty.
     * @return string Themes directory URI.
     */
    function get_theme_root_uri($stylesheet_or_template = '', $theme_root = '')
    {
    }
    /**
     * Gets the raw theme root relative to the content directory with no filters applied.
     *
     * @since 3.1.0
     *
     * @global array $wp_theme_directories
     *
     * @param string $stylesheet_or_template The stylesheet or template name of the theme.
     * @param bool   $skip_cache             Optional. Whether to skip the cache.
     *                                       Defaults to false, meaning the cache is used.
     * @return string Theme root.
     */
    function get_raw_theme_root($stylesheet_or_template, $skip_cache = \false)
    {
    }
    /**
     * Displays localized stylesheet link element.
     *
     * @since 2.1.0
     * @phpstan-return void
     */
    function locale_stylesheet()
    {
    }
    /**
     * Switches the theme.
     *
     * Accepts one argument: $stylesheet of the theme. It also accepts an additional function signature
     * of two arguments: $template then $stylesheet. This is for backward compatibility.
     *
     * @since 2.5.0
     *
     * @global array                $wp_theme_directories
     * @global WP_Customize_Manager $wp_customize
     * @global array                $sidebars_widgets
     * @global array                $wp_registered_sidebars
     *
     * @param string $stylesheet Stylesheet name.
     */
    function switch_theme($stylesheet)
    {
    }
    /**
     * Checks that the active theme has the required files.
     *
     * Standalone themes need to have a `templates/index.html` or `index.php` template file.
     * Child themes need to have a `Template` header in the `style.css` stylesheet.
     *
     * Does not initially check the default theme, which is the fallback and should always exist.
     * But if it doesn't exist, it'll fall back to the latest core default theme that does exist.
     * Will switch theme to the fallback theme if active theme does not validate.
     *
     * You can use the {@see 'validate_current_theme'} filter to return false to disable
     * this functionality.
     *
     * @since 1.5.0
     * @since 6.0.0 Removed the requirement for block themes to have an `index.php` template.
     *
     * @see WP_DEFAULT_THEME
     *
     * @return bool
     */
    function validate_current_theme()
    {
    }
    /**
     * Validates the theme requirements for WordPress version and PHP version.
     *
     * Uses the information from `Requires at least` and `Requires PHP` headers
     * defined in the theme's `style.css` file.
     *
     * @since 5.5.0
     * @since 5.8.0 Removed support for using `readme.txt` as a fallback.
     *
     * @param string $stylesheet Directory name for the theme.
     * @return true|WP_Error True if requirements are met, WP_Error on failure.
     */
    function validate_theme_requirements($stylesheet)
    {
    }
    /**
     * Retrieves all theme modifications.
     *
     * @since 3.1.0
     * @since 5.9.0 The return value is always an array.
     *
     * @return array Theme modifications.
     */
    function get_theme_mods()
    {
    }
    /**
     * Retrieves theme modification value for the active theme.
     *
     * If the modification name does not exist and `$default_value` is a string, then the
     * default will be passed through the {@link https://www.php.net/sprintf sprintf()}
     * PHP function with the template directory URI as the first value and the
     * stylesheet directory URI as the second value.
     *
     * @since 2.1.0
     *
     * @param string $name          Theme modification name.
     * @param mixed  $default_value Optional. Theme modification default value. Default false.
     * @return mixed Theme modification value.
     */
    function get_theme_mod($name, $default_value = \false)
    {
    }
    /**
     * Updates theme modification value for the active theme.
     *
     * @since 2.1.0
     * @since 5.6.0 A return value was added.
     *
     * @param string $name  Theme modification name.
     * @param mixed  $value Theme modification value.
     * @return bool True if the value was updated, false otherwise.
     */
    function set_theme_mod($name, $value)
    {
    }
    /**
     * Removes theme modification name from active theme list.
     *
     * If removing the name also removes all elements, then the entire option
     * will be removed.
     *
     * @since 2.1.0
     *
     * @param string $name Theme modification name.
     * @phpstan-return void
     */
    function remove_theme_mod($name)
    {
    }
    /**
     * Removes theme modifications option for the active theme.
     *
     * @since 2.1.0
     */
    function remove_theme_mods()
    {
    }
    /**
     * Retrieves the custom header text color in 3- or 6-digit hexadecimal form.
     *
     * @since 2.1.0
     *
     * @return string Header text color in 3- or 6-digit hexadecimal form (minus the hash symbol).
     */
    function get_header_textcolor()
    {
    }
    /**
     * Displays the custom header text color in 3- or 6-digit hexadecimal form (minus the hash symbol).
     *
     * @since 2.1.0
     */
    function header_textcolor()
    {
    }
    /**
     * Whether to display the header text.
     *
     * @since 3.4.0
     *
     * @return bool
     */
    function display_header_text()
    {
    }
    /**
     * Checks whether a header image is set or not.
     *
     * @since 4.2.0
     *
     * @see get_header_image()
     *
     * @return bool Whether a header image is set or not.
     */
    function has_header_image()
    {
    }
    /**
     * Retrieves header image for custom header.
     *
     * @since 2.1.0
     *
     * @return string|false
     */
    function get_header_image()
    {
    }
    /**
     * Creates image tag markup for a custom header image.
     *
     * @since 4.4.0
     *
     * @param array $attr Optional. Additional attributes for the image tag. Can be used
     *                              to override the default attributes. Default empty.
     * @return string HTML image element markup or empty string on failure.
     */
    function get_header_image_tag($attr = array())
    {
    }
    /**
     * Displays the image markup for a custom header image.
     *
     * @since 4.4.0
     *
     * @param array $attr Optional. Attributes for the image markup. Default empty.
     */
    function the_header_image_tag($attr = array())
    {
    }
    /**
     * Gets random header image data from registered images in theme.
     *
     * @since 3.4.0
     *
     * @access private
     *
     * @global array $_wp_default_headers
     *
     * @return object
     */
    function _get_random_header_data()
    {
    }
    /**
     * Gets random header image URL from registered images in theme.
     *
     * @since 3.2.0
     *
     * @return string Path to header image.
     */
    function get_random_header_image()
    {
    }
    /**
     * Checks if random header image is in use.
     *
     * Always true if user expressly chooses the option in Appearance > Header.
     * Also true if theme has multiple header images registered, no specific header image
     * is chosen, and theme turns on random headers with add_theme_support().
     *
     * @since 3.2.0
     *
     * @param string $type The random pool to use. Possible values include 'any',
     *                     'default', 'uploaded'. Default 'any'.
     * @return bool
     */
    function is_random_header_image($type = 'any')
    {
    }
    /**
     * Displays header image URL.
     *
     * @since 2.1.0
     */
    function header_image()
    {
    }
    /**
     * Gets the header images uploaded for the active theme.
     *
     * @since 3.2.0
     *
     * @return array
     */
    function get_uploaded_header_images()
    {
    }
    /**
     * Gets the header image data.
     *
     * @since 3.4.0
     *
     * @global array $_wp_default_headers
     *
     * @return object
     */
    function get_custom_header()
    {
    }
    /**
     * Registers a selection of default headers to be displayed by the custom header admin UI.
     *
     * @since 3.0.0
     *
     * @global array $_wp_default_headers
     *
     * @param array $headers Array of headers keyed by a string ID. The IDs point to arrays
     *                       containing 'url', 'thumbnail_url', and 'description' keys.
     */
    function register_default_headers($headers)
    {
    }
    /**
     * Unregisters default headers.
     *
     * This function must be called after register_default_headers() has already added the
     * header you want to remove.
     *
     * @see register_default_headers()
     * @since 3.0.0
     *
     * @global array $_wp_default_headers
     *
     * @param string|array $header The header string id (key of array) to remove, or an array thereof.
     * @return bool|void A single header returns true on success, false on failure.
     *                   There is currently no return value for multiple headers.
     */
    function unregister_default_headers($header)
    {
    }
    /**
     * Checks whether a header video is set or not.
     *
     * @since 4.7.0
     *
     * @see get_header_video_url()
     *
     * @return bool Whether a header video is set or not.
     */
    function has_header_video()
    {
    }
    /**
     * Retrieves header video URL for custom header.
     *
     * Uses a local video if present, or falls back to an external video.
     *
     * @since 4.7.0
     *
     * @return string|false Header video URL or false if there is no video.
     */
    function get_header_video_url()
    {
    }
    /**
     * Displays header video URL.
     *
     * @since 4.7.0
     */
    function the_header_video_url()
    {
    }
    /**
     * Retrieves header video settings.
     *
     * @since 4.7.0
     *
     * @return array
     */
    function get_header_video_settings()
    {
    }
    /**
     * Checks whether a custom header is set or not.
     *
     * @since 4.7.0
     *
     * @return bool True if a custom header is set. False if not.
     */
    function has_custom_header()
    {
    }
    /**
     * Checks whether the custom header video is eligible to show on the current page.
     *
     * @since 4.7.0
     *
     * @return bool True if the custom header video should be shown. False if not.
     */
    function is_header_video_active()
    {
    }
    /**
     * Retrieves the markup for a custom header.
     *
     * The container div will always be returned in the Customizer preview.
     *
     * @since 4.7.0
     *
     * @return string The markup for a custom header on success.
     */
    function get_custom_header_markup()
    {
    }
    /**
     * Prints the markup for a custom header.
     *
     * A container div will always be printed in the Customizer preview.
     *
     * @since 4.7.0
     * @phpstan-return void
     */
    function the_custom_header_markup()
    {
    }
    /**
     * Retrieves background image for custom background.
     *
     * @since 3.0.0
     *
     * @return string
     */
    function get_background_image()
    {
    }
    /**
     * Displays background image path.
     *
     * @since 3.0.0
     */
    function background_image()
    {
    }
    /**
     * Retrieves value for custom background color.
     *
     * @since 3.0.0
     *
     * @return string
     */
    function get_background_color()
    {
    }
    /**
     * Displays background color value.
     *
     * @since 3.0.0
     */
    function background_color()
    {
    }
    /**
     * Default custom background callback.
     *
     * @since 3.0.0
     * @phpstan-return void
     */
    function _custom_background_cb()
    {
    }
    /**
     * Renders the Custom CSS style element.
     *
     * @since 4.7.0
     */
    function wp_custom_css_cb()
    {
    }
    /**
     * Fetches the `custom_css` post for a given theme.
     *
     * @since 4.7.0
     *
     * @param string $stylesheet Optional. A theme object stylesheet name. Defaults to the active theme.
     * @return WP_Post|null The custom_css post or null if none exists.
     */
    function wp_get_custom_css_post($stylesheet = '')
    {
    }
    /**
     * Fetches the saved Custom CSS content for rendering.
     *
     * @since 4.7.0
     *
     * @param string $stylesheet Optional. A theme object stylesheet name. Defaults to the active theme.
     * @return string The Custom CSS Post content.
     */
    function wp_get_custom_css($stylesheet = '')
    {
    }
    /**
     * Updates the `custom_css` post for a given theme.
     *
     * Inserts a `custom_css` post when one doesn't yet exist.
     *
     * @since 4.7.0
     *
     * @param string $css CSS, stored in `post_content`.
     * @param array  $args {
     *     Args.
     *
     *     @type string $preprocessed Optional. Pre-processed CSS, stored in `post_content_filtered`.
     *                                Normally empty string.
     *     @type string $stylesheet   Optional. Stylesheet (child theme) to update.
     *                                Defaults to active theme/stylesheet.
     * }
     * @return WP_Post|WP_Error Post on success, error on failure.
     * @phpstan-param array{
     *   preprocessed?: string,
     *   stylesheet?: string,
     * } $args
     */
    function wp_update_custom_css_post($css, $args = array())
    {
    }
    /**
     * Adds callback for custom TinyMCE editor stylesheets.
     *
     * The parameter $stylesheet is the name of the stylesheet, relative to
     * the theme root. It also accepts an array of stylesheets.
     * It is optional and defaults to 'editor-style.css'.
     *
     * This function automatically adds another stylesheet with -rtl prefix, e.g. editor-style-rtl.css.
     * If that file doesn't exist, it is removed before adding the stylesheet(s) to TinyMCE.
     * If an array of stylesheets is passed to add_editor_style(),
     * RTL is only added for the first stylesheet.
     *
     * Since version 3.4 the TinyMCE body has .rtl CSS class.
     * It is a better option to use that class and add any RTL styles to the main stylesheet.
     *
     * @since 3.0.0
     *
     * @global array $editor_styles
     *
     * @param array|string $stylesheet Optional. Stylesheet name or array thereof, relative to theme root.
     *                                 Defaults to 'editor-style.css'
     */
    function add_editor_style($stylesheet = 'editor-style.css')
    {
    }
    /**
     * Removes all visual editor stylesheets.
     *
     * @since 3.1.0
     *
     * @global array $editor_styles
     *
     * @return bool True on success, false if there were no stylesheets to remove.
     */
    function remove_editor_styles()
    {
    }
    /**
     * Retrieves any registered editor stylesheet URLs.
     *
     * @since 4.0.0
     *
     * @global array $editor_styles Registered editor stylesheets
     *
     * @return string[] If registered, a list of editor stylesheet URLs.
     */
    function get_editor_stylesheets()
    {
    }
    /**
     * Expands a theme's starter content configuration using core-provided data.
     *
     * @since 4.7.0
     *
     * @return array Array of starter content.
     */
    function get_theme_starter_content()
    {
    }
    /**
     * Registers theme support for a given feature.
     *
     * Must be called in the theme's functions.php file to work.
     * If attached to a hook, it must be {@see 'after_setup_theme'}.
     * The {@see 'init'} hook may be too late for some features.
     *
     * Example usage:
     *
     *     add_theme_support( 'title-tag' );
     *     add_theme_support( 'custom-logo', array(
     *         'height' => 480,
     *         'width'  => 720,
     *     ) );
     *
     * @since 2.9.0
     * @since 3.4.0 The `custom-header-uploads` feature was deprecated.
     * @since 3.6.0 The `html5` feature was added.
     * @since 3.6.1 The `html5` feature requires an array of types to be passed. Defaults to
     *              'comment-list', 'comment-form', 'search-form' for backward compatibility.
     * @since 3.9.0 The `html5` feature now also accepts 'gallery' and 'caption'.
     * @since 4.1.0 The `title-tag` feature was added.
     * @since 4.5.0 The `customize-selective-refresh-widgets` feature was added.
     * @since 4.7.0 The `starter-content` feature was added.
     * @since 5.0.0 The `responsive-embeds`, `align-wide`, `dark-editor-style`, `disable-custom-colors`,
     *              `disable-custom-font-sizes`, `editor-color-palette`, `editor-font-sizes`,
     *              `editor-styles`, and `wp-block-styles` features were added.
     * @since 5.3.0 The `html5` feature now also accepts 'script' and 'style'.
     * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
     *              by adding it to the function signature.
     * @since 5.4.0 The `disable-custom-gradients` feature limits to default gradients or gradients added
     *              through `editor-gradient-presets` theme support.
     * @since 5.5.0 The `core-block-patterns` feature was added and is enabled by default.
     * @since 5.5.0 The `custom-logo` feature now also accepts 'unlink-homepage-logo'.
     * @since 5.6.0 The `post-formats` feature warns if no array is passed as the second parameter.
     * @since 5.8.0 The `widgets-block-editor` feature enables the Widgets block editor.
     * @since 5.8.0 The `block-templates` feature indicates whether a theme uses block-based templates.
     * @since 6.0.0 The `html5` feature warns if no array is passed as the second parameter.
     * @since 6.1.0 The `block-template-parts` feature allows to edit any reusable template part from site editor.
     * @since 6.1.0 The `disable-layout-styles` feature disables the default layout styles.
     * @since 6.3.0 The `link-color` feature allows to enable the link color setting.
     * @since 6.3.0 The `border` feature allows themes without theme.json to add border styles to blocks.
     * @since 6.5.0 The `appearance-tools` feature enables a few design tools for blocks,
     *              see `WP_Theme_JSON::APPEARANCE_TOOLS_OPT_INS` for a complete list.
     * @since 6.6.0 The `editor-spacing-sizes` feature was added.
     *
     * @global array $_wp_theme_features
     *
     * @param string $feature The feature being added. Likely core values include:
     *                          - 'admin-bar'
     *                          - 'align-wide'
     *                          - 'appearance-tools'
     *                          - 'automatic-feed-links'
     *                          - 'block-templates'
     *                          - 'block-template-parts'
     *                          - 'border'
     *                          - 'core-block-patterns'
     *                          - 'custom-background'
     *                          - 'custom-header'
     *                          - 'custom-line-height'
     *                          - 'custom-logo'
     *                          - 'customize-selective-refresh-widgets'
     *                          - 'custom-spacing'
     *                          - 'custom-units'
     *                          - 'dark-editor-style'
     *                          - 'disable-custom-colors'
     *                          - 'disable-custom-font-sizes'
     *                          - 'disable-custom-gradients'
     *                          - 'disable-layout-styles'
     *                          - 'editor-color-palette'
     *                          - 'editor-gradient-presets'
     *                          - 'editor-font-sizes'
     *                          - 'editor-spacing-sizes'
     *                          - 'editor-styles'
     *                          - 'featured-content'
     *                          - 'html5'
     *                          - 'link-color'
     *                          - 'menus'
     *                          - 'post-formats'
     *                          - 'post-thumbnails'
     *                          - 'responsive-embeds'
     *                          - 'starter-content'
     *                          - 'title-tag'
     *                          - 'widgets'
     *                          - 'widgets-block-editor'
     *                          - 'wp-block-styles'
     * @param mixed  ...$args Optional extra arguments to pass along with certain features.
     * @return void|false Void on success, false on failure.
     */
    function add_theme_support($feature, ...$args)
    {
    }
    /**
     * Registers the internal custom header and background routines.
     *
     * @since 3.4.0
     * @access private
     *
     * @global Custom_Image_Header $custom_image_header
     * @global Custom_Background   $custom_background
     */
    function _custom_header_background_just_in_time()
    {
    }
    /**
     * Adds CSS to hide header text for custom logo, based on Customizer setting.
     *
     * @since 4.5.0
     * @access private
     */
    function _custom_logo_header_styles()
    {
    }
    /**
     * Gets the theme support arguments passed when registering that support.
     *
     * Example usage:
     *
     *     get_theme_support( 'custom-logo' );
     *     get_theme_support( 'custom-header', 'width' );
     *
     * @since 3.1.0
     * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
     *              by adding it to the function signature.
     *
     * @global array $_wp_theme_features
     *
     * @param string $feature The feature to check. See add_theme_support() for the list
     *                        of possible values.
     * @param mixed  ...$args Optional extra arguments to be checked against certain features.
     * @return mixed The array of extra arguments or the value for the registered feature.
     */
    function get_theme_support($feature, ...$args)
    {
    }
    /**
     * Allows a theme to de-register its support of a certain feature
     *
     * Should be called in the theme's functions.php file. Generally would
     * be used for child themes to override support from the parent theme.
     *
     * @since 3.0.0
     *
     * @see add_theme_support()
     *
     * @param string $feature The feature being removed. See add_theme_support() for the list
     *                        of possible values.
     * @return bool|void Whether feature was removed.
     */
    function remove_theme_support($feature)
    {
    }
    /**
     * Do not use. Removes theme support internally without knowledge of those not used
     * by themes directly.
     *
     * @access private
     * @since 3.1.0
     * @global array               $_wp_theme_features
     * @global Custom_Image_Header $custom_image_header
     * @global Custom_Background   $custom_background
     *
     * @param string $feature The feature being removed. See add_theme_support() for the list
     *                        of possible values.
     * @return bool True if support was removed, false if the feature was not registered.
     */
    function _remove_theme_support($feature)
    {
    }
    /**
     * Checks a theme's support for a given feature.
     *
     * Example usage:
     *
     *     current_theme_supports( 'custom-logo' );
     *     current_theme_supports( 'html5', 'comment-form' );
     *
     * @since 2.9.0
     * @since 5.3.0 Formalized the existing and already documented `...$args` parameter
     *              by adding it to the function signature.
     *
     * @global array $_wp_theme_features
     *
     * @param string $feature The feature being checked. See add_theme_support() for the list
     *                        of possible values.
     * @param mixed  ...$args Optional extra arguments to be checked against certain features.
     * @return bool True if the active theme supports the feature, false otherwise.
     */
    function current_theme_supports($feature, ...$args)
    {
    }
    /**
     * Checks a theme's support for a given feature before loading the functions which implement it.
     *
     * @since 2.9.0
     *
     * @param string $feature The feature being checked. See add_theme_support() for the list
     *                        of possible values.
     * @param string $file    Path to the file.
     * @return bool True if the active theme supports the supplied feature, false otherwise.
     */
    function require_if_theme_supports($feature, $file)
    {
    }
    /**
     * Registers a theme feature for use in add_theme_support().
     *
     * This does not indicate that the active theme supports the feature, it only describes
     * the feature's supported options.
     *
     * @since 5.5.0
     *
     * @see add_theme_support()
     *
     * @global array $_wp_registered_theme_features
     *
     * @param string $feature The name uniquely identifying the feature. See add_theme_support()
     *                        for the list of possible values.
     * @param array  $args {
     *     Data used to describe the theme.
     *
     *     @type string     $type         The type of data associated with this feature.
     *                                    Valid values are 'string', 'boolean', 'integer',
     *                                    'number', 'array', and 'object'. Defaults to 'boolean'.
     *     @type bool       $variadic     Does this feature utilize the variadic support
     *                                    of add_theme_support(), or are all arguments specified
     *                                    as the second parameter. Must be used with the "array" type.
     *     @type string     $description  A short description of the feature. Included in
     *                                    the Themes REST API schema. Intended for developers.
     *     @type bool|array $show_in_rest {
     *         Whether this feature should be included in the Themes REST API endpoint.
     *         Defaults to not being included. When registering an 'array' or 'object' type,
     *         this argument must be an array with the 'schema' key.
     *
     *         @type array    $schema           Specifies the JSON Schema definition describing
     *                                          the feature. If any objects in the schema do not include
     *                                          the 'additionalProperties' keyword, it is set to false.
     *         @type string   $name             An alternate name to be used as the property name
     *                                          in the REST API.
     *         @type callable $prepare_callback A function used to format the theme support in the REST API.
     *                                          Receives the raw theme support value.
     *      }
     * }
     * @return true|WP_Error True if the theme feature was successfully registered, a WP_Error object if not.
     * @phpstan-param array{
     *   type?: string,
     *   variadic?: bool,
     *   description?: string,
     *   show_in_rest?: bool|array{
     *     schema: array,
     *     name: string,
     *     prepare_callback: callable,
     *   },
     * } $args
     */
    function register_theme_feature($feature, $args = array())
    {
    }
    /**
     * Gets the list of registered theme features.
     *
     * @since 5.5.0
     *
     * @global array $_wp_registered_theme_features
     *
     * @return array[] List of theme features, keyed by their name.
     */
    function get_registered_theme_features()
    {
    }
    /**
     * Gets the registration config for a theme feature.
     *
     * @since 5.5.0
     *
     * @global array $_wp_registered_theme_features
     *
     * @param string $feature The feature name. See add_theme_support() for the list
     *                        of possible values.
     * @return array|null The registration args, or null if the feature was not registered.
     */
    function get_registered_theme_feature($feature)
    {
    }
    /**
     * Checks an attachment being deleted to see if it's a header or background image.
     *
     * If true it removes the theme modification which would be pointing at the deleted
     * attachment.
     *
     * @access private
     * @since 3.0.0
     * @since 4.3.0 Also removes `header_image_data`.
     * @since 4.5.0 Also removes custom logo theme mods.
     * @since 6.6.0 Also removes `site_logo` option set by the site logo block.
     *
     * @param int $id The attachment ID.
     */
    function _delete_attachment_theme_mod($id)
    {
    }
    /**
     * Checks if a theme has been changed and runs 'after_switch_theme' hook on the next WP load.
     *
     * See {@see 'after_switch_theme'}.
     *
     * @since 3.3.0
     */
    function check_theme_switched()
    {
    }
    /**
     * Includes and instantiates the WP_Customize_Manager class.
     *
     * Loads the Customizer at plugins_loaded when accessing the customize.php admin
     * page or when any request includes a wp_customize=on param or a customize_changeset
     * param (a UUID). This param is a signal for whether to bootstrap the Customizer when
     * WordPress is loading, especially in the Customizer preview
     * or when making Customizer Ajax requests for widgets or menus.
     *
     * @since 3.4.0
     *
     * @global WP_Customize_Manager $wp_customize
     * @phpstan-return void
     */
    function _wp_customize_include()
    {
    }
    /**
     * Publishes a snapshot's changes.
     *
     * @since 4.7.0
     * @access private
     *
     * @global WP_Customize_Manager $wp_customize Customizer instance.
     *
     * @param string  $new_status     New post status.
     * @param string  $old_status     Old post status.
     * @param WP_Post $changeset_post Changeset post object.
     * @phpstan-return void
     */
    function _wp_customize_publish_changeset($new_status, $old_status, $changeset_post)
    {
    }
    /**
     * Filters changeset post data upon insert to ensure post_name is intact.
     *
     * This is needed to prevent the post_name from being dropped when the post is
     * transitioned into pending status by a contributor.
     *
     * @since 4.7.0
     *
     * @see wp_insert_post()
     *
     * @param array $post_data          An array of slashed post data.
     * @param array $supplied_post_data An array of sanitized, but otherwise unmodified post data.
     * @return array Filtered data.
     */
    function _wp_customize_changeset_filter_insert_post_data($post_data, $supplied_post_data)
    {
    }
    /**
     * Adds settings for the customize-loader script.
     *
     * @since 3.4.0
     */
    function _wp_customize_loader_settings()
    {
    }
    /**
     * Returns a URL to load the Customizer.
     *
     * @since 3.4.0
     *
     * @param string $stylesheet Optional. Theme to customize. Defaults to active theme.
     *                           The theme's stylesheet will be urlencoded if necessary.
     * @return string
     */
    function wp_customize_url($stylesheet = '')
    {
    }
    /**
     * Prints a script to check whether or not the Customizer is supported,
     * and apply either the no-customize-support or customize-support class
     * to the body.
     *
     * This function MUST be called inside the body tag.
     *
     * Ideally, call this function immediately after the body tag is opened.
     * This prevents a flash of unstyled content.
     *
     * It is also recommended that you add the "no-customize-support" class
     * to the body tag by default.
     *
     * @since 3.4.0
     * @since 4.7.0 Support for IE8 and below is explicitly removed via conditional comments.
     * @since 5.5.0 IE8 and older are no longer supported.
     */
    function wp_customize_support_script()
    {
    }
    /**
     * Whether the site is being previewed in the Customizer.
     *
     * @since 4.0.0
     *
     * @global WP_Customize_Manager $wp_customize Customizer instance.
     *
     * @return bool True if the site is being previewed in the Customizer, false otherwise.
     */
    function is_customize_preview()
    {
    }
    /**
     * Makes sure that auto-draft posts get their post_date bumped or status changed
     * to draft to prevent premature garbage-collection.
     *
     * When a changeset is updated but remains an auto-draft, ensure the post_date
     * for the auto-draft posts remains the same so that it will be
     * garbage-collected at the same time by `wp_delete_auto_drafts()`. Otherwise,
     * if the changeset is updated to be a draft then update the posts
     * to have a far-future post_date so that they will never be garbage collected
     * unless the changeset post itself is deleted.
     *
     * When a changeset is updated to be a persistent draft or to be scheduled for
     * publishing, then transition any dependent auto-drafts to a draft status so
     * that they likewise will not be garbage-collected but also so that they can
     * be edited in the admin before publishing since there is not yet a post/page
     * editing flow in the Customizer. See #39752.
     *
     * @link https://core.trac.wordpress.org/ticket/39752
     *
     * @since 4.8.0
     * @access private
     * @see wp_delete_auto_drafts()
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string   $new_status Transition to this post status.
     * @param string   $old_status Previous post status.
     * @param \WP_Post $post       Post data.
     * @phpstan-return void
     */
    function _wp_keep_alive_customize_changeset_dependent_auto_drafts($new_status, $old_status, $post)
    {
    }
    /**
     * Creates the initial theme features when the 'setup_theme' action is fired.
     *
     * See {@see 'setup_theme'}.
     *
     * @since 5.5.0
     * @since 6.0.1 The `block-templates` feature was added.
     */
    function create_initial_theme_features()
    {
    }
    /**
     * Returns whether the active theme is a block-based theme or not.
     *
     * @since 5.9.0
     *
     * @return bool Whether the active theme is a block-based theme or not.
     */
    function wp_is_block_theme()
    {
    }
    /**
     * Given an element name, returns a class name.
     *
     * Alias of WP_Theme_JSON::get_element_class_name.
     *
     * @since 6.1.0
     *
     * @param string $element The name of the element.
     *
     * @return string The name of the class.
     */
    function wp_theme_get_element_class_name($element)
    {
    }
    /**
     * Adds default theme supports for block themes when the 'after_setup_theme' action fires.
     *
     * See {@see 'after_setup_theme'}.
     *
     * @since 5.9.0
     * @access private
     */
    function _add_default_theme_supports()
    {
    }
    /**
     * Checks WordPress version against the newest version.
     *
     * The WordPress version, PHP version, and locale is sent.
     *
     * Checks against the WordPress server at api.wordpress.org. Will only check
     * if WordPress isn't installing.
     *
     * @since 2.3.0
     *
     * @global string $wp_version       Used to check against the newest WordPress version.
     * @global wpdb   $wpdb             WordPress database abstraction object.
     * @global string $wp_local_package Locale code of the package.
     *
     * @param array $extra_stats Extra statistics to report to the WordPress.org API.
     * @param bool  $force_check Whether to bypass the transient cache and force a fresh update check.
     *                           Defaults to false, true if $extra_stats is set.
     * @phpstan-return void
     */
    function wp_version_check($extra_stats = array(), $force_check = \false)
    {
    }
    /**
     * Checks for available updates to plugins based on the latest versions hosted on WordPress.org.
     *
     * Despite its name this function does not actually perform any updates, it only checks for available updates.
     *
     * A list of all plugins installed is sent to WP, along with the site locale.
     *
     * Checks against the WordPress server at api.wordpress.org. Will only check
     * if WordPress isn't installing.
     *
     * @since 2.3.0
     *
     * @global string $wp_version The WordPress version string.
     *
     * @param array $extra_stats Extra statistics to report to the WordPress.org API.
     */
    function wp_update_plugins($extra_stats = array())
    {
    }
    /**
     * Checks for available updates to themes based on the latest versions hosted on WordPress.org.
     *
     * Despite its name this function does not actually perform any updates, it only checks for available updates.
     *
     * A list of all themes installed is sent to WP, along with the site locale.
     *
     * Checks against the WordPress server at api.wordpress.org. Will only check
     * if WordPress isn't installing.
     *
     * @since 2.7.0
     *
     * @global string $wp_version The WordPress version string.
     *
     * @param array $extra_stats Extra statistics to report to the WordPress.org API.
     * @phpstan-return void
     */
    function wp_update_themes($extra_stats = array())
    {
    }
    /**
     * Performs WordPress automatic background updates.
     *
     * Updates WordPress core plus any plugins and themes that have automatic updates enabled.
     *
     * @since 3.7.0
     */
    function wp_maybe_auto_update()
    {
    }
    /**
     * Retrieves a list of all language updates available.
     *
     * @since 3.7.0
     *
     * @return object[] Array of translation objects that have available updates.
     */
    function wp_get_translation_updates()
    {
    }
    /**
     * Collects counts and UI strings for available updates.
     *
     * @since 3.3.0
     *
     * @return array
     */
    function wp_get_update_data()
    {
    }
    /**
     * Determines whether core should be updated.
     *
     * @since 2.8.0
     *
     * @global string $wp_version The WordPress version string.
     * @phpstan-return void
     */
    function _maybe_update_core()
    {
    }
    /**
     * Checks the last time plugins were run before checking plugin versions.
     *
     * This might have been backported to WordPress 2.6.1 for performance reasons.
     * This is used for the wp-admin to check only so often instead of every page
     * load.
     *
     * @since 2.7.0
     * @access private
     * @phpstan-return void
     */
    function _maybe_update_plugins()
    {
    }
    /**
     * Checks themes versions only after a duration of time.
     *
     * This is for performance reasons to make sure that on the theme version
     * checker is not run on every page load.
     *
     * @since 2.7.0
     * @access private
     * @phpstan-return void
     */
    function _maybe_update_themes()
    {
    }
    /**
     * Schedules core, theme, and plugin update checks.
     *
     * @since 3.1.0
     */
    function wp_schedule_update_checks()
    {
    }
    /**
     * Clears existing update caches for plugins, themes, and core.
     *
     * @since 4.1.0
     */
    function wp_clean_update_cache()
    {
    }
    /**
     * Schedules the removal of all contents in the temporary backup directory.
     *
     * @since 6.3.0
     * @phpstan-return void
     */
    function wp_delete_all_temp_backups()
    {
    }
    /**
     * Deletes all contents in the temporary backup directory.
     *
     * @since 6.3.0
     *
     * @access private
     *
     * @global WP_Filesystem_Base $wp_filesystem WordPress filesystem subclass.
     * @phpstan-return void
     */
    function _wp_delete_all_temp_backups()
    {
    }
    /**
     * Authenticates and logs a user in with 'remember' capability.
     *
     * The credentials is an array that has 'user_login', 'user_password', and
     * 'remember' indices. If the credentials is not given, then the log in form
     * will be assumed and used if set.
     *
     * The various authentication cookies will be set by this function and will be
     * set for a longer period depending on if the 'remember' credential is set to
     * true.
     *
     * Note: wp_signon() doesn't handle setting the current user. This means that if the
     * function is called before the {@see 'init'} hook is fired, is_user_logged_in() will
     * evaluate as false until that point. If is_user_logged_in() is needed in conjunction
     * with wp_signon(), wp_set_current_user() should be called explicitly.
     *
     * @since 2.5.0
     *
     * @global string $auth_secure_cookie
     * @global wpdb   $wpdb               WordPress database abstraction object.
     *
     * @param array       $credentials {
     *     Optional. User info in order to sign on.
     *
     *     @type string $user_login    Username.
     *     @type string $user_password User password.
     *     @type bool   $remember      Whether to 'remember' the user. Increases the time
     *                                 that the cookie will be kept. Default false.
     * }
     * @param string|bool $secure_cookie Optional. Whether to use secure cookie.
     * @return WP_User|WP_Error WP_User on success, WP_Error on failure.
     * @phpstan-param array{
     *   user_login?: string,
     *   user_password?: string,
     *   remember?: bool,
     * } $credentials
     */
    function wp_signon($credentials = array(), $secure_cookie = '')
    {
    }
    /**
     * Authenticates a user, confirming the username and password are valid.
     *
     * @since 2.8.0
     *
     * @param WP_User|WP_Error|null $user     WP_User or WP_Error object from a previous callback. Default null.
     * @param string                $username Username for authentication.
     * @param string                $password Password for authentication.
     * @return WP_User|WP_Error WP_User on success, WP_Error on failure.
     */
    function wp_authenticate_username_password($user, $username, $password)
    {
    }
    /**
     * Authenticates a user using the email and password.
     *
     * @since 4.5.0
     *
     * @param WP_User|WP_Error|null $user     WP_User or WP_Error object if a previous
     *                                        callback failed authentication.
     * @param string                $email    Email address for authentication.
     * @param string                $password Password for authentication.
     * @return WP_User|WP_Error WP_User on success, WP_Error on failure.
     */
    function wp_authenticate_email_password($user, $email, $password)
    {
    }
    /**
     * Authenticates the user using the WordPress auth cookie.
     *
     * @since 2.8.0
     *
     * @global string $auth_secure_cookie
     *
     * @param WP_User|WP_Error|null $user     WP_User or WP_Error object from a previous callback. Default null.
     * @param string                $username Username. If not empty, cancels the cookie authentication.
     * @param string                $password Password. If not empty, cancels the cookie authentication.
     * @return WP_User|WP_Error WP_User on success, WP_Error on failure.
     */
    function wp_authenticate_cookie($user, $username, $password)
    {
    }
    /**
     * Authenticates the user using an application password.
     *
     * @since 5.6.0
     *
     * @param WP_User|WP_Error|null $input_user WP_User or WP_Error object if a previous
     *                                          callback failed authentication.
     * @param string                $username   Username for authentication.
     * @param string                $password   Password for authentication.
     * @return WP_User|WP_Error|null WP_User on success, WP_Error on failure, null if
     *                               null is passed in and this isn't an API request.
     */
    function wp_authenticate_application_password($input_user, $username, $password)
    {
    }
    /**
     * Validates the application password credentials passed via Basic Authentication.
     *
     * @since 5.6.0
     *
     * @param int|false $input_user User ID if one has been determined, false otherwise.
     * @return int|false The authenticated user ID if successful, false otherwise.
     */
    function wp_validate_application_password($input_user)
    {
    }
    /**
     * For Multisite blogs, checks if the authenticated user has been marked as a
     * spammer, or if the user's primary blog has been marked as spam.
     *
     * @since 3.7.0
     *
     * @param WP_User|WP_Error|null $user WP_User or WP_Error object from a previous callback. Default null.
     * @return WP_User|WP_Error WP_User on success, WP_Error if the user is considered a spammer.
     */
    function wp_authenticate_spam_check($user)
    {
    }
    /**
     * Validates the logged-in cookie.
     *
     * Checks the logged-in cookie if the previous auth cookie could not be
     * validated and parsed.
     *
     * This is a callback for the {@see 'determine_current_user'} filter, rather than API.
     *
     * @since 3.9.0
     *
     * @param int|false $user_id The user ID (or false) as received from
     *                           the `determine_current_user` filter.
     * @return int|false User ID if validated, false otherwise. If a user ID from
     *                   an earlier filter callback is received, that value is returned.
     */
    function wp_validate_logged_in_cookie($user_id)
    {
    }
    /**
     * Gets the number of posts a user has written.
     *
     * @since 3.0.0
     * @since 4.1.0 Added `$post_type` argument.
     * @since 4.3.0 Added `$public_only` argument. Added the ability to pass an array
     *              of post types to `$post_type`.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int          $userid      User ID.
     * @param array|string $post_type   Optional. Single post type or array of post types to count the number of posts for. Default 'post'.
     * @param bool         $public_only Optional. Whether to only return counts for public posts. Default false.
     * @return string Number of posts the user has written in this post type.
     */
    function count_user_posts($userid, $post_type = 'post', $public_only = \false)
    {
    }
    /**
     * Gets the number of posts written by a list of users.
     *
     * @since 3.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int[]           $users       Array of user IDs.
     * @param string|string[] $post_type   Optional. Single post type or array of post types to check. Defaults to 'post'.
     * @param bool            $public_only Optional. Only return counts for public posts.  Defaults to false.
     * @return string[] Amount of posts each user has written, as strings, keyed by user ID.
     */
    function count_many_users_posts($users, $post_type = 'post', $public_only = \false)
    {
    }
    /**
     * Gets the current user's ID.
     *
     * @since MU (3.0.0)
     *
     * @return int The current user's ID, or 0 if no user is logged in.
     */
    function get_current_user_id()
    {
    }
    /**
     * Retrieves user option that can be either per Site or per Network.
     *
     * If the user ID is not given, then the current user will be used instead. If
     * the user ID is given, then the user data will be retrieved. The filter for
     * the result, will also pass the original option name and finally the user data
     * object as the third parameter.
     *
     * The option will first check for the per site name and then the per Network name.
     *
     * @since 2.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string $option     User option name.
     * @param int    $user       Optional. User ID.
     * @param string $deprecated Use get_option() to check for an option in the options table.
     * @return mixed User option value on success, false on failure.
     */
    function get_user_option($option, $user = 0, $deprecated = '')
    {
    }
    /**
     * Updates user option with global blog capability.
     *
     * User options are just like user metadata except that they have support for
     * global blog options. If the 'is_global' parameter is false, which it is by default,
     * it will prepend the WordPress table prefix to the option name.
     *
     * Deletes the user option if $newvalue is empty.
     *
     * @since 2.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $user_id     User ID.
     * @param string $option_name User option name.
     * @param mixed  $newvalue    User option value.
     * @param bool   $is_global   Optional. Whether option name is global or blog specific.
     *                            Default false (blog specific).
     * @return int|bool User meta ID if the option didn't exist, true on successful update,
     *                  false on failure.
     */
    function update_user_option($user_id, $option_name, $newvalue, $is_global = \false)
    {
    }
    /**
     * Deletes user option with global blog capability.
     *
     * User options are just like user metadata except that they have support for
     * global blog options. If the 'is_global' parameter is false, which it is by default,
     * it will prepend the WordPress table prefix to the option name.
     *
     * @since 3.0.0
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int    $user_id     User ID
     * @param string $option_name User option name.
     * @param bool   $is_global   Optional. Whether option name is global or blog specific.
     *                            Default false (blog specific).
     * @return bool True on success, false on failure.
     */
    function delete_user_option($user_id, $option_name, $is_global = \false)
    {
    }
    /**
     * Retrieves user info by user ID.
     *
     * @since 6.7.0
     *
     * @param int $user_id User ID.
     *
     * @return WP_User|false WP_User object on success, false on failure.
     * @phpstan-return ($user_id is int<min, 0> ? false : \WP_User|false)
     */
    function get_user($user_id)
    {
    }
    /**
     * Retrieves list of users matching criteria.
     *
     * @since 3.1.0
     *
     * @see WP_User_Query
     *
     * @param array $args Optional. Arguments to retrieve users. See WP_User_Query::prepare_query()
     *                    for more information on accepted arguments.
     * @return array List of users.
     * @phpstan-param array{
     *   blog_id?: int,
     *   role?: string|string[],
     *   role__in?: string[],
     *   role__not_in?: string[],
     *   meta_key?: string|string[],
     *   meta_value?: string|string[],
     *   meta_compare?: string,
     *   meta_compare_key?: string,
     *   meta_type?: string,
     *   meta_type_key?: string,
     *   meta_query?: array,
     *   capability?: string|string[],
     *   capability__in?: string[],
     *   capability__not_in?: string[],
     *   include?: int[],
     *   exclude?: int[],
     *   search?: string,
     *   search_columns?: string[],
     *   orderby?: string|array,
     *   order?: string,
     *   offset?: int,
     *   number?: int,
     *   paged?: int,
     *   count_total?: bool,
     *   fields?: string|string[],
     *   who?: string,
     *   has_published_posts?: bool|string[],
     *   nicename?: string,
     *   nicename__in?: string[],
     *   nicename__not_in?: string[],
     *   login?: string,
     *   login__in?: string[],
     *   login__not_in?: string[],
     *   cache_results?: bool,
     * } $args See WP_User_Query::prepare_query()
     */
    function get_users($args = array())
    {
    }
    /**
     * Lists all the users of the site, with several options available.
     *
     * @since 5.9.0
     *
     * @param string|array $args {
     *     Optional. Array or string of default arguments.
     *
     *     @type string $orderby       How to sort the users. Accepts 'nicename', 'email', 'url', 'registered',
     *                                 'user_nicename', 'user_email', 'user_url', 'user_registered', 'name',
     *                                 'display_name', 'post_count', 'ID', 'meta_value', 'user_login'. Default 'name'.
     *     @type string $order         Sorting direction for $orderby. Accepts 'ASC', 'DESC'. Default 'ASC'.
     *     @type int    $number        Maximum users to return or display. Default empty (all users).
     *     @type bool   $exclude_admin Whether to exclude the 'admin' account, if it exists. Default false.
     *     @type bool   $show_fullname Whether to show the user's full name. Default false.
     *     @type string $feed          If not empty, show a link to the user's feed and use this text as the alt
     *                                 parameter of the link. Default empty.
     *     @type string $feed_image    If not empty, show a link to the user's feed and use this image URL as
     *                                 clickable anchor. Default empty.
     *     @type string $feed_type     The feed type to link to, such as 'rss2'. Defaults to default feed type.
     *     @type bool   $echo          Whether to output the result or instead return it. Default true.
     *     @type string $style         If 'list', each user is wrapped in an `<li>` element, otherwise the users
     *                                 will be separated by commas.
     *     @type bool   $html          Whether to list the items in HTML form or plaintext. Default true.
     *     @type string $exclude       An array, comma-, or space-separated list of user IDs to exclude. Default empty.
     *     @type string $include       An array, comma-, or space-separated list of user IDs to include. Default empty.
     * }
     * @return string|null The output if echo is false. Otherwise null.
     * @phpstan-param array{
     *   orderby?: string,
     *   order?: string,
     *   number?: int,
     *   exclude_admin?: bool,
     *   show_fullname?: bool,
     *   feed?: string,
     *   feed_image?: string,
     *   feed_type?: string,
     *   echo?: bool,
     *   style?: string,
     *   html?: bool,
     *   exclude?: string,
     *   include?: string,
     * } $args
     */
    function wp_list_users($args = array())
    {
    }
    /**
     * Gets the sites a user belongs to.
     *
     * @since 3.0.0
     * @since 4.7.0 Converted to use `get_sites()`.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int  $user_id User ID
     * @param bool $all     Whether to retrieve all sites, or only sites that are not
     *                      marked as deleted, archived, or spam.
     * @return object[] A list of the user's sites. An empty array if the user doesn't exist
     *                  or belongs to no sites.
     */
    function get_blogs_of_user($user_id, $all = \false)
    {
    }
    /**
     * Finds out whether a user is a member of a given blog.
     *
     * @since MU (3.0.0)
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int $user_id Optional. The unique ID of the user. Defaults to the current user.
     * @param int $blog_id Optional. ID of the blog to check. Defaults to the current site.
     * @return bool
     */
    function is_user_member_of_blog($user_id = 0, $blog_id = 0)
    {
    }
    /**
     * Adds meta data to a user.
     *
     * @since 3.0.0
     *
     * @param int    $user_id    User ID.
     * @param string $meta_key   Metadata name.
     * @param mixed  $meta_value Metadata value. Must be serializable if non-scalar.
     * @param bool   $unique     Optional. Whether the same key should not be added.
     *                           Default false.
     * @return int|false Meta ID on success, false on failure.
     */
    function add_user_meta($user_id, $meta_key, $meta_value, $unique = \false)
    {
    }
    /**
     * Removes metadata matching criteria from a user.
     *
     * You can match based on the key, or key and value. Removing based on key and
     * value, will keep from removing duplicate metadata with the same key. It also
     * allows removing all metadata matching key, if needed.
     *
     * @since 3.0.0
     *
     * @link https://developer.wordpress.org/reference/functions/delete_user_meta/
     *
     * @param int    $user_id    User ID
     * @param string $meta_key   Metadata name.
     * @param mixed  $meta_value Optional. Metadata value. If provided,
     *                           rows will only be removed that match the value.
     *                           Must be serializable if non-scalar. Default empty.
     * @return bool True on success, false on failure.
     */
    function delete_user_meta($user_id, $meta_key, $meta_value = '')
    {
    }
    /**
     * Retrieves user meta field for a user.
     *
     * @since 3.0.0
     *
     * @link https://developer.wordpress.org/reference/functions/get_user_meta/
     *
     * @param int    $user_id User ID.
     * @param string $key     Optional. The meta key to retrieve. By default,
     *                        returns data for all keys.
     * @param bool   $single  Optional. Whether to return a single value.
     *                        This parameter has no effect if `$key` is not specified.
     *                        Default false.
     * @return mixed An array of values if `$single` is false.
     *               The value of meta data field if `$single` is true.
     *               False for an invalid `$user_id` (non-numeric, zero, or negative value).
     *               An empty array if a valid but non-existing user ID is passed and `$single` is false.
     *               An empty string if a valid but non-existing user ID is passed and `$single` is true.
     */
    function get_user_meta($user_id, $key = '', $single = \false)
    {
    }
    /**
     * Updates user meta field based on user ID.
     *
     * Use the $prev_value parameter to differentiate between meta fields with the
     * same key and user ID.
     *
     * If the meta field for the user does not exist, it will be added.
     *
     * @since 3.0.0
     *
     * @link https://developer.wordpress.org/reference/functions/update_user_meta/
     *
     * @param int    $user_id    User ID.
     * @param string $meta_key   Metadata key.
     * @param mixed  $meta_value Metadata value. Must be serializable if non-scalar.
     * @param mixed  $prev_value Optional. Previous value to check before updating.
     *                           If specified, only update existing metadata entries with
     *                           this value. Otherwise, update all entries. Default empty.
     * @return int|bool Meta ID if the key didn't exist, true on successful update,
     *                  false on failure or if the value passed to the function
     *                  is the same as the one that is already in the database.
     */
    function update_user_meta($user_id, $meta_key, $meta_value, $prev_value = '')
    {
    }
    /**
     * Counts number of users who have each of the user roles.
     *
     * Assumes there are neither duplicated nor orphaned capabilities meta_values.
     * Assumes role names are unique phrases. Same assumption made by WP_User_Query::prepare_query()
     * Using $strategy = 'time' this is CPU-intensive and should handle around 10^7 users.
     * Using $strategy = 'memory' this is memory-intensive and should handle around 10^5 users, but see WP Bug #12257.
     *
     * @since 3.0.0
     * @since 4.4.0 The number of users with no role is now included in the `none` element.
     * @since 4.9.0 The `$site_id` parameter was added to support multisite.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param string   $strategy Optional. The computational strategy to use when counting the users.
     *                           Accepts either 'time' or 'memory'. Default 'time'.
     * @param int|null $site_id  Optional. The site ID to count users for. Defaults to the current site.
     * @return array {
     *     User counts.
     *
     *     @type int   $total_users Total number of users on the site.
     *     @type int[] $avail_roles Array of user counts keyed by user role.
     * }
     * @phpstan-param 'time'|'memory' $strategy
     * @phpstan-return array{
     *   total_users: int,
     *   avail_roles: int[],
     * }
     */
    function count_users($strategy = 'time', $site_id = \null)
    {
    }
    /**
     * Returns the number of active users in your installation.
     *
     * Note that on a large site the count may be cached and only updated twice daily.
     *
     * @since MU (3.0.0)
     * @since 4.8.0 The `$network_id` parameter has been added.
     * @since 6.0.0 Moved to wp-includes/user.php.
     *
     * @param int|null $network_id ID of the network. Defaults to the current network.
     * @return int Number of active users on the network.
     */
    function get_user_count($network_id = \null)
    {
    }
    /**
     * Updates the total count of users on the site if live user counting is enabled.
     *
     * @since 6.0.0
     *
     * @param int|null $network_id ID of the network. Defaults to the current network.
     * @return bool Whether the update was successful.
     */
    function wp_maybe_update_user_counts($network_id = \null)
    {
    }
    /**
     * Updates the total count of users on the site.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     * @since 6.0.0
     *
     * @param int|null $network_id ID of the network. Defaults to the current network.
     * @return bool Whether the update was successful.
     */
    function wp_update_user_counts($network_id = \null)
    {
    }
    /**
     * Schedules a recurring recalculation of the total count of users.
     *
     * @since 6.0.0
     * @phpstan-return void
     */
    function wp_schedule_update_user_counts()
    {
    }
    /**
     * Determines whether the site has a large number of users.
     *
     * The default criteria for a large site is more than 10,000 users.
     *
     * @since 6.0.0
     *
     * @param int|null $network_id ID of the network. Defaults to the current network.
     * @return bool Whether the site has a large number of users.
     */
    function wp_is_large_user_count($network_id = \null)
    {
    }
    /**
     * Sets up global user vars.
     *
     * Used by wp_set_current_user() for back compat. Might be deprecated in the future.
     *
     * @since 2.0.4
     *
     * @global string  $user_login    The user username for logging in
     * @global WP_User $userdata      User data.
     * @global int     $user_level    The level of the user
     * @global int     $user_ID       The ID of the user
     * @global string  $user_email    The email address of the user
     * @global string  $user_url      The url in the user's profile
     * @global string  $user_identity The display name of the user
     *
     * @param int $for_user_id Optional. User ID to set up global data. Default 0.
     * @phpstan-return void
     */
    function setup_userdata($for_user_id = 0)
    {
    }
    /**
     * Creates dropdown HTML content of users.
     *
     * The content can either be displayed, which it is by default, or retrieved by
     * setting the 'echo' argument to false. The 'include' and 'exclude' arguments
     * are optional; if they are not specified, all users will be displayed. Only one
     * can be used in a single call, either 'include' or 'exclude', but not both.
     *
     * @since 2.3.0
     * @since 4.5.0 Added the 'display_name_with_login' value for 'show'.
     * @since 4.7.0 Added the 'role', 'role__in', and 'role__not_in' parameters.
     * @since 5.9.0 Added the 'capability', 'capability__in', and 'capability__not_in' parameters.
     *              Deprecated the 'who' parameter.
     *
     * @param array|string $args {
     *     Optional. Array or string of arguments to generate a drop-down of users.
     *     See WP_User_Query::prepare_query() for additional available arguments.
     *
     *     @type string          $show_option_all         Text to show as the drop-down default (all).
     *                                                    Default empty.
     *     @type string          $show_option_none        Text to show as the drop-down default when no
     *                                                    users were found. Default empty.
     *     @type int|string      $option_none_value       Value to use for `$show_option_none` when no users
     *                                                    were found. Default -1.
     *     @type string          $hide_if_only_one_author Whether to skip generating the drop-down
     *                                                    if only one user was found. Default empty.
     *     @type string          $orderby                 Field to order found users by. Accepts user fields.
     *                                                    Default 'display_name'.
     *     @type string          $order                   Whether to order users in ascending or descending
     *                                                    order. Accepts 'ASC' (ascending) or 'DESC' (descending).
     *                                                    Default 'ASC'.
     *     @type int[]|string    $include                 Array or comma-separated list of user IDs to include.
     *                                                    Default empty.
     *     @type int[]|string    $exclude                 Array or comma-separated list of user IDs to exclude.
     *                                                    Default empty.
     *     @type bool|int        $multi                   Whether to skip the ID attribute on the 'select' element.
     *                                                    Accepts 1|true or 0|false. Default 0|false.
     *     @type string          $show                    User data to display. If the selected item is empty
     *                                                    then the 'user_login' will be displayed in parentheses.
     *                                                    Accepts any user field, or 'display_name_with_login' to show
     *                                                    the display name with user_login in parentheses.
     *                                                    Default 'display_name'.
     *     @type int|bool        $echo                    Whether to echo or return the drop-down. Accepts 1|true (echo)
     *                                                    or 0|false (return). Default 1|true.
     *     @type int             $selected                Which user ID should be selected. Default 0.
     *     @type bool            $include_selected        Whether to always include the selected user ID in the drop-
     *                                                    down. Default false.
     *     @type string          $name                    Name attribute of select element. Default 'user'.
     *     @type string          $id                      ID attribute of the select element. Default is the value of `$name`.
     *     @type string          $class                   Class attribute of the select element. Default empty.
     *     @type int             $blog_id                 ID of blog (Multisite only). Default is ID of the current blog.
     *     @type string          $who                     Deprecated, use `$capability` instead.
     *                                                    Which type of users to query. Accepts only an empty string or
     *                                                    'authors'. Default empty (all users).
     *     @type string|string[] $role                    An array or a comma-separated list of role names that users
     *                                                    must match to be included in results. Note that this is
     *                                                    an inclusive list: users must match *each* role. Default empty.
     *     @type string[]        $role__in                An array of role names. Matched users must have at least one
     *                                                    of these roles. Default empty array.
     *     @type string[]        $role__not_in            An array of role names to exclude. Users matching one or more
     *                                                    of these roles will not be included in results. Default empty array.
     *     @type string|string[] $capability              An array or a comma-separated list of capability names that users
     *                                                    must match to be included in results. Note that this is
     *                                                    an inclusive list: users must match *each* capability.
     *                                                    Does NOT work for capabilities not in the database or filtered
     *                                                    via {@see 'map_meta_cap'}. Default empty.
     *     @type string[]        $capability__in          An array of capability names. Matched users must have at least one
     *                                                    of these capabilities.
     *                                                    Does NOT work for capabilities not in the database or filtered
     *                                                    via {@see 'map_meta_cap'}. Default empty array.
     *     @type string[]        $capability__not_in      An array of capability names to exclude. Users matching one or more
     *                                                    of these capabilities will not be included in results.
     *                                                    Does NOT work for capabilities not in the database or filtered
     *                                                    via {@see 'map_meta_cap'}. Default empty array.
     * }
     * @return string HTML dropdown list of users.
     * @phpstan-param array{
     *   show_option_all?: string,
     *   show_option_none?: string,
     *   option_none_value?: int|string,
     *   hide_if_only_one_author?: string,
     *   orderby?: string,
     *   order?: string,
     *   include?: int[]|string,
     *   exclude?: int[]|string,
     *   multi?: bool|int,
     *   show?: string,
     *   echo?: int|bool,
     *   selected?: int,
     *   include_selected?: bool,
     *   name?: string,
     *   id?: string,
     *   class?: string,
     *   blog_id?: int,
     *   who?: string,
     *   role?: string|string[],
     *   role__in?: string[],
     *   role__not_in?: string[],
     *   capability?: string|string[],
     *   capability__in?: string[],
     *   capability__not_in?: string[],
     *   blog_id?: int,
     *   role?: string|string[],
     *   role__in?: string[],
     *   role__not_in?: string[],
     *   meta_key?: string|string[],
     *   meta_value?: string|string[],
     *   meta_compare?: string,
     *   meta_compare_key?: string,
     *   meta_type?: string,
     *   meta_type_key?: string,
     *   meta_query?: array,
     *   capability?: string|string[],
     *   capability__in?: string[],
     *   capability__not_in?: string[],
     *   include?: int[],
     *   exclude?: int[],
     *   search?: string,
     *   search_columns?: string[],
     *   orderby?: string|array,
     *   order?: string,
     *   offset?: int,
     *   number?: int,
     *   paged?: int,
     *   count_total?: bool,
     *   fields?: string|string[],
     *   who?: string,
     *   has_published_posts?: bool|string[],
     *   nicename?: string,
     *   nicename__in?: string[],
     *   nicename__not_in?: string[],
     *   login?: string,
     *   login__in?: string[],
     *   login__not_in?: string[],
     *   cache_results?: bool,
     * } $args
     */
    function wp_dropdown_users($args = '')
    {
    }
    /**
     * Sanitizes user field based on context.
     *
     * Possible context values are:  'raw', 'edit', 'db', 'display', 'attribute' and 'js'. The
     * 'display' context is used by default. 'attribute' and 'js' contexts are treated like 'display'
     * when calling filters.
     *
     * @since 2.3.0
     *
     * @param string $field   The user Object field name.
     * @param mixed  $value   The user Object value.
     * @param int    $user_id User ID.
     * @param string $context How to sanitize user fields. Looks for 'raw', 'edit', 'db', 'display',
     *                        'attribute' and 'js'.
     * @return mixed Sanitized value.
     */
    function sanitize_user_field($field, $value, $user_id, $context)
    {
    }
    /**
     * Updates all user caches.
     *
     * @since 3.0.0
     *
     * @param object|WP_User $user User object or database row to be cached
     * @return void|false Void on success, false on failure.
     */
    function update_user_caches($user)
    {
    }
    /**
     * Cleans all user caches.
     *
     * @since 3.0.0
     * @since 4.4.0 'clean_user_cache' action was added.
     * @since 6.2.0 User metadata caches are now cleared.
     *
     * @param WP_User|int $user User object or ID to be cleaned from the cache
     * @phpstan-return void
     */
    function clean_user_cache($user)
    {
    }
    /**
     * Determines whether the given username exists.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.0.0
     *
     * @param string $username The username to check for existence.
     * @return int|false The user ID on success, false on failure.
     */
    function username_exists($username)
    {
    }
    /**
     * Determines whether the given email exists.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.1.0
     *
     * @param string $email The email to check for existence.
     * @return int|false The user ID on success, false on failure.
     */
    function email_exists($email)
    {
    }
    /**
     * Checks whether a username is valid.
     *
     * @since 2.0.1
     * @since 4.4.0 Empty sanitized usernames are now considered invalid.
     *
     * @param string $username Username.
     * @return bool Whether username given is valid.
     */
    function validate_username($username)
    {
    }
    /**
     * Inserts a user into the database.
     *
     * Most of the `$userdata` array fields have filters associated with the values. Exceptions are
     * 'ID', 'rich_editing', 'syntax_highlighting', 'comment_shortcuts', 'admin_color', 'use_ssl',
     * 'user_registered', 'user_activation_key', 'spam', and 'role'. The filters have the prefix
     * 'pre_user_' followed by the field name. An example using 'description' would have the filter
     * called 'pre_user_description' that can be hooked into.
     *
     * @since 2.0.0
     * @since 3.6.0 The `aim`, `jabber`, and `yim` fields were removed as default user contact
     *              methods for new installations. See wp_get_user_contact_methods().
     * @since 4.7.0 The `locale` field can be passed to `$userdata`.
     * @since 5.3.0 The `user_activation_key` field can be passed to `$userdata`.
     * @since 5.3.0 The `spam` field can be passed to `$userdata` (Multisite only).
     * @since 5.9.0 The `meta_input` field can be passed to `$userdata` to allow addition of user meta data.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param array|object|WP_User $userdata {
     *     An array, object, or WP_User object of user data arguments.
     *
     *     @type int    $ID                   User ID. If supplied, the user will be updated.
     *     @type string $user_pass            The plain-text user password for new users.
     *                                        Hashed password for existing users.
     *     @type string $user_login           The user's login username.
     *     @type string $user_nicename        The URL-friendly user name.
     *     @type string $user_url             The user URL.
     *     @type string $user_email           The user email address.
     *     @type string $display_name         The user's display name.
     *                                        Default is the user's username.
     *     @type string $nickname             The user's nickname.
     *                                        Default is the user's username.
     *     @type string $first_name           The user's first name. For new users, will be used
     *                                        to build the first part of the user's display name
     *                                        if `$display_name` is not specified.
     *     @type string $last_name            The user's last name. For new users, will be used
     *                                        to build the second part of the user's display name
     *                                        if `$display_name` is not specified.
     *     @type string $description          The user's biographical description.
     *     @type string $rich_editing         Whether to enable the rich-editor for the user.
     *                                        Accepts 'true' or 'false' as a string literal,
     *                                        not boolean. Default 'true'.
     *     @type string $syntax_highlighting  Whether to enable the rich code editor for the user.
     *                                        Accepts 'true' or 'false' as a string literal,
     *                                        not boolean. Default 'true'.
     *     @type string $comment_shortcuts    Whether to enable comment moderation keyboard
     *                                        shortcuts for the user. Accepts 'true' or 'false'
     *                                        as a string literal, not boolean. Default 'false'.
     *     @type string $admin_color          Admin color scheme for the user. Default 'fresh'.
     *     @type bool   $use_ssl              Whether the user should always access the admin over
     *                                        https. Default false.
     *     @type string $user_registered      Date the user registered in UTC. Format is 'Y-m-d H:i:s'.
     *     @type string $user_activation_key  Password reset key. Default empty.
     *     @type bool   $spam                 Multisite only. Whether the user is marked as spam.
     *                                        Default false.
     *     @type string $show_admin_bar_front Whether to display the Admin Bar for the user
     *                                        on the site's front end. Accepts 'true' or 'false'
     *                                        as a string literal, not boolean. Default 'true'.
     *     @type string $role                 User's role.
     *     @type string $locale               User's locale. Default empty.
     *     @type array  $meta_input           Array of custom user meta values keyed by meta key.
     *                                        Default empty.
     * }
     * @return int|WP_Error The newly created user's ID or a WP_Error object if the user could not
     *                      be created.
     * @phpstan-param \WP_User|object|array{
     *   ID?: int,
     *   user_pass?: string,
     *   user_login?: string,
     *   user_nicename?: string,
     *   user_url?: string,
     *   user_email?: string,
     *   display_name?: string,
     *   nickname?: string,
     *   first_name?: string,
     *   last_name?: string,
     *   description?: string,
     *   rich_editing?: string,
     *   syntax_highlighting?: string,
     *   comment_shortcuts?: string,
     *   admin_color?: string,
     *   use_ssl?: bool,
     *   user_registered?: string,
     *   user_activation_key?: string,
     *   spam?: bool,
     *   show_admin_bar_front?: string,
     *   role?: string,
     *   locale?: string,
     *   meta_input?: array,
     * } $userdata
     */
    function wp_insert_user($userdata)
    {
    }
    /**
     * Updates a user in the database.
     *
     * It is possible to update a user's password by specifying the 'user_pass'
     * value in the $userdata parameter array.
     *
     * If current user's password is being updated, then the cookies will be
     * cleared.
     *
     * @since 2.0.0
     *
     * @see wp_insert_user() For what fields can be set in $userdata.
     *
     * @param array|object|WP_User $userdata An array of user data or a user object of type stdClass or WP_User.
     * @return int|WP_Error The updated user's ID or a WP_Error object if the user could not be updated.
     */
    function wp_update_user($userdata)
    {
    }
    /**
     * Provides a simpler way of inserting a user into the database.
     *
     * Creates a new user with just the username, password, and email. For more
     * complex user creation use wp_insert_user() to specify more information.
     *
     * @since 2.0.0
     *
     * @see wp_insert_user() More complete way to create a new user.
     *
     * @param string $username The user's username.
     * @param string $password The user's password.
     * @param string $email    Optional. The user's email. Default empty.
     * @return int|WP_Error The newly created user's ID or a WP_Error object if the user could not
     *                      be created.
     */
    function wp_create_user($username, $password, $email = '')
    {
    }
    /**
     * Returns a list of meta keys to be (maybe) populated in wp_update_user().
     *
     * The list of keys returned via this function are dependent on the presence
     * of those keys in the user meta data to be set.
     *
     * @since 3.3.0
     * @access private
     *
     * @param WP_User $user WP_User instance.
     * @return string[] List of user keys to be populated in wp_update_user().
     */
    function _get_additional_user_keys($user)
    {
    }
    /**
     * Sets up the user contact methods.
     *
     * Default contact methods were removed in 3.6. A filter dictates contact methods.
     *
     * @since 3.7.0
     *
     * @param WP_User|null $user Optional. WP_User object.
     * @return string[] Array of contact method labels keyed by contact method.
     */
    function wp_get_user_contact_methods($user = \null)
    {
    }
    /**
     * The old private function for setting up user contact methods.
     *
     * Use wp_get_user_contact_methods() instead.
     *
     * @since 2.9.0
     * @access private
     *
     * @param WP_User|null $user Optional. WP_User object. Default null.
     * @return string[] Array of contact method labels keyed by contact method.
     */
    function _wp_get_user_contactmethods($user = \null)
    {
    }
    /**
     * Gets the text suggesting how to create strong passwords.
     *
     * @since 4.1.0
     *
     * @return string The password hint text.
     */
    function wp_get_password_hint()
    {
    }
    /**
     * Creates, stores, then returns a password reset key for user.
     *
     * @since 4.4.0
     *
     * @global PasswordHash $wp_hasher Portable PHP password hashing framework instance.
     *
     * @param WP_User $user User to retrieve password reset key for.
     * @return string|WP_Error Password reset key on success. WP_Error on error.
     */
    function get_password_reset_key($user)
    {
    }
    /**
     * Retrieves a user row based on password reset key and login.
     *
     * A key is considered 'expired' if it exactly matches the value of the
     * user_activation_key field, rather than being matched after going through the
     * hashing process. This field is now hashed; old values are no longer accepted
     * but have a different WP_Error code so good user feedback can be provided.
     *
     * @since 3.1.0
     *
     * @global PasswordHash $wp_hasher Portable PHP password hashing framework instance.
     *
     * @param string $key       Hash to validate sending user's password.
     * @param string $login     The user login.
     * @return WP_User|WP_Error WP_User object on success, WP_Error object for invalid or expired keys.
     */
    function check_password_reset_key($key, $login)
    {
    }
    /**
     * Handles sending a password retrieval email to a user.
     *
     * @since 2.5.0
     * @since 5.7.0 Added `$user_login` parameter.
     *
     * @global wpdb         $wpdb      WordPress database abstraction object.
     * @global PasswordHash $wp_hasher Portable PHP password hashing framework instance.
     *
     * @param string $user_login Optional. Username to send a password retrieval email for.
     *                           Defaults to `$_POST['user_login']` if not set.
     * @return true|WP_Error True when finished, WP_Error object on error.
     */
    function retrieve_password($user_login = \null)
    {
    }
    /**
     * Handles resetting the user's password.
     *
     * @since 2.5.0
     *
     * @param WP_User $user     The user
     * @param string  $new_pass New password for the user in plaintext
     */
    function reset_password($user, $new_pass)
    {
    }
    /**
     * Handles registering a new user.
     *
     * @since 2.5.0
     *
     * @param string $user_login User's username for logging in
     * @param string $user_email User's email address to send password and add
     * @return int|WP_Error Either user's ID or error on failure.
     */
    function register_new_user($user_login, $user_email)
    {
    }
    /**
     * Initiates email notifications related to the creation of new users.
     *
     * Notifications are sent both to the site admin and to the newly created user.
     *
     * @since 4.4.0
     * @since 4.6.0 Converted the `$notify` parameter to accept 'user' for sending
     *              notifications only to the user created.
     *
     * @param int    $user_id ID of the newly created user.
     * @param string $notify  Optional. Type of notification that should happen. Accepts 'admin'
     *                        or an empty string (admin only), 'user', or 'both' (admin and user).
     *                        Default 'both'.
     * @phpstan-param 'admin'|'user'|'both' $notify
     */
    function wp_send_new_user_notifications($user_id, $notify = 'both')
    {
    }
    /**
     * Retrieves the current session token from the logged_in cookie.
     *
     * @since 4.0.0
     *
     * @return string Token.
     */
    function wp_get_session_token()
    {
    }
    /**
     * Retrieves a list of sessions for the current user.
     *
     * @since 4.0.0
     *
     * @return array Array of sessions.
     */
    function wp_get_all_sessions()
    {
    }
    /**
     * Removes the current session token from the database.
     *
     * @since 4.0.0
     */
    function wp_destroy_current_session()
    {
    }
    /**
     * Removes all but the current session token for the current user for the database.
     *
     * @since 4.0.0
     */
    function wp_destroy_other_sessions()
    {
    }
    /**
     * Removes all session tokens for the current user from the database.
     *
     * @since 4.0.0
     */
    function wp_destroy_all_sessions()
    {
    }
    /**
     * Gets the user IDs of all users with no role on this site.
     *
     * @since 4.4.0
     * @since 4.9.0 The `$site_id` parameter was added to support multisite.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     *
     * @param int|null $site_id Optional. The site ID to get users with no role for. Defaults to the current site.
     * @return string[] Array of user IDs as strings.
     */
    function wp_get_users_with_no_role($site_id = \null)
    {
    }
    /**
     * Retrieves the current user object.
     *
     * Will set the current user, if the current user is not set. The current user
     * will be set to the logged-in person. If no user is logged-in, then it will
     * set the current user to 0, which is invalid and won't have any permissions.
     *
     * This function is used by the pluggable functions wp_get_current_user() and
     * get_currentuserinfo(), the latter of which is deprecated but used for backward
     * compatibility.
     *
     * @since 4.5.0
     * @access private
     *
     * @see wp_get_current_user()
     * @global WP_User $current_user Checks if the current user is set.
     *
     * @return WP_User Current WP_User instance.
     */
    function _wp_get_current_user()
    {
    }
    /**
     * Sends a confirmation request email when a change of user email address is attempted.
     *
     * @since 3.0.0
     * @since 4.9.0 This function was moved from wp-admin/includes/ms.php so it's no longer Multisite specific.
     *
     * @global WP_Error $errors WP_Error object.
     */
    function send_confirmation_on_profile_email()
    {
    }
    /**
     * Adds an admin notice alerting the user to check for confirmation request email
     * after email address change.
     *
     * @since 3.0.0
     * @since 4.9.0 This function was moved from wp-admin/includes/ms.php so it's no longer Multisite specific.
     *
     * @global string $pagenow The filename of the current screen.
     */
    function new_user_email_admin_notice()
    {
    }
    /**
     * Gets all personal data request types.
     *
     * @since 4.9.6
     * @access private
     *
     * @return string[] List of core privacy action types.
     */
    function _wp_privacy_action_request_types()
    {
    }
    /**
     * Registers the personal data exporter for users.
     *
     * @since 4.9.6
     *
     * @param array[] $exporters An array of personal data exporters.
     * @return array[] An array of personal data exporters.
     */
    function wp_register_user_personal_data_exporter($exporters)
    {
    }
    /**
     * Finds and exports personal data associated with an email address from the user and user_meta table.
     *
     * @since 4.9.6
     * @since 5.4.0 Added 'Community Events Location' group to the export data.
     * @since 5.4.0 Added 'Session Tokens' group to the export data.
     *
     * @param string $email_address  The user's email address.
     * @return array {
     *     An array of personal data.
     *
     *     @type array[] $data An array of personal data arrays.
     *     @type bool    $done Whether the exporter is finished.
     * }
     * @phpstan-return array{
     *   data: array[],
     *   done: bool,
     * }
     */
    function wp_user_personal_data_exporter($email_address)
    {
    }
    /**
     * Updates log when privacy request is confirmed.
     *
     * @since 4.9.6
     * @access private
     *
     * @param int $request_id ID of the request.
     * @phpstan-return void
     */
    function _wp_privacy_account_request_confirmed($request_id)
    {
    }
    /**
     * Notifies the site administrator via email when a request is confirmed.
     *
     * Without this, the admin would have to manually check the site to see if any
     * action was needed on their part yet.
     *
     * @since 4.9.6
     *
     * @param int $request_id The ID of the request.
     * @phpstan-return void
     */
    function _wp_privacy_send_request_confirmation_notification($request_id)
    {
    }
    /**
     * Notifies the user when their erasure request is fulfilled.
     *
     * Without this, the user would never know if their data was actually erased.
     *
     * @since 4.9.6
     *
     * @param int $request_id The privacy request post ID associated with this request.
     * @phpstan-return void
     */
    function _wp_privacy_send_erasure_fulfillment_notification($request_id)
    {
    }
    /**
     * Returns request confirmation message HTML.
     *
     * @since 4.9.6
     * @access private
     *
     * @param int $request_id The request ID being confirmed.
     * @return string The confirmation message.
     */
    function _wp_privacy_account_request_confirmed_message($request_id)
    {
    }
    /**
     * Creates and logs a user request to perform a specific action.
     *
     * Requests are stored inside a post type named `user_request` since they can apply to both
     * users on the site, or guests without a user account.
     *
     * @since 4.9.6
     * @since 5.7.0 Added the `$status` parameter.
     *
     * @param string $email_address           User email address. This can be the address of a registered
     *                                        or non-registered user.
     * @param string $action_name             Name of the action that is being confirmed. Required.
     * @param array  $request_data            Misc data you want to send with the verification request and pass
     *                                        to the actions once the request is confirmed.
     * @param string $status                  Optional request status (pending or confirmed). Default 'pending'.
     * @return int|WP_Error                   Returns the request ID if successful, or a WP_Error object on failure.
     */
    function wp_create_user_request($email_address = '', $action_name = '', $request_data = array(), $status = 'pending')
    {
    }
    /**
     * Gets action description from the name and return a string.
     *
     * @since 4.9.6
     *
     * @param string $action_name Action name of the request.
     * @return string Human readable action name.
     */
    function wp_user_request_action_description($action_name)
    {
    }
    /**
     * Send a confirmation request email to confirm an action.
     *
     * If the request is not already pending, it will be updated.
     *
     * @since 4.9.6
     *
     * @param string $request_id ID of the request created via wp_create_user_request().
     * @return true|WP_Error True on success, `WP_Error` on failure.
     */
    function wp_send_user_request($request_id)
    {
    }
    /**
     * Returns a confirmation key for a user action and stores the hashed version for future comparison.
     *
     * @since 4.9.6
     *
     * @global PasswordHash $wp_hasher Portable PHP password hashing framework instance.
     *
     * @param int $request_id Request ID.
     * @return string Confirmation key.
     */
    function wp_generate_user_request_key($request_id)
    {
    }
    /**
     * Validates a user request by comparing the key with the request's key.
     *
     * @since 4.9.6
     *
     * @global PasswordHash $wp_hasher Portable PHP password hashing framework instance.
     *
     * @param string $request_id ID of the request being confirmed.
     * @param string $key        Provided key to validate.
     * @return true|WP_Error True on success, WP_Error on failure.
     */
    function wp_validate_user_request_key($request_id, $key)
    {
    }
    /**
     * Returns the user request object for the specified request ID.
     *
     * @since 4.9.6
     *
     * @param int $request_id The ID of the user request.
     * @return WP_User_Request|false
     */
    function wp_get_user_request($request_id)
    {
    }
    /**
     * Checks if Application Passwords is supported.
     *
     * Application Passwords is supported only by sites using SSL or local environments
     * but may be made available using the {@see 'wp_is_application_passwords_available'} filter.
     *
     * @since 5.9.0
     *
     * @return bool
     */
    function wp_is_application_passwords_supported()
    {
    }
    /**
     * Checks if Application Passwords is globally available.
     *
     * By default, Application Passwords is available to all sites using SSL or to local environments.
     * Use the {@see 'wp_is_application_passwords_available'} filter to adjust its availability.
     *
     * @since 5.6.0
     *
     * @return bool
     */
    function wp_is_application_passwords_available()
    {
    }
    /**
     * Checks if Application Passwords is available for a specific user.
     *
     * By default all users can use Application Passwords. Use {@see 'wp_is_application_passwords_available_for_user'}
     * to restrict availability to certain users.
     *
     * @since 5.6.0
     *
     * @param int|WP_User $user The user to check.
     * @return bool
     */
    function wp_is_application_passwords_available_for_user($user)
    {
    }
    /**
     * Registers the user meta property for persisted preferences.
     *
     * This property is used to store user preferences across page reloads and is
     * currently used by the block editor for preferences like 'fullscreenMode' and
     * 'fixedToolbar'.
     *
     * @since 6.1.0
     * @access private
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    function wp_register_persisted_preferences_meta()
    {
    }
    /**
     * Sets the last changed time for the 'users' cache group.
     *
     * @since 6.3.0
     */
    function wp_cache_set_users_last_changed()
    {
    }
    /**
     * Checks if password reset is allowed for a specific user.
     *
     * @since 6.3.0
     *
     * @param int|WP_User $user The user to check.
     * @return bool|WP_Error True if allowed, false or WP_Error otherwise.
     */
    function wp_is_password_reset_allowed_for_user($user)
    {
    }
    /**
     * Test if the current browser runs on a mobile device (smart phone, tablet, etc.).
     *
     * @since 3.4.0
     * @since 6.4.0 Added checking for the Sec-CH-UA-Mobile request header.
     *
     * @return bool
     */
    function wp_is_mobile()
    {
    }
    /**
     * Register a widget
     *
     * Registers a WP_Widget widget
     *
     * @since 2.8.0
     * @since 4.6.0 Updated the `$widget` parameter to also accept a WP_Widget instance object
     *              instead of simply a `WP_Widget` subclass name.
     *
     * @see WP_Widget
     *
     * @global WP_Widget_Factory $wp_widget_factory
     *
     * @param string|WP_Widget $widget Either the name of a `WP_Widget` subclass or an instance of a `WP_Widget` subclass.
     */
    function register_widget($widget)
    {
    }
    /**
     * Unregisters a widget.
     *
     * Unregisters a WP_Widget widget. Useful for un-registering default widgets.
     * Run within a function hooked to the {@see 'widgets_init'} action.
     *
     * @since 2.8.0
     * @since 4.6.0 Updated the `$widget` parameter to also accept a WP_Widget instance object
     *              instead of simply a `WP_Widget` subclass name.
     *
     * @see WP_Widget
     *
     * @global WP_Widget_Factory $wp_widget_factory
     *
     * @param string|WP_Widget $widget Either the name of a `WP_Widget` subclass or an instance of a `WP_Widget` subclass.
     */
    function unregister_widget($widget)
    {
    }
    /**
     * Creates multiple sidebars.
     *
     * If you wanted to quickly create multiple sidebars for a theme or internally.
     * This function will allow you to do so. If you don't pass the 'name' and/or
     * 'id' in `$args`, then they will be built for you.
     *
     * @since 2.2.0
     *
     * @see register_sidebar() The second parameter is documented by register_sidebar() and is the same here.
     *
     * @global array $wp_registered_sidebars The new sidebars are stored in this array by sidebar ID.
     *
     * @param int          $number Optional. Number of sidebars to create. Default 1.
     * @param array|string $args {
     *     Optional. Array or string of arguments for building a sidebar.
     *
     *     @type string $id   The base string of the unique identifier for each sidebar. If provided, and multiple
     *                        sidebars are being defined, the ID will have "-2" appended, and so on.
     *                        Default 'sidebar-' followed by the number the sidebar creation is currently at.
     *     @type string $name The name or title for the sidebars displayed in the admin dashboard. If registering
     *                        more than one sidebar, include '%d' in the string as a placeholder for the uniquely
     *                        assigned number for each sidebar.
     *                        Default 'Sidebar' for the first sidebar, otherwise 'Sidebar %d'.
     * }
     * @phpstan-param array{
     *   id?: string,
     *   name?: string,
     * } $args
     */
    function register_sidebars($number = 1, $args = array())
    {
    }
    /**
     * Builds the definition for a single sidebar and returns the ID.
     *
     * Accepts either a string or an array and then parses that against a set
     * of default arguments for the new sidebar. WordPress will automatically
     * generate a sidebar ID and name based on the current number of registered
     * sidebars if those arguments are not included.
     *
     * When allowing for automatic generation of the name and ID parameters, keep
     * in mind that the incrementor for your sidebar can change over time depending
     * on what other plugins and themes are installed.
     *
     * If theme support for 'widgets' has not yet been added when this function is
     * called, it will be automatically enabled through the use of add_theme_support()
     *
     * @since 2.2.0
     * @since 5.6.0 Added the `before_sidebar` and `after_sidebar` arguments.
     * @since 5.9.0 Added the `show_in_rest` argument.
     *
     * @global array $wp_registered_sidebars The registered sidebars.
     *
     * @param array|string $args {
     *     Optional. Array or string of arguments for the sidebar being registered.
     *
     *     @type string $name           The name or title of the sidebar displayed in the Widgets
     *                                  interface. Default 'Sidebar $instance'.
     *     @type string $id             The unique identifier by which the sidebar will be called.
     *                                  Default 'sidebar-$instance'.
     *     @type string $description    Description of the sidebar, displayed in the Widgets interface.
     *                                  Default empty string.
     *     @type string $class          Extra CSS class to assign to the sidebar in the Widgets interface.
     *                                  Default empty.
     *     @type string $before_widget  HTML content to prepend to each widget's HTML output when assigned
     *                                  to this sidebar. Receives the widget's ID attribute as `%1$s`
     *                                  and class name as `%2$s`. Default is an opening list item element.
     *     @type string $after_widget   HTML content to append to each widget's HTML output when assigned
     *                                  to this sidebar. Default is a closing list item element.
     *     @type string $before_title   HTML content to prepend to the sidebar title when displayed.
     *                                  Default is an opening h2 element.
     *     @type string $after_title    HTML content to append to the sidebar title when displayed.
     *                                  Default is a closing h2 element.
     *     @type string $before_sidebar HTML content to prepend to the sidebar when displayed.
     *                                  Receives the `$id` argument as `%1$s` and `$class` as `%2$s`.
     *                                  Outputs after the {@see 'dynamic_sidebar_before'} action.
     *                                  Default empty string.
     *     @type string $after_sidebar  HTML content to append to the sidebar when displayed.
     *                                  Outputs before the {@see 'dynamic_sidebar_after'} action.
     *                                  Default empty string.
     *     @type bool $show_in_rest     Whether to show this sidebar publicly in the REST API.
     *                                  Defaults to only showing the sidebar to administrator users.
     * }
     * @return string Sidebar ID added to $wp_registered_sidebars global.
     * @phpstan-param array{
     *   name?: string,
     *   id?: string,
     *   description?: string,
     *   class?: string,
     *   before_widget?: string,
     *   after_widget?: string,
     *   before_title?: string,
     *   after_title?: string,
     *   before_sidebar?: string,
     *   after_sidebar?: string,
     *   show_in_rest?: bool,
     * } $args
     */
    function register_sidebar($args = array())
    {
    }
    /**
     * Removes a sidebar from the list.
     *
     * @since 2.2.0
     *
     * @global array $wp_registered_sidebars The registered sidebars.
     *
     * @param string|int $sidebar_id The ID of the sidebar when it was registered.
     */
    function unregister_sidebar($sidebar_id)
    {
    }
    /**
     * Checks if a sidebar is registered.
     *
     * @since 4.4.0
     *
     * @global array $wp_registered_sidebars The registered sidebars.
     *
     * @param string|int $sidebar_id The ID of the sidebar when it was registered.
     * @return bool True if the sidebar is registered, false otherwise.
     */
    function is_registered_sidebar($sidebar_id)
    {
    }
    /**
     * Register an instance of a widget.
     *
     * The default widget option is 'classname' that can be overridden.
     *
     * The function can also be used to un-register widgets when `$output_callback`
     * parameter is an empty string.
     *
     * @since 2.2.0
     * @since 5.3.0 Formalized the existing and already documented `...$params` parameter
     *              by adding it to the function signature.
     * @since 5.8.0 Added show_instance_in_rest option.
     *
     * @global array $wp_registered_widgets            Uses stored registered widgets.
     * @global array $wp_registered_widget_controls    Stores the registered widget controls (options).
     * @global array $wp_registered_widget_updates     The registered widget updates.
     * @global array $_wp_deprecated_widgets_callbacks
     *
     * @param int|string $id              Widget ID.
     * @param string     $name            Widget display title.
     * @param callable   $output_callback Run when widget is called.
     * @param array      $options {
     *     Optional. An array of supplementary widget options for the instance.
     *
     *     @type string $classname             Class name for the widget's HTML container. Default is a shortened
     *                                         version of the output callback name.
     *     @type string $description           Widget description for display in the widget administration
     *                                         panel and/or theme.
     *     @type bool   $show_instance_in_rest Whether to show the widget's instance settings in the REST API.
     *                                         Only available for WP_Widget based widgets.
     * }
     * @param mixed      ...$params       Optional additional parameters to pass to the callback function when it's called.
     * @phpstan-param array{
     *   classname?: string,
     *   description?: string,
     *   show_instance_in_rest?: bool,
     * } $options
     * @phpstan-return void
     */
    function wp_register_sidebar_widget($id, $name, $output_callback, $options = array(), ...$params)
    {
    }
    /**
     * Retrieve description for widget.
     *
     * When registering widgets, the options can also include 'description' that
     * describes the widget for display on the widget administration panel or
     * in the theme.
     *
     * @since 2.5.0
     *
     * @global array $wp_registered_widgets The registered widgets.
     *
     * @param int|string $id Widget ID.
     * @return string|void Widget description, if available.
     */
    function wp_widget_description($id)
    {
    }
    /**
     * Retrieve description for a sidebar.
     *
     * When registering sidebars a 'description' parameter can be included that
     * describes the sidebar for display on the widget administration panel.
     *
     * @since 2.9.0
     *
     * @global array $wp_registered_sidebars The registered sidebars.
     *
     * @param string $id sidebar ID.
     * @return string|void Sidebar description, if available.
     */
    function wp_sidebar_description($id)
    {
    }
    /**
     * Remove widget from sidebar.
     *
     * @since 2.2.0
     *
     * @param int|string $id Widget ID.
     */
    function wp_unregister_sidebar_widget($id)
    {
    }
    /**
     * Registers widget control callback for customizing options.
     *
     * @since 2.2.0
     * @since 5.3.0 Formalized the existing and already documented `...$params` parameter
     *              by adding it to the function signature.
     *
     * @global array $wp_registered_widget_controls The registered widget controls.
     * @global array $wp_registered_widget_updates  The registered widget updates.
     * @global array $wp_registered_widgets         The registered widgets.
     * @global array $_wp_deprecated_widgets_callbacks
     *
     * @param int|string $id               Sidebar ID.
     * @param string     $name             Sidebar display name.
     * @param callable   $control_callback Run when sidebar is displayed.
     * @param array      $options {
     *     Optional. Array or string of control options. Default empty array.
     *
     *     @type int        $height  Never used. Default 200.
     *     @type int        $width   Width of the fully expanded control form (but try hard to use the default width).
     *                               Default 250.
     *     @type int|string $id_base Required for multi-widgets, i.e widgets that allow multiple instances such as the
     *                               text widget. The widget ID will end up looking like `{$id_base}-{$unique_number}`.
     * }
     * @param mixed      ...$params        Optional additional parameters to pass to the callback function when it's called.
     * @phpstan-param array{
     *   height?: int,
     *   width?: int,
     *   id_base?: int|string,
     * } $options
     * @phpstan-return void
     */
    function wp_register_widget_control($id, $name, $control_callback, $options = array(), ...$params)
    {
    }
    /**
     * Registers the update callback for a widget.
     *
     * @since 2.8.0
     * @since 5.3.0 Formalized the existing and already documented `...$params` parameter
     *              by adding it to the function signature.
     *
     * @global array $wp_registered_widget_updates The registered widget updates.
     *
     * @param string   $id_base         The base ID of a widget created by extending WP_Widget.
     * @param callable $update_callback Update callback method for the widget.
     * @param array    $options         Optional. Widget control options. See wp_register_widget_control().
     *                                  Default empty array.
     * @param mixed    ...$params       Optional additional parameters to pass to the callback function when it's called.
     * @phpstan-param array{
     *   height?: int,
     *   width?: int,
     *   id_base?: int|string,
     * } $options See wp_register_widget_control()
     * @phpstan-return void
     */
    function _register_widget_update_callback($id_base, $update_callback, $options = array(), ...$params)
    {
    }
    /**
     * Registers the form callback for a widget.
     *
     * @since 2.8.0
     * @since 5.3.0 Formalized the existing and already documented `...$params` parameter
     *              by adding it to the function signature.
     *
     * @global array $wp_registered_widget_controls The registered widget controls.
     *
     * @param int|string $id            Widget ID.
     * @param string     $name          Name attribute for the widget.
     * @param callable   $form_callback Form callback.
     * @param array      $options       Optional. Widget control options. See wp_register_widget_control().
     *                                  Default empty array.
     * @param mixed      ...$params     Optional additional parameters to pass to the callback function when it's called.
     * @phpstan-param array{
     *   height?: int,
     *   width?: int,
     *   id_base?: int|string,
     * } $options See wp_register_widget_control()
     * @phpstan-return void
     */
    function _register_widget_form_callback($id, $name, $form_callback, $options = array(), ...$params)
    {
    }
    /**
     * Remove control callback for widget.
     *
     * @since 2.2.0
     *
     * @param int|string $id Widget ID.
     */
    function wp_unregister_widget_control($id)
    {
    }
    /**
     * Display dynamic sidebar.
     *
     * By default this displays the default sidebar or 'sidebar-1'. If your theme specifies the 'id' or
     * 'name' parameter for its registered sidebars you can pass an ID or name as the $index parameter.
     * Otherwise, you can pass in a numerical index to display the sidebar at that index.
     *
     * @since 2.2.0
     *
     * @global array $wp_registered_sidebars The registered sidebars.
     * @global array $wp_registered_widgets  The registered widgets.
     *
     * @param int|string $index Optional. Index, name or ID of dynamic sidebar. Default 1.
     * @return bool True, if widget sidebar was found and called. False if not found or not called.
     */
    function dynamic_sidebar($index = 1)
    {
    }
    /**
     * Determines whether a given widget is displayed on the front end.
     *
     * Either $callback or $id_base can be used
     * $id_base is the first argument when extending WP_Widget class
     * Without the optional $widget_id parameter, returns the ID of the first sidebar
     * in which the first instance of the widget with the given callback or $id_base is found.
     * With the $widget_id parameter, returns the ID of the sidebar where
     * the widget with that callback/$id_base AND that ID is found.
     *
     * NOTE: $widget_id and $id_base are the same for single widgets. To be effective
     * this function has to run after widgets have initialized, at action {@see 'init'} or later.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.2.0
     *
     * @global array $wp_registered_widgets The registered widgets.
     *
     * @param callable|false $callback      Optional. Widget callback to check. Default false.
     * @param string|false   $widget_id     Optional. Widget ID. Optional, but needed for checking.
     *                                      Default false.
     * @param string|false   $id_base       Optional. The base ID of a widget created by extending WP_Widget.
     *                                      Default false.
     * @param bool           $skip_inactive Optional. Whether to check in 'wp_inactive_widgets'.
     *                                      Default true.
     * @return string|false ID of the sidebar in which the widget is active,
     *                      false if the widget is not active.
     */
    function is_active_widget($callback = \false, $widget_id = \false, $id_base = \false, $skip_inactive = \true)
    {
    }
    /**
     * Determines whether the dynamic sidebar is enabled and used by the theme.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.2.0
     *
     * @global array $wp_registered_widgets  The registered widgets.
     * @global array $wp_registered_sidebars The registered sidebars.
     *
     * @return bool True if using widgets, false otherwise.
     */
    function is_dynamic_sidebar()
    {
    }
    /**
     * Determines whether a sidebar contains widgets.
     *
     * For more information on this and similar theme functions, check out
     * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
     * Conditional Tags} article in the Theme Developer Handbook.
     *
     * @since 2.8.0
     *
     * @param string|int $index Sidebar name, id or number to check.
     * @return bool True if the sidebar has widgets, false otherwise.
     */
    function is_active_sidebar($index)
    {
    }
    /**
     * Retrieve full list of sidebars and their widget instance IDs.
     *
     * Will upgrade sidebar widget list, if needed. Will also save updated list, if
     * needed.
     *
     * @since 2.2.0
     * @access private
     *
     * @global array $_wp_sidebars_widgets
     * @global array $sidebars_widgets
     *
     * @param bool $deprecated Not used (argument deprecated).
     * @return array Upgraded list of widgets to version 3 array format when called from the admin.
     */
    function wp_get_sidebars_widgets($deprecated = \true)
    {
    }
    /**
     * Retrieves the registered sidebar with the given ID.
     *
     * @since 5.9.0
     *
     * @global array $wp_registered_sidebars The registered sidebars.
     *
     * @param string $id The sidebar ID.
     * @return array|null The discovered sidebar, or null if it is not registered.
     */
    function wp_get_sidebar($id)
    {
    }
    /**
     * Set the sidebar widget option to update sidebars.
     *
     * @since 2.2.0
     * @access private
     *
     * @global array $_wp_sidebars_widgets
     * @param array $sidebars_widgets Sidebar widgets and their settings.
     */
    function wp_set_sidebars_widgets($sidebars_widgets)
    {
    }
    /**
     * Retrieve default registered sidebars list.
     *
     * @since 2.2.0
     * @access private
     *
     * @global array $wp_registered_sidebars The registered sidebars.
     *
     * @return array
     */
    function wp_get_widget_defaults()
    {
    }
    /**
     * Converts the widget settings from single to multi-widget format.
     *
     * @since 2.8.0
     *
     * @global array $_wp_sidebars_widgets
     *
     * @param string $base_name   Root ID for all widgets of this type.
     * @param string $option_name Option name for this widget type.
     * @param array  $settings    The array of widget instance settings.
     * @return array The array of widget settings converted to multi-widget format.
     */
    function wp_convert_widget_settings($base_name, $option_name, $settings)
    {
    }
    /**
     * Output an arbitrary widget as a template tag.
     *
     * @since 2.8.0
     *
     * @global WP_Widget_Factory $wp_widget_factory
     *
     * @param string $widget   The widget's PHP class name (see class-wp-widget.php).
     * @param array  $instance Optional. The widget's instance settings. Default empty array.
     * @param array  $args {
     *     Optional. Array of arguments to configure the display of the widget.
     *
     *     @type string $before_widget HTML content that will be prepended to the widget's HTML output.
     *                                 Default `<div class="widget %s">`, where `%s` is the widget's class name.
     *     @type string $after_widget  HTML content that will be appended to the widget's HTML output.
     *                                 Default `</div>`.
     *     @type string $before_title  HTML content that will be prepended to the widget's title when displayed.
     *                                 Default `<h2 class="widgettitle">`.
     *     @type string $after_title   HTML content that will be appended to the widget's title when displayed.
     *                                 Default `</h2>`.
     * }
     * @phpstan-param array{
     *   before_widget?: string,
     *   after_widget?: string,
     *   before_title?: string,
     *   after_title?: string,
     * } $args
     * @phpstan-return void
     */
    function the_widget($widget, $instance = array(), $args = array())
    {
    }
    /**
     * Retrieves the widget ID base value.
     *
     * @since 2.8.0
     *
     * @param string $id Widget ID.
     * @return string Widget ID base.
     */
    function _get_widget_id_base($id)
    {
    }
    /**
     * Handle sidebars config after theme change
     *
     * @access private
     * @since 3.3.0
     *
     * @global array $sidebars_widgets
     */
    function _wp_sidebars_changed()
    {
    }
    /**
     * Validates and remaps any "orphaned" widgets to wp_inactive_widgets sidebar,
     * and saves the widget settings. This has to run at least on each theme change.
     *
     * For example, let's say theme A has a "footer" sidebar, and theme B doesn't have one.
     * After switching from theme A to theme B, all the widgets previously assigned
     * to the footer would be inaccessible. This function detects this scenario, and
     * moves all the widgets previously assigned to the footer under wp_inactive_widgets.
     *
     * Despite the word "retrieve" in the name, this function actually updates the database
     * and the global `$sidebars_widgets`. For that reason it should not be run on front end,
     * unless the `$theme_changed` value is 'customize' (to bypass the database write).
     *
     * @since 2.8.0
     *
     * @global array $wp_registered_sidebars The registered sidebars.
     * @global array $sidebars_widgets
     * @global array $wp_registered_widgets  The registered widgets.
     *
     * @param string|bool $theme_changed Whether the theme was changed as a boolean. A value
     *                                   of 'customize' defers updates for the Customizer.
     * @return array Updated sidebars widgets.
     */
    function retrieve_widgets($theme_changed = \false)
    {
    }
    /**
     * Compares a list of sidebars with their widgets against an allowed list.
     *
     * @since 4.9.0
     * @since 4.9.2 Always tries to restore widget assignments from previous data, not just if sidebars needed mapping.
     *
     * @global array $wp_registered_sidebars The registered sidebars.
     *
     * @param array $existing_sidebars_widgets List of sidebars and their widget instance IDs.
     * @return array Mapped sidebars widgets.
     */
    function wp_map_sidebars_widgets($existing_sidebars_widgets)
    {
    }
    /**
     * Compares a list of sidebars with their widgets against an allowed list.
     *
     * @since 4.9.0
     *
     * @global array $wp_registered_widgets The registered widgets.
     *
     * @param array $sidebars_widgets   List of sidebars and their widget instance IDs.
     * @param array $allowed_widget_ids Optional. List of widget IDs to compare against. Default: Registered widgets.
     * @return array Sidebars with allowed widgets.
     */
    function _wp_remove_unregistered_widgets($sidebars_widgets, $allowed_widget_ids = array())
    {
    }
    /**
     * Display the RSS entries in a list.
     *
     * @since 2.5.0
     *
     * @param string|array|object $rss  RSS url.
     * @param array               $args Widget arguments.
     * @phpstan-return void
     */
    function wp_widget_rss_output($rss, $args = array())
    {
    }
    /**
     * Display RSS widget options form.
     *
     * The options for what fields are displayed for the RSS form are all booleans
     * and are as follows: 'url', 'title', 'items', 'show_summary', 'show_author',
     * 'show_date'.
     *
     * @since 2.5.0
     *
     * @param array|string $args   Values for input fields.
     * @param array        $inputs Override default display options.
     * @phpstan-param array{number: int, error: bool, title?: string, url?: string, items?: int, show_summary?: int, show_author?: int, show_date?: int} $args
     * @phpstan-param array{title?: bool, url?: bool, items?: bool, show_summary?: bool, show_author?: bool, show_date?: bool} $inputs
     * @phpstan-return void
     */
    function wp_widget_rss_form($args, $inputs = \null)
    {
    }
    /**
     * Process RSS feed widget data and optionally retrieve feed items.
     *
     * The feed widget can not have more than 20 items or it will reset back to the
     * default, which is 10.
     *
     * The resulting array has the feed title, feed url, feed link (from channel),
     * feed items, error (if any), and whether to show summary, author, and date.
     * All respectively in the order of the array elements.
     *
     * @since 2.5.0
     *
     * @param array $widget_rss RSS widget feed data. Expects unescaped data.
     * @param bool  $check_feed Optional. Whether to check feed for errors. Default true.
     * @return array
     */
    function wp_widget_rss_process($widget_rss, $check_feed = \true)
    {
    }
    /**
     * Registers all of the default WordPress widgets on startup.
     *
     * Calls {@see 'widgets_init'} action after all of the WordPress widgets have been registered.
     *
     * @since 2.2.0
     * @phpstan-return void
     */
    function wp_widgets_init()
    {
    }
    /**
     * Enables the widgets block editor. This is hooked into 'after_setup_theme' so
     * that the block editor is enabled by default but can be disabled by themes.
     *
     * @since 5.8.0
     *
     * @access private
     */
    function wp_setup_widgets_block_editor()
    {
    }
    /**
     * Whether or not to use the block editor to manage widgets. Defaults to true
     * unless a theme has removed support for widgets-block-editor or a plugin has
     * filtered the return value of this function.
     *
     * @since 5.8.0
     *
     * @return bool Whether to use the block editor to manage widgets.
     */
    function wp_use_widgets_block_editor()
    {
    }
    /**
     * Converts a widget ID into its id_base and number components.
     *
     * @since 5.8.0
     *
     * @param string $id Widget ID.
     * @return array Array containing a widget's id_base and number components.
     */
    function wp_parse_widget_id($id)
    {
    }
    /**
     * Finds the sidebar that a given widget belongs to.
     *
     * @since 5.8.0
     *
     * @param string $widget_id The widget ID to look for.
     * @return string|null The found sidebar's ID, or null if it was not found.
     */
    function wp_find_widgets_sidebar($widget_id)
    {
    }
    /**
     * Assigns a widget to the given sidebar.
     *
     * @since 5.8.0
     *
     * @param string $widget_id  The widget ID to assign.
     * @param string $sidebar_id The sidebar ID to assign to. If empty, the widget won't be added to any sidebar.
     */
    function wp_assign_widget_to_sidebar($widget_id, $sidebar_id)
    {
    }
    /**
     * Calls the render callback of a widget and returns the output.
     *
     * @since 5.8.0
     *
     * @global array $wp_registered_widgets  The registered widgets.
     * @global array $wp_registered_sidebars The registered sidebars.
     *
     * @param string $widget_id Widget ID.
     * @param string $sidebar_id Sidebar ID.
     * @return string
     */
    function wp_render_widget($widget_id, $sidebar_id)
    {
    }
    /**
     * Calls the control callback of a widget and returns the output.
     *
     * @since 5.8.0
     *
     * @global array $wp_registered_widget_controls The registered widget controls.
     *
     * @param string $id Widget ID.
     * @return string|null
     */
    function wp_render_widget_control($id)
    {
    }
    /**
     * Displays a _doing_it_wrong() message for conflicting widget editor scripts.
     *
     * The 'wp-editor' script module is exposed as window.wp.editor. This overrides
     * the legacy TinyMCE editor module which is required by the widgets editor.
     * Because of that conflict, these two shouldn't be enqueued together.
     * See https://core.trac.wordpress.org/ticket/53569.
     *
     * There is also another conflict related to styles where the block widgets
     * editor is hidden if a block enqueues 'wp-edit-post' stylesheet.
     * See https://core.trac.wordpress.org/ticket/53569.
     *
     * @since 5.8.0
     * @access private
     *
     * @global WP_Scripts $wp_scripts
     * @global WP_Styles  $wp_styles
     */
    function wp_check_widget_editor_deps()
    {
    }
    /**
     * Registers the previous theme's sidebars for the block themes.
     *
     * @since 6.2.0
     * @access private
     *
     * @global array $wp_registered_sidebars The registered sidebars.
     * @phpstan-return void
     */
    function _wp_block_theme_register_classic_sidebars()
    {
    }
    /**
     * Outputs the login page header.
     *
     * @since 2.1.0
     *
     * @global string      $error         Login error message set by deprecated pluggable wp_login() function
     *                                    or plugins replacing it.
     * @global bool|string $interim_login Whether interim login modal is being displayed. String 'success'
     *                                    upon successful login.
     * @global string      $action        The action that brought the visitor to the login page.
     *
     * @param string|null   $title    Optional. WordPress login page title to display in the `<title>` element.
     *                                Defaults to 'Log In'.
     * @param string        $message  Optional. Message to display in header. Default empty.
     * @param WP_Error|null $wp_error Optional. The error to pass. Defaults to a WP_Error instance.
     */
    function login_header($title = \null, $message = '', $wp_error = \null)
    {
    }
    /**
     * Outputs the footer for the login page.
     *
     * @since 3.1.0
     *
     * @global bool|string $interim_login Whether interim login modal is being displayed. String 'success'
     *                                    upon successful login.
     *
     * @param string $input_id Which input to auto-focus.
     */
    function login_footer($input_id = '')
    {
    }
    /**
     * Outputs the JavaScript to handle the form shaking on the login page.
     *
     * @since 3.0.0
     */
    function wp_shake_js()
    {
    }
    /**
     * Outputs the viewport meta tag for the login page.
     *
     * @since 3.7.0
     */
    function wp_login_viewport_meta()
    {
    }
    /**
     * Prints signup_header via wp_head.
     *
     * @since MU (3.0.0)
     */
    function do_signup_header()
    {
    }
    /**
     * Prints styles for front-end Multisite Sign-up pages.
     *
     * @since MU (3.0.0)
     */
    function wpmu_signup_stylesheet()
    {
    }
    /**
     * Generates and displays the Sign-up and Create Site forms.
     *
     * @since MU (3.0.0)
     *
     * @param string          $blogname   The new site name.
     * @param string          $blog_title The new site title.
     * @param WP_Error|string $errors     A WP_Error object containing existing errors. Defaults to empty string.
     */
    function show_blog_form($blogname = '', $blog_title = '', $errors = '')
    {
    }
    /**
     * Validates the new site sign-up.
     *
     * @since MU (3.0.0)
     *
     * @return array Contains the new site data and error messages.
     *               See wpmu_validate_blog_signup() for details.
     */
    function validate_blog_form()
    {
    }
    /**
     * Displays the fields for the new user account registration form.
     *
     * @since MU (3.0.0)
     *
     * @param string          $user_name  The entered username.
     * @param string          $user_email The entered email address.
     * @param WP_Error|string $errors     A WP_Error object containing existing errors. Defaults to empty string.
     */
    function show_user_form($user_name = '', $user_email = '', $errors = '')
    {
    }
    /**
     * Validates user sign-up name and email.
     *
     * @since MU (3.0.0)
     *
     * @return array Contains username, email, and error messages.
     *               See wpmu_validate_user_signup() for details.
     */
    function validate_user_form()
    {
    }
    /**
     * Shows a form for returning users to sign up for another site.
     *
     * @since MU (3.0.0)
     *
     * @param string          $blogname   The new site name
     * @param string          $blog_title The new site title.
     * @param WP_Error|string $errors     A WP_Error object containing existing errors. Defaults to empty string.
     */
    function signup_another_blog($blogname = '', $blog_title = '', $errors = '')
    {
    }
    /**
     * Validates a new site sign-up for an existing user.
     *
     * @since MU (3.0.0)
     *
     * @global string   $blogname   The new site's subdomain or directory name.
     * @global string   $blog_title The new site's title.
     * @global WP_Error $errors     Existing errors in the global scope.
     * @global string   $domain     The new site's domain.
     * @global string   $path       The new site's path.
     *
     * @return null|bool True if site signup was validated, false on error.
     *                   The function halts all execution if the user is not logged in.
     */
    function validate_another_blog_signup()
    {
    }
    /**
     * Shows a message confirming that the new site has been created.
     *
     * @since MU (3.0.0)
     * @since 4.4.0 Added the `$blog_id` parameter.
     *
     * @param string $domain     The domain URL.
     * @param string $path       The site root path.
     * @param string $blog_title The site title.
     * @param string $user_name  The username.
     * @param string $user_email The user's email address.
     * @param array  $meta       Any additional meta from the {@see 'add_signup_meta'} filter in validate_blog_signup().
     * @param int    $blog_id    The site ID.
     */
    function confirm_another_blog_signup($domain, $path, $blog_title, $user_name, $user_email = '', $meta = array(), $blog_id = 0)
    {
    }
    /**
     * Shows a form for a visitor to sign up for a new user account.
     *
     * @since MU (3.0.0)
     *
     * @global string $active_signup String that returns registration type. The value can be
     *                               'all', 'none', 'blog', or 'user'.
     *
     * @param string          $user_name  The username.
     * @param string          $user_email The user's email.
     * @param WP_Error|string $errors     A WP_Error object containing existing errors. Defaults to empty string.
     */
    function signup_user($user_name = '', $user_email = '', $errors = '')
    {
    }
    /**
     * Validates the new user sign-up.
     *
     * @since MU (3.0.0)
     *
     * @return bool True if new user sign-up was validated, false on error.
     */
    function validate_user_signup()
    {
    }
    /**
     * Shows a message confirming that the new user has been registered and is awaiting activation.
     *
     * @since MU (3.0.0)
     *
     * @param string $user_name  The username.
     * @param string $user_email The user's email address.
     */
    function confirm_user_signup($user_name, $user_email)
    {
    }
    /**
     * Shows a form for a user or visitor to sign up for a new site.
     *
     * @since MU (3.0.0)
     *
     * @param string          $user_name  The username.
     * @param string          $user_email The user's email address.
     * @param string          $blogname   The site name.
     * @param string          $blog_title The site title.
     * @param WP_Error|string $errors     A WP_Error object containing existing errors. Defaults to empty string.
     */
    function signup_blog($user_name = '', $user_email = '', $blogname = '', $blog_title = '', $errors = '')
    {
    }
    /**
     * Validates new site signup.
     *
     * @since MU (3.0.0)
     *
     * @return bool True if the site sign-up was validated, false on error.
     */
    function validate_blog_signup()
    {
    }
    /**
     * Shows a message confirming that the new site has been registered and is awaiting activation.
     *
     * @since MU (3.0.0)
     *
     * @param string $domain     The domain or subdomain of the site.
     * @param string $path       The path of the site.
     * @param string $blog_title The title of the new site.
     * @param string $user_name  The user's username.
     * @param string $user_email The user's email address.
     * @param array  $meta       Any additional meta from the {@see 'add_signup_meta'} filter in validate_blog_signup().
     */
    function confirm_blog_signup($domain, $path, $blog_title, $user_name = '', $user_email = '', $meta = array())
    {
    }
    /**
     * Retrieves languages available during the site/user sign-up process.
     *
     * @since 4.4.0
     *
     * @see get_available_languages()
     *
     * @return string[] Array of available language codes. Language codes are formed by
     *                  stripping the .mo extension from the language file names.
     */
    function signup_get_available_languages()
    {
    }
    /**
     * Response to a trackback.
     *
     * Responds with an error or success XML message.
     *
     * @since 0.71
     *
     * @param int|bool $error         Whether there was an error.
     *                                Default '0'. Accepts '0' or '1', true or false.
     * @param string   $error_message Error message if an error occurred. Default empty string.
     */
    function trackback_response($error = 0, $error_message = '')
    {
    }
    /**
     * logIO() - Writes logging info to a file.
     *
     * @since 1.2.0
     * @deprecated 3.4.0 Use error_log()
     * @see error_log()
     *
     * @global int|bool $xmlrpc_logging Whether to enable XML-RPC logging.
     *
     * @param string $io  Whether input or output.
     * @param string $msg Information describing logging reason.
     */
    function logIO($io, $msg)
    {
    }
}
namespace {
/**
 * WordPress database abstraction object.
 * @var wpdb
 */
$wpdb = \null;
}
